/* Build.c generated by valac 0.56.19, the Vala compiler
 * generated from Build.vala, do not modify */

#include <stdlib.h>
#include <string.h>
#include <glib.h>

#define BUILD_NAME "Tuba"
#define BUILD_VERSION "0.11.1"
#define BUILD_DOMAIN "dev.geopjr.Tuba"
#define BUILD_RESOURCES "/dev/geopjr/Tuba/"
#define BUILD_PROFILE "production"
#define BUILD_GETTEXT_PACKAGE "dev.geopjr.Tuba"
#define BUILD_LOCALEDIR "/usr/share/locale"
#define BUILD_WEBSITE "https://codeberg.org/GeopJr/Tuba"
#define BUILD_DONATE_WEBSITE "https://geopjr.dev/donate"
#define BUILD_TRANSLATE_WEBSITE "https://translate.codeberg.org/engage/tuba/"
#define BUILD_WIKI_WEBSITE "https://codeberg.org/GeopJr/Tuba/wiki"
#define BUILD_PREFIX "/usr"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif

