/* GroupedNotification.c generated by valac 0.56.19, the Vala compiler
 * generated from GroupedNotification.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <adwaita.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>

#define TUBA_INSTANCE_ACCOUNT_KIND_FAVOURITE "favourite"
#define TUBA_INSTANCE_ACCOUNT_KIND_REBLOG "reblog"
#define TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP "admin.sign_up"
#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW "follow"
#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST "follow_request"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_STATUS (tuba_widgets_status_get_type ())
#define TUBA_WIDGETS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatus))
#define TUBA_WIDGETS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))
#define TUBA_WIDGETS_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))

typedef struct _TubaWidgetsStatus TubaWidgetsStatus;
typedef struct _TubaWidgetsStatusClass TubaWidgetsStatusClass;
typedef struct _TubaWidgetsStatusPrivate TubaWidgetsStatusPrivate;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;
typedef void (*TubaDialogsComposerDialogSuccessCallback) (TubaAPIStatus* cb_status, gpointer user_data);

#define TUBA_WIDGETS_TYPE_RICH_LABEL (tuba_widgets_rich_label_get_type ())
#define TUBA_WIDGETS_RICH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabel))
#define TUBA_WIDGETS_RICH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabelClass))
#define TUBA_WIDGETS_IS_RICH_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL))
#define TUBA_WIDGETS_IS_RICH_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_RICH_LABEL))
#define TUBA_WIDGETS_RICH_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_RICH_LABEL, TubaWidgetsRichLabelClass))

typedef struct _TubaWidgetsRichLabel TubaWidgetsRichLabel;
typedef struct _TubaWidgetsRichLabelClass TubaWidgetsRichLabelClass;

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;

#define TUBA_WIDGETS_TYPE_MARKUP_VIEW (tuba_widgets_markup_view_get_type ())
#define TUBA_WIDGETS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupView))
#define TUBA_WIDGETS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))
#define TUBA_WIDGETS_IS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_IS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_MARKUP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))

typedef struct _TubaWidgetsMarkupView TubaWidgetsMarkupView;
typedef struct _TubaWidgetsMarkupViewClass TubaWidgetsMarkupViewClass;

#define TUBA_WIDGETS_TYPE_FADE_BIN (tuba_widgets_fade_bin_get_type ())
#define TUBA_WIDGETS_FADE_BIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBin))
#define TUBA_WIDGETS_FADE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBinClass))
#define TUBA_WIDGETS_IS_FADE_BIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_FADE_BIN))
#define TUBA_WIDGETS_IS_FADE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_FADE_BIN))
#define TUBA_WIDGETS_FADE_BIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_FADE_BIN, TubaWidgetsFadeBinClass))

typedef struct _TubaWidgetsFadeBin TubaWidgetsFadeBin;
typedef struct _TubaWidgetsFadeBinClass TubaWidgetsFadeBinClass;

#define TUBA_WIDGETS_TYPE_PREVIEW_CARD (tuba_widgets_preview_card_get_type ())
#define TUBA_WIDGETS_PREVIEW_CARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCard))
#define TUBA_WIDGETS_PREVIEW_CARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCardClass))
#define TUBA_WIDGETS_IS_PREVIEW_CARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD))
#define TUBA_WIDGETS_IS_PREVIEW_CARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD))
#define TUBA_WIDGETS_PREVIEW_CARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD, TubaWidgetsPreviewCardClass))

typedef struct _TubaWidgetsPreviewCard TubaWidgetsPreviewCard;
typedef struct _TubaWidgetsPreviewCardClass TubaWidgetsPreviewCardClass;

#define TUBA_WIDGETS_TYPE_VOTE_BOX (tuba_widgets_vote_box_get_type ())
#define TUBA_WIDGETS_VOTE_BOX(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBox))
#define TUBA_WIDGETS_VOTE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBoxClass))
#define TUBA_WIDGETS_IS_VOTE_BOX(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX))
#define TUBA_WIDGETS_IS_VOTE_BOX_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_VOTE_BOX))
#define TUBA_WIDGETS_VOTE_BOX_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_VOTE_BOX, TubaWidgetsVoteBoxClass))

typedef struct _TubaWidgetsVoteBox TubaWidgetsVoteBox;
typedef struct _TubaWidgetsVoteBoxClass TubaWidgetsVoteBoxClass;

#define TUBA_WIDGETS_TYPE_NOTIFICATION (tuba_widgets_notification_get_type ())
#define TUBA_WIDGETS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotification))
#define TUBA_WIDGETS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))
#define TUBA_WIDGETS_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))

typedef struct _TubaWidgetsNotification TubaWidgetsNotification;
typedef struct _TubaWidgetsNotificationClass TubaWidgetsNotificationClass;
typedef struct _TubaWidgetsNotificationPrivate TubaWidgetsNotificationPrivate;

#define TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION (tuba_widgets_grouped_notification_get_type ())
#define TUBA_WIDGETS_GROUPED_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotification))
#define TUBA_WIDGETS_GROUPED_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotificationClass))
#define TUBA_WIDGETS_IS_GROUPED_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION))
#define TUBA_WIDGETS_IS_GROUPED_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION))
#define TUBA_WIDGETS_GROUPED_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotificationClass))

typedef struct _TubaWidgetsGroupedNotification TubaWidgetsGroupedNotification;
typedef struct _TubaWidgetsGroupedNotificationClass TubaWidgetsGroupedNotificationClass;
typedef struct _TubaWidgetsGroupedNotificationPrivate TubaWidgetsGroupedNotificationPrivate;
enum  {
	TUBA_WIDGETS_GROUPED_NOTIFICATION_0_PROPERTY,
	TUBA_WIDGETS_GROUPED_NOTIFICATION_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_grouped_notification_properties[TUBA_WIDGETS_GROUPED_NOTIFICATION_NUM_PROPERTIES];

#define TUBA_API_TYPE_NOTIFICATION (tuba_api_notification_get_type ())
#define TUBA_API_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotification))
#define TUBA_API_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))
#define TUBA_API_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))

typedef struct _TubaAPINotification TubaAPINotification;
typedef struct _TubaAPINotificationClass TubaAPINotificationClass;

#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP (tuba_api_grouped_notifications_results_notification_group_get_type ())
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroup))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroupClass))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_IS_NOTIFICATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_IS_NOTIFICATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroupClass))

typedef struct _TubaAPIGroupedNotificationsResultsNotificationGroup TubaAPIGroupedNotificationsResultsNotificationGroup;
typedef struct _TubaAPIGroupedNotificationsResultsNotificationGroupClass TubaAPIGroupedNotificationsResultsNotificationGroupClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_INSTANCE_ACCOUNT_TYPE_KIND (tuba_instance_account_kind_get_type ())
typedef struct _TubaInstanceAccountKind TubaInstanceAccountKind;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_TYPE_EMOJI (tuba_api_emoji_get_type ())
#define TUBA_API_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmoji))
#define TUBA_API_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))
#define TUBA_API_IS_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_EMOJI))
#define TUBA_API_IS_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_EMOJI))
#define TUBA_API_EMOJI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))

typedef struct _TubaAPIEmoji TubaAPIEmoji;
typedef struct _TubaAPIEmojiClass TubaAPIEmojiClass;
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS (tuba_widgets_label_with_widgets_get_type ())
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgets))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))

typedef struct _TubaWidgetsLabelWithWidgets TubaWidgetsLabelWithWidgets;
typedef struct _TubaWidgetsLabelWithWidgetsClass TubaWidgetsLabelWithWidgetsClass;

#define TUBA_WIDGETS_TYPE_EMOJI_LABEL (tuba_widgets_emoji_label_get_type ())
#define TUBA_WIDGETS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabel))
#define TUBA_WIDGETS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))
#define TUBA_WIDGETS_IS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_IS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_EMOJI_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))

typedef struct _TubaWidgetsEmojiLabel TubaWidgetsEmojiLabel;
typedef struct _TubaWidgetsEmojiLabelClass TubaWidgetsEmojiLabelClass;

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

struct _TubaWidgetsStatus {
	GtkListBoxRow parent_instance;
	TubaWidgetsStatusPrivate * priv;
	TubaDialogsComposerDialogSuccessCallback reply_cb;
	gpointer reply_cb_target;
	GDestroyNotify reply_cb_target_destroy_notify;
	GtkBox* status_box;
	GtkBox* avatar_side;
	GtkBox* title_box;
	GtkBox* content_side;
	AdwWrapBox* name_wrapbox;
	GtkMenuButton* menu_button;
	GtkImage* header_icon;
	TubaWidgetsRichLabel* header_label;
	GtkButton* header_button;
	TubaWidgetsAvatar* avatar;
	GtkOverlay* avatar_overlay;
	GtkButton* name_button;
	TubaWidgetsRichLabel* name_label;
	GtkLabel* handle_label;
	GtkBox* indicators;
	GtkLabel* date_label;
	GtkImage* pin_indicator;
	GtkImage* edited_indicator;
	GtkImage* visibility_indicator;
	GtkBox* content_column;
	GtkStack* spoiler_stack;
	GtkBox* content_box;
	TubaWidgetsMarkupView* content;
	GtkButton* spoiler_button;
	GtkLabel* spoiler_label;
	GtkLabel* spoiler_label_rev;
	GtkBox* spoiler_status_con;
	TubaWidgetsFadeBin* fade_bin;
	GtkStack* filter_stack;
	GtkLabel* filter_label;
	GtkLabel* filter_author_label;
	TubaWidgetsPreviewCard* prev_card;
	TubaWidgetsVoteBox* poll;
};

struct _TubaWidgetsStatusClass {
	GtkListBoxRowClass parent_class;
	void (*on_open) (TubaWidgetsStatus* self);
	void (*change_kind) (TubaWidgetsStatus* self);
	void (*bind) (TubaWidgetsStatus* self);
};

struct _TubaWidgetsNotification {
	TubaWidgetsStatus parent_instance;
	TubaWidgetsNotificationPrivate * priv;
};

struct _TubaWidgetsNotificationClass {
	TubaWidgetsStatusClass parent_class;
};

struct _TubaWidgetsGroupedNotification {
	TubaWidgetsNotification parent_instance;
	TubaWidgetsGroupedNotificationPrivate * priv;
};

struct _TubaWidgetsGroupedNotificationClass {
	TubaWidgetsNotificationClass parent_class;
};

struct _TubaInstanceAccountKind {
	gchar* icon;
	gchar* description;
	gchar* url;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

static gpointer tuba_widgets_grouped_notification_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_widgets_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatus, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN GType tuba_widgets_rich_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsRichLabel, g_object_unref)
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN GType tuba_widgets_markup_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsMarkupView, g_object_unref)
VALA_EXTERN GType tuba_widgets_fade_bin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsFadeBin, g_object_unref)
VALA_EXTERN GType tuba_widgets_preview_card_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsPreviewCard, g_object_unref)
VALA_EXTERN GType tuba_widgets_vote_box_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsVoteBox, g_object_unref)
VALA_EXTERN GType tuba_widgets_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotification, g_object_unref)
VALA_EXTERN GType tuba_widgets_grouped_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsGroupedNotification, g_object_unref)
VALA_EXTERN GType tuba_api_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotification, g_object_unref)
VALA_EXTERN GType tuba_api_grouped_notifications_results_notification_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIGroupedNotificationsResultsNotificationGroup, g_object_unref)
VALA_EXTERN TubaWidgetsGroupedNotification* tuba_widgets_grouped_notification_new (TubaAPIGroupedNotificationsResultsNotificationGroup* obj);
VALA_EXTERN TubaWidgetsGroupedNotification* tuba_widgets_grouped_notification_construct (GType object_type,
                                                                             TubaAPIGroupedNotificationsResultsNotificationGroup* obj);
VALA_EXTERN const gchar* tuba_api_notification_get_kind (TubaAPINotification* self);
VALA_EXTERN TubaWidgetsNotification* tuba_widgets_notification_new (TubaAPINotification* obj,
                                                        gboolean with_kind);
VALA_EXTERN TubaWidgetsNotification* tuba_widgets_notification_construct (GType object_type,
                                                              TubaAPINotification* obj,
                                                              gboolean with_kind);
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (TubaAPIGroupedNotificationsResultsNotificationGroup* self);
VALA_EXTERN GType tuba_instance_account_kind_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaInstanceAccountKind* tuba_instance_account_kind_dup (const TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_free (TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_copy (const TubaInstanceAccountKind* self,
                                      TubaInstanceAccountKind* dest);
VALA_EXTERN void tuba_instance_account_kind_destroy (TubaInstanceAccountKind* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaInstanceAccountKind, tuba_instance_account_kind_destroy)
VALA_EXTERN GtkBox* tuba_widgets_grouped_notification_group_box (TubaAPIGroupedNotificationsResultsNotificationGroup* obj,
                                                     const gchar* old_kind,
                                                     TubaInstanceAccountKind* res_kind);
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN GeeHashMap* tuba_api_account_get_emojis_map (TubaAPIAccount* self);
VALA_EXTERN GType tuba_api_emoji_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIEmoji, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_account_get_emojis (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_emoji_get_shortcode (TubaAPIEmoji* self);
VALA_EXTERN const gchar* tuba_api_emoji_get_url (TubaAPIEmoji* self);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN void tuba_instance_account_describe_kind (TubaInstanceAccount* self,
                                          const gchar* kind,
                                          TubaInstanceAccountKind* _result_,
                                          const gchar* actor_name,
                                          const gchar* callback_url,
                                          const gchar* other_data);
VALA_EXTERN const gchar* tuba_api_notification_get_emoji (TubaAPINotification* self);
VALA_EXTERN GType tuba_widgets_label_with_widgets_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsLabelWithWidgets, g_object_unref)
VALA_EXTERN GType tuba_widgets_emoji_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsEmojiLabel, g_object_unref)
VALA_EXTERN TubaWidgetsEmojiLabel* tuba_widgets_emoji_label_new (const gchar* text,
                                                     GeeHashMap* emojis);
VALA_EXTERN TubaWidgetsEmojiLabel* tuba_widgets_emoji_label_construct (GType object_type,
                                                           const gchar* text,
                                                           GeeHashMap* emojis);
VALA_EXTERN void tuba_widgets_label_with_widgets_set_use_markup (TubaWidgetsLabelWithWidgets* self,
                                                     gboolean value);
VALA_EXTERN void tuba_widgets_label_with_widgets_set_ellipsize (TubaWidgetsLabelWithWidgets* self,
                                                    gboolean value);
VALA_EXTERN void tuba_widgets_emoji_label_set_instance_emojis (TubaWidgetsEmojiLabel* self,
                                                   GeeHashMap* value);
VALA_EXTERN void tuba_widgets_emoji_label_set_content (TubaWidgetsEmojiLabel* self,
                                           const gchar* value);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_new (void);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_construct (GType object_type);
VALA_EXTERN void tuba_widgets_avatar_set_account (TubaWidgetsAvatar* self,
                                      TubaAPIAccount* value);
VALA_EXTERN void tuba_widgets_avatar_set_size (TubaWidgetsAvatar* self,
                                   gint value);
VALA_EXTERN void tuba_widgets_avatar_set_allow_mini_profile (TubaWidgetsAvatar* self,
                                                 gboolean value);
static void tuba_widgets_grouped_notification_on_open_sub_account (TubaAPIAccount* acc);
static void _tuba_widgets_grouped_notification_on_open_sub_account_tuba_widgets_avatar_mini_clicked (TubaWidgetsAvatar* _sender,
                                                                                              TubaAPIAccount* acc,
                                                                                              gpointer self);
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static GType tuba_widgets_grouped_notification_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

TubaWidgetsGroupedNotification*
tuba_widgets_grouped_notification_construct (GType object_type,
                                             TubaAPIGroupedNotificationsResultsNotificationGroup* obj)
{
	TubaWidgetsGroupedNotification * self = NULL;
	gchar* old_kind = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	GeeArrayList* _tmp3_;
	GeeArrayList* _tmp4_;
	gint _tmp5_;
	gint _tmp6_;
	TubaInstanceAccountKind res_kind = {0};
	GtkBox* box = NULL;
	const gchar* _tmp7_;
	TubaInstanceAccountKind _tmp8_ = {0};
	GtkBox* _tmp9_;
	GtkImage* group_icon = NULL;
	TubaInstanceAccountKind _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	gchar** _tmp13_;
	GtkImage* _tmp14_ = NULL;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	GQuark _tmp18_ = 0U;
	static GQuark _tmp17_label0 = 0;
	static GQuark _tmp17_label1 = 0;
	static GQuark _tmp17_label2 = 0;
	static GQuark _tmp17_label3 = 0;
	static GQuark _tmp17_label4 = 0;
	GtkBox* _tmp23_;
	GtkImage* _tmp24_;
	GtkBox* _tmp25_;
	GtkBox* _tmp26_;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = tuba_api_notification_get_kind ((TubaAPINotification*) obj);
	_tmp1_ = _tmp0_;
	_tmp2_ = g_strdup (_tmp1_);
	old_kind = _tmp2_;
	self = (TubaWidgetsGroupedNotification*) tuba_widgets_notification_construct (object_type, (TubaAPINotification*) obj, FALSE);
	_tmp3_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
	_tmp4_ = _tmp3_;
	_tmp5_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp4_);
	_tmp6_ = _tmp5_;
	if (_tmp6_ == 0) {
		_g_free0 (old_kind);
		return self;
	}
	_tmp7_ = old_kind;
	_tmp9_ = tuba_widgets_grouped_notification_group_box (obj, _tmp7_, &_tmp8_);
	tuba_instance_account_kind_destroy (&res_kind);
	res_kind = _tmp8_;
	box = _tmp9_;
	_tmp10_ = res_kind;
	_tmp11_ = _tmp10_.icon;
	_tmp12_ = g_strdup ("grouped-icon");
	_tmp13_ = g_new0 (gchar*, 1 + 1);
	_tmp13_[0] = _tmp12_;
	_tmp14_ = (GtkImage*) gtk_image_new_from_icon_name (_tmp11_);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp14_, 22);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp14_, 3);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp14_, _tmp13_);
	_tmp13_ = (_vala_array_free (_tmp13_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp14_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp14_);
	group_icon = _tmp14_;
	_tmp15_ = old_kind;
	_tmp16_ = _tmp15_;
	_tmp18_ = (NULL == _tmp16_) ? 0 : g_quark_from_string (_tmp16_);
	if (_tmp18_ == ((0 != _tmp17_label0) ? _tmp17_label0 : (_tmp17_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FAVOURITE)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp19_;
				_tmp19_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp19_, "star");
				break;
			}
		}
	} else if (_tmp18_ == ((0 != _tmp17_label1) ? _tmp17_label1 : (_tmp17_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_REBLOG)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp20_;
				_tmp20_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp20_, "reblog");
				break;
			}
		}
	} else if (_tmp18_ == ((0 != _tmp17_label2) ? _tmp17_label2 : (_tmp17_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp21_;
				_tmp21_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp21_, "sign-up");
				break;
			}
		}
	} else if ((_tmp18_ == ((0 != _tmp17_label3) ? _tmp17_label3 : (_tmp17_label3 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW)))) || (_tmp18_ == ((0 != _tmp17_label4) ? _tmp17_label4 : (_tmp17_label4 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST))))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp22_;
				_tmp22_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp22_, "follow");
				break;
			}
		}
	}
	_tmp23_ = ((TubaWidgetsStatus*) self)->avatar_side;
	_tmp24_ = group_icon;
	gtk_box_prepend (_tmp23_, (GtkWidget*) _tmp24_);
	_tmp25_ = ((TubaWidgetsStatus*) self)->content_side;
	_tmp26_ = box;
	gtk_box_prepend (_tmp25_, (GtkWidget*) _tmp26_);
	_g_object_unref0 (group_icon);
	_g_object_unref0 (box);
	tuba_instance_account_kind_destroy (&res_kind);
	_g_free0 (old_kind);
	return self;
}

TubaWidgetsGroupedNotification*
tuba_widgets_grouped_notification_new (TubaAPIGroupedNotificationsResultsNotificationGroup* obj)
{
	return tuba_widgets_grouped_notification_construct (TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, obj);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gchar*
string_replace (const gchar* self,
                const gchar* old,
                const gchar* replacement)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	if ((*((gchar*) self)) == '\0') {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = (*((gchar*) old)) == '\0';
	}
	if (_tmp1_) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = g_strcmp0 (old, replacement) == 0;
	}
	if (_tmp0_) {
		gchar* _tmp2_;
		_tmp2_ = g_strdup (self);
		result = _tmp2_;
		return result;
	}
	{
		GRegex* regex = NULL;
		gchar* _tmp3_;
		gchar* _tmp4_;
		GRegex* _tmp5_;
		GRegex* _tmp6_;
		gchar* _tmp7_ = NULL;
		GRegex* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		_tmp3_ = g_regex_escape_string (old, -1);
		_tmp4_ = _tmp3_;
		_tmp5_ = g_regex_new (_tmp4_, 0, 0, &_inner_error0_);
		_tmp6_ = _tmp5_;
		_g_free0 (_tmp4_);
		regex = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp8_ = regex;
		_tmp9_ = g_regex_replace_literal (_tmp8_, self, (gssize) -1, 0, replacement, 0, &_inner_error0_);
		_tmp7_ = _tmp9_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp10_ = _tmp7_;
		_tmp7_ = NULL;
		result = _tmp10_;
		_g_free0 (_tmp7_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		g_clear_error (&_inner_error0_);
		g_assert_not_reached ();
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

static void
_tuba_widgets_grouped_notification_on_open_sub_account_tuba_widgets_avatar_mini_clicked (TubaWidgetsAvatar* _sender,
                                                                                         TubaAPIAccount* acc,
                                                                                         gpointer self)
{
	tuba_widgets_grouped_notification_on_open_sub_account (acc);
}

GtkBox*
tuba_widgets_grouped_notification_group_box (TubaAPIGroupedNotificationsResultsNotificationGroup* obj,
                                             const gchar* old_kind,
                                             TubaInstanceAccountKind* res_kind)
{
	TubaInstanceAccountKind _vala_res_kind = {0};
	GeeHashMap* mojis = NULL;
	gchar* kind_actor_name = NULL;
	GeeArrayList* _tmp0_;
	GeeArrayList* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	TubaAccountStore* _tmp134_;
	TubaInstanceAccount* _tmp135_;
	TubaInstanceAccount* _tmp136_;
	const gchar* _tmp137_;
	const gchar* _tmp138_;
	const gchar* _tmp139_;
	TubaInstanceAccountKind _tmp140_ = {0};
	TubaWidgetsEmojiLabel* title_label = NULL;
	gchar* _tmp141_;
	gchar* _tmp142_;
	gchar* _tmp143_;
	gchar** _tmp144_;
	TubaWidgetsEmojiLabel* _tmp145_ = NULL;
	TubaWidgetsEmojiLabel* _tmp146_;
	GeeHashMap* _tmp147_;
	TubaWidgetsEmojiLabel* _tmp148_;
	TubaInstanceAccountKind _tmp149_;
	const gchar* _tmp150_;
	GtkBox* avi_box = NULL;
	GtkBox* _tmp151_;
	GtkBox* box = NULL;
	GtkBox* _tmp165_;
	GtkBox* _tmp166_;
	TubaWidgetsEmojiLabel* _tmp167_;
	GtkBox* result;
	g_return_val_if_fail (obj != NULL, NULL);
	g_return_val_if_fail (old_kind != NULL, NULL);
	mojis = NULL;
	_tmp0_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
	_tmp1_ = _tmp0_;
	_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
	_tmp3_ = _tmp2_;
	switch (_tmp3_ - 1) {
		case 0:
		{
			GeeArrayList* _tmp4_;
			GeeArrayList* _tmp5_;
			gpointer _tmp6_;
			TubaAPIAccount* _tmp7_;
			const gchar* _tmp8_;
			const gchar* _tmp9_;
			gchar* _tmp10_;
			GeeArrayList* _tmp11_;
			GeeArrayList* _tmp12_;
			gpointer _tmp13_;
			TubaAPIAccount* _tmp14_;
			GeeHashMap* _tmp15_;
			GeeHashMap* _tmp16_;
			_tmp4_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp5_ = _tmp4_;
			_tmp6_ = gee_abstract_list_get ((GeeAbstractList*) _tmp5_, 0);
			_tmp7_ = (TubaAPIAccount*) _tmp6_;
			_tmp8_ = tuba_api_account_get_display_name (_tmp7_);
			_tmp9_ = _tmp8_;
			_tmp10_ = g_strdup (_tmp9_);
			_g_free0 (kind_actor_name);
			kind_actor_name = _tmp10_;
			_g_object_unref0 (_tmp7_);
			_tmp11_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp12_ = _tmp11_;
			_tmp13_ = gee_abstract_list_get ((GeeAbstractList*) _tmp12_, 0);
			_tmp14_ = (TubaAPIAccount*) _tmp13_;
			_tmp15_ = tuba_api_account_get_emojis_map (_tmp14_);
			_tmp16_ = _tmp15_;
			_g_object_unref0 (mojis);
			mojis = _tmp16_;
			_g_object_unref0 (_tmp14_);
			break;
		}
		case 1:
		{
			GeeHashMap* _tmp17_;
			TubaAPIAccount* acc_1 = NULL;
			GeeArrayList* _tmp18_;
			GeeArrayList* _tmp19_;
			gpointer _tmp20_;
			TubaAPIAccount* acc_2 = NULL;
			GeeArrayList* _tmp21_;
			GeeArrayList* _tmp22_;
			gpointer _tmp23_;
			gchar* diffed_name_1 = NULL;
			TubaAPIAccount* _tmp24_;
			const gchar* _tmp25_;
			const gchar* _tmp26_;
			gchar* _tmp27_;
			gchar* diffed_name_2 = NULL;
			TubaAPIAccount* _tmp28_;
			const gchar* _tmp29_;
			const gchar* _tmp30_;
			gchar* _tmp31_;
			gboolean _tmp32_ = FALSE;
			TubaAPIAccount* _tmp33_;
			GeeArrayList* _tmp34_;
			GeeArrayList* _tmp35_;
			gboolean _tmp73_ = FALSE;
			TubaAPIAccount* _tmp74_;
			GeeArrayList* _tmp75_;
			GeeArrayList* _tmp76_;
			const gchar* _tmp114_;
			const gchar* _tmp115_;
			gchar* _tmp116_;
			_tmp17_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
			_g_object_unref0 (mojis);
			mojis = _tmp17_;
			_tmp18_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp19_ = _tmp18_;
			_tmp20_ = gee_abstract_list_get ((GeeAbstractList*) _tmp19_, 0);
			acc_1 = (TubaAPIAccount*) _tmp20_;
			_tmp21_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp22_ = _tmp21_;
			_tmp23_ = gee_abstract_list_get ((GeeAbstractList*) _tmp22_, 1);
			acc_2 = (TubaAPIAccount*) _tmp23_;
			_tmp24_ = acc_1;
			_tmp25_ = tuba_api_account_get_display_name (_tmp24_);
			_tmp26_ = _tmp25_;
			_tmp27_ = g_strdup (_tmp26_);
			diffed_name_1 = _tmp27_;
			_tmp28_ = acc_2;
			_tmp29_ = tuba_api_account_get_display_name (_tmp28_);
			_tmp30_ = _tmp29_;
			_tmp31_ = g_strdup (_tmp30_);
			diffed_name_2 = _tmp31_;
			_tmp33_ = acc_1;
			_tmp34_ = tuba_api_account_get_emojis (_tmp33_);
			_tmp35_ = _tmp34_;
			if (_tmp35_ != NULL) {
				TubaAPIAccount* _tmp36_;
				GeeArrayList* _tmp37_;
				GeeArrayList* _tmp38_;
				gint _tmp39_;
				gint _tmp40_;
				_tmp36_ = acc_1;
				_tmp37_ = tuba_api_account_get_emojis (_tmp36_);
				_tmp38_ = _tmp37_;
				_tmp39_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp38_);
				_tmp40_ = _tmp39_;
				_tmp32_ = _tmp40_ > 0;
			} else {
				_tmp32_ = FALSE;
			}
			if (_tmp32_) {
				{
					GeeArrayList* _e_list = NULL;
					TubaAPIAccount* _tmp41_;
					GeeArrayList* _tmp42_;
					GeeArrayList* _tmp43_;
					gint _e_size = 0;
					GeeArrayList* _tmp44_;
					gint _tmp45_;
					gint _tmp46_;
					gint _e_index = 0;
					_tmp41_ = acc_1;
					_tmp42_ = tuba_api_account_get_emojis (_tmp41_);
					_tmp43_ = _tmp42_;
					_e_list = _tmp43_;
					_tmp44_ = _e_list;
					_tmp45_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp44_);
					_tmp46_ = _tmp45_;
					_e_size = _tmp46_;
					_e_index = -1;
					while (TRUE) {
						gint _tmp47_;
						gint _tmp48_;
						TubaAPIEmoji* e = NULL;
						GeeArrayList* _tmp49_;
						gpointer _tmp50_;
						gchar* new_name = NULL;
						TubaAPIEmoji* _tmp51_;
						const gchar* _tmp52_;
						const gchar* _tmp53_;
						const gchar* _tmp54_;
						gchar* _tmp55_;
						const gchar* _tmp56_;
						TubaAPIEmoji* _tmp57_;
						const gchar* _tmp58_;
						const gchar* _tmp59_;
						const gchar* _tmp60_;
						gchar* _tmp61_;
						gchar* _tmp62_;
						const gchar* _tmp63_;
						const gchar* _tmp64_;
						gchar* _tmp65_;
						gchar* _tmp66_;
						gchar* _tmp67_;
						GeeHashMap* _tmp68_;
						const gchar* _tmp69_;
						TubaAPIEmoji* _tmp70_;
						const gchar* _tmp71_;
						const gchar* _tmp72_;
						_e_index = _e_index + 1;
						_tmp47_ = _e_index;
						_tmp48_ = _e_size;
						if (!(_tmp47_ < _tmp48_)) {
							break;
						}
						_tmp49_ = _e_list;
						_tmp50_ = gee_abstract_list_get ((GeeAbstractList*) _tmp49_, _e_index);
						e = (TubaAPIEmoji*) _tmp50_;
						_tmp51_ = e;
						_tmp52_ = tuba_api_emoji_get_shortcode (_tmp51_);
						_tmp53_ = _tmp52_;
						_tmp54_ = string_to_string (_tmp53_);
						_tmp55_ = g_strconcat ("tuba_1_", _tmp54_, NULL);
						new_name = _tmp55_;
						_tmp56_ = diffed_name_1;
						_tmp57_ = e;
						_tmp58_ = tuba_api_emoji_get_shortcode (_tmp57_);
						_tmp59_ = _tmp58_;
						_tmp60_ = string_to_string (_tmp59_);
						_tmp61_ = g_strconcat (":", _tmp60_, ":", NULL);
						_tmp62_ = _tmp61_;
						_tmp63_ = new_name;
						_tmp64_ = string_to_string (_tmp63_);
						_tmp65_ = g_strconcat (":", _tmp64_, ":", NULL);
						_tmp66_ = _tmp65_;
						_tmp67_ = string_replace (_tmp56_, _tmp62_, _tmp66_);
						_g_free0 (diffed_name_1);
						diffed_name_1 = _tmp67_;
						_g_free0 (_tmp66_);
						_g_free0 (_tmp62_);
						_tmp68_ = mojis;
						_tmp69_ = new_name;
						_tmp70_ = e;
						_tmp71_ = tuba_api_emoji_get_url (_tmp70_);
						_tmp72_ = _tmp71_;
						gee_abstract_map_set ((GeeAbstractMap*) _tmp68_, _tmp69_, _tmp72_);
						_g_free0 (new_name);
						_g_object_unref0 (e);
					}
				}
			}
			_tmp74_ = acc_2;
			_tmp75_ = tuba_api_account_get_emojis (_tmp74_);
			_tmp76_ = _tmp75_;
			if (_tmp76_ != NULL) {
				TubaAPIAccount* _tmp77_;
				GeeArrayList* _tmp78_;
				GeeArrayList* _tmp79_;
				gint _tmp80_;
				gint _tmp81_;
				_tmp77_ = acc_2;
				_tmp78_ = tuba_api_account_get_emojis (_tmp77_);
				_tmp79_ = _tmp78_;
				_tmp80_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp79_);
				_tmp81_ = _tmp80_;
				_tmp73_ = _tmp81_ > 0;
			} else {
				_tmp73_ = FALSE;
			}
			if (_tmp73_) {
				{
					GeeArrayList* _e_list = NULL;
					TubaAPIAccount* _tmp82_;
					GeeArrayList* _tmp83_;
					GeeArrayList* _tmp84_;
					gint _e_size = 0;
					GeeArrayList* _tmp85_;
					gint _tmp86_;
					gint _tmp87_;
					gint _e_index = 0;
					_tmp82_ = acc_2;
					_tmp83_ = tuba_api_account_get_emojis (_tmp82_);
					_tmp84_ = _tmp83_;
					_e_list = _tmp84_;
					_tmp85_ = _e_list;
					_tmp86_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp85_);
					_tmp87_ = _tmp86_;
					_e_size = _tmp87_;
					_e_index = -1;
					while (TRUE) {
						gint _tmp88_;
						gint _tmp89_;
						TubaAPIEmoji* e = NULL;
						GeeArrayList* _tmp90_;
						gpointer _tmp91_;
						gchar* new_name = NULL;
						TubaAPIEmoji* _tmp92_;
						const gchar* _tmp93_;
						const gchar* _tmp94_;
						const gchar* _tmp95_;
						gchar* _tmp96_;
						const gchar* _tmp97_;
						TubaAPIEmoji* _tmp98_;
						const gchar* _tmp99_;
						const gchar* _tmp100_;
						const gchar* _tmp101_;
						gchar* _tmp102_;
						gchar* _tmp103_;
						const gchar* _tmp104_;
						const gchar* _tmp105_;
						gchar* _tmp106_;
						gchar* _tmp107_;
						gchar* _tmp108_;
						GeeHashMap* _tmp109_;
						const gchar* _tmp110_;
						TubaAPIEmoji* _tmp111_;
						const gchar* _tmp112_;
						const gchar* _tmp113_;
						_e_index = _e_index + 1;
						_tmp88_ = _e_index;
						_tmp89_ = _e_size;
						if (!(_tmp88_ < _tmp89_)) {
							break;
						}
						_tmp90_ = _e_list;
						_tmp91_ = gee_abstract_list_get ((GeeAbstractList*) _tmp90_, _e_index);
						e = (TubaAPIEmoji*) _tmp91_;
						_tmp92_ = e;
						_tmp93_ = tuba_api_emoji_get_shortcode (_tmp92_);
						_tmp94_ = _tmp93_;
						_tmp95_ = string_to_string (_tmp94_);
						_tmp96_ = g_strconcat ("tuba_2_", _tmp95_, NULL);
						new_name = _tmp96_;
						_tmp97_ = diffed_name_2;
						_tmp98_ = e;
						_tmp99_ = tuba_api_emoji_get_shortcode (_tmp98_);
						_tmp100_ = _tmp99_;
						_tmp101_ = string_to_string (_tmp100_);
						_tmp102_ = g_strconcat (":", _tmp101_, ":", NULL);
						_tmp103_ = _tmp102_;
						_tmp104_ = new_name;
						_tmp105_ = string_to_string (_tmp104_);
						_tmp106_ = g_strconcat (":", _tmp105_, ":", NULL);
						_tmp107_ = _tmp106_;
						_tmp108_ = string_replace (_tmp97_, _tmp103_, _tmp107_);
						_g_free0 (diffed_name_2);
						diffed_name_2 = _tmp108_;
						_g_free0 (_tmp107_);
						_g_free0 (_tmp103_);
						_tmp109_ = mojis;
						_tmp110_ = new_name;
						_tmp111_ = e;
						_tmp112_ = tuba_api_emoji_get_url (_tmp111_);
						_tmp113_ = _tmp112_;
						gee_abstract_map_set ((GeeAbstractMap*) _tmp109_, _tmp110_, _tmp113_);
						_g_free0 (new_name);
						_g_object_unref0 (e);
					}
				}
			}
			_tmp114_ = diffed_name_1;
			_tmp115_ = diffed_name_2;
			_tmp116_ = g_strdup_printf ("%s & %s", _tmp114_, _tmp115_);
			_g_free0 (kind_actor_name);
			kind_actor_name = _tmp116_;
			_g_free0 (diffed_name_2);
			_g_free0 (diffed_name_1);
			_g_object_unref0 (acc_2);
			_g_object_unref0 (acc_1);
			break;
		}
		default:
		{
			GeeArrayList* _tmp117_;
			GeeArrayList* _tmp118_;
			gpointer _tmp119_;
			TubaAPIAccount* _tmp120_;
			const gchar* _tmp121_;
			const gchar* _tmp122_;
			GeeArrayList* _tmp123_;
			GeeArrayList* _tmp124_;
			gint _tmp125_;
			gint _tmp126_;
			gchar* _tmp127_;
			GeeArrayList* _tmp128_;
			GeeArrayList* _tmp129_;
			gpointer _tmp130_;
			TubaAPIAccount* _tmp131_;
			GeeHashMap* _tmp132_;
			GeeHashMap* _tmp133_;
			_tmp117_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp118_ = _tmp117_;
			_tmp119_ = gee_abstract_list_get ((GeeAbstractList*) _tmp118_, 0);
			_tmp120_ = (TubaAPIAccount*) _tmp119_;
			_tmp121_ = tuba_api_account_get_display_name (_tmp120_);
			_tmp122_ = _tmp121_;
			_tmp123_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp124_ = _tmp123_;
			_tmp125_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp124_);
			_tmp126_ = _tmp125_;
			_tmp127_ = g_strdup_printf (_ ("%s (& %d others)"), _tmp122_, _tmp126_ - 1);
			_g_free0 (kind_actor_name);
			kind_actor_name = _tmp127_;
			_g_object_unref0 (_tmp120_);
			_tmp128_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
			_tmp129_ = _tmp128_;
			_tmp130_ = gee_abstract_list_get ((GeeAbstractList*) _tmp129_, 0);
			_tmp131_ = (TubaAPIAccount*) _tmp130_;
			_tmp132_ = tuba_api_account_get_emojis_map (_tmp131_);
			_tmp133_ = _tmp132_;
			_g_object_unref0 (mojis);
			mojis = _tmp133_;
			_g_object_unref0 (_tmp131_);
			break;
		}
	}
	_tmp134_ = tuba_accounts;
	_tmp135_ = tuba_account_store_get_active (_tmp134_);
	_tmp136_ = _tmp135_;
	_tmp137_ = kind_actor_name;
	_tmp138_ = tuba_api_notification_get_emoji ((TubaAPINotification*) obj);
	_tmp139_ = _tmp138_;
	tuba_instance_account_describe_kind (_tmp136_, old_kind, &_tmp140_, _tmp137_, NULL, _tmp139_);
	tuba_instance_account_kind_destroy (&_vala_res_kind);
	_vala_res_kind = _tmp140_;
	_tmp141_ = g_strdup ("dim-label");
	_tmp142_ = g_strdup ("font-bold");
	_tmp143_ = g_strdup ("font-small");
	_tmp144_ = g_new0 (gchar*, 3 + 1);
	_tmp144_[0] = _tmp141_;
	_tmp144_[1] = _tmp142_;
	_tmp144_[2] = _tmp143_;
	_tmp145_ = tuba_widgets_emoji_label_new (NULL, NULL);
	tuba_widgets_label_with_widgets_set_use_markup ((TubaWidgetsLabelWithWidgets*) _tmp145_, FALSE);
	tuba_widgets_label_with_widgets_set_ellipsize ((TubaWidgetsLabelWithWidgets*) _tmp145_, TRUE);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp145_, _tmp144_);
	_tmp144_ = (_vala_array_free (_tmp144_, 3, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp145_);
	title_label = _tmp145_;
	_tmp146_ = title_label;
	_tmp147_ = mojis;
	tuba_widgets_emoji_label_set_instance_emojis (_tmp146_, _tmp147_);
	_tmp148_ = title_label;
	_tmp149_ = _vala_res_kind;
	_tmp150_ = _tmp149_.description;
	tuba_widgets_emoji_label_set_content (_tmp148_, _tmp150_);
	_tmp151_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
	g_object_ref_sink (_tmp151_);
	avi_box = _tmp151_;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp152_ = FALSE;
			_tmp152_ = TRUE;
			while (TRUE) {
				GeeArrayList* _tmp154_;
				GeeArrayList* _tmp155_;
				gint _tmp156_;
				gint _tmp157_;
				TubaWidgetsAvatar* avi = NULL;
				GeeArrayList* _tmp158_;
				GeeArrayList* _tmp159_;
				gpointer _tmp160_;
				TubaWidgetsAvatar* _tmp161_ = NULL;
				TubaWidgetsAvatar* _tmp162_;
				GtkBox* _tmp163_;
				TubaWidgetsAvatar* _tmp164_;
				if (!_tmp152_) {
					gint _tmp153_;
					_tmp153_ = i;
					i = _tmp153_ + 1;
				}
				_tmp152_ = FALSE;
				_tmp154_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
				_tmp155_ = _tmp154_;
				_tmp156_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp155_);
				_tmp157_ = _tmp156_;
				if (!(i < MIN (6, _tmp157_))) {
					break;
				}
				_tmp158_ = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (obj);
				_tmp159_ = _tmp158_;
				_tmp160_ = gee_abstract_list_get ((GeeAbstractList*) _tmp159_, i);
				_tmp161_ = tuba_widgets_avatar_new ();
				tuba_widgets_avatar_set_account (_tmp161_, (TubaAPIAccount*) _tmp160_);
				_g_object_unref0 (_tmp160_);
				tuba_widgets_avatar_set_size (_tmp161_, 30);
				gtk_widget_set_overflow ((GtkWidget*) _tmp161_, GTK_OVERFLOW_HIDDEN);
				tuba_widgets_avatar_set_allow_mini_profile (_tmp161_, TRUE);
				g_object_ref_sink (_tmp161_);
				avi = _tmp161_;
				_tmp162_ = avi;
				g_signal_connect (_tmp162_, "mini-clicked", (GCallback) _tuba_widgets_grouped_notification_on_open_sub_account_tuba_widgets_avatar_mini_clicked, NULL);
				_tmp163_ = avi_box;
				_tmp164_ = avi;
				gtk_box_append (_tmp163_, (GtkWidget*) _tmp164_);
				_g_object_unref0 (avi);
			}
		}
	}
	_tmp165_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
	g_object_ref_sink (_tmp165_);
	box = _tmp165_;
	_tmp166_ = avi_box;
	gtk_box_append (box, (GtkWidget*) _tmp166_);
	_tmp167_ = title_label;
	gtk_box_append (box, (GtkWidget*) _tmp167_);
	result = box;
	_g_object_unref0 (avi_box);
	_g_object_unref0 (title_label);
	_g_free0 (kind_actor_name);
	_g_object_unref0 (mojis);
	if (res_kind) {
		*res_kind = _vala_res_kind;
	} else {
		tuba_instance_account_kind_destroy (&_vala_res_kind);
	}
	return result;
}

static void
tuba_widgets_grouped_notification_on_open_sub_account (TubaAPIAccount* acc)
{
	tuba_widgetizable_open ((TubaWidgetizable*) acc);
}

static void
tuba_widgets_grouped_notification_class_init (TubaWidgetsGroupedNotificationClass * klass,
                                              gpointer klass_data)
{
	tuba_widgets_grouped_notification_parent_class = g_type_class_peek_parent (klass);
}

static void
tuba_widgets_grouped_notification_instance_init (TubaWidgetsGroupedNotification * self,
                                                 gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_grouped_notification_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsGroupedNotificationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_grouped_notification_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsGroupedNotification), 0, (GInstanceInitFunc) tuba_widgets_grouped_notification_instance_init, NULL };
	GType tuba_widgets_grouped_notification_type_id;
	tuba_widgets_grouped_notification_type_id = g_type_register_static (TUBA_WIDGETS_TYPE_NOTIFICATION, "TubaWidgetsGroupedNotification", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_widgets_grouped_notification_type_id;
}

GType
tuba_widgets_grouped_notification_get_type (void)
{
	static GType tuba_widgets_grouped_notification_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_grouped_notification_type_id__once)) {
		GType tuba_widgets_grouped_notification_type_id;
		tuba_widgets_grouped_notification_type_id = tuba_widgets_grouped_notification_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_grouped_notification_type_id__once, tuba_widgets_grouped_notification_type_id);
	}
	return tuba_widgets_grouped_notification_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

