/* NotificationRequestsList.c generated by valac 0.56.19, the Vala compiler
 * generated from NotificationRequestsList.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST (tuba_views_notification_requests_list_get_type ())
#define TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST, TubaViewsNotificationRequestsList))
#define TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST, TubaViewsNotificationRequestsListClass))
#define TUBA_VIEWS_IS_NOTIFICATION_REQUESTS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST))
#define TUBA_VIEWS_IS_NOTIFICATION_REQUESTS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST))
#define TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST, TubaViewsNotificationRequestsListClass))

typedef struct _TubaViewsNotificationRequestsList TubaViewsNotificationRequestsList;
typedef struct _TubaViewsNotificationRequestsListClass TubaViewsNotificationRequestsListClass;
typedef struct _TubaViewsNotificationRequestsListPrivate TubaViewsNotificationRequestsListPrivate;

#define TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST (tuba_widgets_notification_request_get_type ())
#define TUBA_WIDGETS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequest))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))

typedef struct _TubaWidgetsNotificationRequest TubaWidgetsNotificationRequest;
typedef struct _TubaWidgetsNotificationRequestClass TubaWidgetsNotificationRequestClass;
enum  {
	TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST_0_PROPERTY,
	TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST_NUM_PROPERTIES
};
static GParamSpec* tuba_views_notification_requests_list_properties[TUBA_VIEWS_NOTIFICATION_REQUESTS_LIST_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_API_TYPE_NOTIFICATION (tuba_api_notification_get_type ())
#define TUBA_API_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotification))
#define TUBA_API_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))
#define TUBA_API_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))

typedef struct _TubaAPINotification TubaAPINotification;
typedef struct _TubaAPINotificationClass TubaAPINotificationClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsNotificationRequestsList {
	TubaViewsTimeline parent_instance;
	TubaViewsNotificationRequestsListPrivate * priv;
};

struct _TubaViewsNotificationRequestsListClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaViewsNotificationRequestsListPrivate {
	TubaWidgetsNotificationRequest* notification_req_wdg;
	GtkButton* dismiss_btn;
	GtkButton* accept_btn;
};

static gint TubaViewsNotificationRequestsList_private_offset;
static gpointer tuba_views_notification_requests_list_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_notification_requests_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsNotificationRequestsList, g_object_unref)
VALA_EXTERN GType tuba_widgets_notification_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotificationRequest, g_object_unref)
VALA_EXTERN void tuba_views_base_build_header (TubaViewsBase* self);
VALA_EXTERN TubaViewsNotificationRequestsList* tuba_views_notification_requests_list_new (const gchar* account_id,
                                                                              const gchar* account_handle,
                                                                              TubaWidgetsNotificationRequest* notification_req_wdg);
VALA_EXTERN TubaViewsNotificationRequestsList* tuba_views_notification_requests_list_construct (GType object_type,
                                                                                    const gchar* account_id,
                                                                                    const gchar* account_handle,
                                                                                    TubaWidgetsNotificationRequest* notification_req_wdg);
VALA_EXTERN GType tuba_api_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotification, g_object_unref)
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
static void tuba_views_notification_requests_list_real_build_header (TubaViewsBase* base);
static void tuba_views_notification_requests_list_on_dismiss (TubaViewsNotificationRequestsList* self);
static void _tuba_views_notification_requests_list_on_dismiss_gtk_button_clicked (GtkButton* _sender,
                                                                           gpointer self);
static void tuba_views_notification_requests_list_on_accept (TubaViewsNotificationRequestsList* self);
static void _tuba_views_notification_requests_list_on_accept_gtk_button_clicked (GtkButton* _sender,
                                                                          gpointer self);
VALA_EXTERN void tuba_widgets_notification_request_on_dismiss (TubaWidgetsNotificationRequest* self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN gboolean tuba_dialogs_main_window_back (TubaDialogsMainWindow* self);
VALA_EXTERN void tuba_widgets_notification_request_on_accept (TubaWidgetsNotificationRequest* self);
static void tuba_views_notification_requests_list_finalize (GObject * obj);
static GType tuba_views_notification_requests_list_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_views_notification_requests_list_get_instance_private (TubaViewsNotificationRequestsList* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsNotificationRequestsList_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaViewsNotificationRequestsList*
tuba_views_notification_requests_list_construct (GType object_type,
                                                 const gchar* account_id,
                                                 const gchar* account_handle,
                                                 TubaWidgetsNotificationRequest* notification_req_wdg)
{
	TubaViewsNotificationRequestsList * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	TubaWidgetsNotificationRequest* _tmp7_;
	g_return_val_if_fail (account_id != NULL, NULL);
	g_return_val_if_fail (account_handle != NULL, NULL);
	g_return_val_if_fail (notification_req_wdg != NULL, NULL);
	_tmp0_ = string_to_string (account_id);
	_tmp1_ = g_strconcat ("/api/v1/notifications?account_id=", _tmp0_, NULL);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strdup_printf (_ ("Notifications by %s"), account_handle);
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strdup_printf (_ ("No Notifications by %s"), account_handle);
	_tmp6_ = _tmp5_;
	self = (TubaViewsNotificationRequestsList*) g_object_new (object_type, "url", _tmp2_, "label", _tmp4_, "icon", "tuba-bell-outline-symbolic", "empty-state-title", _tmp6_, "batch-size-min", 20, NULL);
	_g_free0 (_tmp6_);
	_g_free0 (_tmp4_);
	_g_free0 (_tmp2_);
	tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_NOTIFICATION);
	_tmp7_ = _g_object_ref0 (notification_req_wdg);
	_g_object_unref0 (self->priv->notification_req_wdg);
	self->priv->notification_req_wdg = _tmp7_;
	return self;
}

TubaViewsNotificationRequestsList*
tuba_views_notification_requests_list_new (const gchar* account_id,
                                           const gchar* account_handle,
                                           TubaWidgetsNotificationRequest* notification_req_wdg)
{
	return tuba_views_notification_requests_list_construct (TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST, account_id, account_handle, notification_req_wdg);
}

static void
_tuba_views_notification_requests_list_on_dismiss_gtk_button_clicked (GtkButton* _sender,
                                                                      gpointer self)
{
	tuba_views_notification_requests_list_on_dismiss ((TubaViewsNotificationRequestsList*) self);
}

static void
_tuba_views_notification_requests_list_on_accept_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self)
{
	tuba_views_notification_requests_list_on_accept ((TubaViewsNotificationRequestsList*) self);
}

static void
tuba_views_notification_requests_list_real_build_header (TubaViewsBase* base)
{
	TubaViewsNotificationRequestsList * self;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	gchar* _tmp4_;
	GtkButton* _tmp5_ = NULL;
	GtkButton* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar** _tmp10_;
	gchar* _tmp11_;
	GtkButton* _tmp12_ = NULL;
	GtkButton* _tmp13_;
	AdwHeaderBar* _tmp14_;
	GtkButton* _tmp15_;
	AdwHeaderBar* _tmp16_;
	GtkButton* _tmp17_;
	self = (TubaViewsNotificationRequestsList*) base;
	TUBA_VIEWS_BASE_CLASS (tuba_views_notification_requests_list_parent_class)->build_header ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline));
	_tmp0_ = g_strdup ("user-trash-symbolic");
	_tmp1_ = g_strdup ("flat");
	_tmp2_ = g_strdup ("error");
	_tmp3_ = g_new0 (gchar*, 2 + 1);
	_tmp3_[0] = _tmp1_;
	_tmp3_[1] = _tmp2_;
	_tmp4_ = g_strdup (_ ("Dismiss"));
	_tmp5_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp5_, _tmp0_);
	_g_free0 (_tmp0_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp5_, _tmp3_);
	_tmp3_ = (_vala_array_free (_tmp3_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp5_, _tmp4_);
	_g_free0 (_tmp4_);
	g_object_ref_sink (_tmp5_);
	_g_object_unref0 (self->priv->dismiss_btn);
	self->priv->dismiss_btn = _tmp5_;
	_tmp6_ = self->priv->dismiss_btn;
	g_signal_connect_object (_tmp6_, "clicked", (GCallback) _tuba_views_notification_requests_list_on_dismiss_gtk_button_clicked, self, 0);
	_tmp7_ = g_strdup ("tuba-check-round-outline-symbolic");
	_tmp8_ = g_strdup ("flat");
	_tmp9_ = g_strdup ("success");
	_tmp10_ = g_new0 (gchar*, 2 + 1);
	_tmp10_[0] = _tmp8_;
	_tmp10_[1] = _tmp9_;
	_tmp11_ = g_strdup (_ ("Accept"));
	_tmp12_ = (GtkButton*) gtk_button_new ();
	gtk_button_set_icon_name (_tmp12_, _tmp7_);
	_g_free0 (_tmp7_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp12_, _tmp10_);
	_tmp10_ = (_vala_array_free (_tmp10_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp12_, _tmp11_);
	_g_free0 (_tmp11_);
	g_object_ref_sink (_tmp12_);
	_g_object_unref0 (self->priv->accept_btn);
	self->priv->accept_btn = _tmp12_;
	_tmp13_ = self->priv->accept_btn;
	g_signal_connect_object (_tmp13_, "clicked", (GCallback) _tuba_views_notification_requests_list_on_accept_gtk_button_clicked, self, 0);
	_tmp14_ = ((TubaViewsBase*) self)->header;
	_tmp15_ = self->priv->accept_btn;
	adw_header_bar_pack_end (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = ((TubaViewsBase*) self)->header;
	_tmp17_ = self->priv->dismiss_btn;
	adw_header_bar_pack_end (_tmp16_, (GtkWidget*) _tmp17_);
}

static void
tuba_views_notification_requests_list_on_dismiss (TubaViewsNotificationRequestsList* self)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	TubaWidgetsNotificationRequest* _tmp2_;
	TubaApplication* _tmp3_;
	TubaDialogsMainWindow* _tmp4_;
	TubaDialogsMainWindow* _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->dismiss_btn;
	_tmp1_ = self->priv->accept_btn;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, FALSE);
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
	_tmp2_ = self->priv->notification_req_wdg;
	tuba_widgets_notification_request_on_dismiss (_tmp2_);
	_tmp3_ = tuba_app;
	_tmp4_ = tuba_application_get_main_window (_tmp3_);
	_tmp5_ = _tmp4_;
	tuba_dialogs_main_window_back (_tmp5_);
}

static void
tuba_views_notification_requests_list_on_accept (TubaViewsNotificationRequestsList* self)
{
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	TubaWidgetsNotificationRequest* _tmp2_;
	TubaApplication* _tmp3_;
	TubaDialogsMainWindow* _tmp4_;
	TubaDialogsMainWindow* _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->dismiss_btn;
	_tmp1_ = self->priv->accept_btn;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp1_, FALSE);
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
	_tmp2_ = self->priv->notification_req_wdg;
	tuba_widgets_notification_request_on_accept (_tmp2_);
	_tmp3_ = tuba_app;
	_tmp4_ = tuba_application_get_main_window (_tmp3_);
	_tmp5_ = _tmp4_;
	tuba_dialogs_main_window_back (_tmp5_);
}

static void
tuba_views_notification_requests_list_class_init (TubaViewsNotificationRequestsListClass * klass,
                                                  gpointer klass_data)
{
	tuba_views_notification_requests_list_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsNotificationRequestsList_private_offset);
	((TubaViewsBaseClass *) klass)->build_header = (void (*) (TubaViewsBase*)) tuba_views_notification_requests_list_real_build_header;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_notification_requests_list_finalize;
}

static void
tuba_views_notification_requests_list_instance_init (TubaViewsNotificationRequestsList * self,
                                                     gpointer klass)
{
	self->priv = tuba_views_notification_requests_list_get_instance_private (self);
}

static void
tuba_views_notification_requests_list_finalize (GObject * obj)
{
	TubaViewsNotificationRequestsList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS_LIST, TubaViewsNotificationRequestsList);
	_g_object_unref0 (self->priv->notification_req_wdg);
	_g_object_unref0 (self->priv->dismiss_btn);
	_g_object_unref0 (self->priv->accept_btn);
	G_OBJECT_CLASS (tuba_views_notification_requests_list_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_notification_requests_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsNotificationRequestsListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_notification_requests_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsNotificationRequestsList), 0, (GInstanceInitFunc) tuba_views_notification_requests_list_instance_init, NULL };
	GType tuba_views_notification_requests_list_type_id;
	tuba_views_notification_requests_list_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsNotificationRequestsList", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsNotificationRequestsList_private_offset = g_type_add_instance_private (tuba_views_notification_requests_list_type_id, sizeof (TubaViewsNotificationRequestsListPrivate));
	return tuba_views_notification_requests_list_type_id;
}

GType
tuba_views_notification_requests_list_get_type (void)
{
	static GType tuba_views_notification_requests_list_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_notification_requests_list_type_id__once)) {
		GType tuba_views_notification_requests_list_type_id;
		tuba_views_notification_requests_list_type_id = tuba_views_notification_requests_list_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_notification_requests_list_type_id__once, tuba_views_notification_requests_list_type_id);
	}
	return tuba_views_notification_requests_list_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

