/* Report.c generated by valac 0.56.19, the Vala compiler
 * generated from Report.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>
#include <gee.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_ADMIN_TYPE_REPORT (tuba_widgets_admin_report_get_type ())
#define TUBA_WIDGETS_ADMIN_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_REPORT, TubaWidgetsAdminReport))
#define TUBA_WIDGETS_ADMIN_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_REPORT, TubaWidgetsAdminReportClass))
#define TUBA_WIDGETS_ADMIN_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_REPORT))
#define TUBA_WIDGETS_ADMIN_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_REPORT))
#define TUBA_WIDGETS_ADMIN_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_REPORT, TubaWidgetsAdminReportClass))

typedef struct _TubaWidgetsAdminReport TubaWidgetsAdminReport;
typedef struct _TubaWidgetsAdminReportClass TubaWidgetsAdminReportClass;
typedef struct _TubaWidgetsAdminReportPrivate TubaWidgetsAdminReportPrivate;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_ADMIN_TYPE_REPORT (tuba_api_admin_report_get_type ())
#define TUBA_API_ADMIN_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReport))
#define TUBA_API_ADMIN_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))
#define TUBA_API_ADMIN_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))

typedef struct _TubaAPIAdminReport TubaAPIAdminReport;
typedef struct _TubaAPIAdminReportClass TubaAPIAdminReportClass;
enum  {
	TUBA_WIDGETS_ADMIN_REPORT_0_PROPERTY,
	TUBA_WIDGETS_ADMIN_REPORT_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_admin_report_properties[TUBA_WIDGETS_ADMIN_REPORT_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_ADMIN_TYPE_ACCOUNT (tuba_api_admin_account_get_type ())
#define TUBA_API_ADMIN_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount))
#define TUBA_API_ADMIN_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))
#define TUBA_API_ADMIN_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))

typedef struct _TubaAPIAdminAccount TubaAPIAdminAccount;
typedef struct _TubaAPIAdminAccountClass TubaAPIAdminAccountClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;
enum  {
	TUBA_WIDGETS_ADMIN_REPORT_REPORT_ACTIVATED_SIGNAL,
	TUBA_WIDGETS_ADMIN_REPORT_NUM_SIGNALS
};
static guint tuba_widgets_admin_report_signals[TUBA_WIDGETS_ADMIN_REPORT_NUM_SIGNALS] = {0};

struct _TubaWidgetsAdminReport {
	AdwActionRow parent_instance;
	TubaWidgetsAdminReportPrivate * priv;
};

struct _TubaWidgetsAdminReportClass {
	AdwActionRowClass parent_class;
};

struct _TubaWidgetsAdminReportPrivate {
	TubaAPIAdminReport* report;
};

static gint TubaWidgetsAdminReport_private_offset;
static gpointer tuba_widgets_admin_report_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_admin_report_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminReport, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_admin_report_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminReport, g_object_unref)
VALA_EXTERN TubaWidgetsAdminReport* tuba_widgets_admin_report_new (TubaAPIAdminReport* report);
VALA_EXTERN TubaWidgetsAdminReport* tuba_widgets_admin_report_construct (GType object_type,
                                                             TubaAPIAdminReport* report);
static void tuba_widgets_admin_report_on_activate (TubaWidgetsAdminReport* self);
static void _tuba_widgets_admin_report_on_activate_adw_action_row_activated (AdwActionRow* _sender,
                                                                      gpointer self);
VALA_EXTERN GType tuba_api_admin_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccount, g_object_unref)
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_report_get_target_account (TubaAPIAdminReport* self);
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN TubaAPIAccount* tuba_api_admin_account_get_account (TubaAPIAdminAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
VALA_EXTERN gboolean tuba_api_admin_report_get_action_taken (TubaAPIAdminReport* self);
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_report_get_action_taken_by_account (TubaAPIAdminReport* self);
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_report_get_assigned_account (TubaAPIAdminReport* self);
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_admin_report_get_statuses (TubaAPIAdminReport* self);
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_report_get_account (TubaAPIAdminReport* self);
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_new (void);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_construct (GType object_type);
VALA_EXTERN void tuba_widgets_avatar_set_account (TubaWidgetsAvatar* self,
                                      TubaAPIAccount* value);
VALA_EXTERN void tuba_widgets_avatar_set_size (TubaWidgetsAvatar* self,
                                   gint value);
VALA_EXTERN gboolean tuba_api_admin_account_get_suspended (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_silenced (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_disabled (TubaAPIAdminAccount* self);
static void tuba_widgets_admin_report_finalize (GObject * obj);
static GType tuba_widgets_admin_report_get_type_once (void);

static inline gpointer
tuba_widgets_admin_report_get_instance_private (TubaWidgetsAdminReport* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAdminReport_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_widgets_admin_report_on_activate_adw_action_row_activated (AdwActionRow* _sender,
                                                                 gpointer self)
{
	tuba_widgets_admin_report_on_activate ((TubaWidgetsAdminReport*) self);
}

TubaWidgetsAdminReport*
tuba_widgets_admin_report_construct (GType object_type,
                                     TubaAPIAdminReport* report)
{
	TubaWidgetsAdminReport * self = NULL;
	TubaAPIAdminReport* _tmp0_;
	TubaAPIAdminAccount* _tmp1_;
	TubaAPIAdminAccount* _tmp2_;
	TubaAPIAccount* _tmp3_;
	TubaAPIAccount* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* last_line_title = NULL;
	gchar* last_line_subtitle = NULL;
	gboolean _tmp8_;
	gboolean _tmp9_;
	gint _tmp34_ = 0;
	GeeArrayList* _tmp35_;
	GeeArrayList* _tmp36_;
	TubaAPIAdminAccount* _tmp41_;
	TubaAPIAdminAccount* _tmp42_;
	TubaAPIAccount* _tmp43_;
	TubaAPIAccount* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	const gchar* _tmp48_;
	const gchar* _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	TubaAPIAdminAccount* _tmp52_;
	TubaAPIAdminAccount* _tmp53_;
	TubaAPIAccount* _tmp54_;
	TubaAPIAccount* _tmp55_;
	TubaAPIAccount* _tmp56_;
	TubaWidgetsAvatar* _tmp57_ = NULL;
	TubaWidgetsAvatar* _tmp58_;
	gchar* status = NULL;
	gchar* _tmp59_;
	gboolean _tmp60_;
	gboolean _tmp61_;
	const gchar* _tmp77_;
	GtkLabel* _tmp78_ = NULL;
	GtkLabel* _tmp79_;
	g_return_val_if_fail (report != NULL, NULL);
	self = (TubaWidgetsAdminReport*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (report);
	_g_object_unref0 (self->priv->report);
	self->priv->report = _tmp0_;
	g_signal_connect_object ((AdwActionRow*) self, "activated", (GCallback) _tuba_widgets_admin_report_on_activate_adw_action_row_activated, self, 0);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, TRUE);
	gtk_widget_set_overflow ((GtkWidget*) self, GTK_OVERFLOW_HIDDEN);
	adw_action_row_set_subtitle_lines ((AdwActionRow*) self, 0);
	_tmp1_ = tuba_api_admin_report_get_target_account (report);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_admin_account_get_account (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = tuba_api_account_get_full_handle (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _tmp6_;
	adw_preferences_row_set_title ((AdwPreferencesRow*) self, _tmp7_);
	_g_free0 (_tmp7_);
	_tmp8_ = tuba_api_admin_report_get_action_taken (report);
	_tmp9_ = _tmp8_;
	if (_tmp9_) {
		gchar* _tmp10_ = NULL;
		TubaAPIAdminAccount* _tmp11_;
		TubaAPIAdminAccount* _tmp12_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		_tmp11_ = tuba_api_admin_report_get_action_taken_by_account (report);
		_tmp12_ = _tmp11_;
		if (_tmp12_ == NULL) {
			gchar* _tmp13_;
			_tmp13_ = g_strdup (_ ("Nobody"));
			_g_free0 (_tmp10_);
			_tmp10_ = _tmp13_;
		} else {
			TubaAPIAdminAccount* _tmp14_;
			TubaAPIAdminAccount* _tmp15_;
			TubaAPIAccount* _tmp16_;
			TubaAPIAccount* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			_tmp14_ = tuba_api_admin_report_get_action_taken_by_account (report);
			_tmp15_ = _tmp14_;
			_tmp16_ = tuba_api_admin_account_get_account (_tmp15_);
			_tmp17_ = _tmp16_;
			_tmp18_ = tuba_api_account_get_full_handle (_tmp17_);
			_tmp19_ = _tmp18_;
			_g_free0 (_tmp10_);
			_tmp10_ = _tmp19_;
		}
		_tmp20_ = _tmp10_;
		_tmp10_ = NULL;
		_g_free0 (last_line_subtitle);
		last_line_subtitle = _tmp20_;
		_tmp21_ = g_strdup (_ ("Action Taken by"));
		_g_free0 (last_line_title);
		last_line_title = _tmp21_;
		_g_free0 (_tmp10_);
	} else {
		gchar* _tmp22_ = NULL;
		TubaAPIAdminAccount* _tmp23_;
		TubaAPIAdminAccount* _tmp24_;
		gchar* _tmp32_;
		gchar* _tmp33_;
		_tmp23_ = tuba_api_admin_report_get_assigned_account (report);
		_tmp24_ = _tmp23_;
		if (_tmp24_ == NULL) {
			gchar* _tmp25_;
			_tmp25_ = g_strdup (_ ("Nobody"));
			_g_free0 (_tmp22_);
			_tmp22_ = _tmp25_;
		} else {
			TubaAPIAdminAccount* _tmp26_;
			TubaAPIAdminAccount* _tmp27_;
			TubaAPIAccount* _tmp28_;
			TubaAPIAccount* _tmp29_;
			gchar* _tmp30_;
			gchar* _tmp31_;
			_tmp26_ = tuba_api_admin_report_get_assigned_account (report);
			_tmp27_ = _tmp26_;
			_tmp28_ = tuba_api_admin_account_get_account (_tmp27_);
			_tmp29_ = _tmp28_;
			_tmp30_ = tuba_api_account_get_full_handle (_tmp29_);
			_tmp31_ = _tmp30_;
			_g_free0 (_tmp22_);
			_tmp22_ = _tmp31_;
		}
		_tmp32_ = _tmp22_;
		_tmp22_ = NULL;
		_g_free0 (last_line_subtitle);
		last_line_subtitle = _tmp32_;
		_tmp33_ = g_strdup (_ ("Assigned to"));
		_g_free0 (last_line_title);
		last_line_title = _tmp33_;
		_g_free0 (_tmp22_);
	}
	_tmp35_ = tuba_api_admin_report_get_statuses (report);
	_tmp36_ = _tmp35_;
	if (_tmp36_ == NULL) {
		_tmp34_ = 0;
	} else {
		GeeArrayList* _tmp37_;
		GeeArrayList* _tmp38_;
		gint _tmp39_;
		gint _tmp40_;
		_tmp37_ = tuba_api_admin_report_get_statuses (report);
		_tmp38_ = _tmp37_;
		_tmp39_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp38_);
		_tmp40_ = _tmp39_;
		_tmp34_ = _tmp40_;
	}
	_tmp41_ = tuba_api_admin_report_get_account (report);
	_tmp42_ = _tmp41_;
	_tmp43_ = tuba_api_admin_account_get_account (_tmp42_);
	_tmp44_ = _tmp43_;
	_tmp45_ = tuba_api_account_get_full_handle (_tmp44_);
	_tmp46_ = _tmp45_;
	_tmp47_ = _tmp46_;
	_tmp48_ = last_line_title;
	_tmp49_ = last_line_subtitle;
	_tmp50_ = g_strdup_printf ("<b>%s:</b> %s\n<b>%s:</b> %d\n<b>%s:</b> %s", _ ("Reported by"), _tmp47_, _ ("Reported Posts"), _tmp34_, _tmp48_, _tmp49_);
	_tmp51_ = _tmp50_;
	adw_action_row_set_subtitle ((AdwActionRow*) self, _tmp51_);
	_g_free0 (_tmp51_);
	_g_free0 (_tmp47_);
	_tmp52_ = tuba_api_admin_report_get_target_account (report);
	_tmp53_ = _tmp52_;
	_tmp54_ = tuba_api_admin_account_get_account (_tmp53_);
	_tmp55_ = _tmp54_;
	_tmp56_ = _g_object_ref0 (_tmp55_);
	_tmp57_ = tuba_widgets_avatar_new ();
	tuba_widgets_avatar_set_account (_tmp57_, _tmp56_);
	_g_object_unref0 (_tmp56_);
	tuba_widgets_avatar_set_size (_tmp57_, 48);
	gtk_widget_set_overflow ((GtkWidget*) _tmp57_, GTK_OVERFLOW_HIDDEN);
	g_object_ref_sink (_tmp57_);
	_tmp58_ = _tmp57_;
	adw_action_row_add_prefix ((AdwActionRow*) self, (GtkWidget*) _tmp58_);
	_g_object_unref0 (_tmp58_);
	_tmp59_ = g_strdup (_ ("No Limits"));
	status = _tmp59_;
	_tmp60_ = tuba_api_admin_report_get_action_taken (report);
	_tmp61_ = _tmp60_;
	if (_tmp61_) {
		TubaAPIAdminAccount* _tmp62_;
		TubaAPIAdminAccount* _tmp63_;
		gboolean _tmp64_;
		gboolean _tmp65_;
		_tmp62_ = tuba_api_admin_report_get_target_account (report);
		_tmp63_ = _tmp62_;
		_tmp64_ = tuba_api_admin_account_get_suspended (_tmp63_);
		_tmp65_ = _tmp64_;
		if (_tmp65_) {
			gchar* _tmp66_;
			_tmp66_ = g_strdup (_ ("Suspended"));
			_g_free0 (status);
			status = _tmp66_;
		} else {
			TubaAPIAdminAccount* _tmp67_;
			TubaAPIAdminAccount* _tmp68_;
			gboolean _tmp69_;
			gboolean _tmp70_;
			_tmp67_ = tuba_api_admin_report_get_target_account (report);
			_tmp68_ = _tmp67_;
			_tmp69_ = tuba_api_admin_account_get_silenced (_tmp68_);
			_tmp70_ = _tmp69_;
			if (_tmp70_) {
				gchar* _tmp71_;
				_tmp71_ = g_strdup (_ ("Limited"));
				_g_free0 (status);
				status = _tmp71_;
			} else {
				TubaAPIAdminAccount* _tmp72_;
				TubaAPIAdminAccount* _tmp73_;
				gboolean _tmp74_;
				gboolean _tmp75_;
				_tmp72_ = tuba_api_admin_report_get_target_account (report);
				_tmp73_ = _tmp72_;
				_tmp74_ = tuba_api_admin_account_get_disabled (_tmp73_);
				_tmp75_ = _tmp74_;
				if (_tmp75_) {
					gchar* _tmp76_;
					_tmp76_ = g_strdup (_ ("Disabled"));
					_g_free0 (status);
					status = _tmp76_;
				}
			}
		}
	}
	_tmp77_ = status;
	_tmp78_ = (GtkLabel*) gtk_label_new (_tmp77_);
	gtk_label_set_xalign (_tmp78_, 1.0f);
	gtk_label_set_wrap (_tmp78_, TRUE);
	gtk_label_set_wrap_mode (_tmp78_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp78_, TRUE);
	g_object_ref_sink (_tmp78_);
	_tmp79_ = _tmp78_;
	adw_action_row_add_suffix ((AdwActionRow*) self, (GtkWidget*) _tmp79_);
	_g_object_unref0 (_tmp79_);
	_g_free0 (status);
	_g_free0 (last_line_subtitle);
	_g_free0 (last_line_title);
	return self;
}

TubaWidgetsAdminReport*
tuba_widgets_admin_report_new (TubaAPIAdminReport* report)
{
	return tuba_widgets_admin_report_construct (TUBA_WIDGETS_ADMIN_TYPE_REPORT, report);
}

static void
tuba_widgets_admin_report_on_activate (TubaWidgetsAdminReport* self)
{
	TubaAPIAdminReport* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->report;
	g_signal_emit (self, tuba_widgets_admin_report_signals[TUBA_WIDGETS_ADMIN_REPORT_REPORT_ACTIVATED_SIGNAL], 0, _tmp0_);
}

static void
tuba_widgets_admin_report_class_init (TubaWidgetsAdminReportClass * klass,
                                      gpointer klass_data)
{
	tuba_widgets_admin_report_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAdminReport_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_admin_report_finalize;
	tuba_widgets_admin_report_signals[TUBA_WIDGETS_ADMIN_REPORT_REPORT_ACTIVATED_SIGNAL] = g_signal_new ("report-activated", TUBA_WIDGETS_ADMIN_TYPE_REPORT, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_API_ADMIN_TYPE_REPORT);
}

static void
tuba_widgets_admin_report_instance_init (TubaWidgetsAdminReport * self,
                                         gpointer klass)
{
	self->priv = tuba_widgets_admin_report_get_instance_private (self);
}

static void
tuba_widgets_admin_report_finalize (GObject * obj)
{
	TubaWidgetsAdminReport * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ADMIN_TYPE_REPORT, TubaWidgetsAdminReport);
	g_debug ("Report.vala:5: Destroying Report");
	_g_object_unref0 (self->priv->report);
	G_OBJECT_CLASS (tuba_widgets_admin_report_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_admin_report_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAdminReportClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_admin_report_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAdminReport), 0, (GInstanceInitFunc) tuba_widgets_admin_report_instance_init, NULL };
	GType tuba_widgets_admin_report_type_id;
	tuba_widgets_admin_report_type_id = g_type_register_static (adw_action_row_get_type (), "TubaWidgetsAdminReport", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAdminReport_private_offset = g_type_add_instance_private (tuba_widgets_admin_report_type_id, sizeof (TubaWidgetsAdminReportPrivate));
	return tuba_widgets_admin_report_type_id;
}

GType
tuba_widgets_admin_report_get_type (void)
{
	static GType tuba_widgets_admin_report_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_admin_report_type_id__once)) {
		GType tuba_widgets_admin_report_type_id;
		tuba_widgets_admin_report_type_id = tuba_widgets_admin_report_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_admin_report_type_id__once, tuba_widgets_admin_report_type_id);
	}
	return tuba_widgets_admin_report_type_id__once;
}

