/* AccountSuggestions.c generated by valac 0.56.19, the Vala compiler
 * generated from AccountSuggestions.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <glib.h>
#include <float.h>
#include <math.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS (tuba_widgets_account_suggestions_get_type ())
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS, TubaWidgetsAccountSuggestions))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS, TubaWidgetsAccountSuggestionsClass))
#define TUBA_WIDGETS_IS_ACCOUNT_SUGGESTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS))
#define TUBA_WIDGETS_IS_ACCOUNT_SUGGESTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS, TubaWidgetsAccountSuggestionsClass))

typedef struct _TubaWidgetsAccountSuggestions TubaWidgetsAccountSuggestions;
typedef struct _TubaWidgetsAccountSuggestionsClass TubaWidgetsAccountSuggestionsClass;
typedef struct _TubaWidgetsAccountSuggestionsPrivate TubaWidgetsAccountSuggestionsPrivate;
enum  {
	TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_0_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_account_suggestions_properties[TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION (tuba_widgets_account_suggestions_account_suggestion_get_type ())
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, TubaWidgetsAccountSuggestionsAccountSuggestion))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, TubaWidgetsAccountSuggestionsAccountSuggestionClass))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_IS_ACCOUNT_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_IS_ACCOUNT_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION))
#define TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, TubaWidgetsAccountSuggestionsAccountSuggestionClass))

typedef struct _TubaWidgetsAccountSuggestionsAccountSuggestion TubaWidgetsAccountSuggestionsAccountSuggestion;
typedef struct _TubaWidgetsAccountSuggestionsAccountSuggestionClass TubaWidgetsAccountSuggestionsAccountSuggestionClass;
typedef struct _Block87Data Block87Data;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
typedef void (*TubaNetworkNodeCallback) (JsonNode* node, gpointer user_data, GError** error);

#define TUBA_API_TYPE_SUGGESTION (tuba_api_suggestion_get_type ())
#define TUBA_API_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestion))
#define TUBA_API_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestionClass))
#define TUBA_API_IS_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SUGGESTION))
#define TUBA_API_IS_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SUGGESTION))
#define TUBA_API_SUGGESTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestionClass))

typedef struct _TubaAPISuggestion TubaAPISuggestion;
typedef struct _TubaAPISuggestionClass TubaAPISuggestionClass;
typedef struct _TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData;
typedef struct _Block88Data Block88Data;

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;
typedef struct _TubaWidgetsAccountSuggestionsAccountSuggestionPrivate TubaWidgetsAccountSuggestionsAccountSuggestionPrivate;

#define TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON (tuba_widgets_relationship_button_get_type ())
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButton))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))

typedef struct _TubaWidgetsRelationshipButton TubaWidgetsRelationshipButton;
typedef struct _TubaWidgetsRelationshipButtonClass TubaWidgetsRelationshipButtonClass;
enum  {
	TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION_0_PROPERTY,
	TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_account_suggestions_account_suggestion_properties[TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_ACCOUNT_SUGGESTION_NUM_PROPERTIES];

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS (tuba_widgets_label_with_widgets_get_type ())
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgets))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_IS_LABEL_WITH_WIDGETS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS))
#define TUBA_WIDGETS_LABEL_WITH_WIDGETS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LABEL_WITH_WIDGETS, TubaWidgetsLabelWithWidgetsClass))

typedef struct _TubaWidgetsLabelWithWidgets TubaWidgetsLabelWithWidgets;
typedef struct _TubaWidgetsLabelWithWidgetsClass TubaWidgetsLabelWithWidgetsClass;

#define TUBA_WIDGETS_TYPE_EMOJI_LABEL (tuba_widgets_emoji_label_get_type ())
#define TUBA_WIDGETS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabel))
#define TUBA_WIDGETS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))
#define TUBA_WIDGETS_IS_EMOJI_LABEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_IS_EMOJI_LABEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_EMOJI_LABEL))
#define TUBA_WIDGETS_EMOJI_LABEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_EMOJI_LABEL, TubaWidgetsEmojiLabelClass))

typedef struct _TubaWidgetsEmojiLabel TubaWidgetsEmojiLabel;
typedef struct _TubaWidgetsEmojiLabelClass TubaWidgetsEmojiLabelClass;

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

struct _TubaWidgetsAccountSuggestions {
	GtkListBoxRow parent_instance;
	TubaWidgetsAccountSuggestionsPrivate * priv;
};

struct _TubaWidgetsAccountSuggestionsClass {
	GtkListBoxRowClass parent_class;
};

struct _TubaWidgetsAccountSuggestionsPrivate {
	GtkScrolledWindow* scrolled_window;
	GtkBox* account_box;
	GtkButton* back_button;
	GtkButton* next_button;
};

struct _Block87Data {
	int _ref_count_;
	TubaWidgetsAccountSuggestions* self;
	GeeHashMap* widgets;
	GtkWidget* last_sep;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaWidgetsAccountSuggestions* self;
	TubaRequestV2* req;
	TubaAccountStore* _tmp0_;
	TubaInstanceAccount* _tmp1_;
	TubaInstanceAccount* _tmp2_;
	TubaInstanceAccount* _tmp3_;
	TubaRequestV2* _tmp4_;
	TubaRequestV2* _tmp5_;
	Block87Data* _data87_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp6_;
	GInputStream* _tmp7_;
	JsonParser* parser;
	GInputStream* _tmp8_;
	JsonParser* _tmp9_;
	GeeHashMap* _tmp10_;
	JsonParser* _tmp11_;
	GtkWidget* _tmp12_;
	GtkBox* _tmp13_;
	GtkWidget* _tmp14_;
	GeeHashMap* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	GeeHashMap* _tmp18_;
	GError* _inner_error0_;
};

struct _Block88Data {
	int _ref_count_;
	TubaWidgetsAccountSuggestions* self;
	GeeHashMap* account_widgets;
};

struct _TubaWidgetsAccountSuggestionsAccountSuggestion {
	GtkBox parent_instance;
	TubaWidgetsAccountSuggestionsAccountSuggestionPrivate * priv;
};

struct _TubaWidgetsAccountSuggestionsAccountSuggestionClass {
	GtkBoxClass parent_class;
};

struct _TubaWidgetsAccountSuggestionsAccountSuggestionPrivate {
	TubaWidgetsRelationshipButton* rsbtn;
	TubaAPIAccount* acc;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

static gint TubaWidgetsAccountSuggestions_private_offset;
static gpointer tuba_widgets_account_suggestions_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaSettings* tuba_settings;
static gint TubaWidgetsAccountSuggestionsAccountSuggestion_private_offset;
static gpointer tuba_widgets_account_suggestions_account_suggestion_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_account_suggestions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccountSuggestions, g_object_unref)
static void tuba_widgets_account_suggestions_next_page (TubaWidgetsAccountSuggestions* self);
static void tuba_widgets_account_suggestions_prev_page (TubaWidgetsAccountSuggestions* self);
static void tuba_widgets_account_suggestions_populate_account_suggestions_data_free (gpointer _data);
static void tuba_widgets_account_suggestions_populate_account_suggestions (TubaWidgetsAccountSuggestions* self,
                                                                    GAsyncReadyCallback _callback_,
                                                                    gpointer _user_data_);
static void tuba_widgets_account_suggestions_populate_account_suggestions_finish (TubaWidgetsAccountSuggestions* self,
                                                                           GAsyncResult* _res_);
static gboolean tuba_widgets_account_suggestions_populate_account_suggestions_co (TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_add_parameter (TubaRequestV2* self,
                                    const gchar* key,
                                    const gchar* value);
VALA_EXTERN GType tuba_widgets_account_suggestions_account_suggestion_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAccountSuggestionsAccountSuggestion, g_object_unref)
static Block87Data* block87_data_ref (Block87Data* _data87_);
static void block87_data_unref (void * _userdata_);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_widgets_account_suggestions_populate_account_suggestions_ready (GObject* source_object,
                                                                          GAsyncResult* _res_,
                                                                          gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void tuba_network_parse_array (JsonParser* parser,
                               TubaNetworkNodeCallback cb,
                               gpointer cb_target,
                               GDestroyNotify cb_target_destroy_notify,
                               GError** error);
static void ___lambda210_ (Block87Data* _data87_,
                    JsonNode* node,
                    GError** error);
VALA_EXTERN GType tuba_api_suggestion_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPISuggestion, g_object_unref)
VALA_EXTERN TubaEntity* tuba_helper_entity_from_json (JsonNode* node,
                                          GType type,
                                          gboolean force);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
VALA_EXTERN TubaAPIAccount* tuba_api_suggestion_get_account (TubaAPISuggestion* self);
VALA_EXTERN TubaWidgetsAccountSuggestionsAccountSuggestion* tuba_widgets_account_suggestions_account_suggestion_new (TubaAPIAccount* acc);
VALA_EXTERN TubaWidgetsAccountSuggestionsAccountSuggestion* tuba_widgets_account_suggestions_account_suggestion_construct (GType object_type,
                                                                                                               TubaAPIAccount* acc);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
static void ____lambda210__tuba_network_node_callback (JsonNode* node,
                                                gpointer self,
                                                GError** error);
static gboolean tuba_widgets_account_suggestions_populate_account_suggestions_relationships (TubaWidgetsAccountSuggestions* self,
                                                                                      GeeHashMap* account_widgets);
static void tuba_widgets_account_suggestions_on_page_changed (TubaWidgetsAccountSuggestions* self);
static Block88Data* block88_data_ref (Block88Data* _data88_);
static void block88_data_unref (void * _userdata_);
VALA_EXTERN void tuba_api_relationship_request_many (gchar** ids,
                                         gint ids_length1,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN GeeHashMap* tuba_api_relationship_request_many_finish (GAsyncResult* _res_,
                                                       GError** error);
static void __lambda211_ (Block88Data* _data88_,
                   GObject* obj,
                   GAsyncResult* res);
static gboolean ____lambda212_ (Block88Data* _data88_,
                         GeeMapEntry* e);
VALA_EXTERN void tuba_widgets_account_suggestions_account_suggestion_update_rs (TubaWidgetsAccountSuggestionsAccountSuggestion* self,
                                                                    TubaAPIRelationship* new_rs);
static gboolean _____lambda212__gee_forall_func (gpointer g,
                                          gpointer self);
static void ___lambda211__gasync_ready_callback (GObject* source_object,
                                          GAsyncResult* res,
                                          gpointer self);
static void tuba_widgets_account_suggestions_on_dra_clicked (TubaWidgetsAccountSuggestions* self);
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN void tuba_settings_set_account_suggestions (TubaSettings* self,
                                            gboolean value);
VALA_EXTERN TubaWidgetsAccountSuggestions* tuba_widgets_account_suggestions_new (void);
VALA_EXTERN TubaWidgetsAccountSuggestions* tuba_widgets_account_suggestions_construct (GType object_type);
VALA_EXTERN GType tuba_widgets_relationship_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsRelationshipButton, g_object_unref)
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_new (void);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_construct (GType object_type);
VALA_EXTERN void tuba_widgets_avatar_set_account (TubaWidgetsAvatar* self,
                                      TubaAPIAccount* value);
VALA_EXTERN void tuba_widgets_avatar_set_size (TubaWidgetsAvatar* self,
                                   gint value);
static void tuba_widgets_account_suggestions_account_suggestion_on_clicked (TubaWidgetsAccountSuggestionsAccountSuggestion* self);
static void _tuba_widgets_account_suggestions_account_suggestion_on_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                         gpointer self);
VALA_EXTERN GType tuba_widgets_label_with_widgets_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsLabelWithWidgets, g_object_unref)
VALA_EXTERN GType tuba_widgets_emoji_label_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsEmojiLabel, g_object_unref)
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN TubaWidgetsEmojiLabel* tuba_widgets_emoji_label_new (const gchar* text,
                                                     GeeHashMap* emojis);
VALA_EXTERN TubaWidgetsEmojiLabel* tuba_widgets_emoji_label_construct (GType object_type,
                                                           const gchar* text,
                                                           GeeHashMap* emojis);
VALA_EXTERN void tuba_widgets_label_with_widgets_set_use_markup (TubaWidgetsLabelWithWidgets* self,
                                                     gboolean value);
VALA_EXTERN void tuba_widgets_label_with_widgets_set_ellipsize (TubaWidgetsLabelWithWidgets* self,
                                                    gboolean value);
VALA_EXTERN GeeHashMap* tuba_api_account_get_emojis_map (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_emoji_label_set_instance_emojis (TubaWidgetsEmojiLabel* self,
                                                   GeeHashMap* value);
VALA_EXTERN void tuba_widgets_emoji_label_set_content (TubaWidgetsEmojiLabel* self,
                                           const gchar* value);
VALA_EXTERN TubaWidgetsRelationshipButton* tuba_widgets_relationship_button_new (void);
VALA_EXTERN TubaWidgetsRelationshipButton* tuba_widgets_relationship_button_construct (GType object_type);
VALA_EXTERN void tuba_widgets_relationship_button_set_handle (TubaWidgetsRelationshipButton* self,
                                                  const gchar* value);
VALA_EXTERN void tuba_widgets_relationship_button_set_rs (TubaWidgetsRelationshipButton* self,
                                              TubaAPIRelationship* value);
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static void tuba_widgets_account_suggestions_account_suggestion_finalize (GObject * obj);
static GType tuba_widgets_account_suggestions_account_suggestion_get_type_once (void);
static GObject * tuba_widgets_account_suggestions_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
static void _tuba_widgets_account_suggestions_prev_page_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self);
static void _tuba_widgets_account_suggestions_next_page_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self);
static void _tuba_widgets_account_suggestions_on_dra_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                          gpointer self);
static void _tuba_widgets_account_suggestions_on_page_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                                     gpointer self);
static void tuba_widgets_account_suggestions_finalize (GObject * obj);
static GType tuba_widgets_account_suggestions_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_widgets_account_suggestions_get_instance_private (TubaWidgetsAccountSuggestions* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAccountSuggestions_private_offset);
}

static void
tuba_widgets_account_suggestions_next_page (TubaWidgetsAccountSuggestions* self)
{
	gdouble new_val = 0.0;
	GtkScrolledWindow* _tmp0_;
	GtkAdjustment* _tmp1_;
	GtkAdjustment* _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
	GtkScrolledWindow* _tmp5_;
	GtkAdjustment* _tmp6_;
	GtkAdjustment* _tmp7_;
	gdouble _tmp8_;
	gdouble _tmp9_;
	gdouble end = 0.0;
	GtkScrolledWindow* _tmp10_;
	GtkAdjustment* _tmp11_;
	GtkAdjustment* _tmp12_;
	gdouble _tmp13_;
	gdouble _tmp14_;
	GtkScrolledWindow* _tmp15_;
	GtkAdjustment* _tmp16_;
	GtkAdjustment* _tmp17_;
	gdouble _tmp18_;
	gdouble _tmp19_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->scrolled_window;
	_tmp1_ = gtk_scrolled_window_get_hadjustment (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = self->priv->scrolled_window;
	_tmp6_ = gtk_scrolled_window_get_hadjustment (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gtk_adjustment_get_page_increment (_tmp7_);
	_tmp9_ = _tmp8_;
	new_val = _tmp4_ + (_tmp9_ / 2);
	_tmp10_ = self->priv->scrolled_window;
	_tmp11_ = gtk_scrolled_window_get_hadjustment (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = gtk_adjustment_get_upper (_tmp12_);
	_tmp14_ = _tmp13_;
	_tmp15_ = self->priv->scrolled_window;
	_tmp16_ = gtk_scrolled_window_get_hadjustment (_tmp15_);
	_tmp17_ = _tmp16_;
	_tmp18_ = gtk_adjustment_get_page_size (_tmp17_);
	_tmp19_ = _tmp18_;
	end = _tmp14_ - _tmp19_;
	if ((new_val + 42) > end) {
		GtkScrolledWindow* _tmp20_;
		GtkAdjustment* _tmp21_;
		GtkAdjustment* _tmp22_;
		_tmp20_ = self->priv->scrolled_window;
		_tmp21_ = gtk_scrolled_window_get_hadjustment (_tmp20_);
		_tmp22_ = _tmp21_;
		gtk_adjustment_set_value (_tmp22_, end);
	} else {
		GtkScrolledWindow* _tmp23_;
		GtkAdjustment* _tmp24_;
		GtkAdjustment* _tmp25_;
		_tmp23_ = self->priv->scrolled_window;
		_tmp24_ = gtk_scrolled_window_get_hadjustment (_tmp23_);
		_tmp25_ = _tmp24_;
		gtk_adjustment_set_value (_tmp25_, new_val);
	}
}

static void
tuba_widgets_account_suggestions_prev_page (TubaWidgetsAccountSuggestions* self)
{
	gdouble new_val = 0.0;
	GtkScrolledWindow* _tmp0_;
	GtkAdjustment* _tmp1_;
	GtkAdjustment* _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
	GtkScrolledWindow* _tmp5_;
	GtkAdjustment* _tmp6_;
	GtkAdjustment* _tmp7_;
	gdouble _tmp8_;
	gdouble _tmp9_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->scrolled_window;
	_tmp1_ = gtk_scrolled_window_get_hadjustment (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = gtk_adjustment_get_value (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = self->priv->scrolled_window;
	_tmp6_ = gtk_scrolled_window_get_hadjustment (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = gtk_adjustment_get_page_increment (_tmp7_);
	_tmp9_ = _tmp8_;
	new_val = _tmp4_ - (_tmp9_ / 2);
	if ((new_val - 42) < ((gdouble) 0)) {
		GtkScrolledWindow* _tmp10_;
		GtkAdjustment* _tmp11_;
		GtkAdjustment* _tmp12_;
		_tmp10_ = self->priv->scrolled_window;
		_tmp11_ = gtk_scrolled_window_get_hadjustment (_tmp10_);
		_tmp12_ = _tmp11_;
		gtk_adjustment_set_value (_tmp12_, (gdouble) 0);
	} else {
		GtkScrolledWindow* _tmp13_;
		GtkAdjustment* _tmp14_;
		GtkAdjustment* _tmp15_;
		_tmp13_ = self->priv->scrolled_window;
		_tmp14_ = gtk_scrolled_window_get_hadjustment (_tmp13_);
		_tmp15_ = _tmp14_;
		gtk_adjustment_set_value (_tmp15_, new_val);
	}
}

static void
tuba_widgets_account_suggestions_populate_account_suggestions_data_free (gpointer _data)
{
	TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_widgets_account_suggestions_populate_account_suggestions (TubaWidgetsAccountSuggestions* self,
                                                               GAsyncReadyCallback _callback_,
                                                               gpointer _user_data_)
{
	TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_;
	TubaWidgetsAccountSuggestions* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_widgets_account_suggestions_populate_account_suggestions_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_widgets_account_suggestions_populate_account_suggestions_co (_data_);
}

static void
tuba_widgets_account_suggestions_populate_account_suggestions_finish (TubaWidgetsAccountSuggestions* self,
                                                                      GAsyncResult* _res_)
{
	TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block87Data*
block87_data_ref (Block87Data* _data87_)
{
	g_atomic_int_inc (&_data87_->_ref_count_);
	return _data87_;
}

static void
block87_data_unref (void * _userdata_)
{
	Block87Data* _data87_;
	_data87_ = (Block87Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data87_->_ref_count_)) {
		TubaWidgetsAccountSuggestions* self;
		self = _data87_->self;
		_g_object_unref0 (_data87_->last_sep);
		_g_object_unref0 (_data87_->widgets);
		_g_object_unref0 (self);
		g_slice_free (Block87Data, _data87_);
	}
}

static void
tuba_widgets_account_suggestions_populate_account_suggestions_ready (GObject* source_object,
                                                                     GAsyncResult* _res_,
                                                                     gpointer _user_data_)
{
	TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_widgets_account_suggestions_populate_account_suggestions_co (_data_);
}

static JsonNode*
_vala_JsonNode_copy (JsonNode* self)
{
	return g_boxed_copy (json_node_get_type (), self);
}

static gpointer
__vala_JsonNode_copy0 (gpointer self)
{
	return self ? _vala_JsonNode_copy (self) : NULL;
}

static void
___lambda210_ (Block87Data* _data87_,
               JsonNode* node,
               GError** error)
{
	TubaWidgetsAccountSuggestions* self;
	TubaAPISuggestion* entity = NULL;
	JsonNode* _tmp0_;
	TubaEntity* _tmp1_;
	TubaAPISuggestion* _tmp2_;
	TubaAPISuggestion* _tmp3_;
	self = _data87_->self;
	g_return_if_fail (node != NULL);
	_tmp0_ = __vala_JsonNode_copy0 (node);
	_tmp1_ = tuba_helper_entity_from_json (_tmp0_, TUBA_API_TYPE_SUGGESTION, FALSE);
	_tmp2_ = TUBA_API_IS_SUGGESTION (_tmp1_) ? ((TubaAPISuggestion*) _tmp1_) : NULL;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (_tmp1_);
	}
	entity = _tmp2_;
	_tmp3_ = entity;
	if (_tmp3_ != NULL) {
		TubaWidgetsAccountSuggestionsAccountSuggestion* widget = NULL;
		TubaAPISuggestion* _tmp4_;
		TubaAPIAccount* _tmp5_;
		TubaAPIAccount* _tmp6_;
		TubaWidgetsAccountSuggestionsAccountSuggestion* _tmp7_;
		GeeHashMap* _tmp8_;
		TubaAPISuggestion* _tmp9_;
		TubaAPIAccount* _tmp10_;
		TubaAPIAccount* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		TubaWidgetsAccountSuggestionsAccountSuggestion* _tmp14_;
		GtkBox* _tmp15_;
		TubaWidgetsAccountSuggestionsAccountSuggestion* _tmp16_;
		GtkSeparator* _tmp17_;
		GtkBox* _tmp18_;
		GtkWidget* _tmp19_;
		_tmp4_ = entity;
		_tmp5_ = tuba_api_suggestion_get_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TUBA_API_TYPE_SUGGESTION, TubaAPISuggestion));
		_tmp6_ = _tmp5_;
		_tmp7_ = tuba_widgets_account_suggestions_account_suggestion_new (_tmp6_);
		g_object_ref_sink (_tmp7_);
		widget = _tmp7_;
		_tmp8_ = _data87_->widgets;
		_tmp9_ = entity;
		_tmp10_ = tuba_api_suggestion_get_account (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, TUBA_API_TYPE_SUGGESTION, TubaAPISuggestion));
		_tmp11_ = _tmp10_;
		_tmp12_ = tuba_api_account_get_id (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = widget;
		gee_abstract_map_set ((GeeAbstractMap*) _tmp8_, _tmp13_, _tmp14_);
		_tmp15_ = self->priv->account_box;
		_tmp16_ = widget;
		gtk_box_append (_tmp15_, (GtkWidget*) _tmp16_);
		_tmp17_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_VERTICAL);
		g_object_ref_sink (_tmp17_);
		_g_object_unref0 (_data87_->last_sep);
		_data87_->last_sep = (GtkWidget*) _tmp17_;
		_tmp18_ = self->priv->account_box;
		_tmp19_ = _data87_->last_sep;
		gtk_box_append (_tmp18_, _tmp19_);
		_g_object_unref0 (widget);
	}
	_g_object_unref0 (entity);
}

static void
____lambda210__tuba_network_node_callback (JsonNode* node,
                                           gpointer self,
                                           GError** error)
{
	___lambda210_ (self, node, error);
}

static gboolean
tuba_widgets_account_suggestions_populate_account_suggestions_co (TubaWidgetsAccountSuggestionsPopulateAccountSuggestionsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = tuba_accounts;
	_data_->_tmp1_ = tuba_account_store_get_active (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = _g_object_ref0 (_data_->_tmp2_);
	_data_->_tmp4_ = NULL;
	_data_->_tmp4_ = tuba_request_v2_new ("/api/v2/suggestions", TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_data_->_tmp4_, _data_->_tmp3_);
	_g_object_unref0 (_data_->_tmp3_);
	_data_->req = _data_->_tmp4_;
	_data_->_tmp5_ = _data_->req;
	tuba_request_v2_add_parameter (_data_->_tmp5_, "limit", "10");
	{
		_data_->_data87_ = g_slice_new0 (Block87Data);
		_data_->_data87_->_ref_count_ = 1;
		_data_->_data87_->self = g_object_ref (_data_->self);
		_data_->_tmp6_ = _data_->req;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp6_, tuba_widgets_account_suggestions_populate_account_suggestions_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp7_ = tuba_request_v2_exec_finish (_data_->_tmp6_, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->in_stream = _data_->_tmp7_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			block87_data_unref (_data_->_data87_);
			_data_->_data87_ = NULL;
			goto __catch0_g_error;
		}
		_data_->_tmp8_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp8_, NULL, tuba_widgets_account_suggestions_populate_account_suggestions_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp9_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp9_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->in_stream);
			block87_data_unref (_data_->_data87_);
			_data_->_data87_ = NULL;
			goto __catch0_g_error;
		}
		_data_->_tmp10_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
		_data_->_data87_->widgets = _data_->_tmp10_;
		_data_->_data87_->last_sep = NULL;
		_data_->_tmp11_ = _data_->parser;
		tuba_network_parse_array (_data_->_tmp11_, ____lambda210__tuba_network_node_callback, block87_data_ref (_data_->_data87_), block87_data_unref, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			block87_data_unref (_data_->_data87_);
			_data_->_data87_ = NULL;
			goto __catch0_g_error;
		}
		_data_->_tmp12_ = _data_->_data87_->last_sep;
		if (_data_->_tmp12_ != NULL) {
			_data_->_tmp13_ = _data_->self->priv->account_box;
			_data_->_tmp14_ = _data_->_data87_->last_sep;
			gtk_box_remove (_data_->_tmp13_, _data_->_tmp14_);
		}
		_data_->_tmp15_ = _data_->_data87_->widgets;
		_data_->_tmp16_ = gee_abstract_map_get_size ((GeeAbstractMap*) _data_->_tmp15_);
		_data_->_tmp17_ = _data_->_tmp16_;
		if (_data_->_tmp17_ > 0) {
			gtk_widget_set_visible ((GtkWidget*) _data_->self, TRUE);
			_data_->_tmp18_ = _data_->_data87_->widgets;
			tuba_widgets_account_suggestions_populate_account_suggestions_relationships (_data_->self, _data_->_tmp18_);
		} else {
			gtk_widget_set_visible ((GtkWidget*) _data_->self, FALSE);
		}
		tuba_widgets_account_suggestions_on_page_changed (_data_->self);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
		block87_data_unref (_data_->_data87_);
		_data_->_data87_ = NULL;
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_data_->_inner_error0_);
		gtk_widget_set_visible ((GtkWidget*) _data_->self, FALSE);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static Block88Data*
block88_data_ref (Block88Data* _data88_)
{
	g_atomic_int_inc (&_data88_->_ref_count_);
	return _data88_;
}

static void
block88_data_unref (void * _userdata_)
{
	Block88Data* _data88_;
	_data88_ = (Block88Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data88_->_ref_count_)) {
		TubaWidgetsAccountSuggestions* self;
		self = _data88_->self;
		_g_object_unref0 (_data88_->account_widgets);
		_g_object_unref0 (self);
		g_slice_free (Block88Data, _data88_);
	}
}

static gboolean
____lambda212_ (Block88Data* _data88_,
                GeeMapEntry* e)
{
	TubaWidgetsAccountSuggestions* self;
	gconstpointer _tmp0_;
	gconstpointer _tmp1_;
	gboolean result;
	self = _data88_->self;
	g_return_val_if_fail (e != NULL, FALSE);
	_tmp0_ = gee_map_entry_get_key (e);
	_tmp1_ = _tmp0_;
	if (gee_abstract_map_has_key ((GeeAbstractMap*) _data88_->account_widgets, (const gchar*) _tmp1_)) {
		gconstpointer _tmp2_;
		gconstpointer _tmp3_;
		gpointer _tmp4_;
		TubaWidgetsAccountSuggestionsAccountSuggestion* _tmp5_;
		gconstpointer _tmp6_;
		gconstpointer _tmp7_;
		_tmp2_ = gee_map_entry_get_key (e);
		_tmp3_ = _tmp2_;
		_tmp4_ = gee_abstract_map_get ((GeeAbstractMap*) _data88_->account_widgets, (const gchar*) _tmp3_);
		_tmp5_ = (TubaWidgetsAccountSuggestionsAccountSuggestion*) _tmp4_;
		_tmp6_ = gee_map_entry_get_value (e);
		_tmp7_ = _tmp6_;
		tuba_widgets_account_suggestions_account_suggestion_update_rs (_tmp5_, (TubaAPIRelationship*) _tmp7_);
		_g_object_unref0 (_tmp5_);
	}
	result = TRUE;
	_g_object_unref0 (e);
	return result;
}

static gboolean
_____lambda212__gee_forall_func (gpointer g,
                                 gpointer self)
{
	gboolean result;
	result = ____lambda212_ (self, (GeeMapEntry*) g);
	return result;
}

static void
__lambda211_ (Block88Data* _data88_,
              GObject* obj,
              GAsyncResult* res)
{
	TubaWidgetsAccountSuggestions* self;
	GError* _inner_error0_ = NULL;
	self = _data88_->self;
	g_return_if_fail (res != NULL);
	{
		GeeHashMap* relationships = NULL;
		GeeHashMap* _tmp0_;
		gint _tmp1_;
		gint _tmp2_;
		_tmp0_ = tuba_api_relationship_request_many_finish (res, &_inner_error0_);
		relationships = _tmp0_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_tmp1_ = gee_abstract_map_get_size ((GeeAbstractMap*) relationships);
		_tmp2_ = _tmp1_;
		if (_tmp2_ > 0) {
			gee_abstract_map_foreach ((GeeAbstractMap*) relationships, _____lambda212__gee_forall_func, _data88_);
			gee_abstract_map_clear ((GeeAbstractMap*) _data88_->account_widgets);
			tuba_widgets_account_suggestions_on_page_changed (self);
		}
		_g_object_unref0 (relationships);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp3_ = e;
		_tmp4_ = _tmp3_->message;
		g_warning ("AccountSuggestions.vala:206: %s", _tmp4_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
___lambda211__gasync_ready_callback (GObject* source_object,
                                     GAsyncResult* res,
                                     gpointer self)
{
	__lambda211_ (self, source_object, res);
	block88_data_unref (self);
}

static gboolean
tuba_widgets_account_suggestions_populate_account_suggestions_relationships (TubaWidgetsAccountSuggestions* self,
                                                                             GeeHashMap* account_widgets)
{
	Block88Data* _data88_;
	GeeHashMap* _tmp0_;
	GeeSet* _tmp1_;
	GeeSet* _tmp2_;
	GeeSet* _tmp3_;
	gint _tmp4_ = 0;
	gpointer* _tmp5_;
	gchar** _tmp6_;
	gint _tmp6__length1;
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (account_widgets != NULL, FALSE);
	_data88_ = g_slice_new0 (Block88Data);
	_data88_->_ref_count_ = 1;
	_data88_->self = g_object_ref (self);
	_tmp0_ = _g_object_ref0 (account_widgets);
	_g_object_unref0 (_data88_->account_widgets);
	_data88_->account_widgets = _tmp0_;
	_tmp1_ = gee_abstract_map_get_keys ((GeeAbstractMap*) _data88_->account_widgets);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp5_ = gee_collection_to_array ((GeeCollection*) _tmp3_, &_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp6__length1 = _tmp4_;
	tuba_api_relationship_request_many (_tmp6_, (gint) _tmp4_, ___lambda211__gasync_ready_callback, block88_data_ref (_data88_));
	_tmp6_ = (_vala_array_free (_tmp6_, _tmp6__length1, (GDestroyNotify) g_free), NULL);
	_g_object_unref0 (_tmp3_);
	result = G_SOURCE_REMOVE;
	block88_data_unref (_data88_);
	_data88_ = NULL;
	return result;
}

static void
tuba_widgets_account_suggestions_on_page_changed (TubaWidgetsAccountSuggestions* self)
{
	GtkButton* _tmp0_;
	GtkScrolledWindow* _tmp1_;
	GtkAdjustment* _tmp2_;
	GtkAdjustment* _tmp3_;
	gdouble _tmp4_;
	gdouble _tmp5_;
	GtkButton* _tmp6_;
	GtkScrolledWindow* _tmp7_;
	GtkAdjustment* _tmp8_;
	GtkAdjustment* _tmp9_;
	gdouble _tmp10_;
	gdouble _tmp11_;
	GtkScrolledWindow* _tmp12_;
	GtkAdjustment* _tmp13_;
	GtkAdjustment* _tmp14_;
	gdouble _tmp15_;
	gdouble _tmp16_;
	GtkScrolledWindow* _tmp17_;
	GtkAdjustment* _tmp18_;
	GtkAdjustment* _tmp19_;
	gdouble _tmp20_;
	gdouble _tmp21_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->back_button;
	_tmp1_ = self->priv->scrolled_window;
	_tmp2_ = gtk_scrolled_window_get_hadjustment (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = gtk_adjustment_get_value (_tmp3_);
	_tmp5_ = _tmp4_;
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, _tmp5_ > ((gdouble) 0));
	_tmp6_ = self->priv->next_button;
	_tmp7_ = self->priv->scrolled_window;
	_tmp8_ = gtk_scrolled_window_get_hadjustment (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = gtk_adjustment_get_value (_tmp9_);
	_tmp11_ = _tmp10_;
	_tmp12_ = self->priv->scrolled_window;
	_tmp13_ = gtk_scrolled_window_get_hadjustment (_tmp12_);
	_tmp14_ = _tmp13_;
	_tmp15_ = gtk_adjustment_get_upper (_tmp14_);
	_tmp16_ = _tmp15_;
	_tmp17_ = self->priv->scrolled_window;
	_tmp18_ = gtk_scrolled_window_get_hadjustment (_tmp17_);
	_tmp19_ = _tmp18_;
	_tmp20_ = gtk_adjustment_get_page_size (_tmp19_);
	_tmp21_ = _tmp20_;
	gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp11_ < (_tmp16_ - _tmp21_));
}

static void
tuba_widgets_account_suggestions_on_dra_clicked (TubaWidgetsAccountSuggestions* self)
{
	TubaSettings* _tmp0_;
	g_return_if_fail (self != NULL);
	gtk_widget_set_visible ((GtkWidget*) self, FALSE);
	_tmp0_ = tuba_settings;
	tuba_settings_set_account_suggestions (_tmp0_, FALSE);
}

TubaWidgetsAccountSuggestions*
tuba_widgets_account_suggestions_construct (GType object_type)
{
	TubaWidgetsAccountSuggestions * self = NULL;
	self = (TubaWidgetsAccountSuggestions*) g_object_new (object_type, NULL);
	return self;
}

TubaWidgetsAccountSuggestions*
tuba_widgets_account_suggestions_new (void)
{
	return tuba_widgets_account_suggestions_construct (TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS);
}

static inline gpointer
tuba_widgets_account_suggestions_account_suggestion_get_instance_private (TubaWidgetsAccountSuggestionsAccountSuggestion* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAccountSuggestionsAccountSuggestion_private_offset);
}

static void
_tuba_widgets_account_suggestions_account_suggestion_on_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                                    gpointer self)
{
	tuba_widgets_account_suggestions_account_suggestion_on_clicked ((TubaWidgetsAccountSuggestionsAccountSuggestion*) self);
}

TubaWidgetsAccountSuggestionsAccountSuggestion*
tuba_widgets_account_suggestions_account_suggestion_construct (GType object_type,
                                                               TubaAPIAccount* acc)
{
	TubaWidgetsAccountSuggestionsAccountSuggestion * self = NULL;
	TubaAPIAccount* _tmp0_;
	TubaWidgetsAvatar* avi = NULL;
	TubaAPIAccount* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	TubaWidgetsAvatar* _tmp6_ = NULL;
	TubaWidgetsAvatar* _tmp7_;
	GtkBox* title_box = NULL;
	GtkBox* _tmp8_;
	TubaWidgetsEmojiLabel* title_label = NULL;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	gchar* _tmp11_;
	TubaWidgetsEmojiLabel* _tmp12_ = NULL;
	GeeHashMap* _tmp13_;
	GeeHashMap* _tmp14_;
	GeeHashMap* _tmp15_;
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	gchar* _tmp20_;
	gchar* _tmp21_;
	gchar** _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	GtkLabel* _tmp25_ = NULL;
	GtkLabel* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	TubaWidgetsRelationshipButton* _tmp29_ = NULL;
	TubaWidgetsRelationshipButton* _tmp30_;
	g_return_val_if_fail (acc != NULL, NULL);
	self = (TubaWidgetsAccountSuggestionsAccountSuggestion*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (acc);
	_g_object_unref0 (self->priv->acc);
	self->priv->acc = _tmp0_;
	gtk_orientable_set_orientation ((GtkOrientable*) self, GTK_ORIENTATION_VERTICAL);
	gtk_box_set_spacing ((GtkBox*) self, 12);
	g_object_set ((GtkWidget*) self, "width-request", 120, NULL);
	gtk_widget_set_margin_bottom ((GtkWidget*) self, 12);
	gtk_widget_set_margin_top ((GtkWidget*) self, 12);
	gtk_widget_set_margin_end ((GtkWidget*) self, 12);
	gtk_widget_set_margin_start ((GtkWidget*) self, 12);
	_tmp1_ = _g_object_ref0 (acc);
	_tmp2_ = tuba_api_account_get_full_handle (acc);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = g_strdup_printf (_ ("Open %s's Profile"), _tmp4_);
	_tmp6_ = tuba_widgets_avatar_new ();
	tuba_widgets_avatar_set_account (_tmp6_, _tmp1_);
	_g_object_unref0 (_tmp1_);
	tuba_widgets_avatar_set_size (_tmp6_, 64);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp6_, _tmp5_);
	_g_free0 (_tmp5_);
	g_object_ref_sink (_tmp6_);
	_tmp7_ = _tmp6_;
	_g_free0 (_tmp4_);
	avi = _tmp7_;
	g_signal_connect_object ((GtkButton*) avi, "clicked", (GCallback) _tuba_widgets_account_suggestions_account_suggestion_on_clicked_gtk_button_clicked, self, 0);
	gtk_box_append ((GtkBox*) self, (GtkWidget*) avi);
	_tmp8_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 3);
	g_object_ref_sink (_tmp8_);
	title_box = _tmp8_;
	_tmp9_ = tuba_api_account_get_display_name (acc);
	_tmp10_ = _tmp9_;
	_tmp11_ = g_strdup (_tmp10_);
	_tmp12_ = tuba_widgets_emoji_label_new (NULL, NULL);
	tuba_widgets_label_with_widgets_set_use_markup ((TubaWidgetsLabelWithWidgets*) _tmp12_, FALSE);
	tuba_widgets_label_with_widgets_set_ellipsize ((TubaWidgetsLabelWithWidgets*) _tmp12_, TRUE);
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp12_, _tmp11_);
	_g_free0 (_tmp11_);
	g_object_ref_sink (_tmp12_);
	title_label = _tmp12_;
	_tmp13_ = tuba_api_account_get_emojis_map (acc);
	_tmp14_ = _tmp13_;
	_tmp15_ = _tmp14_;
	tuba_widgets_emoji_label_set_instance_emojis (title_label, _tmp15_);
	_g_object_unref0 (_tmp15_);
	_tmp16_ = tuba_api_account_get_display_name (acc);
	_tmp17_ = _tmp16_;
	tuba_widgets_emoji_label_set_content (title_label, _tmp17_);
	gtk_box_append (title_box, (GtkWidget*) title_label);
	_tmp18_ = tuba_api_account_get_full_handle (acc);
	_tmp19_ = _tmp18_;
	_tmp20_ = _tmp19_;
	_tmp21_ = g_strdup ("dim-label");
	_tmp22_ = g_new0 (gchar*, 1 + 1);
	_tmp22_[0] = _tmp21_;
	_tmp23_ = tuba_api_account_get_full_handle (acc);
	_tmp24_ = _tmp23_;
	_tmp25_ = (GtkLabel*) gtk_label_new (_tmp20_);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp25_, TRUE);
	gtk_label_set_xalign (_tmp25_, 0.0f);
	gtk_label_set_single_line_mode (_tmp25_, TRUE);
	gtk_label_set_ellipsize (_tmp25_, PANGO_ELLIPSIZE_END);
	gtk_label_set_use_markup (_tmp25_, FALSE);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp25_, _tmp22_);
	_tmp22_ = (_vala_array_free (_tmp22_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp25_, _tmp24_);
	_g_free0 (_tmp24_);
	gtk_widget_set_halign ((GtkWidget*) _tmp25_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp25_);
	_tmp26_ = _tmp25_;
	gtk_box_append (title_box, (GtkWidget*) _tmp26_);
	_g_object_unref0 (_tmp26_);
	_g_free0 (_tmp20_);
	gtk_box_append ((GtkBox*) self, (GtkWidget*) title_box);
	_tmp27_ = tuba_api_account_get_full_handle (acc);
	_tmp28_ = _tmp27_;
	_tmp29_ = tuba_widgets_relationship_button_new ();
	tuba_widgets_relationship_button_set_handle (_tmp29_, _tmp28_);
	_g_free0 (_tmp28_);
	gtk_widget_set_visible ((GtkWidget*) _tmp29_, FALSE);
	g_object_ref_sink (_tmp29_);
	_g_object_unref0 (self->priv->rsbtn);
	self->priv->rsbtn = _tmp29_;
	_tmp30_ = self->priv->rsbtn;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp30_);
	_g_object_unref0 (title_label);
	_g_object_unref0 (title_box);
	_g_object_unref0 (avi);
	return self;
}

TubaWidgetsAccountSuggestionsAccountSuggestion*
tuba_widgets_account_suggestions_account_suggestion_new (TubaAPIAccount* acc)
{
	return tuba_widgets_account_suggestions_account_suggestion_construct (TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, acc);
}

void
tuba_widgets_account_suggestions_account_suggestion_update_rs (TubaWidgetsAccountSuggestionsAccountSuggestion* self,
                                                               TubaAPIRelationship* new_rs)
{
	TubaWidgetsRelationshipButton* _tmp0_;
	TubaWidgetsRelationshipButton* _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->rsbtn;
	gtk_widget_set_visible ((GtkWidget*) _tmp0_, new_rs != NULL);
	_tmp1_ = self->priv->rsbtn;
	tuba_widgets_relationship_button_set_rs (_tmp1_, new_rs);
}

static void
tuba_widgets_account_suggestions_account_suggestion_on_clicked (TubaWidgetsAccountSuggestionsAccountSuggestion* self)
{
	TubaAPIAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->acc;
	tuba_widgetizable_open ((TubaWidgetizable*) _tmp0_);
}

static void
tuba_widgets_account_suggestions_account_suggestion_class_init (TubaWidgetsAccountSuggestionsAccountSuggestionClass * klass,
                                                                gpointer klass_data)
{
	tuba_widgets_account_suggestions_account_suggestion_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAccountSuggestionsAccountSuggestion_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_account_suggestions_account_suggestion_finalize;
}

static void
tuba_widgets_account_suggestions_account_suggestion_instance_init (TubaWidgetsAccountSuggestionsAccountSuggestion * self,
                                                                   gpointer klass)
{
	self->priv = tuba_widgets_account_suggestions_account_suggestion_get_instance_private (self);
}

static void
tuba_widgets_account_suggestions_account_suggestion_finalize (GObject * obj)
{
	TubaWidgetsAccountSuggestionsAccountSuggestion * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ACCOUNT_SUGGESTIONS_TYPE_ACCOUNT_SUGGESTION, TubaWidgetsAccountSuggestionsAccountSuggestion);
	_g_object_unref0 (self->priv->rsbtn);
	_g_object_unref0 (self->priv->acc);
	G_OBJECT_CLASS (tuba_widgets_account_suggestions_account_suggestion_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_account_suggestions_account_suggestion_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAccountSuggestionsAccountSuggestionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_account_suggestions_account_suggestion_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAccountSuggestionsAccountSuggestion), 0, (GInstanceInitFunc) tuba_widgets_account_suggestions_account_suggestion_instance_init, NULL };
	GType tuba_widgets_account_suggestions_account_suggestion_type_id;
	tuba_widgets_account_suggestions_account_suggestion_type_id = g_type_register_static (gtk_box_get_type (), "TubaWidgetsAccountSuggestionsAccountSuggestion", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAccountSuggestionsAccountSuggestion_private_offset = g_type_add_instance_private (tuba_widgets_account_suggestions_account_suggestion_type_id, sizeof (TubaWidgetsAccountSuggestionsAccountSuggestionPrivate));
	return tuba_widgets_account_suggestions_account_suggestion_type_id;
}

GType
tuba_widgets_account_suggestions_account_suggestion_get_type (void)
{
	static GType tuba_widgets_account_suggestions_account_suggestion_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_account_suggestions_account_suggestion_type_id__once)) {
		GType tuba_widgets_account_suggestions_account_suggestion_type_id;
		tuba_widgets_account_suggestions_account_suggestion_type_id = tuba_widgets_account_suggestions_account_suggestion_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_account_suggestions_account_suggestion_type_id__once, tuba_widgets_account_suggestions_account_suggestion_type_id);
	}
	return tuba_widgets_account_suggestions_account_suggestion_type_id__once;
}

static void
_tuba_widgets_account_suggestions_prev_page_gtk_button_clicked (GtkButton* _sender,
                                                                gpointer self)
{
	tuba_widgets_account_suggestions_prev_page ((TubaWidgetsAccountSuggestions*) self);
}

static void
_tuba_widgets_account_suggestions_next_page_gtk_button_clicked (GtkButton* _sender,
                                                                gpointer self)
{
	tuba_widgets_account_suggestions_next_page ((TubaWidgetsAccountSuggestions*) self);
}

static void
_tuba_widgets_account_suggestions_on_dra_clicked_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self)
{
	tuba_widgets_account_suggestions_on_dra_clicked ((TubaWidgetsAccountSuggestions*) self);
}

static void
_tuba_widgets_account_suggestions_on_page_changed_gtk_adjustment_value_changed (GtkAdjustment* _sender,
                                                                                gpointer self)
{
	tuba_widgets_account_suggestions_on_page_changed ((TubaWidgetsAccountSuggestions*) self);
}

static GObject *
tuba_widgets_account_suggestions_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaWidgetsAccountSuggestions * self;
	GtkBox* _tmp0_;
	GtkBox* _tmp1_;
	GtkWidget* _tmp2_;
	GtkScrolledWindow* _tmp3_ = NULL;
	GtkOverlay* overlay = NULL;
	GtkScrolledWindow* _tmp4_;
	GtkWidget* _tmp5_;
	GtkOverlay* _tmp6_ = NULL;
	gint _tmp7_ = 0;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar** _tmp10_;
	gchar* _tmp11_;
	GtkButton* _tmp12_ = NULL;
	GtkButton* _tmp13_;
	GtkOverlay* _tmp14_;
	GtkButton* _tmp15_;
	gint _tmp16_ = 0;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar** _tmp19_;
	gchar* _tmp20_;
	GtkButton* _tmp21_ = NULL;
	GtkButton* _tmp22_;
	GtkOverlay* _tmp23_;
	GtkButton* _tmp24_;
	GtkBox* header_box = NULL;
	GtkBox* _tmp25_;
	GtkBox* _tmp26_;
	gchar* _tmp27_;
	gchar** _tmp28_;
	GtkLabel* _tmp29_ = NULL;
	GtkLabel* _tmp30_;
	gint _tmp31_ = 0;
	GtkButton* dra_button = NULL;
	gchar* _tmp32_;
	gchar* _tmp33_;
	gchar* _tmp34_;
	gchar** _tmp35_;
	GtkButton* _tmp36_ = NULL;
	GtkButton* _tmp37_;
	GtkBox* _tmp38_;
	GtkButton* _tmp39_;
	GtkBox* main_box = NULL;
	GtkBox* _tmp40_;
	GtkBox* _tmp41_;
	GtkBox* _tmp42_;
	GtkBox* _tmp43_;
	GtkSeparator* _tmp44_;
	GtkSeparator* _tmp45_;
	GtkBox* _tmp46_;
	GtkOverlay* _tmp47_;
	GtkBox* _tmp48_;
	GtkScrolledWindow* _tmp49_;
	GtkAdjustment* _tmp50_;
	GtkAdjustment* _tmp51_;
	parent_class = G_OBJECT_CLASS (tuba_widgets_account_suggestions_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS, TubaWidgetsAccountSuggestions);
	gtk_widget_set_visible ((GtkWidget*) self, FALSE);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, FALSE);
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->account_box);
	self->priv->account_box = _tmp0_;
	_tmp1_ = self->priv->account_box;
	_tmp2_ = _g_object_ref0 ((GtkWidget*) _tmp1_);
	_tmp3_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_scrolled_window_set_child (_tmp3_, _tmp2_);
	_g_object_unref0 (_tmp2_);
	g_object_set (_tmp3_, "vscrollbar-policy", GTK_POLICY_NEVER, NULL);
	g_object_ref_sink (_tmp3_);
	_g_object_unref0 (self->priv->scrolled_window);
	self->priv->scrolled_window = _tmp3_;
	_tmp4_ = self->priv->scrolled_window;
	_tmp5_ = _g_object_ref0 ((GtkWidget*) _tmp4_);
	_tmp6_ = (GtkOverlay*) gtk_overlay_new ();
	gtk_overlay_set_child (_tmp6_, _tmp5_);
	_g_object_unref0 (_tmp5_);
	g_object_ref_sink (_tmp6_);
	overlay = _tmp6_;
	_tmp7_ = 3;
	_tmp8_ = g_strdup ("circular");
	_tmp9_ = g_strdup ("osd");
	_tmp10_ = g_new0 (gchar*, 2 + 1);
	_tmp10_[0] = _tmp8_;
	_tmp10_[1] = _tmp9_;
	_tmp11_ = g_strdup (_ ("Back"));
	_tmp12_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-left-large-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp12_, _tmp10_);
	_tmp10_ = (_vala_array_free (_tmp10_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp12_, _tmp11_);
	_g_free0 (_tmp11_);
	gtk_widget_set_halign ((GtkWidget*) _tmp12_, GTK_ALIGN_START);
	gtk_widget_set_valign ((GtkWidget*) _tmp12_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp12_, _tmp7_);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp12_, _tmp7_);
	g_object_ref_sink (_tmp12_);
	_g_object_unref0 (self->priv->back_button);
	self->priv->back_button = _tmp12_;
	_tmp13_ = self->priv->back_button;
	g_signal_connect_object (_tmp13_, "clicked", (GCallback) _tuba_widgets_account_suggestions_prev_page_gtk_button_clicked, self, 0);
	_tmp14_ = overlay;
	_tmp15_ = self->priv->back_button;
	gtk_overlay_add_overlay (_tmp14_, (GtkWidget*) _tmp15_);
	_tmp16_ = 3;
	_tmp17_ = g_strdup ("circular");
	_tmp18_ = g_strdup ("osd");
	_tmp19_ = g_new0 (gchar*, 2 + 1);
	_tmp19_[0] = _tmp17_;
	_tmp19_[1] = _tmp18_;
	_tmp20_ = g_strdup (_ ("Next"));
	_tmp21_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-right-large-symbolic");
	gtk_widget_set_css_classes ((GtkWidget*) _tmp21_, _tmp19_);
	_tmp19_ = (_vala_array_free (_tmp19_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp21_, _tmp20_);
	_g_free0 (_tmp20_);
	gtk_widget_set_halign ((GtkWidget*) _tmp21_, GTK_ALIGN_END);
	gtk_widget_set_valign ((GtkWidget*) _tmp21_, GTK_ALIGN_CENTER);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp21_, _tmp16_);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp21_, _tmp16_);
	g_object_ref_sink (_tmp21_);
	_g_object_unref0 (self->priv->next_button);
	self->priv->next_button = _tmp21_;
	_tmp22_ = self->priv->next_button;
	g_signal_connect_object (_tmp22_, "clicked", (GCallback) _tuba_widgets_account_suggestions_next_page_gtk_button_clicked, self, 0);
	_tmp23_ = overlay;
	_tmp24_ = self->priv->next_button;
	gtk_overlay_add_overlay (_tmp23_, (GtkWidget*) _tmp24_);
	_tmp25_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
	g_object_ref_sink (_tmp25_);
	header_box = _tmp25_;
	_tmp26_ = header_box;
	_tmp27_ = g_strdup ("heading");
	_tmp28_ = g_new0 (gchar*, 1 + 1);
	_tmp28_[0] = _tmp27_;
	_tmp29_ = (GtkLabel*) gtk_label_new (_ ("Follow Suggestions"));
	gtk_label_set_wrap (_tmp29_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp29_, TRUE);
	gtk_label_set_wrap_mode (_tmp29_, PANGO_WRAP_WORD_CHAR);
	gtk_label_set_xalign (_tmp29_, 0.0f);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp29_, _tmp28_);
	_tmp28_ = (_vala_array_free (_tmp28_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp29_, 12);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp29_, 12);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp29_, 6);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp29_, 6);
	g_object_ref_sink (_tmp29_);
	_tmp30_ = _tmp29_;
	gtk_box_append (_tmp26_, (GtkWidget*) _tmp30_);
	_g_object_unref0 (_tmp30_);
	_tmp31_ = 6;
	_tmp32_ = g_strdup (_ ("Don't remind me again"));
	_tmp33_ = g_strdup ("circular");
	_tmp34_ = g_strdup ("error");
	_tmp35_ = g_new0 (gchar*, 2 + 1);
	_tmp35_[0] = _tmp33_;
	_tmp35_[1] = _tmp34_;
	_tmp36_ = (GtkButton*) gtk_button_new_from_icon_name ("user-trash-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp36_, _tmp32_);
	_g_free0 (_tmp32_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp36_, _tmp35_);
	_tmp35_ = (_vala_array_free (_tmp35_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp36_, _tmp31_);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp36_, _tmp31_);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp36_, _tmp31_);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp36_, _tmp31_);
	g_object_ref_sink (_tmp36_);
	dra_button = _tmp36_;
	_tmp37_ = dra_button;
	g_signal_connect_object (_tmp37_, "clicked", (GCallback) _tuba_widgets_account_suggestions_on_dra_clicked_gtk_button_clicked, self, 0);
	_tmp38_ = header_box;
	_tmp39_ = dra_button;
	gtk_box_append (_tmp38_, (GtkWidget*) _tmp39_);
	_tmp40_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
	g_object_ref_sink (_tmp40_);
	main_box = _tmp40_;
	_tmp41_ = main_box;
	_tmp42_ = header_box;
	gtk_box_append (_tmp41_, (GtkWidget*) _tmp42_);
	_tmp43_ = main_box;
	_tmp44_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
	g_object_ref_sink (_tmp44_);
	_tmp45_ = _tmp44_;
	gtk_box_append (_tmp43_, (GtkWidget*) _tmp45_);
	_g_object_unref0 (_tmp45_);
	_tmp46_ = main_box;
	_tmp47_ = overlay;
	gtk_box_append (_tmp46_, (GtkWidget*) _tmp47_);
	_tmp48_ = main_box;
	gtk_list_box_row_set_child ((GtkListBoxRow*) self, (GtkWidget*) _tmp48_);
	tuba_widgets_account_suggestions_on_page_changed (self);
	tuba_widgets_account_suggestions_populate_account_suggestions (self, NULL, NULL);
	_tmp49_ = self->priv->scrolled_window;
	_tmp50_ = gtk_scrolled_window_get_hadjustment (_tmp49_);
	_tmp51_ = _tmp50_;
	g_signal_connect_object (_tmp51_, "value-changed", (GCallback) _tuba_widgets_account_suggestions_on_page_changed_gtk_adjustment_value_changed, self, 0);
	_g_object_unref0 (main_box);
	_g_object_unref0 (dra_button);
	_g_object_unref0 (header_box);
	_g_object_unref0 (overlay);
	return obj;
}

static void
tuba_widgets_account_suggestions_class_init (TubaWidgetsAccountSuggestionsClass * klass,
                                             gpointer klass_data)
{
	tuba_widgets_account_suggestions_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAccountSuggestions_private_offset);
	G_OBJECT_CLASS (klass)->constructor = tuba_widgets_account_suggestions_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_account_suggestions_finalize;
}

static void
tuba_widgets_account_suggestions_instance_init (TubaWidgetsAccountSuggestions * self,
                                                gpointer klass)
{
	self->priv = tuba_widgets_account_suggestions_get_instance_private (self);
}

static void
tuba_widgets_account_suggestions_finalize (GObject * obj)
{
	TubaWidgetsAccountSuggestions * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_ACCOUNT_SUGGESTIONS, TubaWidgetsAccountSuggestions);
	_g_object_unref0 (self->priv->scrolled_window);
	_g_object_unref0 (self->priv->account_box);
	_g_object_unref0 (self->priv->back_button);
	_g_object_unref0 (self->priv->next_button);
	G_OBJECT_CLASS (tuba_widgets_account_suggestions_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_account_suggestions_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAccountSuggestionsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_account_suggestions_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAccountSuggestions), 0, (GInstanceInitFunc) tuba_widgets_account_suggestions_instance_init, NULL };
	GType tuba_widgets_account_suggestions_type_id;
	tuba_widgets_account_suggestions_type_id = g_type_register_static (gtk_list_box_row_get_type (), "TubaWidgetsAccountSuggestions", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAccountSuggestions_private_offset = g_type_add_instance_private (tuba_widgets_account_suggestions_type_id, sizeof (TubaWidgetsAccountSuggestionsPrivate));
	return tuba_widgets_account_suggestions_type_id;
}

GType
tuba_widgets_account_suggestions_get_type (void)
{
	static GType tuba_widgets_account_suggestions_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_account_suggestions_type_id__once)) {
		GType tuba_widgets_account_suggestions_type_id;
		tuba_widgets_account_suggestions_type_id = tuba_widgets_account_suggestions_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_account_suggestions_type_id__once, tuba_widgets_account_suggestions_type_id);
	}
	return tuba_widgets_account_suggestions_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

