/* AccountRow.c generated by valac 0.56.19, the Vala compiler
 * generated from AccountRow.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW (tuba_widgets_admin_account_row_get_type ())
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRow))
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRowClass))
#define TUBA_WIDGETS_ADMIN_IS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ADMIN_IS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRowClass))

typedef struct _TubaWidgetsAdminAccountRow TubaWidgetsAdminAccountRow;
typedef struct _TubaWidgetsAdminAccountRowClass TubaWidgetsAdminAccountRowClass;
typedef struct _TubaWidgetsAdminAccountRowPrivate TubaWidgetsAdminAccountRowPrivate;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_ADMIN_TYPE_ACCOUNT (tuba_api_admin_account_get_type ())
#define TUBA_API_ADMIN_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount))
#define TUBA_API_ADMIN_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))
#define TUBA_API_ADMIN_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))

typedef struct _TubaAPIAdminAccount TubaAPIAdminAccount;
typedef struct _TubaAPIAdminAccountClass TubaAPIAdminAccountClass;
enum  {
	TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_0_PROPERTY,
	TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_admin_account_row_properties[TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_WIDGETS_TYPE_AVATAR (tuba_widgets_avatar_get_type ())
#define TUBA_WIDGETS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatar))
#define TUBA_WIDGETS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))
#define TUBA_WIDGETS_IS_AVATAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_IS_AVATAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_AVATAR))
#define TUBA_WIDGETS_AVATAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_AVATAR, TubaWidgetsAvatarClass))

typedef struct _TubaWidgetsAvatar TubaWidgetsAvatar;
typedef struct _TubaWidgetsAvatarClass TubaWidgetsAvatarClass;
enum  {
	TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_ACCOUNT_OPENED_SIGNAL,
	TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_NUM_SIGNALS
};
static guint tuba_widgets_admin_account_row_signals[TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_NUM_SIGNALS] = {0};

struct _TubaWidgetsAdminAccountRow {
	AdwActionRow parent_instance;
	TubaWidgetsAdminAccountRowPrivate * priv;
};

struct _TubaWidgetsAdminAccountRowClass {
	AdwActionRowClass parent_class;
};

struct _TubaWidgetsAdminAccountRowPrivate {
	TubaAPIAdminAccount* account_obj;
};

static gint TubaWidgetsAdminAccountRow_private_offset;
static gpointer tuba_widgets_admin_account_row_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_admin_account_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminAccountRow, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_admin_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccount, g_object_unref)
VALA_EXTERN TubaWidgetsAdminAccountRow* tuba_widgets_admin_account_row_new (TubaAPIAdminAccount* account);
VALA_EXTERN TubaWidgetsAdminAccountRow* tuba_widgets_admin_account_row_construct (GType object_type,
                                                                      TubaAPIAdminAccount* account);
VALA_EXTERN const gchar* tuba_api_admin_account_get_ip (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_admin_account_get_email (TubaAPIAdminAccount* self);
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN TubaAPIAccount* tuba_api_admin_account_get_account (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
VALA_EXTERN void tuba_widgets_admin_account_row_on_activate (TubaWidgetsAdminAccountRow* self);
static void _tuba_widgets_admin_account_row_on_activate_adw_action_row_activated (AdwActionRow* _sender,
                                                                           gpointer self);
VALA_EXTERN GType tuba_widgets_avatar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAvatar, g_object_unref)
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_new (void);
VALA_EXTERN TubaWidgetsAvatar* tuba_widgets_avatar_construct (GType object_type);
VALA_EXTERN void tuba_widgets_avatar_set_account (TubaWidgetsAvatar* self,
                                      TubaAPIAccount* value);
VALA_EXTERN void tuba_widgets_avatar_set_size (TubaWidgetsAvatar* self,
                                   gint value);
VALA_EXTERN gboolean tuba_api_admin_account_get_suspended (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_silenced (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_disabled (TubaAPIAdminAccount* self);
VALA_EXTERN gboolean tuba_api_admin_account_get_approved (TubaAPIAdminAccount* self);
static void tuba_widgets_admin_account_row_finalize (GObject * obj);
static GType tuba_widgets_admin_account_row_get_type_once (void);

static inline gpointer
tuba_widgets_admin_account_row_get_instance_private (TubaWidgetsAdminAccountRow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAdminAccountRow_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_tuba_widgets_admin_account_row_on_activate_adw_action_row_activated (AdwActionRow* _sender,
                                                                      gpointer self)
{
	tuba_widgets_admin_account_row_on_activate ((TubaWidgetsAdminAccountRow*) self);
}

TubaWidgetsAdminAccountRow*
tuba_widgets_admin_account_row_construct (GType object_type,
                                          TubaAPIAdminAccount* account)
{
	TubaWidgetsAdminAccountRow * self = NULL;
	TubaAPIAdminAccount* _tmp0_;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* ip = NULL;
	gchar* _tmp9_;
	const gchar* _tmp10_ = NULL;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* email = NULL;
	gchar* _tmp15_;
	TubaAPIAccount* _tmp16_;
	TubaAPIAccount* _tmp17_;
	const gchar* _tmp18_;
	const gchar* _tmp19_;
	TubaAPIAccount* _tmp20_;
	TubaAPIAccount* _tmp21_;
	gchar* _tmp22_;
	gchar* _tmp23_;
	gchar* _tmp24_;
	const gchar* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	TubaAPIAccount* _tmp32_;
	TubaAPIAccount* _tmp33_;
	TubaAPIAccount* _tmp34_;
	TubaWidgetsAvatar* _tmp35_ = NULL;
	TubaWidgetsAvatar* _tmp36_;
	gchar* status = NULL;
	gchar* _tmp37_;
	gboolean _tmp38_;
	gboolean _tmp39_;
	const gchar* _tmp50_;
	GtkLabel* _tmp51_ = NULL;
	GtkLabel* _tmp52_;
	g_return_val_if_fail (account != NULL, NULL);
	self = (TubaWidgetsAdminAccountRow*) g_object_new (object_type, NULL);
	_tmp0_ = _g_object_ref0 (account);
	_g_object_unref0 (self->priv->account_obj);
	self->priv->account_obj = _tmp0_;
	_tmp2_ = tuba_api_admin_account_get_ip (account);
	_tmp3_ = _tmp2_;
	if (_tmp3_ == NULL) {
		gchar* _tmp4_;
		_tmp4_ = g_strdup ("");
		_g_free0 (_tmp1_);
		_tmp1_ = _tmp4_;
	} else {
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		_tmp5_ = tuba_api_admin_account_get_ip (account);
		_tmp6_ = _tmp5_;
		_tmp7_ = string_to_string (_tmp6_);
		_tmp8_ = g_strconcat (_tmp7_, "\n", NULL);
		_g_free0 (_tmp1_);
		_tmp1_ = _tmp8_;
	}
	_tmp9_ = _tmp1_;
	_tmp1_ = NULL;
	ip = _tmp9_;
	_tmp11_ = tuba_api_admin_account_get_email (account);
	_tmp12_ = _tmp11_;
	if (_tmp12_ == NULL) {
		_tmp10_ = "";
	} else {
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		_tmp13_ = tuba_api_admin_account_get_email (account);
		_tmp14_ = _tmp13_;
		_tmp10_ = _tmp14_;
	}
	_tmp15_ = g_strdup (_tmp10_);
	email = _tmp15_;
	gtk_widget_set_overflow ((GtkWidget*) self, GTK_OVERFLOW_HIDDEN);
	adw_action_row_set_subtitle_lines ((AdwActionRow*) self, 0);
	_tmp16_ = tuba_api_admin_account_get_account (account);
	_tmp17_ = _tmp16_;
	_tmp18_ = tuba_api_account_get_display_name (_tmp17_);
	_tmp19_ = _tmp18_;
	adw_preferences_row_set_title ((AdwPreferencesRow*) self, _tmp19_);
	_tmp20_ = tuba_api_admin_account_get_account (account);
	_tmp21_ = _tmp20_;
	_tmp22_ = tuba_api_account_get_full_handle (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = _tmp23_;
	_tmp25_ = string_to_string (_tmp24_);
	_tmp26_ = ip;
	_tmp27_ = string_to_string (_tmp26_);
	_tmp28_ = email;
	_tmp29_ = string_to_string (_tmp28_);
	_tmp30_ = g_strconcat (_tmp25_, "\n", _tmp27_, _tmp29_, NULL);
	_tmp31_ = _tmp30_;
	adw_action_row_set_subtitle ((AdwActionRow*) self, _tmp31_);
	_g_free0 (_tmp31_);
	_g_free0 (_tmp24_);
	g_signal_connect_object ((AdwActionRow*) self, "activated", (GCallback) _tuba_widgets_admin_account_row_on_activate_adw_action_row_activated, self, 0);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) self, TRUE);
	_tmp32_ = tuba_api_admin_account_get_account (account);
	_tmp33_ = _tmp32_;
	_tmp34_ = _g_object_ref0 (_tmp33_);
	_tmp35_ = tuba_widgets_avatar_new ();
	tuba_widgets_avatar_set_account (_tmp35_, _tmp34_);
	_g_object_unref0 (_tmp34_);
	tuba_widgets_avatar_set_size (_tmp35_, 48);
	gtk_widget_set_overflow ((GtkWidget*) _tmp35_, GTK_OVERFLOW_HIDDEN);
	g_object_ref_sink (_tmp35_);
	_tmp36_ = _tmp35_;
	adw_action_row_add_prefix ((AdwActionRow*) self, (GtkWidget*) _tmp36_);
	_g_object_unref0 (_tmp36_);
	_tmp37_ = g_strdup (_ ("No Limits"));
	status = _tmp37_;
	_tmp38_ = tuba_api_admin_account_get_suspended (account);
	_tmp39_ = _tmp38_;
	if (_tmp39_) {
		gchar* _tmp40_;
		_tmp40_ = g_strdup (_ ("Suspended"));
		_g_free0 (status);
		status = _tmp40_;
	} else {
		gboolean _tmp41_;
		gboolean _tmp42_;
		_tmp41_ = tuba_api_admin_account_get_silenced (account);
		_tmp42_ = _tmp41_;
		if (_tmp42_) {
			gchar* _tmp43_;
			_tmp43_ = g_strdup (_ ("Limited"));
			_g_free0 (status);
			status = _tmp43_;
		} else {
			gboolean _tmp44_;
			gboolean _tmp45_;
			_tmp44_ = tuba_api_admin_account_get_disabled (account);
			_tmp45_ = _tmp44_;
			if (_tmp45_) {
				gchar* _tmp46_;
				_tmp46_ = g_strdup (_ ("Disabled"));
				_g_free0 (status);
				status = _tmp46_;
			} else {
				gboolean _tmp47_;
				gboolean _tmp48_;
				_tmp47_ = tuba_api_admin_account_get_approved (account);
				_tmp48_ = _tmp47_;
				if (!_tmp48_) {
					gchar* _tmp49_;
					_tmp49_ = g_strdup (_ ("Waiting Approval"));
					_g_free0 (status);
					status = _tmp49_;
				}
			}
		}
	}
	_tmp50_ = status;
	_tmp51_ = (GtkLabel*) gtk_label_new (_tmp50_);
	gtk_label_set_xalign (_tmp51_, 1.0f);
	gtk_label_set_wrap (_tmp51_, TRUE);
	gtk_label_set_wrap_mode (_tmp51_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp51_, TRUE);
	g_object_ref_sink (_tmp51_);
	_tmp52_ = _tmp51_;
	adw_action_row_add_suffix ((AdwActionRow*) self, (GtkWidget*) _tmp52_);
	_g_object_unref0 (_tmp52_);
	_g_free0 (status);
	_g_free0 (email);
	_g_free0 (ip);
	_g_free0 (_tmp1_);
	return self;
}

TubaWidgetsAdminAccountRow*
tuba_widgets_admin_account_row_new (TubaAPIAdminAccount* account)
{
	return tuba_widgets_admin_account_row_construct (TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, account);
}

void
tuba_widgets_admin_account_row_on_activate (TubaWidgetsAdminAccountRow* self)
{
	TubaAPIAdminAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->account_obj;
	g_signal_emit (self, tuba_widgets_admin_account_row_signals[TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_ACCOUNT_OPENED_SIGNAL], 0, _tmp0_);
}

static void
tuba_widgets_admin_account_row_class_init (TubaWidgetsAdminAccountRowClass * klass,
                                           gpointer klass_data)
{
	tuba_widgets_admin_account_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAdminAccountRow_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_admin_account_row_finalize;
	tuba_widgets_admin_account_row_signals[TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_ACCOUNT_OPENED_SIGNAL] = g_signal_new ("account-opened", TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_API_ADMIN_TYPE_ACCOUNT);
}

static void
tuba_widgets_admin_account_row_instance_init (TubaWidgetsAdminAccountRow * self,
                                              gpointer klass)
{
	self->priv = tuba_widgets_admin_account_row_get_instance_private (self);
}

static void
tuba_widgets_admin_account_row_finalize (GObject * obj)
{
	TubaWidgetsAdminAccountRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRow);
	g_debug ("AccountRow.vala:5: Destroying AccountRow");
	_g_object_unref0 (self->priv->account_obj);
	G_OBJECT_CLASS (tuba_widgets_admin_account_row_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_admin_account_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAdminAccountRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_admin_account_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAdminAccountRow), 0, (GInstanceInitFunc) tuba_widgets_admin_account_row_instance_init, NULL };
	GType tuba_widgets_admin_account_row_type_id;
	tuba_widgets_admin_account_row_type_id = g_type_register_static (adw_action_row_get_type (), "TubaWidgetsAdminAccountRow", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAdminAccountRow_private_offset = g_type_add_instance_private (tuba_widgets_admin_account_row_type_id, sizeof (TubaWidgetsAdminAccountRowPrivate));
	return tuba_widgets_admin_account_row_type_id;
}

GType
tuba_widgets_admin_account_row_get_type (void)
{
	static GType tuba_widgets_admin_account_row_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_admin_account_row_type_id__once)) {
		GType tuba_widgets_admin_account_row_type_id;
		tuba_widgets_admin_account_row_type_id = tuba_widgets_admin_account_row_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_admin_account_row_type_id__once, tuba_widgets_admin_account_row_type_id);
	}
	return tuba_widgets_admin_account_row_type_id__once;
}

