/* Account.c generated by valac 0.56.19, the Vala compiler
 * generated from Account.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_TYPE_BASIC_WIDGETIZABLE (tuba_basic_widgetizable_get_type ())
#define TUBA_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizable))
#define TUBA_IS_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE))
#define TUBA_BASIC_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizableIface))

typedef struct _TubaBasicWidgetizable TubaBasicWidgetizable;
typedef struct _TubaBasicWidgetizableIface TubaBasicWidgetizableIface;

#define TUBA_API_ADMIN_TYPE_ACCOUNT (tuba_api_admin_account_get_type ())
#define TUBA_API_ADMIN_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount))
#define TUBA_API_ADMIN_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))
#define TUBA_API_ADMIN_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))

typedef struct _TubaAPIAdminAccount TubaAPIAdminAccount;
typedef struct _TubaAPIAdminAccountClass TubaAPIAdminAccountClass;
typedef struct _TubaAPIAdminAccountPrivate TubaAPIAdminAccountPrivate;

#define TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS (tuba_api_admin_account_ip_address_get_type ())
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddress))
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddressClass))
#define TUBA_API_ADMIN_ACCOUNT_IS_IP_ADDRESS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS))
#define TUBA_API_ADMIN_ACCOUNT_IS_IP_ADDRESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS))
#define TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddressClass))

typedef struct _TubaAPIAdminAccountIPAddress TubaAPIAdminAccountIPAddress;
typedef struct _TubaAPIAdminAccountIPAddressClass TubaAPIAdminAccountIPAddressClass;

#define TUBA_API_TYPE_ACCOUNT_ROLE (tuba_api_account_role_get_type ())
#define TUBA_API_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRole))
#define TUBA_API_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))
#define TUBA_API_IS_ACCOUNT_ROLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_IS_ACCOUNT_ROLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_ROLE))
#define TUBA_API_ACCOUNT_ROLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_ROLE, TubaAPIAccountRoleClass))

typedef struct _TubaAPIAccountRole TubaAPIAccountRole;
typedef struct _TubaAPIAccountRoleClass TubaAPIAccountRoleClass;
enum  {
	TUBA_API_ADMIN_ACCOUNT_0_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_NUM_PROPERTIES
};
static GParamSpec* tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW (tuba_widgets_admin_account_row_get_type ())
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRow))
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRowClass))
#define TUBA_WIDGETS_ADMIN_IS_ACCOUNT_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ADMIN_IS_ACCOUNT_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW))
#define TUBA_WIDGETS_ADMIN_ACCOUNT_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_ACCOUNT_ROW, TubaWidgetsAdminAccountRowClass))

typedef struct _TubaWidgetsAdminAccountRow TubaWidgetsAdminAccountRow;
typedef struct _TubaWidgetsAdminAccountRowClass TubaWidgetsAdminAccountRowClass;
typedef struct _TubaAPIAdminAccountIPAddressPrivate TubaAPIAdminAccountIPAddressPrivate;
enum  {
	TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_0_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY,
	TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_admin_account_ip_address_properties[TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaBasicWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaBasicWidgetizable* self);
};

struct _TubaAPIAdminAccount {
	TubaEntity parent_instance;
	TubaAPIAdminAccountPrivate * priv;
};

struct _TubaAPIAdminAccountClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAdminAccountPrivate {
	gchar* _id;
	gchar* _username;
	gchar* _domain;
	gchar* _email;
	gchar* _ip;
	GeeArrayList* _ips;
	gboolean _confirmed;
	gboolean _suspended;
	gboolean _disabled;
	gboolean _silenced;
	gboolean _approved;
	gchar* _invite_request;
	TubaAPIAccountRole* _role;
	TubaAPIAccount* _account;
};

struct _TubaAPIAdminAccountIPAddress {
	TubaEntity parent_instance;
	TubaAPIAdminAccountIPAddressPrivate * priv;
};

struct _TubaAPIAdminAccountIPAddressClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAdminAccountIPAddressPrivate {
	gchar* _ip;
};

static gint TubaAPIAdminAccount_private_offset;
static gpointer tuba_api_admin_account_parent_class = NULL;
static gint TubaAPIAdminAccountIPAddress_private_offset;
static gpointer tuba_api_admin_account_ip_address_parent_class = NULL;
static TubaBasicWidgetizableIface * tuba_api_admin_account_tuba_basic_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_basic_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaBasicWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_admin_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccount, g_object_unref)
VALA_EXTERN GType tuba_api_admin_account_ip_address_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccountIPAddress, g_object_unref)
VALA_EXTERN GType tuba_api_account_role_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountRole, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_admin_account_real_deserialize_array_type (TubaEntity* base,
                                                          const gchar* prop);
static GtkWidget* tuba_api_admin_account_real_to_widget (TubaBasicWidgetizable* base);
VALA_EXTERN TubaWidgetsAdminAccountRow* tuba_widgets_admin_account_row_new (TubaAPIAdminAccount* account);
VALA_EXTERN TubaWidgetsAdminAccountRow* tuba_widgets_admin_account_row_construct (GType object_type,
                                                                      TubaAPIAdminAccount* account);
VALA_EXTERN GType tuba_widgets_admin_account_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminAccountRow, g_object_unref)
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_account_new (void);
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_account_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_admin_account_get_id (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_id (TubaAPIAdminAccount* self,
                                    const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_account_get_username (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_username (TubaAPIAdminAccount* self,
                                          const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_account_get_domain (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_domain (TubaAPIAdminAccount* self,
                                        const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_account_get_email (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_email (TubaAPIAdminAccount* self,
                                       const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_account_get_ip (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_ip (TubaAPIAdminAccount* self,
                                    const gchar* value);
VALA_EXTERN GeeArrayList* tuba_api_admin_account_get_ips (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_ips (TubaAPIAdminAccount* self,
                                     GeeArrayList* value);
VALA_EXTERN gboolean tuba_api_admin_account_get_confirmed (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_confirmed (TubaAPIAdminAccount* self,
                                           gboolean value);
VALA_EXTERN gboolean tuba_api_admin_account_get_suspended (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_suspended (TubaAPIAdminAccount* self,
                                           gboolean value);
VALA_EXTERN gboolean tuba_api_admin_account_get_disabled (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_disabled (TubaAPIAdminAccount* self,
                                          gboolean value);
VALA_EXTERN gboolean tuba_api_admin_account_get_silenced (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_silenced (TubaAPIAdminAccount* self,
                                          gboolean value);
VALA_EXTERN gboolean tuba_api_admin_account_get_approved (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_approved (TubaAPIAdminAccount* self,
                                          gboolean value);
VALA_EXTERN const gchar* tuba_api_admin_account_get_invite_request (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_invite_request (TubaAPIAdminAccount* self,
                                                const gchar* value);
VALA_EXTERN TubaAPIAccountRole* tuba_api_admin_account_get_role (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_role (TubaAPIAdminAccount* self,
                                      TubaAPIAccountRole* value);
VALA_EXTERN TubaAPIAccount* tuba_api_admin_account_get_account (TubaAPIAdminAccount* self);
VALA_EXTERN void tuba_api_admin_account_set_account (TubaAPIAdminAccount* self,
                                         TubaAPIAccount* value);
VALA_EXTERN TubaAPIAdminAccountIPAddress* tuba_api_admin_account_ip_address_new (void);
VALA_EXTERN TubaAPIAdminAccountIPAddress* tuba_api_admin_account_ip_address_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_admin_account_ip_address_get_ip (TubaAPIAdminAccountIPAddress* self);
VALA_EXTERN void tuba_api_admin_account_ip_address_set_ip (TubaAPIAdminAccountIPAddress* self,
                                               const gchar* value);
static void tuba_api_admin_account_ip_address_finalize (GObject * obj);
static GType tuba_api_admin_account_ip_address_get_type_once (void);
static void _vala_tuba_api_admin_account_ip_address_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_tuba_api_admin_account_ip_address_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);
VALA_EXTERN GtkWidget* tuba_basic_widgetizable_to_widget (TubaBasicWidgetizable* self);
static void tuba_api_admin_account_finalize (GObject * obj);
static GType tuba_api_admin_account_get_type_once (void);
static void _vala_tuba_api_admin_account_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_tuba_api_admin_account_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);

static inline gpointer
tuba_api_admin_account_get_instance_private (TubaAPIAdminAccount* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAdminAccount_private_offset);
}

static GType
tuba_api_admin_account_real_deserialize_array_type (TubaEntity* base,
                                                    const gchar* prop)
{
	TubaAPIAdminAccount * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIAdminAccount*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("ips")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_admin_account_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static GtkWidget*
tuba_api_admin_account_real_to_widget (TubaBasicWidgetizable* base)
{
	TubaAPIAdminAccount * self;
	TubaWidgetsAdminAccountRow* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIAdminAccount*) base;
	_tmp0_ = tuba_widgets_admin_account_row_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

TubaAPIAdminAccount*
tuba_api_admin_account_construct (GType object_type)
{
	TubaAPIAdminAccount * self = NULL;
	self = (TubaAPIAdminAccount*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAdminAccount*
tuba_api_admin_account_new (void)
{
	return tuba_api_admin_account_construct (TUBA_API_ADMIN_TYPE_ACCOUNT);
}

const gchar*
tuba_api_admin_account_get_id (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_id (TubaAPIAdminAccount* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_account_get_username (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_username;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_username (TubaAPIAdminAccount* self,
                                     const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_username (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_username);
		self->priv->_username = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_account_get_domain (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_domain;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_domain (TubaAPIAdminAccount* self,
                                   const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_domain (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_domain);
		self->priv->_domain = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_account_get_email (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_email;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_email (TubaAPIAdminAccount* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_email (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_email);
		self->priv->_email = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_account_get_ip (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_ip;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_ip (TubaAPIAdminAccount* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_ip (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_ip);
		self->priv->_ip = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_admin_account_get_ips (TubaAPIAdminAccount* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_ips;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_api_admin_account_set_ips (TubaAPIAdminAccount* self,
                                GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_ips (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_ips);
		self->priv->_ips = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY]);
	}
}

gboolean
tuba_api_admin_account_get_confirmed (TubaAPIAdminAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_confirmed;
	return result;
}

void
tuba_api_admin_account_set_confirmed (TubaAPIAdminAccount* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_confirmed (self);
	if (old_value != value) {
		self->priv->_confirmed = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY]);
	}
}

gboolean
tuba_api_admin_account_get_suspended (TubaAPIAdminAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_suspended;
	return result;
}

void
tuba_api_admin_account_set_suspended (TubaAPIAdminAccount* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_suspended (self);
	if (old_value != value) {
		self->priv->_suspended = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY]);
	}
}

gboolean
tuba_api_admin_account_get_disabled (TubaAPIAdminAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_disabled;
	return result;
}

void
tuba_api_admin_account_set_disabled (TubaAPIAdminAccount* self,
                                     gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_disabled (self);
	if (old_value != value) {
		self->priv->_disabled = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY]);
	}
}

gboolean
tuba_api_admin_account_get_silenced (TubaAPIAdminAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_silenced;
	return result;
}

void
tuba_api_admin_account_set_silenced (TubaAPIAdminAccount* self,
                                     gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_silenced (self);
	if (old_value != value) {
		self->priv->_silenced = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY]);
	}
}

gboolean
tuba_api_admin_account_get_approved (TubaAPIAdminAccount* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_approved;
	return result;
}

void
tuba_api_admin_account_set_approved (TubaAPIAdminAccount* self,
                                     gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_approved (self);
	if (old_value != value) {
		self->priv->_approved = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_account_get_invite_request (TubaAPIAdminAccount* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_invite_request;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_invite_request (TubaAPIAdminAccount* self,
                                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_invite_request (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_invite_request);
		self->priv->_invite_request = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY]);
	}
}

TubaAPIAccountRole*
tuba_api_admin_account_get_role (TubaAPIAdminAccount* self)
{
	TubaAPIAccountRole* result;
	TubaAPIAccountRole* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_role;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_role (TubaAPIAdminAccount* self,
                                 TubaAPIAccountRole* value)
{
	TubaAPIAccountRole* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_role (self);
	if (old_value != value) {
		TubaAPIAccountRole* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_role);
		self->priv->_role = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY]);
	}
}

TubaAPIAccount*
tuba_api_admin_account_get_account (TubaAPIAdminAccount* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_account;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_set_account (TubaAPIAdminAccount* self,
                                    TubaAPIAccount* value)
{
	TubaAPIAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_get_account (self);
	if (old_value != value) {
		TubaAPIAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_account);
		self->priv->_account = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY]);
	}
}

static inline gpointer
tuba_api_admin_account_ip_address_get_instance_private (TubaAPIAdminAccountIPAddress* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAdminAccountIPAddress_private_offset);
}

TubaAPIAdminAccountIPAddress*
tuba_api_admin_account_ip_address_construct (GType object_type)
{
	TubaAPIAdminAccountIPAddress * self = NULL;
	self = (TubaAPIAdminAccountIPAddress*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAdminAccountIPAddress*
tuba_api_admin_account_ip_address_new (void)
{
	return tuba_api_admin_account_ip_address_construct (TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS);
}

const gchar*
tuba_api_admin_account_ip_address_get_ip (TubaAPIAdminAccountIPAddress* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_ip;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_account_ip_address_set_ip (TubaAPIAdminAccountIPAddress* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_account_ip_address_get_ip (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_ip);
		self->priv->_ip = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_account_ip_address_properties[TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY]);
	}
}

static void
tuba_api_admin_account_ip_address_class_init (TubaAPIAdminAccountIPAddressClass * klass,
                                              gpointer klass_data)
{
	tuba_api_admin_account_ip_address_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAdminAccountIPAddress_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_admin_account_ip_address_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_admin_account_ip_address_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_admin_account_ip_address_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY, tuba_api_admin_account_ip_address_properties[TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY] = g_param_spec_string ("ip", "ip", "ip", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_admin_account_ip_address_instance_init (TubaAPIAdminAccountIPAddress * self,
                                                 gpointer klass)
{
	self->priv = tuba_api_admin_account_ip_address_get_instance_private (self);
}

static void
tuba_api_admin_account_ip_address_finalize (GObject * obj)
{
	TubaAPIAdminAccountIPAddress * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddress);
	_g_free0 (self->priv->_ip);
	G_OBJECT_CLASS (tuba_api_admin_account_ip_address_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_admin_account_ip_address_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAdminAccountIPAddressClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_admin_account_ip_address_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAdminAccountIPAddress), 0, (GInstanceInitFunc) tuba_api_admin_account_ip_address_instance_init, NULL };
	GType tuba_api_admin_account_ip_address_type_id;
	tuba_api_admin_account_ip_address_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAdminAccountIPAddress", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIAdminAccountIPAddress_private_offset = g_type_add_instance_private (tuba_api_admin_account_ip_address_type_id, sizeof (TubaAPIAdminAccountIPAddressPrivate));
	return tuba_api_admin_account_ip_address_type_id;
}

GType
tuba_api_admin_account_ip_address_get_type (void)
{
	static GType tuba_api_admin_account_ip_address_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_admin_account_ip_address_type_id__once)) {
		GType tuba_api_admin_account_ip_address_type_id;
		tuba_api_admin_account_ip_address_type_id = tuba_api_admin_account_ip_address_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_admin_account_ip_address_type_id__once, tuba_api_admin_account_ip_address_type_id);
	}
	return tuba_api_admin_account_ip_address_type_id__once;
}

static void
_vala_tuba_api_admin_account_ip_address_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAdminAccountIPAddress * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddress);
	switch (property_id) {
		case TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_ip_address_get_ip (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_admin_account_ip_address_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAdminAccountIPAddress * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_ACCOUNT_TYPE_IP_ADDRESS, TubaAPIAdminAccountIPAddress);
	switch (property_id) {
		case TUBA_API_ADMIN_ACCOUNT_IP_ADDRESS_IP_PROPERTY:
		tuba_api_admin_account_ip_address_set_ip (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_admin_account_class_init (TubaAPIAdminAccountClass * klass,
                                   gpointer klass_data)
{
	tuba_api_admin_account_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAdminAccount_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_admin_account_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_admin_account_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_admin_account_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_admin_account_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY] = g_param_spec_string ("username", "username", "username", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY] = g_param_spec_string ("domain", "domain", "domain", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY] = g_param_spec_string ("email", "email", "email", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY] = g_param_spec_string ("ip", "ip", "ip", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY] = g_param_spec_object ("ips", "ips", "ips", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY] = g_param_spec_boolean ("confirmed", "confirmed", "confirmed", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY] = g_param_spec_boolean ("suspended", "suspended", "suspended", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY] = g_param_spec_boolean ("disabled", "disabled", "disabled", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY] = g_param_spec_boolean ("silenced", "silenced", "silenced", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY] = g_param_spec_boolean ("approved", "approved", "approved", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY] = g_param_spec_string ("invite-request", "invite-request", "invite-request", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY] = g_param_spec_object ("role", "role", "role", TUBA_API_TYPE_ACCOUNT_ROLE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY, tuba_api_admin_account_properties[TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY] = g_param_spec_object ("account", "account", "account", TUBA_API_TYPE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_admin_account_tuba_basic_widgetizable_interface_init (TubaBasicWidgetizableIface * iface,
                                                               gpointer iface_data)
{
	tuba_api_admin_account_tuba_basic_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaBasicWidgetizable*)) tuba_api_admin_account_real_to_widget;
}

static void
tuba_api_admin_account_instance_init (TubaAPIAdminAccount * self,
                                      gpointer klass)
{
	self->priv = tuba_api_admin_account_get_instance_private (self);
	self->priv->_domain = NULL;
	self->priv->_ip = NULL;
	self->priv->_ips = NULL;
	self->priv->_confirmed = TRUE;
	self->priv->_suspended = FALSE;
	self->priv->_disabled = FALSE;
	self->priv->_silenced = FALSE;
	self->priv->_approved = TRUE;
	self->priv->_invite_request = NULL;
}

static void
tuba_api_admin_account_finalize (GObject * obj)
{
	TubaAPIAdminAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_username);
	_g_free0 (self->priv->_domain);
	_g_free0 (self->priv->_email);
	_g_free0 (self->priv->_ip);
	_g_object_unref0 (self->priv->_ips);
	_g_free0 (self->priv->_invite_request);
	_g_object_unref0 (self->priv->_role);
	_g_object_unref0 (self->priv->_account);
	G_OBJECT_CLASS (tuba_api_admin_account_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_admin_account_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAdminAccountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_admin_account_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAdminAccount), 0, (GInstanceInitFunc) tuba_api_admin_account_instance_init, NULL };
	static const GInterfaceInfo tuba_basic_widgetizable_info = { (GInterfaceInitFunc) tuba_api_admin_account_tuba_basic_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_admin_account_type_id;
	tuba_api_admin_account_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAdminAccount", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_admin_account_type_id, TUBA_TYPE_BASIC_WIDGETIZABLE, &tuba_basic_widgetizable_info);
	TubaAPIAdminAccount_private_offset = g_type_add_instance_private (tuba_api_admin_account_type_id, sizeof (TubaAPIAdminAccountPrivate));
	return tuba_api_admin_account_type_id;
}

GType
tuba_api_admin_account_get_type (void)
{
	static GType tuba_api_admin_account_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_admin_account_type_id__once)) {
		GType tuba_api_admin_account_type_id;
		tuba_api_admin_account_type_id = tuba_api_admin_account_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_admin_account_type_id__once, tuba_api_admin_account_type_id);
	}
	return tuba_api_admin_account_type_id__once;
}

static void
_vala_tuba_api_admin_account_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIAdminAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount);
	switch (property_id) {
		case TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_id (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_username (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_domain (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_email (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_ip (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY:
		g_value_set_object (value, tuba_api_admin_account_get_ips (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY:
		g_value_set_boolean (value, tuba_api_admin_account_get_confirmed (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY:
		g_value_set_boolean (value, tuba_api_admin_account_get_suspended (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY:
		g_value_set_boolean (value, tuba_api_admin_account_get_disabled (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY:
		g_value_set_boolean (value, tuba_api_admin_account_get_silenced (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY:
		g_value_set_boolean (value, tuba_api_admin_account_get_approved (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY:
		g_value_set_string (value, tuba_api_admin_account_get_invite_request (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY:
		g_value_set_object (value, tuba_api_admin_account_get_role (self));
		break;
		case TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY:
		g_value_set_object (value, tuba_api_admin_account_get_account (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_admin_account_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPIAdminAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount);
	switch (property_id) {
		case TUBA_API_ADMIN_ACCOUNT_ID_PROPERTY:
		tuba_api_admin_account_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_USERNAME_PROPERTY:
		tuba_api_admin_account_set_username (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_DOMAIN_PROPERTY:
		tuba_api_admin_account_set_domain (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_EMAIL_PROPERTY:
		tuba_api_admin_account_set_email (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_IP_PROPERTY:
		tuba_api_admin_account_set_ip (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_IPS_PROPERTY:
		tuba_api_admin_account_set_ips (self, g_value_get_object (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_CONFIRMED_PROPERTY:
		tuba_api_admin_account_set_confirmed (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_SUSPENDED_PROPERTY:
		tuba_api_admin_account_set_suspended (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_DISABLED_PROPERTY:
		tuba_api_admin_account_set_disabled (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_SILENCED_PROPERTY:
		tuba_api_admin_account_set_silenced (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_APPROVED_PROPERTY:
		tuba_api_admin_account_set_approved (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_INVITE_REQUEST_PROPERTY:
		tuba_api_admin_account_set_invite_request (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_ROLE_PROPERTY:
		tuba_api_admin_account_set_role (self, g_value_get_object (value));
		break;
		case TUBA_API_ADMIN_ACCOUNT_ACCOUNT_PROPERTY:
		tuba_api_admin_account_set_account (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

