/* Drafts.c generated by valac 0.56.19, the Vala compiler
 * generated from Drafts.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>

#define TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR (2000 + 3000)
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZEABLE (tuba_dialogs_composer_preferred_sizeable_get_type ())
#define TUBA_DIALOGS_COMPOSER_PREFERRED_SIZEABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZEABLE, TubaDialogsComposerPreferredSizeable))
#define TUBA_DIALOGS_COMPOSER_IS_PREFERRED_SIZEABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZEABLE))
#define TUBA_DIALOGS_COMPOSER_PREFERRED_SIZEABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZEABLE, TubaDialogsComposerPreferredSizeableIface))

typedef struct _TubaDialogsComposerPreferredSizeable TubaDialogsComposerPreferredSizeable;
typedef struct _TubaDialogsComposerPreferredSizeableIface TubaDialogsComposerPreferredSizeableIface;

#define TUBA_DIALOGS_TYPE_DRAFTS (tuba_dialogs_drafts_get_type ())
#define TUBA_DIALOGS_DRAFTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDrafts))
#define TUBA_DIALOGS_DRAFTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDraftsClass))
#define TUBA_DIALOGS_IS_DRAFTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_DRAFTS))
#define TUBA_DIALOGS_IS_DRAFTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_DRAFTS))
#define TUBA_DIALOGS_DRAFTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDraftsClass))

typedef struct _TubaDialogsDrafts TubaDialogsDrafts;
typedef struct _TubaDialogsDraftsClass TubaDialogsDraftsClass;
typedef struct _TubaDialogsDraftsPrivate TubaDialogsDraftsPrivate;
enum  {
	TUBA_DIALOGS_DRAFTS_0_PROPERTY,
	TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY,
	TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY,
	TUBA_DIALOGS_DRAFTS_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_drafts_properties[TUBA_DIALOGS_DRAFTS_NUM_PROPERTIES];

#define TUBA_WIDGETS_TYPE_SCHEDULED_STATUS (tuba_widgets_scheduled_status_get_type ())
#define TUBA_WIDGETS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus))
#define TUBA_WIDGETS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))

typedef struct _TubaWidgetsScheduledStatus TubaWidgetsScheduledStatus;
typedef struct _TubaWidgetsScheduledStatusClass TubaWidgetsScheduledStatusClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE (tuba_dialogs_drafts_inline_drafts_timeline_get_type ())
#define TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE, TubaDialogsDraftsInlineDraftsTimeline))
#define TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE, TubaDialogsDraftsInlineDraftsTimelineClass))
#define TUBA_DIALOGS_DRAFTS_IS_INLINE_DRAFTS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE))
#define TUBA_DIALOGS_DRAFTS_IS_INLINE_DRAFTS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE))
#define TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE, TubaDialogsDraftsInlineDraftsTimelineClass))

typedef struct _TubaDialogsDraftsInlineDraftsTimeline TubaDialogsDraftsInlineDraftsTimeline;
typedef struct _TubaDialogsDraftsInlineDraftsTimelineClass TubaDialogsDraftsInlineDraftsTimelineClass;
typedef struct _TubaDialogsDraftsInlineDraftsTimelinePrivate TubaDialogsDraftsInlineDraftsTimelinePrivate;
enum  {
	TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_0_PROPERTY,
	TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_drafts_inline_drafts_timeline_properties[TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_TYPE_SCHEDULED_STATUS (tuba_api_scheduled_status_get_type ())
#define TUBA_API_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus))
#define TUBA_API_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))
#define TUBA_API_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))

typedef struct _TubaAPIScheduledStatus TubaAPIScheduledStatus;
typedef struct _TubaAPIScheduledStatusClass TubaAPIScheduledStatusClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
enum  {
	TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_PICKED_DRAFT_SIGNAL,
	TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_NUM_SIGNALS
};
static guint tuba_dialogs_drafts_inline_drafts_timeline_signals[TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_NUM_SIGNALS] = {0};

#define TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN (tuba_dialogs_composer_preferred_size_bin_get_type ())
#define TUBA_DIALOGS_COMPOSER_PREFERRED_SIZE_BIN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN, TubaDialogsComposerPreferredSizeBin))
#define TUBA_DIALOGS_COMPOSER_PREFERRED_SIZE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN, TubaDialogsComposerPreferredSizeBinClass))
#define TUBA_DIALOGS_COMPOSER_IS_PREFERRED_SIZE_BIN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN))
#define TUBA_DIALOGS_COMPOSER_IS_PREFERRED_SIZE_BIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN))
#define TUBA_DIALOGS_COMPOSER_PREFERRED_SIZE_BIN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZE_BIN, TubaDialogsComposerPreferredSizeBinClass))

typedef struct _TubaDialogsComposerPreferredSizeBin TubaDialogsComposerPreferredSizeBin;
typedef struct _TubaDialogsComposerPreferredSizeBinClass TubaDialogsComposerPreferredSizeBinClass;
enum  {
	TUBA_DIALOGS_DRAFTS_DRAFT_SELECTED_SIGNAL,
	TUBA_DIALOGS_DRAFTS_NUM_SIGNALS
};
static guint tuba_dialogs_drafts_signals[TUBA_DIALOGS_DRAFTS_NUM_SIGNALS] = {0};

struct _TubaDialogsComposerPreferredSizeableIface {
	GTypeInterface parent_iface;
	gint (*get_preferred_height) (TubaDialogsComposerPreferredSizeable* self);
	void (*set_preferred_height) (TubaDialogsComposerPreferredSizeable* self, gint value);
	gint (*get_preferred_width) (TubaDialogsComposerPreferredSizeable* self);
	void (*set_preferred_width) (TubaDialogsComposerPreferredSizeable* self, gint value);
};

struct _TubaDialogsDrafts {
	AdwNavigationPage parent_instance;
	TubaDialogsDraftsPrivate * priv;
};

struct _TubaDialogsDraftsClass {
	AdwNavigationPageClass parent_class;
};

struct _TubaDialogsDraftsPrivate {
	gint _preferred_height;
	gint _preferred_width;
};

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaDialogsDraftsInlineDraftsTimeline {
	TubaViewsTimeline parent_instance;
	TubaDialogsDraftsInlineDraftsTimelinePrivate * priv;
};

struct _TubaDialogsDraftsInlineDraftsTimelineClass {
	TubaViewsTimelineClass parent_class;
};

static gint TubaDialogsDrafts_private_offset;
static gpointer tuba_dialogs_drafts_parent_class = NULL;
static gpointer tuba_dialogs_drafts_inline_drafts_timeline_parent_class = NULL;
static TubaDialogsComposerPreferredSizeableIface * tuba_dialogs_drafts_tuba_dialogs_composer_preferred_sizeable_parent_iface = NULL;

VALA_EXTERN GType tuba_dialogs_composer_preferred_sizeable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerPreferredSizeable, g_object_unref)
VALA_EXTERN GType tuba_dialogs_drafts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsDrafts, g_object_unref)
VALA_EXTERN GType tuba_widgets_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsScheduledStatus, g_object_unref)
static void tuba_dialogs_drafts_on_draft_selected (TubaDialogsDrafts* self,
                                            TubaWidgetsScheduledStatus* draft_status_widget);
VALA_EXTERN TubaDialogsDrafts* tuba_dialogs_drafts_new (void);
VALA_EXTERN TubaDialogsDrafts* tuba_dialogs_drafts_construct (GType object_type);
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_dialogs_drafts_inline_drafts_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsDraftsInlineDraftsTimeline, g_object_unref)
VALA_EXTERN GtkWidget* tuba_views_content_base_on_create_model_widget (TubaViewsContentBase* self,
                                                           GObject* obj);
VALA_EXTERN gboolean tuba_views_timeline_should_hide (TubaViewsTimeline* self,
                                          TubaEntity* entity);
VALA_EXTERN TubaDialogsDraftsInlineDraftsTimeline* tuba_dialogs_drafts_inline_drafts_timeline_new (void);
VALA_EXTERN TubaDialogsDraftsInlineDraftsTimeline* tuba_dialogs_drafts_inline_drafts_timeline_construct (GType object_type);
static GtkWidget* tuba_dialogs_drafts_inline_drafts_timeline_real_on_create_model_widget (TubaViewsContentBase* base,
                                                                                   GObject* obj);
VALA_EXTERN void tuba_widgets_scheduled_status_set_draft (TubaWidgetsScheduledStatus* self,
                                              gboolean value);
VALA_EXTERN void tuba_widgets_scheduled_status_set_is_inline (TubaWidgetsScheduledStatus* self,
                                                  gboolean value);
static void tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked (TubaDialogsDraftsInlineDraftsTimeline* self,
                                                                   TubaWidgetsScheduledStatus* draft_status_widget);
static void _tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked_tuba_widgets_scheduled_status_inline_clicked (TubaWidgetsScheduledStatus* _sender,
                                                                                                                 gpointer self);
static gboolean tuba_dialogs_drafts_inline_drafts_timeline_real_should_hide (TubaViewsTimeline* base,
                                                                      TubaEntity* entity);
VALA_EXTERN GType tuba_api_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatus, g_object_unref)
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_scheduled_at (TubaAPIScheduledStatus* self);
static GObject * tuba_dialogs_drafts_inline_drafts_timeline_constructor (GType type,
                                                                  guint n_construct_properties,
                                                                  GObjectConstructParam * construct_properties);
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
static GType tuba_dialogs_drafts_inline_drafts_timeline_get_type_once (void);
static GObject * tuba_dialogs_drafts_constructor (GType type,
                                           guint n_construct_properties,
                                           GObjectConstructParam * construct_properties);
static void _tuba_dialogs_drafts_on_draft_selected_tuba_dialogs_drafts_inline_drafts_timeline_picked_draft (TubaDialogsDraftsInlineDraftsTimeline* _sender,
                                                                                                     TubaWidgetsScheduledStatus* draft_status_widget,
                                                                                                     gpointer self);
VALA_EXTERN GType tuba_dialogs_composer_preferred_size_bin_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerPreferredSizeBin, g_object_unref)
VALA_EXTERN TubaDialogsComposerPreferredSizeBin* tuba_dialogs_composer_preferred_size_bin_new (void);
VALA_EXTERN TubaDialogsComposerPreferredSizeBin* tuba_dialogs_composer_preferred_size_bin_construct (GType object_type);
VALA_EXTERN void tuba_dialogs_composer_preferred_size_bin_set_child (TubaDialogsComposerPreferredSizeBin* self,
                                                         GtkWidget* value);
VALA_EXTERN gint tuba_dialogs_composer_preferred_sizeable_get_preferred_height (TubaDialogsComposerPreferredSizeable* self);
VALA_EXTERN void tuba_dialogs_composer_preferred_sizeable_set_preferred_height (TubaDialogsComposerPreferredSizeable* self,
                                                                    gint value);
VALA_EXTERN gint tuba_dialogs_composer_preferred_sizeable_get_preferred_width (TubaDialogsComposerPreferredSizeable* self);
VALA_EXTERN void tuba_dialogs_composer_preferred_sizeable_set_preferred_width (TubaDialogsComposerPreferredSizeable* self,
                                                                   gint value);
static void tuba_dialogs_drafts_finalize (GObject * obj);
static GType tuba_dialogs_drafts_get_type_once (void);
static void _vala_tuba_dialogs_drafts_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec);
static void _vala_tuba_dialogs_drafts_set_property (GObject * object,
                                             guint property_id,
                                             const GValue * value,
                                             GParamSpec * pspec);

static inline gpointer
tuba_dialogs_drafts_get_instance_private (TubaDialogsDrafts* self)
{
	return G_STRUCT_MEMBER_P (self, TubaDialogsDrafts_private_offset);
}

static void
tuba_dialogs_drafts_on_draft_selected (TubaDialogsDrafts* self,
                                       TubaWidgetsScheduledStatus* draft_status_widget)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (draft_status_widget != NULL);
	g_signal_emit (self, tuba_dialogs_drafts_signals[TUBA_DIALOGS_DRAFTS_DRAFT_SELECTED_SIGNAL], 0, draft_status_widget);
}

TubaDialogsDrafts*
tuba_dialogs_drafts_construct (GType object_type)
{
	TubaDialogsDrafts * self = NULL;
	self = (TubaDialogsDrafts*) g_object_new (object_type, NULL);
	return self;
}

TubaDialogsDrafts*
tuba_dialogs_drafts_new (void)
{
	return tuba_dialogs_drafts_construct (TUBA_DIALOGS_TYPE_DRAFTS);
}

static gint
tuba_dialogs_drafts_real_get_preferred_height (TubaDialogsComposerPreferredSizeable* base)
{
	gint result;
	TubaDialogsDrafts* self;
	self = (TubaDialogsDrafts*) base;
	result = self->priv->_preferred_height;
	return result;
}

static void
tuba_dialogs_drafts_real_set_preferred_height (TubaDialogsComposerPreferredSizeable* base,
                                               gint value)
{
	TubaDialogsDrafts* self;
	gint old_value;
	self = (TubaDialogsDrafts*) base;
	old_value = tuba_dialogs_drafts_real_get_preferred_height (base);
	if (old_value != value) {
		self->priv->_preferred_height = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_drafts_properties[TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY]);
	}
}

static gint
tuba_dialogs_drafts_real_get_preferred_width (TubaDialogsComposerPreferredSizeable* base)
{
	gint result;
	TubaDialogsDrafts* self;
	self = (TubaDialogsDrafts*) base;
	result = self->priv->_preferred_width;
	return result;
}

static void
tuba_dialogs_drafts_real_set_preferred_width (TubaDialogsComposerPreferredSizeable* base,
                                              gint value)
{
	TubaDialogsDrafts* self;
	gint old_value;
	self = (TubaDialogsDrafts*) base;
	old_value = tuba_dialogs_drafts_real_get_preferred_width (base);
	if (old_value != value) {
		self->priv->_preferred_width = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_drafts_properties[TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY]);
	}
}

TubaDialogsDraftsInlineDraftsTimeline*
tuba_dialogs_drafts_inline_drafts_timeline_construct (GType object_type)
{
	TubaDialogsDraftsInlineDraftsTimeline * self = NULL;
	AdwHeaderBar* _tmp0_;
	AdwHeaderBar* _tmp1_;
	self = (TubaDialogsDraftsInlineDraftsTimeline*) g_object_new (object_type, "url", "/api/v1/scheduled_statuses", "label", _ ("Draft Posts"), "icon", "tuba-chat-symbolic", "empty-state-title", _ ("No Draft Posts"), "batch-size-min", 20, NULL);
	_tmp0_ = ((TubaViewsBase*) self)->header;
	adw_header_bar_set_show_start_title_buttons (_tmp0_, FALSE);
	_tmp1_ = ((TubaViewsBase*) self)->header;
	adw_header_bar_set_show_end_title_buttons (_tmp1_, FALSE);
	return self;
}

TubaDialogsDraftsInlineDraftsTimeline*
tuba_dialogs_drafts_inline_drafts_timeline_new (void)
{
	return tuba_dialogs_drafts_inline_drafts_timeline_construct (TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked_tuba_widgets_scheduled_status_inline_clicked (TubaWidgetsScheduledStatus* _sender,
                                                                                                            gpointer self)
{
	tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked ((TubaDialogsDraftsInlineDraftsTimeline*) self, _sender);
}

static GtkWidget*
tuba_dialogs_drafts_inline_drafts_timeline_real_on_create_model_widget (TubaViewsContentBase* base,
                                                                        GObject* obj)
{
	TubaDialogsDraftsInlineDraftsTimeline * self;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	TubaWidgetsScheduledStatus* widget_scheduled = NULL;
	GtkWidget* _tmp1_;
	TubaWidgetsScheduledStatus* _tmp2_;
	TubaWidgetsScheduledStatus* _tmp3_;
	GtkWidget* result;
	self = (TubaDialogsDraftsInlineDraftsTimeline*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_dialogs_drafts_inline_drafts_timeline_parent_class)->on_create_model_widget ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline), obj);
	widget = _tmp0_;
	_tmp1_ = widget;
	_tmp2_ = _g_object_ref0 (TUBA_WIDGETS_IS_SCHEDULED_STATUS (_tmp1_) ? ((TubaWidgetsScheduledStatus*) _tmp1_) : NULL);
	widget_scheduled = _tmp2_;
	_tmp3_ = widget_scheduled;
	if (_tmp3_ != NULL) {
		TubaWidgetsScheduledStatus* _tmp4_;
		TubaWidgetsScheduledStatus* _tmp5_;
		TubaWidgetsScheduledStatus* _tmp6_;
		_tmp4_ = widget_scheduled;
		tuba_widgets_scheduled_status_set_draft (_tmp4_, TRUE);
		_tmp5_ = widget_scheduled;
		tuba_widgets_scheduled_status_set_is_inline (_tmp5_, TRUE);
		_tmp6_ = widget_scheduled;
		g_signal_connect_object (_tmp6_, "inline-clicked", (GCallback) _tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked_tuba_widgets_scheduled_status_inline_clicked, self, 0);
	}
	result = widget;
	_g_object_unref0 (widget_scheduled);
	return result;
}

static gboolean
tuba_dialogs_drafts_inline_drafts_timeline_real_should_hide (TubaViewsTimeline* base,
                                                             TubaEntity* entity)
{
	TubaDialogsDraftsInlineDraftsTimeline * self;
	TubaAPIScheduledStatus* scheduled_entity = NULL;
	TubaAPIScheduledStatus* _tmp0_;
	gboolean _tmp1_ = FALSE;
	TubaAPIScheduledStatus* _tmp2_;
	gboolean result;
	self = (TubaDialogsDraftsInlineDraftsTimeline*) base;
	g_return_val_if_fail (entity != NULL, FALSE);
	_tmp0_ = _g_object_ref0 (TUBA_API_IS_SCHEDULED_STATUS (entity) ? ((TubaAPIScheduledStatus*) entity) : NULL);
	scheduled_entity = _tmp0_;
	_tmp2_ = scheduled_entity;
	if (_tmp2_ != NULL) {
		TubaAPIScheduledStatus* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		GDateTime* _tmp6_;
		GDateTime* _tmp7_;
		_tmp3_ = scheduled_entity;
		_tmp4_ = tuba_api_scheduled_status_get_scheduled_at (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_date_time_new_from_iso8601 (_tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp1_ = g_date_time_get_year (_tmp7_) <= TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR;
		_g_date_time_unref0 (_tmp7_);
	} else {
		_tmp1_ = FALSE;
	}
	result = _tmp1_;
	_g_object_unref0 (scheduled_entity);
	return result;
}

static void
tuba_dialogs_drafts_inline_drafts_timeline_on_inline_clicked (TubaDialogsDraftsInlineDraftsTimeline* self,
                                                              TubaWidgetsScheduledStatus* draft_status_widget)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (draft_status_widget != NULL);
	g_signal_emit (self, tuba_dialogs_drafts_inline_drafts_timeline_signals[TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_PICKED_DRAFT_SIGNAL], 0, draft_status_widget);
}

static GObject *
tuba_dialogs_drafts_inline_drafts_timeline_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaDialogsDraftsInlineDraftsTimeline * self;
	parent_class = G_OBJECT_CLASS (tuba_dialogs_drafts_inline_drafts_timeline_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE, TubaDialogsDraftsInlineDraftsTimeline);
	tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_SCHEDULED_STATUS);
	return obj;
}

static void
tuba_dialogs_drafts_inline_drafts_timeline_class_init (TubaDialogsDraftsInlineDraftsTimelineClass * klass,
                                                       gpointer klass_data)
{
	tuba_dialogs_drafts_inline_drafts_timeline_parent_class = g_type_class_peek_parent (klass);
	((TubaViewsContentBaseClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsContentBase*, GObject*)) tuba_dialogs_drafts_inline_drafts_timeline_real_on_create_model_widget;
	((TubaViewsTimelineClass *) klass)->should_hide = (gboolean (*) (TubaViewsTimeline*, TubaEntity*)) tuba_dialogs_drafts_inline_drafts_timeline_real_should_hide;
	G_OBJECT_CLASS (klass)->constructor = tuba_dialogs_drafts_inline_drafts_timeline_constructor;
	tuba_dialogs_drafts_inline_drafts_timeline_signals[TUBA_DIALOGS_DRAFTS_INLINE_DRAFTS_TIMELINE_PICKED_DRAFT_SIGNAL] = g_signal_new ("picked-draft", TUBA_DIALOGS_DRAFTS_TYPE_INLINE_DRAFTS_TIMELINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS);
}

static void
tuba_dialogs_drafts_inline_drafts_timeline_instance_init (TubaDialogsDraftsInlineDraftsTimeline * self,
                                                          gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_drafts_inline_drafts_timeline_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsDraftsInlineDraftsTimelineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_drafts_inline_drafts_timeline_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsDraftsInlineDraftsTimeline), 0, (GInstanceInitFunc) tuba_dialogs_drafts_inline_drafts_timeline_instance_init, NULL };
	GType tuba_dialogs_drafts_inline_drafts_timeline_type_id;
	tuba_dialogs_drafts_inline_drafts_timeline_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaDialogsDraftsInlineDraftsTimeline", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_dialogs_drafts_inline_drafts_timeline_type_id;
}

GType
tuba_dialogs_drafts_inline_drafts_timeline_get_type (void)
{
	static GType tuba_dialogs_drafts_inline_drafts_timeline_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_drafts_inline_drafts_timeline_type_id__once)) {
		GType tuba_dialogs_drafts_inline_drafts_timeline_type_id;
		tuba_dialogs_drafts_inline_drafts_timeline_type_id = tuba_dialogs_drafts_inline_drafts_timeline_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_drafts_inline_drafts_timeline_type_id__once, tuba_dialogs_drafts_inline_drafts_timeline_type_id);
	}
	return tuba_dialogs_drafts_inline_drafts_timeline_type_id__once;
}

static void
_tuba_dialogs_drafts_on_draft_selected_tuba_dialogs_drafts_inline_drafts_timeline_picked_draft (TubaDialogsDraftsInlineDraftsTimeline* _sender,
                                                                                                TubaWidgetsScheduledStatus* draft_status_widget,
                                                                                                gpointer self)
{
	tuba_dialogs_drafts_on_draft_selected ((TubaDialogsDrafts*) self, draft_status_widget);
}

static GObject *
tuba_dialogs_drafts_constructor (GType type,
                                 guint n_construct_properties,
                                 GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaDialogsDrafts * self;
	TubaDialogsDraftsInlineDraftsTimeline* timeline = NULL;
	TubaDialogsDraftsInlineDraftsTimeline* _tmp0_;
	TubaDialogsDraftsInlineDraftsTimeline* _tmp1_;
	TubaDialogsComposerPreferredSizeBin* preferred_size_bin = NULL;
	TubaDialogsDraftsInlineDraftsTimeline* _tmp2_;
	GtkWidget* _tmp3_;
	TubaDialogsComposerPreferredSizeBin* _tmp4_ = NULL;
	TubaDialogsComposerPreferredSizeBin* _tmp5_;
	TubaDialogsComposerPreferredSizeBin* _tmp6_;
	TubaDialogsComposerPreferredSizeBin* _tmp7_;
	parent_class = G_OBJECT_CLASS (tuba_dialogs_drafts_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDrafts);
	adw_navigation_page_set_title ((AdwNavigationPage*) self, _ ("Draft Posts"));
	_tmp0_ = tuba_dialogs_drafts_inline_drafts_timeline_new ();
	g_object_ref_sink (_tmp0_);
	timeline = _tmp0_;
	_tmp1_ = timeline;
	g_signal_connect_object (_tmp1_, "picked-draft", (GCallback) _tuba_dialogs_drafts_on_draft_selected_tuba_dialogs_drafts_inline_drafts_timeline_picked_draft, self, 0);
	_tmp2_ = timeline;
	_tmp3_ = _g_object_ref0 ((GtkWidget*) _tmp2_);
	_tmp4_ = tuba_dialogs_composer_preferred_size_bin_new ();
	tuba_dialogs_composer_preferred_size_bin_set_child (_tmp4_, _tmp3_);
	_g_object_unref0 (_tmp3_);
	g_object_ref_sink (_tmp4_);
	preferred_size_bin = _tmp4_;
	_tmp5_ = preferred_size_bin;
	g_object_bind_property_with_closures ((GObject*) self, "preferred-height", (GObject*) _tmp5_, "height", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp6_ = preferred_size_bin;
	g_object_bind_property_with_closures ((GObject*) self, "preferred-width", (GObject*) _tmp6_, "width", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp7_ = preferred_size_bin;
	adw_navigation_page_set_child ((AdwNavigationPage*) self, (GtkWidget*) _tmp7_);
	_g_object_unref0 (preferred_size_bin);
	_g_object_unref0 (timeline);
	return obj;
}

static void
tuba_dialogs_drafts_class_init (TubaDialogsDraftsClass * klass,
                                gpointer klass_data)
{
	tuba_dialogs_drafts_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaDialogsDrafts_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_dialogs_drafts_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_dialogs_drafts_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_dialogs_drafts_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_dialogs_drafts_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY, tuba_dialogs_drafts_properties[TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY] = g_param_spec_int ("preferred-height", "preferred-height", "preferred-height", G_MININT, G_MAXINT, -1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY, tuba_dialogs_drafts_properties[TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY] = g_param_spec_int ("preferred-width", "preferred-width", "preferred-width", G_MININT, G_MAXINT, -1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_dialogs_drafts_signals[TUBA_DIALOGS_DRAFTS_DRAFT_SELECTED_SIGNAL] = g_signal_new ("draft-selected", TUBA_DIALOGS_TYPE_DRAFTS, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_WIDGETS_TYPE_SCHEDULED_STATUS);
}

static void
tuba_dialogs_drafts_tuba_dialogs_composer_preferred_sizeable_interface_init (TubaDialogsComposerPreferredSizeableIface * iface,
                                                                             gpointer iface_data)
{
	tuba_dialogs_drafts_tuba_dialogs_composer_preferred_sizeable_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_preferred_height = tuba_dialogs_drafts_real_get_preferred_height;
	iface->set_preferred_height = tuba_dialogs_drafts_real_set_preferred_height;
	iface->get_preferred_width = tuba_dialogs_drafts_real_get_preferred_width;
	iface->set_preferred_width = tuba_dialogs_drafts_real_set_preferred_width;
}

static void
tuba_dialogs_drafts_instance_init (TubaDialogsDrafts * self,
                                   gpointer klass)
{
	self->priv = tuba_dialogs_drafts_get_instance_private (self);
	self->priv->_preferred_height = -1;
	self->priv->_preferred_width = -1;
}

static void
tuba_dialogs_drafts_finalize (GObject * obj)
{
	TubaDialogsDrafts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDrafts);
	g_debug ("Drafts.vala:7: Destroying Drafts");
	G_OBJECT_CLASS (tuba_dialogs_drafts_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_drafts_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsDraftsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_drafts_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsDrafts), 0, (GInstanceInitFunc) tuba_dialogs_drafts_instance_init, NULL };
	static const GInterfaceInfo tuba_dialogs_composer_preferred_sizeable_info = { (GInterfaceInitFunc) tuba_dialogs_drafts_tuba_dialogs_composer_preferred_sizeable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_dialogs_drafts_type_id;
	tuba_dialogs_drafts_type_id = g_type_register_static (adw_navigation_page_get_type (), "TubaDialogsDrafts", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_dialogs_drafts_type_id, TUBA_DIALOGS_COMPOSER_TYPE_PREFERRED_SIZEABLE, &tuba_dialogs_composer_preferred_sizeable_info);
	TubaDialogsDrafts_private_offset = g_type_add_instance_private (tuba_dialogs_drafts_type_id, sizeof (TubaDialogsDraftsPrivate));
	return tuba_dialogs_drafts_type_id;
}

GType
tuba_dialogs_drafts_get_type (void)
{
	static GType tuba_dialogs_drafts_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_drafts_type_id__once)) {
		GType tuba_dialogs_drafts_type_id;
		tuba_dialogs_drafts_type_id = tuba_dialogs_drafts_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_drafts_type_id__once, tuba_dialogs_drafts_type_id);
	}
	return tuba_dialogs_drafts_type_id__once;
}

static void
_vala_tuba_dialogs_drafts_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec)
{
	TubaDialogsDrafts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDrafts);
	switch (property_id) {
		case TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY:
		g_value_set_int (value, tuba_dialogs_composer_preferred_sizeable_get_preferred_height ((TubaDialogsComposerPreferredSizeable*) self));
		break;
		case TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY:
		g_value_set_int (value, tuba_dialogs_composer_preferred_sizeable_get_preferred_width ((TubaDialogsComposerPreferredSizeable*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_dialogs_drafts_set_property (GObject * object,
                                        guint property_id,
                                        const GValue * value,
                                        GParamSpec * pspec)
{
	TubaDialogsDrafts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_TYPE_DRAFTS, TubaDialogsDrafts);
	switch (property_id) {
		case TUBA_DIALOGS_DRAFTS_PREFERRED_HEIGHT_PROPERTY:
		tuba_dialogs_composer_preferred_sizeable_set_preferred_height ((TubaDialogsComposerPreferredSizeable*) self, g_value_get_int (value));
		break;
		case TUBA_DIALOGS_DRAFTS_PREFERRED_WIDTH_PROPERTY:
		tuba_dialogs_composer_preferred_sizeable_set_preferred_width ((TubaDialogsComposerPreferredSizeable*) self, g_value_get_int (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

