/* HashtagProvider.c generated by valac 0.56.19, the Vala compiler
 * generated from HashtagProvider.vala, do not modify */

#include <glib-object.h>
#include <gtksourceview/gtksource.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_COMPLETION_PROVIDER (tuba_completion_provider_get_type ())
#define TUBA_COMPLETION_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_COMPLETION_PROVIDER, TubaCompletionProvider))
#define TUBA_COMPLETION_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_COMPLETION_PROVIDER, TubaCompletionProviderClass))
#define TUBA_IS_COMPLETION_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_COMPLETION_PROVIDER))
#define TUBA_IS_COMPLETION_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_COMPLETION_PROVIDER))
#define TUBA_COMPLETION_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_COMPLETION_PROVIDER, TubaCompletionProviderClass))

typedef struct _TubaCompletionProvider TubaCompletionProvider;
typedef struct _TubaCompletionProviderClass TubaCompletionProviderClass;
typedef struct _TubaCompletionProviderPrivate TubaCompletionProviderPrivate;

#define TUBA_TYPE_HASHTAG_PROVIDER (tuba_hashtag_provider_get_type ())
#define TUBA_HASHTAG_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_HASHTAG_PROVIDER, TubaHashtagProvider))
#define TUBA_HASHTAG_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_HASHTAG_PROVIDER, TubaHashtagProviderClass))
#define TUBA_IS_HASHTAG_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_HASHTAG_PROVIDER))
#define TUBA_IS_HASHTAG_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_HASHTAG_PROVIDER))
#define TUBA_HASHTAG_PROVIDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_HASHTAG_PROVIDER, TubaHashtagProviderClass))

typedef struct _TubaHashtagProvider TubaHashtagProvider;
typedef struct _TubaHashtagProviderClass TubaHashtagProviderClass;
typedef struct _TubaHashtagProviderPrivate TubaHashtagProviderPrivate;
enum  {
	TUBA_HASHTAG_PROVIDER_0_PROPERTY,
	TUBA_HASHTAG_PROVIDER_NUM_PROPERTIES
};
static GParamSpec* tuba_hashtag_provider_properties[TUBA_HASHTAG_PROVIDER_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block47Data Block47Data;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_SEARCH_RESULTS (tuba_api_search_results_get_type ())
#define TUBA_API_SEARCH_RESULTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SEARCH_RESULTS, TubaAPISearchResults))
#define TUBA_API_SEARCH_RESULTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SEARCH_RESULTS, TubaAPISearchResultsClass))
#define TUBA_API_IS_SEARCH_RESULTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SEARCH_RESULTS))
#define TUBA_API_IS_SEARCH_RESULTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SEARCH_RESULTS))
#define TUBA_API_SEARCH_RESULTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SEARCH_RESULTS, TubaAPISearchResultsClass))

typedef struct _TubaAPISearchResults TubaAPISearchResults;
typedef struct _TubaAPISearchResultsClass TubaAPISearchResultsClass;

#define TUBA_TYPE_NETWORK (tuba_network_get_type ())
#define TUBA_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_NETWORK, TubaNetwork))
#define TUBA_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_NETWORK, TubaNetworkClass))
#define TUBA_IS_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_NETWORK))
#define TUBA_IS_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_NETWORK))
#define TUBA_NETWORK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_NETWORK, TubaNetworkClass))

typedef struct _TubaNetwork TubaNetwork;
typedef struct _TubaNetworkClass TubaNetworkClass;
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))

#define TUBA_API_TYPE_TAG (tuba_api_tag_get_type ())
#define TUBA_API_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_TAG, TubaAPITag))
#define TUBA_API_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_TAG, TubaAPITagClass))
#define TUBA_API_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_TAG))
#define TUBA_API_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_TAG))
#define TUBA_API_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_TAG, TubaAPITagClass))

typedef struct _TubaAPITag TubaAPITag;
typedef struct _TubaAPITagClass TubaAPITagClass;

#define TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL (tuba_hashtag_provider_proposal_get_type ())
#define TUBA_HASHTAG_PROVIDER_PROPOSAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposal))
#define TUBA_HASHTAG_PROVIDER_PROPOSAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposalClass))
#define TUBA_HASHTAG_PROVIDER_IS_PROPOSAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL))
#define TUBA_HASHTAG_PROVIDER_IS_PROPOSAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL))
#define TUBA_HASHTAG_PROVIDER_PROPOSAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposalClass))

typedef struct _TubaHashtagProviderProposal TubaHashtagProviderProposal;
typedef struct _TubaHashtagProviderProposalClass TubaHashtagProviderProposalClass;
typedef struct _TubaHashtagProviderSuggestData TubaHashtagProviderSuggestData;
typedef struct _TubaHashtagProviderProposalPrivate TubaHashtagProviderProposalPrivate;
enum  {
	TUBA_HASHTAG_PROVIDER_PROPOSAL_0_PROPERTY,
	TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY,
	TUBA_HASHTAG_PROVIDER_PROPOSAL_NUM_PROPERTIES
};
static GParamSpec* tuba_hashtag_provider_proposal_properties[TUBA_HASHTAG_PROVIDER_PROPOSAL_NUM_PROPERTIES];

struct _TubaCompletionProvider {
	GObject parent_instance;
	TubaCompletionProviderPrivate * priv;
};

struct _TubaCompletionProviderClass {
	GObjectClass parent_class;
	gboolean (*is_trigger) (TubaCompletionProvider* self, GtkTextIter* iter, gunichar ch);
	void (*refilter) (TubaCompletionProvider* self, GtkSourceCompletionContext* context, GListModel* model);
	void (*activate) (TubaCompletionProvider* self, GtkSourceCompletionContext* context, GtkSourceCompletionProposal* proposal);
	void (*display) (TubaCompletionProvider* self, GtkSourceCompletionContext* context, GtkSourceCompletionProposal* proposal, GtkSourceCompletionCell* cell);
	void (*suggest) (TubaCompletionProvider* self, const gchar* word, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GListModel* (*suggest_finish) (TubaCompletionProvider* self, GAsyncResult* _res_, GError** error);
	gboolean (*word_stop) (TubaCompletionProvider* self, gunichar ch);
	gchar* (*get_formatted_text) (TubaCompletionProvider* self, GtkSourceCompletionProposal* proposal);
};

struct _TubaHashtagProvider {
	TubaCompletionProvider parent_instance;
	TubaHashtagProviderPrivate * priv;
};

struct _TubaHashtagProviderClass {
	TubaCompletionProviderClass parent_class;
};

struct _Block47Data {
	int _ref_count_;
	TubaHashtagProvider* self;
	GListStore* suggestions;
	gpointer _async_data_;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaHashtagProviderSuggestData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaHashtagProvider* self;
	gchar* word;
	GCancellable* cancellable;
	GListModel* result;
	Block47Data* _data47_;
	gchar* tag;
	gchar* _tmp0_;
	GListStore* _tmp1_;
	const gchar* _tmp2_;
	GListStore* _tmp3_;
	GListModel* _tmp4_;
	TubaRequestV2* req;
	const gchar* _tmp5_;
	TubaRequestV2* _tmp6_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp7_;
	GInputStream* _tmp8_;
	JsonParser* parser;
	GInputStream* _tmp9_;
	JsonParser* _tmp10_;
	TubaAPISearchResults* results;
	TubaNetwork* _tmp11_;
	JsonParser* _tmp12_;
	JsonNode* _tmp13_;
	JsonNode* _tmp14_;
	TubaAPISearchResults* _tmp15_;
	TubaAPISearchResults* _tmp16_;
	TubaAPISearchResults* _tmp17_;
	TubaAPISearchResults* _tmp18_;
	GeeArrayList* _tmp19_;
	GeeArrayList* _tmp20_;
	GListStore* _tmp21_;
	GListModel* _tmp22_;
	GError* _inner_error0_;
};

struct _TubaHashtagProviderProposal {
	GObject parent_instance;
	TubaHashtagProviderProposalPrivate * priv;
};

struct _TubaHashtagProviderProposalClass {
	GObjectClass parent_class;
};

struct _TubaHashtagProviderProposalPrivate {
	TubaAPITag* _tag;
};

static gpointer tuba_hashtag_provider_parent_class = NULL;
VALA_EXTERN TubaNetwork* tuba_network;
static gint TubaHashtagProviderProposal_private_offset;
static gpointer tuba_hashtag_provider_proposal_parent_class = NULL;
static GtkSourceCompletionProposalInterface * tuba_hashtag_provider_proposal_gtk_source_completion_proposal_parent_iface = NULL;

VALA_EXTERN GType tuba_completion_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaCompletionProvider, g_object_unref)
VALA_EXTERN GType tuba_hashtag_provider_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaHashtagProvider, g_object_unref)
VALA_EXTERN void tuba_completion_provider_suggest (TubaCompletionProvider* self,
                                       const gchar* word,
                                       GCancellable* cancellable,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN GListModel* tuba_completion_provider_suggest_finish (TubaCompletionProvider* self,
                                                     GAsyncResult* _res_,
                                                     GError** error);
VALA_EXTERN void tuba_completion_provider_display (TubaCompletionProvider* self,
                                       GtkSourceCompletionContext* context,
                                       GtkSourceCompletionProposal* proposal,
                                       GtkSourceCompletionCell* cell);
VALA_EXTERN TubaHashtagProvider* tuba_hashtag_provider_new (void);
VALA_EXTERN TubaHashtagProvider* tuba_hashtag_provider_construct (GType object_type);
static void tuba_hashtag_provider_real_suggest_data_free (gpointer _data);
static void tuba_hashtag_provider_real_suggest (TubaCompletionProvider* base,
                                         const gchar* word,
                                         GCancellable* cancellable,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
static gboolean tuba_hashtag_provider_real_suggest_co (TubaHashtagProviderSuggestData* _data_);
static Block47Data* block47_data_ref (Block47Data* _data47_);
static void block47_data_unref (void * _userdata_);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN TubaRequestV2* tuba_api_tag_search (const gchar* query,
                                    GError** error);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_hashtag_provider_suggest_ready (GObject* source_object,
                                          GAsyncResult* _res_,
                                          gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_search_results_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPISearchResults, g_object_unref)
VALA_EXTERN TubaAPISearchResults* tuba_api_search_results_from (JsonNode* node,
                                                    GError** error);
VALA_EXTERN GType tuba_network_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaNetwork, g_object_unref)
VALA_EXTERN JsonNode* tuba_network_parse_node (TubaNetwork* self,
                                   JsonParser* parser);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN GType tuba_api_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPITag, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_search_results_get_hashtags (TubaAPISearchResults* self);
static gboolean ___lambda69_ (Block47Data* _data47_,
                       TubaAPITag* tag);
VALA_EXTERN GType tuba_hashtag_provider_proposal_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaHashtagProviderProposal, g_object_unref)
VALA_EXTERN TubaHashtagProviderProposal* tuba_hashtag_provider_proposal_new (TubaAPITag* entity);
VALA_EXTERN TubaHashtagProviderProposal* tuba_hashtag_provider_proposal_construct (GType object_type,
                                                                       TubaAPITag* entity);
static gboolean ____lambda69__gee_forall_func (gpointer g,
                                        gpointer self);
static void tuba_hashtag_provider_real_display (TubaCompletionProvider* base,
                                         GtkSourceCompletionContext* context,
                                         GtkSourceCompletionProposal* proposal,
                                         GtkSourceCompletionCell* cell);
VALA_EXTERN TubaAPITag* tuba_hashtag_provider_proposal_get_tag (TubaHashtagProviderProposal* self);
VALA_EXTERN const gchar* tuba_api_tag_get_name (TubaAPITag* self);
VALA_EXTERN gchar* tuba_api_tag_weekly_use (TubaAPITag* self);
static gchar* tuba_hashtag_provider_proposal_real_get_typed_text (GtkSourceCompletionProposal* base);
static void tuba_hashtag_provider_proposal_set_tag (TubaHashtagProviderProposal* self,
                                             TubaAPITag* value);
static void tuba_hashtag_provider_proposal_finalize (GObject * obj);
static GType tuba_hashtag_provider_proposal_get_type_once (void);
static void _vala_tuba_hashtag_provider_proposal_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec);
static void _vala_tuba_hashtag_provider_proposal_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec);
static GType tuba_hashtag_provider_get_type_once (void);

TubaHashtagProvider*
tuba_hashtag_provider_construct (GType object_type)
{
	TubaHashtagProvider * self = NULL;
	self = (TubaHashtagProvider*) g_object_new (object_type, "trigger-char", '#', NULL);
	return self;
}

TubaHashtagProvider*
tuba_hashtag_provider_new (void)
{
	return tuba_hashtag_provider_construct (TUBA_TYPE_HASHTAG_PROVIDER);
}

static void
tuba_hashtag_provider_real_suggest_data_free (gpointer _data)
{
	TubaHashtagProviderSuggestData* _data_;
	_data_ = _data;
	_g_free0 (_data_->word);
	_g_object_unref0 (_data_->cancellable);
	_g_object_unref0 (_data_->result);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaHashtagProviderSuggestData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_hashtag_provider_real_suggest (TubaCompletionProvider* base,
                                    const gchar* word,
                                    GCancellable* cancellable,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_)
{
	TubaHashtagProvider * self;
	TubaHashtagProviderSuggestData* _data_;
	TubaHashtagProvider* _tmp0_;
	gchar* _tmp1_;
	GCancellable* _tmp2_;
	g_return_if_fail (word != NULL);
	self = (TubaHashtagProvider*) base;
	_data_ = g_slice_new0 (TubaHashtagProviderSuggestData);
	_data_->_async_result = g_task_new (G_OBJECT (self), cancellable, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_hashtag_provider_real_suggest_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = g_strdup (word);
	_g_free0 (_data_->word);
	_data_->word = _tmp1_;
	_tmp2_ = _g_object_ref0 (cancellable);
	_g_object_unref0 (_data_->cancellable);
	_data_->cancellable = _tmp2_;
	tuba_hashtag_provider_real_suggest_co (_data_);
}

static GListModel*
tuba_hashtag_provider_suggest_finish (TubaCompletionProvider* base,
                                      GAsyncResult* _res_,
                                      GError** error)
{
	GListModel* result;
	TubaHashtagProviderSuggestData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), error);
	if (NULL == _data_) {
		return NULL;
	}
	result = _data_->result;
	_data_->result = NULL;
	return result;
}

static Block47Data*
block47_data_ref (Block47Data* _data47_)
{
	g_atomic_int_inc (&_data47_->_ref_count_);
	return _data47_;
}

static void
block47_data_unref (void * _userdata_)
{
	Block47Data* _data47_;
	_data47_ = (Block47Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data47_->_ref_count_)) {
		TubaHashtagProvider* self;
		self = _data47_->self;
		_g_object_unref0 (_data47_->suggestions);
		_g_object_unref0 (self);
		g_slice_free (Block47Data, _data47_);
	}
}

static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	glong result;
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
	end = _tmp0_;
	_tmp1_ = end;
	if (_tmp1_ == NULL) {
		result = maxlen;
		return result;
	} else {
		gchar* _tmp2_;
		_tmp2_ = end;
		result = (glong) (_tmp2_ - str);
		return result;
	}
}

static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp3_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	if (offset >= ((glong) 0)) {
		_tmp0_ = len >= ((glong) 0);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		string_length = string_strnlen ((gchar*) self, offset + len);
	} else {
		gint _tmp1_;
		gint _tmp2_;
		_tmp1_ = strlen (self);
		_tmp2_ = _tmp1_;
		string_length = (glong) _tmp2_;
	}
	if (offset < ((glong) 0)) {
		offset = string_length + offset;
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
	} else {
		g_return_val_if_fail (offset <= string_length, NULL);
	}
	if (len < ((glong) 0)) {
		len = string_length - offset;
	}
	g_return_val_if_fail ((offset + len) <= string_length, NULL);
	_tmp3_ = g_strndup (((gchar*) self) + offset, (gsize) len);
	result = _tmp3_;
	return result;
}

static void
tuba_hashtag_provider_suggest_ready (GObject* source_object,
                                     GAsyncResult* _res_,
                                     gpointer _user_data_)
{
	TubaHashtagProviderSuggestData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_hashtag_provider_real_suggest_co (_data_);
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

static gboolean
___lambda69_ (Block47Data* _data47_,
              TubaAPITag* tag)
{
	TubaHashtagProvider* self;
	TubaHashtagProviderProposal* proposal = NULL;
	TubaHashtagProviderProposal* _tmp0_;
	GListStore* _tmp1_;
	gboolean result;
	self = _data47_->self;
	g_return_val_if_fail (tag != NULL, FALSE);
	_tmp0_ = tuba_hashtag_provider_proposal_new (tag);
	proposal = _tmp0_;
	_tmp1_ = _data47_->suggestions;
	g_list_store_append (_tmp1_, (GObject*) proposal);
	result = TRUE;
	_g_object_unref0 (proposal);
	_g_object_unref0 (tag);
	return result;
}

static gboolean
____lambda69__gee_forall_func (gpointer g,
                               gpointer self)
{
	gboolean result;
	result = ___lambda69_ (self, (TubaAPITag*) g);
	return result;
}

static gboolean
tuba_hashtag_provider_real_suggest_co (TubaHashtagProviderSuggestData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_data47_ = g_slice_new0 (Block47Data);
	_data_->_data47_->_ref_count_ = 1;
	_data_->_data47_->self = g_object_ref (_data_->self);
	_data_->_data47_->_async_data_ = _data_;
	_data_->_tmp0_ = string_substring (_data_->word, (glong) 1, (glong) -1);
	_data_->tag = _data_->_tmp0_;
	_data_->_tmp1_ = g_list_store_new (G_TYPE_OBJECT);
	_data_->_data47_->suggestions = _data_->_tmp1_;
	_data_->_tmp2_ = _data_->tag;
	if (g_strcmp0 (_data_->_tmp2_, "") == 0) {
		_data_->_tmp3_ = _data_->_data47_->suggestions;
		_data_->_tmp4_ = _g_object_ref0 ((GListModel*) _data_->_tmp3_);
		_data_->result = _data_->_tmp4_;
		_g_free0 (_data_->tag);
		block47_data_unref (_data_->_data47_);
		_data_->_data47_ = NULL;
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp5_ = _data_->tag;
	_data_->_tmp6_ = tuba_api_tag_search (_data_->_tmp5_, &_data_->_inner_error0_);
	_data_->req = _data_->_tmp6_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_free0 (_data_->tag);
		block47_data_unref (_data_->_data47_);
		_data_->_data47_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp7_ = _data_->req;
	_data_->_state_ = 1;
	tuba_request_v2_exec (_data_->_tmp7_, tuba_hashtag_provider_suggest_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp8_ = tuba_request_v2_exec_finish (_data_->_tmp7_, _data_->_res_, NULL, &_data_->_inner_error0_);
	_data_->in_stream = _data_->_tmp8_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->req);
		_g_free0 (_data_->tag);
		block47_data_unref (_data_->_data47_);
		_data_->_data47_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp9_ = _data_->in_stream;
	_data_->_state_ = 2;
	tuba_network_get_parser_from_inputstream_async (_data_->_tmp9_, NULL, tuba_hashtag_provider_suggest_ready, _data_);
	return FALSE;
	_state_2:
	_data_->_tmp10_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
	_data_->parser = _data_->_tmp10_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		_g_free0 (_data_->tag);
		block47_data_unref (_data_->_data47_);
		_data_->_data47_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp11_ = tuba_network;
	_data_->_tmp12_ = _data_->parser;
	_data_->_tmp13_ = tuba_network_parse_node (_data_->_tmp11_, _data_->_tmp12_);
	_data_->_tmp14_ = _data_->_tmp13_;
	_data_->_tmp15_ = tuba_api_search_results_from (_data_->_tmp14_, &_data_->_inner_error0_);
	_data_->_tmp16_ = _data_->_tmp15_;
	__vala_JsonNode_free0 (_data_->_tmp14_);
	_data_->results = _data_->_tmp16_;
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_task_return_error (_data_->_async_result, _data_->_inner_error0_);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		_g_free0 (_data_->tag);
		block47_data_unref (_data_->_data47_);
		_data_->_data47_ = NULL;
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->_tmp17_ = _data_->results;
	if (_data_->_tmp17_ != NULL) {
		_data_->_tmp18_ = _data_->results;
		_data_->_tmp19_ = tuba_api_search_results_get_hashtags (_data_->_tmp18_);
		_data_->_tmp20_ = _data_->_tmp19_;
		gee_abstract_collection_foreach ((GeeAbstractCollection*) _data_->_tmp20_, ____lambda69__gee_forall_func, _data_->_data47_);
	}
	_data_->_tmp21_ = _data_->_data47_->suggestions;
	_data_->_tmp22_ = _g_object_ref0 ((GListModel*) _data_->_tmp21_);
	_data_->result = _data_->_tmp22_;
	_g_object_unref0 (_data_->results);
	_g_object_unref0 (_data_->parser);
	_g_object_unref0 (_data_->in_stream);
	_g_object_unref0 (_data_->req);
	_g_free0 (_data_->tag);
	block47_data_unref (_data_->_data47_);
	_data_->_data47_ = NULL;
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
tuba_hashtag_provider_real_display (TubaCompletionProvider* base,
                                    GtkSourceCompletionContext* context,
                                    GtkSourceCompletionProposal* proposal,
                                    GtkSourceCompletionCell* cell)
{
	TubaHashtagProvider * self;
	TubaHashtagProviderProposal* real_proposal = NULL;
	TubaHashtagProviderProposal* _tmp0_;
	TubaHashtagProviderProposal* _tmp1_;
	TubaAPITag* tag = NULL;
	TubaHashtagProviderProposal* _tmp2_;
	TubaAPITag* _tmp3_;
	TubaAPITag* _tmp4_;
	TubaAPITag* _tmp5_;
	TubaAPITag* _tmp6_;
	self = (TubaHashtagProvider*) base;
	g_return_if_fail (context != NULL);
	g_return_if_fail (proposal != NULL);
	g_return_if_fail (cell != NULL);
	_tmp0_ = _g_object_ref0 (TUBA_HASHTAG_PROVIDER_IS_PROPOSAL (proposal) ? ((TubaHashtagProviderProposal*) proposal) : NULL);
	real_proposal = _tmp0_;
	_tmp1_ = real_proposal;
	if (_tmp1_ == NULL) {
		_g_object_unref0 (real_proposal);
		return;
	}
	_tmp2_ = real_proposal;
	_tmp3_ = tuba_hashtag_provider_proposal_get_tag (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _g_object_ref0 (_tmp4_);
	tag = _tmp5_;
	_tmp6_ = tag;
	g_return_if_fail (_tmp6_ != NULL);
	switch (gtk_source_completion_cell_get_column (cell)) {
		case GTK_SOURCE_COMPLETION_COLUMN_ICON:
		{
			GtkImage* _tmp7_ = NULL;
			GtkImage* _tmp8_;
			_tmp7_ = (GtkImage*) gtk_image_new_from_icon_name ("tuba-hashtag-symbolic");
			gtk_image_set_pixel_size (_tmp7_, 24);
			g_object_ref_sink (_tmp7_);
			_tmp8_ = _tmp7_;
			gtk_source_completion_cell_set_widget (cell, (GtkWidget*) _tmp8_);
			_g_object_unref0 (_tmp8_);
			break;
		}
		case GTK_SOURCE_COMPLETION_COLUMN_TYPED_TEXT:
		{
			TubaAPITag* _tmp9_;
			const gchar* _tmp10_;
			const gchar* _tmp11_;
			const gchar* _tmp12_;
			TubaAPITag* _tmp13_;
			gchar* _tmp14_;
			gchar* _tmp15_;
			const gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			_tmp9_ = tag;
			_tmp10_ = tuba_api_tag_get_name (_tmp9_);
			_tmp11_ = _tmp10_;
			_tmp12_ = string_to_string (_tmp11_);
			_tmp13_ = tag;
			_tmp14_ = tuba_api_tag_weekly_use (_tmp13_);
			_tmp15_ = _tmp14_;
			_tmp16_ = string_to_string (_tmp15_);
			_tmp17_ = g_strconcat ("<b>", _tmp12_, "</b>\n<span alpha='50%'>", _tmp16_, "</span>", NULL);
			_tmp18_ = _tmp17_;
			gtk_source_completion_cell_set_markup (cell, _tmp18_);
			_g_free0 (_tmp18_);
			_g_free0 (_tmp15_);
			break;
		}
		default:
		{
			g_object_set (cell, "text", NULL, NULL);
			break;
		}
	}
	_g_object_unref0 (tag);
	_g_object_unref0 (real_proposal);
}

static inline gpointer
tuba_hashtag_provider_proposal_get_instance_private (TubaHashtagProviderProposal* self)
{
	return G_STRUCT_MEMBER_P (self, TubaHashtagProviderProposal_private_offset);
}

TubaHashtagProviderProposal*
tuba_hashtag_provider_proposal_construct (GType object_type,
                                          TubaAPITag* entity)
{
	TubaHashtagProviderProposal * self = NULL;
	g_return_val_if_fail (entity != NULL, NULL);
	self = (TubaHashtagProviderProposal*) g_object_new (object_type, "tag", entity, NULL);
	return self;
}

TubaHashtagProviderProposal*
tuba_hashtag_provider_proposal_new (TubaAPITag* entity)
{
	return tuba_hashtag_provider_proposal_construct (TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, entity);
}

static gchar*
tuba_hashtag_provider_proposal_real_get_typed_text (GtkSourceCompletionProposal* base)
{
	TubaHashtagProviderProposal * self;
	TubaAPITag* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* result;
	self = (TubaHashtagProviderProposal*) base;
	_tmp0_ = self->priv->_tag;
	_tmp1_ = tuba_api_tag_get_name (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strdup (_tmp2_);
	result = _tmp3_;
	return result;
}

TubaAPITag*
tuba_hashtag_provider_proposal_get_tag (TubaHashtagProviderProposal* self)
{
	TubaAPITag* result;
	TubaAPITag* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tag;
	result = _tmp0_;
	return result;
}

static void
tuba_hashtag_provider_proposal_set_tag (TubaHashtagProviderProposal* self,
                                        TubaAPITag* value)
{
	TubaAPITag* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_hashtag_provider_proposal_get_tag (self);
	if (old_value != value) {
		TubaAPITag* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_tag);
		self->priv->_tag = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_hashtag_provider_proposal_properties[TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY]);
	}
}

static void
tuba_hashtag_provider_proposal_class_init (TubaHashtagProviderProposalClass * klass,
                                           gpointer klass_data)
{
	tuba_hashtag_provider_proposal_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaHashtagProviderProposal_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_hashtag_provider_proposal_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_hashtag_provider_proposal_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_hashtag_provider_proposal_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY, tuba_hashtag_provider_proposal_properties[TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY] = g_param_spec_object ("tag", "tag", "tag", TUBA_API_TYPE_TAG, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY));
}

static void
tuba_hashtag_provider_proposal_gtk_source_completion_proposal_interface_init (GtkSourceCompletionProposalInterface * iface,
                                                                              gpointer iface_data)
{
	tuba_hashtag_provider_proposal_gtk_source_completion_proposal_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_typed_text = (gchar* (*) (GtkSourceCompletionProposal*)) tuba_hashtag_provider_proposal_real_get_typed_text;
}

static void
tuba_hashtag_provider_proposal_instance_init (TubaHashtagProviderProposal * self,
                                              gpointer klass)
{
	self->priv = tuba_hashtag_provider_proposal_get_instance_private (self);
}

static void
tuba_hashtag_provider_proposal_finalize (GObject * obj)
{
	TubaHashtagProviderProposal * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposal);
	_g_object_unref0 (self->priv->_tag);
	G_OBJECT_CLASS (tuba_hashtag_provider_proposal_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_hashtag_provider_proposal_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaHashtagProviderProposalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_hashtag_provider_proposal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaHashtagProviderProposal), 0, (GInstanceInitFunc) tuba_hashtag_provider_proposal_instance_init, NULL };
	static const GInterfaceInfo gtk_source_completion_proposal_info = { (GInterfaceInitFunc) tuba_hashtag_provider_proposal_gtk_source_completion_proposal_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_hashtag_provider_proposal_type_id;
	tuba_hashtag_provider_proposal_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaHashtagProviderProposal", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_hashtag_provider_proposal_type_id, gtk_source_completion_proposal_get_type (), &gtk_source_completion_proposal_info);
	TubaHashtagProviderProposal_private_offset = g_type_add_instance_private (tuba_hashtag_provider_proposal_type_id, sizeof (TubaHashtagProviderProposalPrivate));
	return tuba_hashtag_provider_proposal_type_id;
}

GType
tuba_hashtag_provider_proposal_get_type (void)
{
	static GType tuba_hashtag_provider_proposal_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_hashtag_provider_proposal_type_id__once)) {
		GType tuba_hashtag_provider_proposal_type_id;
		tuba_hashtag_provider_proposal_type_id = tuba_hashtag_provider_proposal_get_type_once ();
		g_once_init_leave_pointer (&tuba_hashtag_provider_proposal_type_id__once, tuba_hashtag_provider_proposal_type_id);
	}
	return tuba_hashtag_provider_proposal_type_id__once;
}

static void
_vala_tuba_hashtag_provider_proposal_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec)
{
	TubaHashtagProviderProposal * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposal);
	switch (property_id) {
		case TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY:
		g_value_set_object (value, tuba_hashtag_provider_proposal_get_tag (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_hashtag_provider_proposal_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec)
{
	TubaHashtagProviderProposal * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_HASHTAG_PROVIDER_TYPE_PROPOSAL, TubaHashtagProviderProposal);
	switch (property_id) {
		case TUBA_HASHTAG_PROVIDER_PROPOSAL_TAG_PROPERTY:
		tuba_hashtag_provider_proposal_set_tag (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_hashtag_provider_class_init (TubaHashtagProviderClass * klass,
                                  gpointer klass_data)
{
	tuba_hashtag_provider_parent_class = g_type_class_peek_parent (klass);
	((TubaCompletionProviderClass *) klass)->suggest = (void (*) (TubaCompletionProvider*, const gchar*, GCancellable*, GAsyncReadyCallback, gpointer)) tuba_hashtag_provider_real_suggest;
	((TubaCompletionProviderClass *) klass)->suggest_finish = (GListModel* (*) (TubaCompletionProvider*, GAsyncResult*, GError**)) tuba_hashtag_provider_suggest_finish;
	((TubaCompletionProviderClass *) klass)->display = (void (*) (TubaCompletionProvider*, GtkSourceCompletionContext*, GtkSourceCompletionProposal*, GtkSourceCompletionCell*)) tuba_hashtag_provider_real_display;
}

static void
tuba_hashtag_provider_instance_init (TubaHashtagProvider * self,
                                     gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_hashtag_provider_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaHashtagProviderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_hashtag_provider_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaHashtagProvider), 0, (GInstanceInitFunc) tuba_hashtag_provider_instance_init, NULL };
	GType tuba_hashtag_provider_type_id;
	tuba_hashtag_provider_type_id = g_type_register_static (TUBA_TYPE_COMPLETION_PROVIDER, "TubaHashtagProvider", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_hashtag_provider_type_id;
}

GType
tuba_hashtag_provider_get_type (void)
{
	static GType tuba_hashtag_provider_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_hashtag_provider_type_id__once)) {
		GType tuba_hashtag_provider_type_id;
		tuba_hashtag_provider_type_id = tuba_hashtag_provider_get_type_once ();
		g_once_init_leave_pointer (&tuba_hashtag_provider_type_id__once, tuba_hashtag_provider_type_id);
	}
	return tuba_hashtag_provider_type_id__once;
}

