/* Exif.c generated by valac 0.56.19, the Vala compiler
 * generated from Exif.vala, do not modify */

#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <gexiv2/gexiv2.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_UTILS_TYPE_EXIF (tuba_utils_exif_get_type ())
#define TUBA_UTILS_EXIF(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_UTILS_TYPE_EXIF, TubaUtilsExif))
#define TUBA_UTILS_EXIF_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_UTILS_TYPE_EXIF, TubaUtilsExifClass))
#define TUBA_UTILS_IS_EXIF(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_UTILS_TYPE_EXIF))
#define TUBA_UTILS_IS_EXIF_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_UTILS_TYPE_EXIF))
#define TUBA_UTILS_EXIF_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_UTILS_TYPE_EXIF, TubaUtilsExifClass))

typedef struct _TubaUtilsExif TubaUtilsExif;
typedef struct _TubaUtilsExifClass TubaUtilsExifClass;
typedef struct _TubaUtilsExifPrivate TubaUtilsExifPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaUtilsParamSpecExif TubaUtilsParamSpecExif;

struct _TubaUtilsExif {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TubaUtilsExifPrivate * priv;
};

struct _TubaUtilsExifClass {
	GTypeClass parent_class;
	void (*finalize) (TubaUtilsExif *self);
};

struct _TubaUtilsParamSpecExif {
	GParamSpec parent_instance;
};

static gpointer tuba_utils_exif_parent_class = NULL;

VALA_EXTERN gpointer tuba_utils_exif_ref (gpointer instance);
VALA_EXTERN void tuba_utils_exif_unref (gpointer instance);
VALA_EXTERN GParamSpec* tuba_utils_param_spec_exif (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
VALA_EXTERN void tuba_utils_value_set_exif (GValue* value,
                                gpointer v_object);
VALA_EXTERN void tuba_utils_value_take_exif (GValue* value,
                                 gpointer v_object);
VALA_EXTERN gpointer tuba_utils_value_get_exif (const GValue* value);
VALA_EXTERN GType tuba_utils_exif_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaUtilsExif, tuba_utils_exif_unref)
VALA_EXTERN gchar* tuba_utils_exif_extract_alt_text (const gchar* path);
VALA_EXTERN gchar* tuba_utils_exif_extract_alt_text_from_metadata (GExiv2Metadata* metadata,
                                                       GError** error);
VALA_EXTERN TubaUtilsExif* tuba_utils_exif_new (void);
VALA_EXTERN TubaUtilsExif* tuba_utils_exif_construct (GType object_type);
static void tuba_utils_exif_finalize (TubaUtilsExif * obj);
static GType tuba_utils_exif_get_type_once (void);

static const gchar* TUBA_UTILS_EXIF_ALT_KEYS[7] = {"Xmp.iptc.AltTextAccessibility", "Xmp.dc.description", "Iptc.Application2.Caption", "Exif.Image.ImageDescription", "Exif.Photo.UserComment", "Xmp.acdsee.notes", "Exif.Image.XPComment"};

static glong
string_strnlen (gchar* str,
                glong maxlen)
{
	gchar* end = NULL;
	gchar* _tmp0_;
	gchar* _tmp1_;
	glong result;
	_tmp0_ = memchr (str, 0, (gsize) maxlen);
	end = _tmp0_;
	_tmp1_ = end;
	if (_tmp1_ == NULL) {
		result = maxlen;
		return result;
	} else {
		gchar* _tmp2_;
		_tmp2_ = end;
		result = (glong) (_tmp2_ - str);
		return result;
	}
}

static gchar*
string_substring (const gchar* self,
                  glong offset,
                  glong len)
{
	glong string_length = 0L;
	gboolean _tmp0_ = FALSE;
	gchar* _tmp3_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	if (offset >= ((glong) 0)) {
		_tmp0_ = len >= ((glong) 0);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		string_length = string_strnlen ((gchar*) self, offset + len);
	} else {
		gint _tmp1_;
		gint _tmp2_;
		_tmp1_ = strlen (self);
		_tmp2_ = _tmp1_;
		string_length = (glong) _tmp2_;
	}
	if (offset < ((glong) 0)) {
		offset = string_length + offset;
		g_return_val_if_fail (offset >= ((glong) 0), NULL);
	} else {
		g_return_val_if_fail (offset <= string_length, NULL);
	}
	if (len < ((glong) 0)) {
		len = string_length - offset;
	}
	g_return_val_if_fail ((offset + len) <= string_length, NULL);
	_tmp3_ = g_strndup (((gchar*) self) + offset, (gsize) len);
	result = _tmp3_;
	return result;
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

gchar*
tuba_utils_exif_extract_alt_text (const gchar* path)
{
	gchar* _result_ = NULL;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (path != NULL, NULL);
	_result_ = NULL;
	{
		GExiv2Metadata* metadata = NULL;
		GExiv2Metadata* _tmp0_;
		gchar* meta_path = NULL;
		gchar* _tmp1_;
		const gchar* _tmp2_;
		GExiv2Metadata* _tmp7_;
		const gchar* _tmp8_;
		gchar* _tmp9_ = NULL;
		GExiv2Metadata* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		_tmp0_ = gexiv2_metadata_new ();
		metadata = _tmp0_;
		_tmp1_ = g_strdup (path);
		meta_path = _tmp1_;
		_tmp2_ = meta_path;
		if (g_str_has_prefix (_tmp2_, "file://")) {
			const gchar* _tmp3_;
			gchar* _tmp4_;
			gchar* _tmp5_;
			gchar* _tmp6_;
			_tmp3_ = meta_path;
			_tmp4_ = string_substring (_tmp3_, (glong) 7, (glong) -1);
			_tmp5_ = _tmp4_;
			_tmp6_ = g_uri_unescape_string (_tmp5_, NULL);
			_g_free0 (meta_path);
			meta_path = _tmp6_;
			_g_free0 (_tmp5_);
		}
		_tmp7_ = metadata;
		_tmp8_ = meta_path;
		gexiv2_metadata_open_path (_tmp7_, _tmp8_, &_inner_error0_);
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_free0 (meta_path);
			_g_object_unref0 (metadata);
			goto __catch0_g_error;
		}
		_tmp10_ = metadata;
		_tmp11_ = tuba_utils_exif_extract_alt_text_from_metadata (_tmp10_, &_inner_error0_);
		_tmp9_ = _tmp11_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			_g_free0 (meta_path);
			_g_object_unref0 (metadata);
			goto __catch0_g_error;
		}
		_tmp12_ = _tmp9_;
		_tmp9_ = NULL;
		_g_free0 (_result_);
		_result_ = _tmp12_;
		_g_free0 (_tmp9_);
		_g_free0 (meta_path);
		_g_object_unref0 (metadata);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp13_ = e;
		_tmp14_ = _tmp13_->message;
		_tmp15_ = string_to_string (_tmp14_);
		_tmp16_ = g_strconcat ("Error while extracting alt text: ", _tmp15_, NULL);
		_tmp17_ = _tmp16_;
		g_critical ("Exif.vala:26: %s", _tmp17_);
		_g_free0 (_tmp17_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_g_free0 (_result_);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	result = _result_;
	return result;
}

gchar*
tuba_utils_exif_extract_alt_text_from_metadata (GExiv2Metadata* metadata,
                                                GError** error)
{
	gchar* _result_ = NULL;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (metadata != NULL, NULL);
	_result_ = NULL;
	{
		const gchar** tag_collection = NULL;
		gint tag_collection_length1 = 0;
		gint _tag_collection_size_ = 0;
		gint tag_it = 0;
		tag_collection = TUBA_UTILS_EXIF_ALT_KEYS;
		tag_collection_length1 = G_N_ELEMENTS (TUBA_UTILS_EXIF_ALT_KEYS);
		for (tag_it = 0; tag_it < tag_collection_length1; tag_it = tag_it + 1) {
			gchar* _tmp0_;
			gchar* tag = NULL;
			_tmp0_ = g_strdup (tag_collection[tag_it]);
			tag = _tmp0_;
			{
				gboolean _tmp1_ = FALSE;
				const gchar* _tmp2_;
				_tmp2_ = tag;
				_tmp1_ = gexiv2_metadata_try_has_tag (metadata, _tmp2_, &_inner_error0_);
				if (G_UNLIKELY (_inner_error0_ != NULL)) {
					g_propagate_error (error, _inner_error0_);
					_g_free0 (tag);
					_g_free0 (_result_);
					return NULL;
				}
				if (_tmp1_) {
					gchar* alt = NULL;
					const gchar* _tmp3_;
					gchar* _tmp4_;
					gboolean _tmp5_ = FALSE;
					const gchar* _tmp6_;
					_tmp3_ = tag;
					_tmp4_ = gexiv2_metadata_try_get_tag_interpreted_string (metadata, _tmp3_, &_inner_error0_);
					alt = _tmp4_;
					if (G_UNLIKELY (_inner_error0_ != NULL)) {
						g_propagate_error (error, _inner_error0_);
						_g_free0 (tag);
						_g_free0 (_result_);
						return NULL;
					}
					_tmp6_ = alt;
					if (_tmp6_ != NULL) {
						const gchar* _tmp7_;
						gint _tmp8_;
						gint _tmp9_;
						_tmp7_ = alt;
						_tmp8_ = strlen (_tmp7_);
						_tmp9_ = _tmp8_;
						_tmp5_ = _tmp9_ > 0;
					} else {
						_tmp5_ = FALSE;
					}
					if (_tmp5_) {
						const gchar* _tmp10_;
						gchar* _tmp11_;
						const gchar* _tmp12_;
						_tmp10_ = alt;
						_tmp11_ = g_strdup (_tmp10_);
						_g_free0 (_result_);
						_result_ = _tmp11_;
						_tmp12_ = _result_;
						if (g_str_has_prefix (_tmp12_, "lang=\"x-default\" ")) {
							const gchar* _tmp13_;
							gchar* _tmp14_;
							_tmp13_ = _result_;
							_tmp14_ = string_substring (_tmp13_, (glong) 17, (glong) -1);
							_g_free0 (_result_);
							_result_ = _tmp14_;
						} else {
							const gchar* _tmp15_;
							_tmp15_ = _result_;
							if (g_str_has_prefix (_tmp15_, "lang=\"en\" ")) {
								const gchar* _tmp16_;
								gchar* _tmp17_;
								_tmp16_ = _result_;
								_tmp17_ = string_substring (_tmp16_, (glong) 10, (glong) -1);
								_g_free0 (_result_);
								_result_ = _tmp17_;
							}
						}
						_g_free0 (alt);
						_g_free0 (tag);
						break;
					}
					_g_free0 (alt);
				}
				_g_free0 (tag);
			}
		}
	}
	result = _result_;
	return result;
}

TubaUtilsExif*
tuba_utils_exif_construct (GType object_type)
{
	TubaUtilsExif* self = NULL;
	self = (TubaUtilsExif*) g_type_create_instance (object_type);
	return self;
}

TubaUtilsExif*
tuba_utils_exif_new (void)
{
	return tuba_utils_exif_construct (TUBA_UTILS_TYPE_EXIF);
}

static void
tuba_utils_value_exif_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
tuba_utils_value_exif_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		tuba_utils_exif_unref (value->data[0].v_pointer);
	}
}

static void
tuba_utils_value_exif_copy_value (const GValue* src_value,
                                  GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = tuba_utils_exif_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
tuba_utils_value_exif_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
tuba_utils_value_exif_collect_value (GValue* value,
                                     guint n_collect_values,
                                     GTypeCValue* collect_values,
                                     guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		TubaUtilsExif * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = tuba_utils_exif_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
tuba_utils_value_exif_lcopy_value (const GValue* value,
                                   guint n_collect_values,
                                   GTypeCValue* collect_values,
                                   guint collect_flags)
{
	TubaUtilsExif ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = tuba_utils_exif_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
tuba_utils_param_spec_exif (const gchar* name,
                            const gchar* nick,
                            const gchar* blurb,
                            GType object_type,
                            GParamFlags flags)
{
	TubaUtilsParamSpecExif* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TUBA_UTILS_TYPE_EXIF), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
tuba_utils_value_get_exif (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_EXIF), NULL);
	return value->data[0].v_pointer;
}

void
tuba_utils_value_set_exif (GValue* value,
                           gpointer v_object)
{
	TubaUtilsExif * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_EXIF));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_EXIF));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		tuba_utils_exif_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_exif_unref (old);
	}
}

void
tuba_utils_value_take_exif (GValue* value,
                            gpointer v_object)
{
	TubaUtilsExif * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_EXIF));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_EXIF));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_exif_unref (old);
	}
}

static void
tuba_utils_exif_class_init (TubaUtilsExifClass * klass,
                            gpointer klass_data)
{
	tuba_utils_exif_parent_class = g_type_class_peek_parent (klass);
	((TubaUtilsExifClass *) klass)->finalize = tuba_utils_exif_finalize;
}

static void
tuba_utils_exif_instance_init (TubaUtilsExif * self,
                               gpointer klass)
{
	self->ref_count = 1;
}

static void
tuba_utils_exif_finalize (TubaUtilsExif * obj)
{
	TubaUtilsExif * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_TYPE_EXIF, TubaUtilsExif);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
tuba_utils_exif_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { tuba_utils_value_exif_init, tuba_utils_value_exif_free_value, tuba_utils_value_exif_copy_value, tuba_utils_value_exif_peek_pointer, "p", tuba_utils_value_exif_collect_value, "p", tuba_utils_value_exif_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (TubaUtilsExifClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_utils_exif_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaUtilsExif), 0, (GInstanceInitFunc) tuba_utils_exif_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType tuba_utils_exif_type_id;
	tuba_utils_exif_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TubaUtilsExif", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_NONE);
	return tuba_utils_exif_type_id;
}

GType
tuba_utils_exif_get_type (void)
{
	static GType tuba_utils_exif_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_utils_exif_type_id__once)) {
		GType tuba_utils_exif_type_id;
		tuba_utils_exif_type_id = tuba_utils_exif_get_type_once ();
		g_once_init_leave_pointer (&tuba_utils_exif_type_id__once, tuba_utils_exif_type_id);
	}
	return tuba_utils_exif_type_id__once;
}

gpointer
tuba_utils_exif_ref (gpointer instance)
{
	TubaUtilsExif * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
tuba_utils_exif_unref (gpointer instance)
{
	TubaUtilsExif * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		TUBA_UTILS_EXIF_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

