/* Counting.c generated by valac 0.56.19, the Vala compiler
 * generated from Counting.vala, do not modify */

#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <unicode/utypes.h>
#include <unicode/utext.h>
#include <unicode/ubrk.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_UTILS_TYPE_COUNTING (tuba_utils_counting_get_type ())
#define TUBA_UTILS_COUNTING(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_UTILS_TYPE_COUNTING, TubaUtilsCounting))
#define TUBA_UTILS_COUNTING_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_UTILS_TYPE_COUNTING, TubaUtilsCountingClass))
#define TUBA_UTILS_IS_COUNTING(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_UTILS_TYPE_COUNTING))
#define TUBA_UTILS_IS_COUNTING_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_UTILS_TYPE_COUNTING))
#define TUBA_UTILS_COUNTING_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_UTILS_TYPE_COUNTING, TubaUtilsCountingClass))

typedef struct _TubaUtilsCounting TubaUtilsCounting;
typedef struct _TubaUtilsCountingClass TubaUtilsCountingClass;
typedef struct _TubaUtilsCountingPrivate TubaUtilsCountingPrivate;
#define _ubrk_close0(var) ((var == NULL) ? NULL : (var = (ubrk_close (var), NULL)))
#define _utext_close0(var) ((var == NULL) ? NULL : (var = (utext_close (var), NULL)))
#define _tuba_utils_counting_unref0(var) ((var == NULL) ? NULL : (var = (tuba_utils_counting_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
typedef struct _TubaUtilsParamSpecCounting TubaUtilsParamSpecCounting;

struct _TubaUtilsCounting {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TubaUtilsCountingPrivate * priv;
};

struct _TubaUtilsCountingClass {
	GTypeClass parent_class;
	void (*finalize) (TubaUtilsCounting *self);
};

struct _TubaUtilsParamSpecCounting {
	GParamSpec parent_instance;
};

static gpointer tuba_utils_counting_parent_class = NULL;
static GRegex* tuba_utils_counting_mention_regex;
static GRegex* tuba_utils_counting_mention_regex = NULL;

VALA_EXTERN gpointer tuba_utils_counting_ref (gpointer instance);
VALA_EXTERN void tuba_utils_counting_unref (gpointer instance);
VALA_EXTERN GParamSpec* tuba_utils_param_spec_counting (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void tuba_utils_value_set_counting (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void tuba_utils_value_take_counting (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer tuba_utils_value_get_counting (const GValue* value);
VALA_EXTERN GType tuba_utils_counting_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaUtilsCounting, tuba_utils_counting_unref)
VALA_EXTERN gint tuba_utils_counting_chars (const gchar* content,
                                const gchar* language);
VALA_EXTERN gchar* tuba_utils_counting_replace_mentions (const gchar* content);
VALA_EXTERN TubaUtilsCounting* tuba_utils_counting_new (void);
VALA_EXTERN TubaUtilsCounting* tuba_utils_counting_construct (GType object_type);
static void tuba_utils_counting_finalize (TubaUtilsCounting * obj);
static GType tuba_utils_counting_get_type_once (void);

static guint8*
string_get_data (const gchar* self,
                 gint* result_length1)
{
	guint8* result;
	guint8* res = NULL;
	gint res_length1;
	gint _res_size_;
	gint _tmp0_;
	gint _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
	g_return_val_if_fail (self != NULL, NULL);
	res = (guint8*) self;
	res_length1 = -1;
	_res_size_ = res_length1;
	_tmp0_ = strlen (self);
	_tmp1_ = _tmp0_;
	res_length1 = (gint) _tmp1_;
	_tmp2_ = res;
	_tmp2__length1 = res_length1;
	if (result_length1) {
		*result_length1 = _tmp2__length1;
	}
	result = _tmp2_;
	return result;
}

gint
tuba_utils_counting_chars (const gchar* content,
                           const gchar* language)
{
	gint res = 0;
	UErrorCode icu_err = 0;
	UText* icu_text = NULL;
	guint8* _tmp0_;
	gint _tmp0__length1;
	gint _tmp1_ = 0;
	guint8* _tmp2_;
	gint _tmp2__length1;
	UText* _tmp3_;
	UBreakIterator* word_breaker = NULL;
	UBreakIterator* _tmp4_;
	UBreakIterator* _tmp5_;
	UText* _tmp6_;
	gint result;
	g_return_val_if_fail (content != NULL, -1);
	g_return_val_if_fail (language != NULL, -1);
	res = 0;
	icu_err = U_ZERO_ERROR;
	_tmp0_ = string_get_data (content, &_tmp1_);
	_tmp0__length1 = _tmp1_;
	_tmp2_ = _tmp0_;
	_tmp2__length1 = _tmp0__length1;
	_tmp3_ = utext_openUTF8 (NULL, _tmp2_, (int64_t) _tmp2__length1, &icu_err);
	icu_text = _tmp3_;
	_tmp4_ = ubrk_open (UBRK_CHARACTER, language, NULL, (gint32) -1, &icu_err);
	word_breaker = _tmp4_;
	_tmp5_ = word_breaker;
	_tmp6_ = icu_text;
	ubrk_setUText (_tmp5_, _tmp6_, &icu_err);
	if (U_SUCCESS (icu_err)) {
		while (TRUE) {
			UBreakIterator* _tmp7_;
			_tmp7_ = word_breaker;
			if (!(ubrk_next (_tmp7_) != UBRK_DONE)) {
				break;
			}
			res += 1;
		}
	} else {
		gint _tmp8_;
		gint _tmp9_;
		if (g_strcmp0 (language, "en") != 0) {
			result = tuba_utils_counting_chars (content, "en");
			_ubrk_close0 (word_breaker);
			_utext_close0 (icu_text);
			return result;
		}
		_tmp8_ = strlen (content);
		_tmp9_ = _tmp8_;
		res += _tmp9_;
	}
	result = res;
	_ubrk_close0 (word_breaker);
	_utext_close0 (icu_text);
	return result;
}

gchar*
tuba_utils_counting_replace_mentions (const gchar* content)
{
	TubaUtilsCounting* _tmp0_;
	TubaUtilsCounting* _tmp1_;
	GError* _inner_error0_ = NULL;
	gchar* result;
	g_return_val_if_fail (content != NULL, NULL);
	_tmp0_ = tuba_utils_counting_new ();
	_tmp1_ = _tmp0_;
	_tuba_utils_counting_unref0 (_tmp1_);
	{
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_;
		gint _tmp4_;
		gint _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp3_ = tuba_utils_counting_mention_regex;
		_tmp4_ = strlen (content);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_regex_replace (_tmp3_, content, (gssize) _tmp5_, 0, "\\1@\\3", 0, &_inner_error0_);
		_tmp2_ = _tmp6_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
			return NULL;
		}
		_tmp7_ = _tmp2_;
		_tmp2_ = NULL;
		result = _tmp7_;
		_g_free0 (_tmp2_);
		return result;
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		GError* e = NULL;
		GError* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp8_ = e;
		_tmp9_ = _tmp8_->message;
		g_warning ("Counting.vala:44: %s", _tmp9_);
		_tmp10_ = g_strdup (content);
		result = _tmp10_;
		_g_error_free0 (e);
		return result;
	}
	__finally0:
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
	g_clear_error (&_inner_error0_);
	return NULL;
}

TubaUtilsCounting*
tuba_utils_counting_construct (GType object_type)
{
	TubaUtilsCounting* self = NULL;
	self = (TubaUtilsCounting*) g_type_create_instance (object_type);
	return self;
}

TubaUtilsCounting*
tuba_utils_counting_new (void)
{
	return tuba_utils_counting_construct (TUBA_UTILS_TYPE_COUNTING);
}

static void
tuba_utils_value_counting_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
tuba_utils_value_counting_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		tuba_utils_counting_unref (value->data[0].v_pointer);
	}
}

static void
tuba_utils_value_counting_copy_value (const GValue* src_value,
                                      GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = tuba_utils_counting_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
tuba_utils_value_counting_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
tuba_utils_value_counting_collect_value (GValue* value,
                                         guint n_collect_values,
                                         GTypeCValue* collect_values,
                                         guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		TubaUtilsCounting * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = tuba_utils_counting_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
tuba_utils_value_counting_lcopy_value (const GValue* value,
                                       guint n_collect_values,
                                       GTypeCValue* collect_values,
                                       guint collect_flags)
{
	TubaUtilsCounting ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = tuba_utils_counting_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
tuba_utils_param_spec_counting (const gchar* name,
                                const gchar* nick,
                                const gchar* blurb,
                                GType object_type,
                                GParamFlags flags)
{
	TubaUtilsParamSpecCounting* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TUBA_UTILS_TYPE_COUNTING), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
tuba_utils_value_get_counting (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_COUNTING), NULL);
	return value->data[0].v_pointer;
}

void
tuba_utils_value_set_counting (GValue* value,
                               gpointer v_object)
{
	TubaUtilsCounting * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_COUNTING));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_COUNTING));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		tuba_utils_counting_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_counting_unref (old);
	}
}

void
tuba_utils_value_take_counting (GValue* value,
                                gpointer v_object)
{
	TubaUtilsCounting * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_COUNTING));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_COUNTING));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_counting_unref (old);
	}
}

static void
tuba_utils_counting_class_init (TubaUtilsCountingClass * klass,
                                gpointer klass_data)
{
	GError* _inner_error0_ = NULL;
	tuba_utils_counting_parent_class = g_type_class_peek_parent (klass);
	((TubaUtilsCountingClass *) klass)->finalize = tuba_utils_counting_finalize;
	{
		GRegex* _tmp0_ = NULL;
		GRegex* _tmp1_;
		GRegex* _tmp2_;
		_tmp1_ = g_regex_new ("(^|[^/\\w])@(([a-z0-9_]+)@[a-z0-9.-]+[a-z0-9]+)", G_REGEX_OPTIMIZE | G_REGEX_CASELESS, 0, &_inner_error0_);
		_tmp0_ = _tmp1_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			if (_inner_error0_->domain == G_REGEX_ERROR) {
				goto __catch0_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
			g_clear_error (&_inner_error0_);
		}
		_tmp2_ = _tmp0_;
		_tmp0_ = NULL;
		_g_regex_unref0 (tuba_utils_counting_mention_regex);
		tuba_utils_counting_mention_regex = _tmp2_;
		_g_regex_unref0 (_tmp0_);
	}
	goto __finally0;
	__catch0_g_regex_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp3_ = e;
		_tmp4_ = _tmp3_->message;
		g_critical ("Counting.vala:7: %s", _tmp4_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
	}
}

static void
tuba_utils_counting_instance_init (TubaUtilsCounting * self,
                                   gpointer klass)
{
	self->ref_count = 1;
}

static void
tuba_utils_counting_finalize (TubaUtilsCounting * obj)
{
	TubaUtilsCounting * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_TYPE_COUNTING, TubaUtilsCounting);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
tuba_utils_counting_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { tuba_utils_value_counting_init, tuba_utils_value_counting_free_value, tuba_utils_value_counting_copy_value, tuba_utils_value_counting_peek_pointer, "p", tuba_utils_value_counting_collect_value, "p", tuba_utils_value_counting_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (TubaUtilsCountingClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_utils_counting_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaUtilsCounting), 0, (GInstanceInitFunc) tuba_utils_counting_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType tuba_utils_counting_type_id;
	tuba_utils_counting_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TubaUtilsCounting", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_NONE);
	return tuba_utils_counting_type_id;
}

GType
tuba_utils_counting_get_type (void)
{
	static GType tuba_utils_counting_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_utils_counting_type_id__once)) {
		GType tuba_utils_counting_type_id;
		tuba_utils_counting_type_id = tuba_utils_counting_get_type_once ();
		g_once_init_leave_pointer (&tuba_utils_counting_type_id__once, tuba_utils_counting_type_id);
	}
	return tuba_utils_counting_type_id__once;
}

gpointer
tuba_utils_counting_ref (gpointer instance)
{
	TubaUtilsCounting * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
tuba_utils_counting_unref (gpointer instance)
{
	TubaUtilsCounting * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		TUBA_UTILS_COUNTING_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

