/* Folder.c generated by valac 0.56.19, the Vala compiler
 * generated from Folder.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_ICESHRIMP_TYPE_FOLDER (tuba_api_iceshrimp_folder_get_type ())
#define TUBA_API_ICESHRIMP_FOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolder))
#define TUBA_API_ICESHRIMP_FOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolderClass))
#define TUBA_API_ICESHRIMP_IS_FOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ICESHRIMP_TYPE_FOLDER))
#define TUBA_API_ICESHRIMP_IS_FOLDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ICESHRIMP_TYPE_FOLDER))
#define TUBA_API_ICESHRIMP_FOLDER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolderClass))

typedef struct _TubaAPIIceshrimpFolder TubaAPIIceshrimpFolder;
typedef struct _TubaAPIIceshrimpFolderClass TubaAPIIceshrimpFolderClass;
typedef struct _TubaAPIIceshrimpFolderPrivate TubaAPIIceshrimpFolderPrivate;

#define TUBA_API_ICESHRIMP_TYPE_FILE (tuba_api_iceshrimp_file_get_type ())
#define TUBA_API_ICESHRIMP_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFile))
#define TUBA_API_ICESHRIMP_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFileClass))
#define TUBA_API_ICESHRIMP_IS_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ICESHRIMP_TYPE_FILE))
#define TUBA_API_ICESHRIMP_IS_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ICESHRIMP_TYPE_FILE))
#define TUBA_API_ICESHRIMP_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFileClass))

typedef struct _TubaAPIIceshrimpFile TubaAPIIceshrimpFile;
typedef struct _TubaAPIIceshrimpFileClass TubaAPIIceshrimpFileClass;
enum  {
	TUBA_API_ICESHRIMP_FOLDER_0_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY,
	TUBA_API_ICESHRIMP_FOLDER_NUM_PROPERTIES
};
static GParamSpec* tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIIceshrimpFolder {
	TubaEntity parent_instance;
	TubaAPIIceshrimpFolderPrivate * priv;
};

struct _TubaAPIIceshrimpFolderClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIIceshrimpFolderPrivate {
	gchar* _id;
	gchar* _name;
	gchar* _parentId;
	GeeArrayList* _files;
	GeeArrayList* _folders;
};

static gint TubaAPIIceshrimpFolder_private_offset;
static gpointer tuba_api_iceshrimp_folder_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_iceshrimp_folder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIIceshrimpFolder, g_object_unref)
VALA_EXTERN GType tuba_api_iceshrimp_file_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIIceshrimpFile, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_iceshrimp_folder_real_deserialize_array_type (TubaEntity* base,
                                                             const gchar* prop);
VALA_EXTERN TubaAPIIceshrimpFolder* tuba_api_iceshrimp_folder_from (JsonNode* node,
                                                        GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN TubaAPIIceshrimpFolder* tuba_api_iceshrimp_folder_new (void);
VALA_EXTERN TubaAPIIceshrimpFolder* tuba_api_iceshrimp_folder_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_iceshrimp_folder_get_id (TubaAPIIceshrimpFolder* self);
VALA_EXTERN void tuba_api_iceshrimp_folder_set_id (TubaAPIIceshrimpFolder* self,
                                       const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_folder_get_name (TubaAPIIceshrimpFolder* self);
VALA_EXTERN void tuba_api_iceshrimp_folder_set_name (TubaAPIIceshrimpFolder* self,
                                         const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_folder_get_parentId (TubaAPIIceshrimpFolder* self);
VALA_EXTERN void tuba_api_iceshrimp_folder_set_parentId (TubaAPIIceshrimpFolder* self,
                                             const gchar* value);
VALA_EXTERN GeeArrayList* tuba_api_iceshrimp_folder_get_files (TubaAPIIceshrimpFolder* self);
VALA_EXTERN void tuba_api_iceshrimp_folder_set_files (TubaAPIIceshrimpFolder* self,
                                          GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_iceshrimp_folder_get_folders (TubaAPIIceshrimpFolder* self);
VALA_EXTERN void tuba_api_iceshrimp_folder_set_folders (TubaAPIIceshrimpFolder* self,
                                            GeeArrayList* value);
static void tuba_api_iceshrimp_folder_finalize (GObject * obj);
static GType tuba_api_iceshrimp_folder_get_type_once (void);
static void _vala_tuba_api_iceshrimp_folder_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_tuba_api_iceshrimp_folder_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);

static inline gpointer
tuba_api_iceshrimp_folder_get_instance_private (TubaAPIIceshrimpFolder* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIIceshrimpFolder_private_offset);
}

static GType
tuba_api_iceshrimp_folder_real_deserialize_array_type (TubaEntity* base,
                                                       const gchar* prop)
{
	TubaAPIIceshrimpFolder * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	GType result;
	self = (TubaAPIIceshrimpFolder*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("files")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_ICESHRIMP_TYPE_FILE;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("folders")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_ICESHRIMP_TYPE_FOLDER;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_iceshrimp_folder_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIIceshrimpFolder*
tuba_api_iceshrimp_folder_from (JsonNode* node,
                                GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIIceshrimpFolder* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIIceshrimpFolder* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_ICESHRIMP_TYPE_FOLDER, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_ICESHRIMP_IS_FOLDER (_tmp0_) ? ((TubaAPIIceshrimpFolder*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPIIceshrimpFolder*
tuba_api_iceshrimp_folder_construct (GType object_type)
{
	TubaAPIIceshrimpFolder * self = NULL;
	self = (TubaAPIIceshrimpFolder*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIIceshrimpFolder*
tuba_api_iceshrimp_folder_new (void)
{
	return tuba_api_iceshrimp_folder_construct (TUBA_API_ICESHRIMP_TYPE_FOLDER);
}

const gchar*
tuba_api_iceshrimp_folder_get_id (TubaAPIIceshrimpFolder* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_folder_set_id (TubaAPIIceshrimpFolder* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_folder_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_folder_get_name (TubaAPIIceshrimpFolder* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_folder_set_name (TubaAPIIceshrimpFolder* self,
                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_folder_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_folder_get_parentId (TubaAPIIceshrimpFolder* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_parentId;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_folder_set_parentId (TubaAPIIceshrimpFolder* self,
                                        const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_folder_get_parentId (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_parentId);
		self->priv->_parentId = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_iceshrimp_folder_get_files (TubaAPIIceshrimpFolder* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_files;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_folder_set_files (TubaAPIIceshrimpFolder* self,
                                     GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_folder_get_files (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_files);
		self->priv->_files = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_iceshrimp_folder_get_folders (TubaAPIIceshrimpFolder* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_folders;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_folder_set_folders (TubaAPIIceshrimpFolder* self,
                                       GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_folder_get_folders (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_folders);
		self->priv->_folders = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY]);
	}
}

static void
tuba_api_iceshrimp_folder_class_init (TubaAPIIceshrimpFolderClass * klass,
                                      gpointer klass_data)
{
	tuba_api_iceshrimp_folder_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIIceshrimpFolder_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_iceshrimp_folder_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_iceshrimp_folder_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_iceshrimp_folder_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_iceshrimp_folder_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY] = g_param_spec_string ("parentId", "parentId", "parentId", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY] = g_param_spec_object ("files", "files", "files", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY, tuba_api_iceshrimp_folder_properties[TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY] = g_param_spec_object ("folders", "folders", "folders", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_iceshrimp_folder_instance_init (TubaAPIIceshrimpFolder * self,
                                         gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_api_iceshrimp_folder_get_instance_private (self);
	self->priv->_id = NULL;
	_tmp0_ = g_strdup (_ ("Folder"));
	self->priv->_name = _tmp0_;
	self->priv->_parentId = NULL;
	self->priv->_files = NULL;
	self->priv->_folders = NULL;
}

static void
tuba_api_iceshrimp_folder_finalize (GObject * obj)
{
	TubaAPIIceshrimpFolder * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolder);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_parentId);
	_g_object_unref0 (self->priv->_files);
	_g_object_unref0 (self->priv->_folders);
	G_OBJECT_CLASS (tuba_api_iceshrimp_folder_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_iceshrimp_folder_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIIceshrimpFolderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_iceshrimp_folder_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIIceshrimpFolder), 0, (GInstanceInitFunc) tuba_api_iceshrimp_folder_instance_init, NULL };
	GType tuba_api_iceshrimp_folder_type_id;
	tuba_api_iceshrimp_folder_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIIceshrimpFolder", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIIceshrimpFolder_private_offset = g_type_add_instance_private (tuba_api_iceshrimp_folder_type_id, sizeof (TubaAPIIceshrimpFolderPrivate));
	return tuba_api_iceshrimp_folder_type_id;
}

GType
tuba_api_iceshrimp_folder_get_type (void)
{
	static GType tuba_api_iceshrimp_folder_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_iceshrimp_folder_type_id__once)) {
		GType tuba_api_iceshrimp_folder_type_id;
		tuba_api_iceshrimp_folder_type_id = tuba_api_iceshrimp_folder_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_iceshrimp_folder_type_id__once, tuba_api_iceshrimp_folder_type_id);
	}
	return tuba_api_iceshrimp_folder_type_id__once;
}

static void
_vala_tuba_api_iceshrimp_folder_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	TubaAPIIceshrimpFolder * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolder);
	switch (property_id) {
		case TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_folder_get_id (self));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_folder_get_name (self));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_folder_get_parentId (self));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY:
		g_value_set_object (value, tuba_api_iceshrimp_folder_get_files (self));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY:
		g_value_set_object (value, tuba_api_iceshrimp_folder_get_folders (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_iceshrimp_folder_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	TubaAPIIceshrimpFolder * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ICESHRIMP_TYPE_FOLDER, TubaAPIIceshrimpFolder);
	switch (property_id) {
		case TUBA_API_ICESHRIMP_FOLDER_ID_PROPERTY:
		tuba_api_iceshrimp_folder_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_NAME_PROPERTY:
		tuba_api_iceshrimp_folder_set_name (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_PARENT_ID_PROPERTY:
		tuba_api_iceshrimp_folder_set_parentId (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_FILES_PROPERTY:
		tuba_api_iceshrimp_folder_set_files (self, g_value_get_object (value));
		break;
		case TUBA_API_ICESHRIMP_FOLDER_FOLDERS_PROPERTY:
		tuba_api_iceshrimp_folder_set_folders (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

