/* EmojiReaction.c generated by valac 0.56.19, the Vala compiler
 * generated from EmojiReaction.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_EMOJI_REACTION (tuba_api_emoji_reaction_get_type ())
#define TUBA_API_EMOJI_REACTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReaction))
#define TUBA_API_EMOJI_REACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReactionClass))
#define TUBA_API_IS_EMOJI_REACTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_EMOJI_REACTION))
#define TUBA_API_IS_EMOJI_REACTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_EMOJI_REACTION))
#define TUBA_API_EMOJI_REACTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReactionClass))

typedef struct _TubaAPIEmojiReaction TubaAPIEmojiReaction;
typedef struct _TubaAPIEmojiReactionClass TubaAPIEmojiReactionClass;
typedef struct _TubaAPIEmojiReactionPrivate TubaAPIEmojiReactionPrivate;
enum  {
	TUBA_API_EMOJI_REACTION_0_PROPERTY,
	TUBA_API_EMOJI_REACTION_COUNT_PROPERTY,
	TUBA_API_EMOJI_REACTION_URL_PROPERTY,
	TUBA_API_EMOJI_REACTION_NAME_PROPERTY,
	TUBA_API_EMOJI_REACTION_ME_PROPERTY,
	TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY,
	TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY,
	TUBA_API_EMOJI_REACTION_NUM_PROPERTIES
};
static GParamSpec* tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS (tuba_widgets_emoji_reaction_accounts_get_type ())
#define TUBA_WIDGETS_EMOJI_REACTION_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS, TubaWidgetsEmojiReactionAccounts))
#define TUBA_WIDGETS_EMOJI_REACTION_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS, TubaWidgetsEmojiReactionAccountsClass))
#define TUBA_WIDGETS_IS_EMOJI_REACTION_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS))
#define TUBA_WIDGETS_IS_EMOJI_REACTION_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS))
#define TUBA_WIDGETS_EMOJI_REACTION_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_EMOJI_REACTION_ACCOUNTS, TubaWidgetsEmojiReactionAccountsClass))

typedef struct _TubaWidgetsEmojiReactionAccounts TubaWidgetsEmojiReactionAccounts;
typedef struct _TubaWidgetsEmojiReactionAccountsClass TubaWidgetsEmojiReactionAccountsClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIEmojiReaction {
	TubaEntity parent_instance;
	TubaAPIEmojiReactionPrivate * priv;
};

struct _TubaAPIEmojiReactionClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIEmojiReactionPrivate {
	gint64 _count;
	gchar* _url;
	gchar* _name;
	gboolean _me;
	GeeArrayList* _accounts;
	GeeArrayList* _account_ids;
};

static gint TubaAPIEmojiReaction_private_offset;
static gpointer tuba_api_emoji_reaction_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_emoji_reaction_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_emoji_reaction_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIEmojiReaction, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_emoji_reaction_real_deserialize_array_type (TubaEntity* base,
                                                           const gchar* prop);
static GtkWidget* tuba_api_emoji_reaction_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaWidgetsEmojiReactionAccounts* tuba_widgets_emoji_reaction_accounts_new (TubaAPIEmojiReaction* reaction);
VALA_EXTERN TubaWidgetsEmojiReactionAccounts* tuba_widgets_emoji_reaction_accounts_construct (GType object_type,
                                                                                  TubaAPIEmojiReaction* reaction);
VALA_EXTERN GType tuba_widgets_emoji_reaction_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsEmojiReactionAccounts, g_object_unref)
static void tuba_api_emoji_reaction_real_open (TubaWidgetizable* base);
VALA_EXTERN TubaAPIEmojiReaction* tuba_api_emoji_reaction_new (void);
VALA_EXTERN TubaAPIEmojiReaction* tuba_api_emoji_reaction_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN gint64 tuba_api_emoji_reaction_get_count (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_count (TubaAPIEmojiReaction* self,
                                        gint64 value);
VALA_EXTERN const gchar* tuba_api_emoji_reaction_get_url (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_url (TubaAPIEmojiReaction* self,
                                      const gchar* value);
VALA_EXTERN const gchar* tuba_api_emoji_reaction_get_name (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_name (TubaAPIEmojiReaction* self,
                                       const gchar* value);
VALA_EXTERN gboolean tuba_api_emoji_reaction_get_me (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_me (TubaAPIEmojiReaction* self,
                                     gboolean value);
VALA_EXTERN GeeArrayList* tuba_api_emoji_reaction_get_accounts (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_accounts (TubaAPIEmojiReaction* self,
                                           GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_emoji_reaction_get_account_ids (TubaAPIEmojiReaction* self);
VALA_EXTERN void tuba_api_emoji_reaction_set_account_ids (TubaAPIEmojiReaction* self,
                                              GeeArrayList* value);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static void tuba_api_emoji_reaction_finalize (GObject * obj);
static GType tuba_api_emoji_reaction_get_type_once (void);
static void _vala_tuba_api_emoji_reaction_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_tuba_api_emoji_reaction_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);

static inline gpointer
tuba_api_emoji_reaction_get_instance_private (TubaAPIEmojiReaction* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIEmojiReaction_private_offset);
}

static GType
tuba_api_emoji_reaction_real_deserialize_array_type (TubaEntity* base,
                                                     const gchar* prop)
{
	TubaAPIEmojiReaction * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	GType result;
	self = (TubaAPIEmojiReaction*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("accounts")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_ACCOUNT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("account-ids")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_emoji_reaction_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static GtkWidget*
tuba_api_emoji_reaction_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIEmojiReaction * self;
	TubaWidgetsEmojiReactionAccounts* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIEmojiReaction*) base;
	_tmp0_ = tuba_widgets_emoji_reaction_accounts_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

static void
tuba_api_emoji_reaction_real_open (TubaWidgetizable* base)
{
	TubaAPIEmojiReaction * self;
	self = (TubaAPIEmojiReaction*) base;
}

TubaAPIEmojiReaction*
tuba_api_emoji_reaction_construct (GType object_type)
{
	TubaAPIEmojiReaction * self = NULL;
	self = (TubaAPIEmojiReaction*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIEmojiReaction*
tuba_api_emoji_reaction_new (void)
{
	return tuba_api_emoji_reaction_construct (TUBA_API_TYPE_EMOJI_REACTION);
}

gint64
tuba_api_emoji_reaction_get_count (TubaAPIEmojiReaction* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_count;
	return result;
}

void
tuba_api_emoji_reaction_set_count (TubaAPIEmojiReaction* self,
                                   gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_count (self);
	if (old_value != value) {
		self->priv->_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_COUNT_PROPERTY]);
	}
}

const gchar*
tuba_api_emoji_reaction_get_url (TubaAPIEmojiReaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_emoji_reaction_set_url (TubaAPIEmojiReaction* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_URL_PROPERTY]);
	}
}

const gchar*
tuba_api_emoji_reaction_get_name (TubaAPIEmojiReaction* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_emoji_reaction_set_name (TubaAPIEmojiReaction* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_NAME_PROPERTY]);
	}
}

gboolean
tuba_api_emoji_reaction_get_me (TubaAPIEmojiReaction* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_me;
	return result;
}

void
tuba_api_emoji_reaction_set_me (TubaAPIEmojiReaction* self,
                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_me (self);
	if (old_value != value) {
		self->priv->_me = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ME_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_emoji_reaction_get_accounts (TubaAPIEmojiReaction* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_accounts;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_api_emoji_reaction_set_accounts (TubaAPIEmojiReaction* self,
                                      GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_accounts (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_accounts);
		self->priv->_accounts = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_emoji_reaction_get_account_ids (TubaAPIEmojiReaction* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_account_ids;
	result = _tmp0_;
	return result;
}

void
tuba_api_emoji_reaction_set_account_ids (TubaAPIEmojiReaction* self,
                                         GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_emoji_reaction_get_account_ids (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_account_ids);
		self->priv->_account_ids = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY]);
	}
}

static void
tuba_api_emoji_reaction_class_init (TubaAPIEmojiReactionClass * klass,
                                    gpointer klass_data)
{
	tuba_api_emoji_reaction_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIEmojiReaction_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_emoji_reaction_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_emoji_reaction_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_emoji_reaction_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_emoji_reaction_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_COUNT_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_COUNT_PROPERTY] = g_param_spec_int64 ("count", "count", "count", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_URL_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_NAME_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_ME_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ME_PROPERTY] = g_param_spec_boolean ("me", "me", "me", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY] = g_param_spec_object ("accounts", "accounts", "accounts", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY, tuba_api_emoji_reaction_properties[TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY] = g_param_spec_object ("account-ids", "account-ids", "account-ids", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_emoji_reaction_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                          gpointer iface_data)
{
	tuba_api_emoji_reaction_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_emoji_reaction_real_to_widget;
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_emoji_reaction_real_open;
}

static void
tuba_api_emoji_reaction_instance_init (TubaAPIEmojiReaction * self,
                                       gpointer klass)
{
	self->priv = tuba_api_emoji_reaction_get_instance_private (self);
	self->priv->_count = (gint64) 0;
	self->priv->_url = NULL;
	self->priv->_name = NULL;
	self->priv->_me = FALSE;
	self->priv->_accounts = NULL;
	self->priv->_account_ids = NULL;
}

static void
tuba_api_emoji_reaction_finalize (GObject * obj)
{
	TubaAPIEmojiReaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReaction);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_name);
	_g_object_unref0 (self->priv->_accounts);
	_g_object_unref0 (self->priv->_account_ids);
	G_OBJECT_CLASS (tuba_api_emoji_reaction_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_emoji_reaction_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIEmojiReactionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_emoji_reaction_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIEmojiReaction), 0, (GInstanceInitFunc) tuba_api_emoji_reaction_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_emoji_reaction_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_emoji_reaction_type_id;
	tuba_api_emoji_reaction_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIEmojiReaction", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_emoji_reaction_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIEmojiReaction_private_offset = g_type_add_instance_private (tuba_api_emoji_reaction_type_id, sizeof (TubaAPIEmojiReactionPrivate));
	return tuba_api_emoji_reaction_type_id;
}

GType
tuba_api_emoji_reaction_get_type (void)
{
	static GType tuba_api_emoji_reaction_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_emoji_reaction_type_id__once)) {
		GType tuba_api_emoji_reaction_type_id;
		tuba_api_emoji_reaction_type_id = tuba_api_emoji_reaction_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_emoji_reaction_type_id__once, tuba_api_emoji_reaction_type_id);
	}
	return tuba_api_emoji_reaction_type_id__once;
}

static void
_vala_tuba_api_emoji_reaction_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	TubaAPIEmojiReaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReaction);
	switch (property_id) {
		case TUBA_API_EMOJI_REACTION_COUNT_PROPERTY:
		g_value_set_int64 (value, tuba_api_emoji_reaction_get_count (self));
		break;
		case TUBA_API_EMOJI_REACTION_URL_PROPERTY:
		g_value_set_string (value, tuba_api_emoji_reaction_get_url (self));
		break;
		case TUBA_API_EMOJI_REACTION_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_emoji_reaction_get_name (self));
		break;
		case TUBA_API_EMOJI_REACTION_ME_PROPERTY:
		g_value_set_boolean (value, tuba_api_emoji_reaction_get_me (self));
		break;
		case TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY:
		g_value_set_object (value, tuba_api_emoji_reaction_get_accounts (self));
		break;
		case TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY:
		g_value_set_object (value, tuba_api_emoji_reaction_get_account_ids (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_emoji_reaction_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	TubaAPIEmojiReaction * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_EMOJI_REACTION, TubaAPIEmojiReaction);
	switch (property_id) {
		case TUBA_API_EMOJI_REACTION_COUNT_PROPERTY:
		tuba_api_emoji_reaction_set_count (self, g_value_get_int64 (value));
		break;
		case TUBA_API_EMOJI_REACTION_URL_PROPERTY:
		tuba_api_emoji_reaction_set_url (self, g_value_get_string (value));
		break;
		case TUBA_API_EMOJI_REACTION_NAME_PROPERTY:
		tuba_api_emoji_reaction_set_name (self, g_value_get_string (value));
		break;
		case TUBA_API_EMOJI_REACTION_ME_PROPERTY:
		tuba_api_emoji_reaction_set_me (self, g_value_get_boolean (value));
		break;
		case TUBA_API_EMOJI_REACTION_ACCOUNTS_PROPERTY:
		tuba_api_emoji_reaction_set_accounts (self, g_value_get_object (value));
		break;
		case TUBA_API_EMOJI_REACTION_ACCOUNT_IDS_PROPERTY:
		tuba_api_emoji_reaction_set_account_ids (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

