/* PreviewCardInternal.c generated by valac 0.56.19, the Vala compiler
 * generated from PreviewCardInternal.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL (tuba_widgets_preview_card_internal_get_type ())
#define TUBA_WIDGETS_PREVIEW_CARD_INTERNAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL, TubaWidgetsPreviewCardInternal))
#define TUBA_WIDGETS_PREVIEW_CARD_INTERNAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL, TubaWidgetsPreviewCardInternalClass))
#define TUBA_WIDGETS_IS_PREVIEW_CARD_INTERNAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL))
#define TUBA_WIDGETS_IS_PREVIEW_CARD_INTERNAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL))
#define TUBA_WIDGETS_PREVIEW_CARD_INTERNAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL, TubaWidgetsPreviewCardInternalClass))

typedef struct _TubaWidgetsPreviewCardInternal TubaWidgetsPreviewCardInternal;
typedef struct _TubaWidgetsPreviewCardInternalClass TubaWidgetsPreviewCardInternalClass;
typedef struct _TubaWidgetsPreviewCardInternalPrivate TubaWidgetsPreviewCardInternalPrivate;
enum  {
	TUBA_WIDGETS_PREVIEW_CARD_INTERNAL_0_PROPERTY,
	TUBA_WIDGETS_PREVIEW_CARD_INTERNAL_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_preview_card_internal_properties[TUBA_WIDGETS_PREVIEW_CARD_INTERNAL_NUM_PROPERTIES];

struct _TubaWidgetsPreviewCardInternal {
	GtkBox parent_instance;
	TubaWidgetsPreviewCardInternalPrivate * priv;
	GtkLabel* author_label;
	GtkLabel* title_label;
	GtkLabel* description_label;
	GtkBox* internal_box;
};

struct _TubaWidgetsPreviewCardInternalClass {
	GtkBoxClass parent_class;
};

static gpointer tuba_widgets_preview_card_internal_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_preview_card_internal_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsPreviewCardInternal, g_object_unref)
VALA_EXTERN TubaWidgetsPreviewCardInternal* tuba_widgets_preview_card_internal_new (void);
VALA_EXTERN TubaWidgetsPreviewCardInternal* tuba_widgets_preview_card_internal_construct (GType object_type);
static void tuba_widgets_preview_card_internal_finalize (GObject * obj);
static GType tuba_widgets_preview_card_internal_get_type_once (void);

TubaWidgetsPreviewCardInternal*
tuba_widgets_preview_card_internal_construct (GType object_type)
{
	TubaWidgetsPreviewCardInternal * self = NULL;
	self = (TubaWidgetsPreviewCardInternal*) g_object_new (object_type, NULL);
	return self;
}

TubaWidgetsPreviewCardInternal*
tuba_widgets_preview_card_internal_new (void)
{
	return tuba_widgets_preview_card_internal_construct (TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL);
}

static void
tuba_widgets_preview_card_internal_class_init (TubaWidgetsPreviewCardInternalClass * klass,
                                               gpointer klass_data)
{
	tuba_widgets_preview_card_internal_parent_class = g_type_class_peek_parent (klass);
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_preview_card_internal_finalize;
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/dev/geopjr/Tuba/ui/widgets/preview_card_internal.ui");
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "author_label", FALSE, G_STRUCT_OFFSET (TubaWidgetsPreviewCardInternal, author_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, G_STRUCT_OFFSET (TubaWidgetsPreviewCardInternal, title_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "description_label", FALSE, G_STRUCT_OFFSET (TubaWidgetsPreviewCardInternal, description_label));
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "internal_box", FALSE, G_STRUCT_OFFSET (TubaWidgetsPreviewCardInternal, internal_box));
}

static void
tuba_widgets_preview_card_internal_instance_init (TubaWidgetsPreviewCardInternal * self,
                                                  gpointer klass)
{
	gtk_widget_init_template (GTK_WIDGET (self));
}

static void
tuba_widgets_preview_card_internal_finalize (GObject * obj)
{
	TubaWidgetsPreviewCardInternal * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_PREVIEW_CARD_INTERNAL, TubaWidgetsPreviewCardInternal);
	G_OBJECT_CLASS (tuba_widgets_preview_card_internal_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_preview_card_internal_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsPreviewCardInternalClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_preview_card_internal_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsPreviewCardInternal), 0, (GInstanceInitFunc) tuba_widgets_preview_card_internal_instance_init, NULL };
	GType tuba_widgets_preview_card_internal_type_id;
	tuba_widgets_preview_card_internal_type_id = g_type_register_static (gtk_box_get_type (), "TubaWidgetsPreviewCardInternal", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_widgets_preview_card_internal_type_id;
}

GType
tuba_widgets_preview_card_internal_get_type (void)
{
	static GType tuba_widgets_preview_card_internal_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_preview_card_internal_type_id__once)) {
		GType tuba_widgets_preview_card_internal_type_id;
		tuba_widgets_preview_card_internal_type_id = tuba_widgets_preview_card_internal_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_preview_card_internal_type_id__once, tuba_widgets_preview_card_internal_type_id);
	}
	return tuba_widgets_preview_card_internal_type_id__once;
}

