/* List.c generated by valac 0.56.19, the Vala compiler
 * generated from List.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_LIST (tuba_api_list_get_type ())
#define TUBA_API_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_LIST, TubaAPIList))
#define TUBA_API_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_LIST, TubaAPIListClass))
#define TUBA_API_IS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_LIST))
#define TUBA_API_IS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_LIST))
#define TUBA_API_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_LIST, TubaAPIListClass))

typedef struct _TubaAPIList TubaAPIList;
typedef struct _TubaAPIListClass TubaAPIListClass;
typedef struct _TubaAPIListPrivate TubaAPIListPrivate;
enum  {
	TUBA_API_LIST_0_PROPERTY,
	TUBA_API_LIST_ID_PROPERTY,
	TUBA_API_LIST_TITLE_PROPERTY,
	TUBA_API_LIST_REPLIES_POLICY_PROPERTY,
	TUBA_API_LIST_EXCLUSIVE_PROPERTY,
	TUBA_API_LIST_NUM_PROPERTIES
};
static GParamSpec* tuba_api_list_properties[TUBA_API_LIST_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_VIEWS_LISTS_TYPE_ROW (tuba_views_lists_row_get_type ())
#define TUBA_VIEWS_LISTS_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_LISTS_TYPE_ROW, TubaViewsListsRow))
#define TUBA_VIEWS_LISTS_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_LISTS_TYPE_ROW, TubaViewsListsRowClass))
#define TUBA_VIEWS_LISTS_IS_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_LISTS_TYPE_ROW))
#define TUBA_VIEWS_LISTS_IS_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_LISTS_TYPE_ROW))
#define TUBA_VIEWS_LISTS_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_LISTS_TYPE_ROW, TubaViewsListsRowClass))

typedef struct _TubaViewsListsRow TubaViewsListsRow;
typedef struct _TubaViewsListsRowClass TubaViewsListsRowClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;

#define TUBA_VIEWS_TYPE_LIST (tuba_views_list_get_type ())
#define TUBA_VIEWS_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_LIST, TubaViewsList))
#define TUBA_VIEWS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_LIST, TubaViewsListClass))
#define TUBA_VIEWS_IS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_LIST))
#define TUBA_VIEWS_IS_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_LIST))
#define TUBA_VIEWS_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_LIST, TubaViewsListClass))

typedef struct _TubaViewsList TubaViewsList;
typedef struct _TubaViewsListClass TubaViewsListClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIList {
	TubaEntity parent_instance;
	TubaAPIListPrivate * priv;
};

struct _TubaAPIListClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIListPrivate {
	gchar* _id;
	gchar* _title;
	gchar* _replies_policy;
	gboolean _exclusive;
};

static gint TubaAPIList_private_offset;
static gpointer tuba_api_list_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;
static TubaWidgetizableIface * tuba_api_list_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIList, g_object_unref)
VALA_EXTERN TubaAPIList* tuba_api_list_from (JsonNode* node,
                                 GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
static GtkWidget* tuba_api_list_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaViewsListsRow* tuba_views_lists_row_new (TubaAPIList* list);
VALA_EXTERN TubaViewsListsRow* tuba_views_lists_row_construct (GType object_type,
                                                   TubaAPIList* list);
VALA_EXTERN GType tuba_views_lists_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsListsRow, g_object_unref)
static void tuba_api_list_real_open (TubaWidgetizable* base);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN TubaViewsList* tuba_views_list_new (TubaAPIList* l);
VALA_EXTERN TubaViewsList* tuba_views_list_construct (GType object_type,
                                          TubaAPIList* l);
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsList, g_object_unref)
VALA_EXTERN TubaAPIList* tuba_api_list_new (void);
VALA_EXTERN TubaAPIList* tuba_api_list_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_list_get_id (TubaAPIList* self);
VALA_EXTERN void tuba_api_list_set_id (TubaAPIList* self,
                           const gchar* value);
VALA_EXTERN const gchar* tuba_api_list_get_title (TubaAPIList* self);
VALA_EXTERN void tuba_api_list_set_title (TubaAPIList* self,
                              const gchar* value);
VALA_EXTERN const gchar* tuba_api_list_get_replies_policy (TubaAPIList* self);
VALA_EXTERN void tuba_api_list_set_replies_policy (TubaAPIList* self,
                                       const gchar* value);
VALA_EXTERN gboolean tuba_api_list_get_exclusive (TubaAPIList* self);
VALA_EXTERN void tuba_api_list_set_exclusive (TubaAPIList* self,
                                  gboolean value);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static void tuba_api_list_finalize (GObject * obj);
static GType tuba_api_list_get_type_once (void);
static void _vala_tuba_api_list_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_tuba_api_list_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);

static inline gpointer
tuba_api_list_get_instance_private (TubaAPIList* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIList_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIList*
tuba_api_list_from (JsonNode* node,
                    GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIList* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIList* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_LIST, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_LIST (_tmp0_) ? ((TubaAPIList*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static GtkWidget*
tuba_api_list_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIList * self;
	TubaViewsListsRow* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIList*) base;
	_tmp0_ = tuba_views_lists_row_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

static void
tuba_api_list_real_open (TubaWidgetizable* base)
{
	TubaAPIList * self;
	TubaApplication* _tmp0_;
	TubaDialogsMainWindow* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	TubaViewsList* _tmp3_;
	TubaViewsList* _tmp4_;
	TubaViewsBase* _tmp5_;
	TubaViewsBase* _tmp6_;
	self = (TubaAPIList*) base;
	_tmp0_ = tuba_app;
	_tmp1_ = tuba_application_get_main_window (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_views_list_new (self);
	g_object_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	_tmp5_ = tuba_dialogs_main_window_open_view (_tmp2_, (TubaViewsBase*) _tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp6_);
	_g_object_unref0 (_tmp4_);
}

TubaAPIList*
tuba_api_list_construct (GType object_type)
{
	TubaAPIList * self = NULL;
	self = (TubaAPIList*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIList*
tuba_api_list_new (void)
{
	return tuba_api_list_construct (TUBA_API_TYPE_LIST);
}

const gchar*
tuba_api_list_get_id (TubaAPIList* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_list_set_id (TubaAPIList* self,
                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_list_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_list_properties[TUBA_API_LIST_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_list_get_title (TubaAPIList* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}

void
tuba_api_list_set_title (TubaAPIList* self,
                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_list_get_title (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_title);
		self->priv->_title = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_list_properties[TUBA_API_LIST_TITLE_PROPERTY]);
	}
}

const gchar*
tuba_api_list_get_replies_policy (TubaAPIList* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_replies_policy;
	result = _tmp0_;
	return result;
}

void
tuba_api_list_set_replies_policy (TubaAPIList* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_list_get_replies_policy (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_replies_policy);
		self->priv->_replies_policy = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_list_properties[TUBA_API_LIST_REPLIES_POLICY_PROPERTY]);
	}
}

gboolean
tuba_api_list_get_exclusive (TubaAPIList* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_exclusive;
	return result;
}

void
tuba_api_list_set_exclusive (TubaAPIList* self,
                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_list_get_exclusive (self);
	if (old_value != value) {
		self->priv->_exclusive = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_list_properties[TUBA_API_LIST_EXCLUSIVE_PROPERTY]);
	}
}

static void
tuba_api_list_class_init (TubaAPIListClass * klass,
                          gpointer klass_data)
{
	tuba_api_list_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIList_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_list_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_list_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_list_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_LIST_ID_PROPERTY, tuba_api_list_properties[TUBA_API_LIST_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_LIST_TITLE_PROPERTY, tuba_api_list_properties[TUBA_API_LIST_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_LIST_REPLIES_POLICY_PROPERTY, tuba_api_list_properties[TUBA_API_LIST_REPLIES_POLICY_PROPERTY] = g_param_spec_string ("replies-policy", "replies-policy", "replies-policy", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_LIST_EXCLUSIVE_PROPERTY, tuba_api_list_properties[TUBA_API_LIST_EXCLUSIVE_PROPERTY] = g_param_spec_boolean ("exclusive", "exclusive", "exclusive", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_list_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                gpointer iface_data)
{
	tuba_api_list_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_list_real_to_widget;
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_list_real_open;
}

static void
tuba_api_list_instance_init (TubaAPIList * self,
                             gpointer klass)
{
	self->priv = tuba_api_list_get_instance_private (self);
	self->priv->_replies_policy = NULL;
	self->priv->_exclusive = FALSE;
}

static void
tuba_api_list_finalize (GObject * obj)
{
	TubaAPIList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_LIST, TubaAPIList);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_title);
	_g_free0 (self->priv->_replies_policy);
	G_OBJECT_CLASS (tuba_api_list_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_list_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIListClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_list_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIList), 0, (GInstanceInitFunc) tuba_api_list_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_list_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_list_type_id;
	tuba_api_list_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIList", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_list_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIList_private_offset = g_type_add_instance_private (tuba_api_list_type_id, sizeof (TubaAPIListPrivate));
	return tuba_api_list_type_id;
}

GType
tuba_api_list_get_type (void)
{
	static GType tuba_api_list_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_list_type_id__once)) {
		GType tuba_api_list_type_id;
		tuba_api_list_type_id = tuba_api_list_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_list_type_id__once, tuba_api_list_type_id);
	}
	return tuba_api_list_type_id__once;
}

static void
_vala_tuba_api_list_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	TubaAPIList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_LIST, TubaAPIList);
	switch (property_id) {
		case TUBA_API_LIST_ID_PROPERTY:
		g_value_set_string (value, tuba_api_list_get_id (self));
		break;
		case TUBA_API_LIST_TITLE_PROPERTY:
		g_value_set_string (value, tuba_api_list_get_title (self));
		break;
		case TUBA_API_LIST_REPLIES_POLICY_PROPERTY:
		g_value_set_string (value, tuba_api_list_get_replies_policy (self));
		break;
		case TUBA_API_LIST_EXCLUSIVE_PROPERTY:
		g_value_set_boolean (value, tuba_api_list_get_exclusive (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_list_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	TubaAPIList * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_LIST, TubaAPIList);
	switch (property_id) {
		case TUBA_API_LIST_ID_PROPERTY:
		tuba_api_list_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_LIST_TITLE_PROPERTY:
		tuba_api_list_set_title (self, g_value_get_string (value));
		break;
		case TUBA_API_LIST_REPLIES_POLICY_PROPERTY:
		tuba_api_list_set_replies_policy (self, g_value_get_string (value));
		break;
		case TUBA_API_LIST_EXCLUSIVE_PROPERTY:
		tuba_api_list_set_exclusive (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

