/* FollowRequestRow.c generated by valac 0.56.19, the Vala compiler
 * generated from FollowRequestRow.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW (tuba_widgets_follow_request_row_get_type ())
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow))
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRowClass))
#define TUBA_WIDGETS_IS_FOLLOW_REQUEST_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW))
#define TUBA_WIDGETS_IS_FOLLOW_REQUEST_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW))
#define TUBA_WIDGETS_FOLLOW_REQUEST_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRowClass))

typedef struct _TubaWidgetsFollowRequestRow TubaWidgetsFollowRequestRow;
typedef struct _TubaWidgetsFollowRequestRowClass TubaWidgetsFollowRequestRowClass;
typedef struct _TubaWidgetsFollowRequestRowPrivate TubaWidgetsFollowRequestRowPrivate;
enum  {
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_0_PROPERTY,
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY,
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_follow_request_row_properties[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
enum  {
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_DECLINED_SIGNAL,
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ACCEPTED_SIGNAL,
	TUBA_WIDGETS_FOLLOW_REQUEST_ROW_NUM_SIGNALS
};
static guint tuba_widgets_follow_request_row_signals[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_NUM_SIGNALS] = {0};

struct _TubaWidgetsFollowRequestRow {
	GtkBox parent_instance;
	TubaWidgetsFollowRequestRowPrivate * priv;
};

struct _TubaWidgetsFollowRequestRowClass {
	GtkBoxClass parent_class;
};

struct _TubaWidgetsFollowRequestRowPrivate {
	gchar* _id;
	GtkButton* decline_fr_button;
	GtkButton* accept_fr_button;
};

static gint TubaWidgetsFollowRequestRow_private_offset;
static gpointer tuba_widgets_follow_request_row_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_widgets_follow_request_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsFollowRequestRow, g_object_unref)
static void tuba_widgets_follow_request_row_on_decline (TubaWidgetsFollowRequestRow* self);
VALA_EXTERN const gchar* tuba_widgets_follow_request_row_get_id (TubaWidgetsFollowRequestRow* self);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
static void tuba_widgets_follow_request_row_on_accept (TubaWidgetsFollowRequestRow* self);
VALA_EXTERN TubaWidgetsFollowRequestRow* tuba_widgets_follow_request_row_new (const gchar* t_id);
VALA_EXTERN TubaWidgetsFollowRequestRow* tuba_widgets_follow_request_row_construct (GType object_type,
                                                                        const gchar* t_id);
VALA_EXTERN void tuba_widgets_follow_request_row_set_id (TubaWidgetsFollowRequestRow* self,
                                             const gchar* value);
static GObject * tuba_widgets_follow_request_row_constructor (GType type,
                                                       guint n_construct_properties,
                                                       GObjectConstructParam * construct_properties);
static void _tuba_widgets_follow_request_row_on_decline_gtk_button_clicked (GtkButton* _sender,
                                                                     gpointer self);
static void _tuba_widgets_follow_request_row_on_accept_gtk_button_clicked (GtkButton* _sender,
                                                                    gpointer self);
static void tuba_widgets_follow_request_row_finalize (GObject * obj);
static GType tuba_widgets_follow_request_row_get_type_once (void);
static void _vala_tuba_widgets_follow_request_row_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec);
static void _vala_tuba_widgets_follow_request_row_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_widgets_follow_request_row_get_instance_private (TubaWidgetsFollowRequestRow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsFollowRequestRow_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_widgets_follow_request_row_on_decline (TubaWidgetsFollowRequestRow* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_ = NULL;
	TubaRequestV2* _tmp9_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_id;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("/api/v1/follow_requests/", _tmp1_, "/reject", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_accounts;
	_tmp5_ = tuba_account_store_get_active (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _g_object_ref0 (_tmp6_);
	_tmp8_ = tuba_request_v2_new (_tmp3_, TUBA_REQUEST_V2_METHOD_POST);
	tuba_request_v2_set_account (_tmp8_, _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp9_ = _tmp8_;
	g_signal_emit (self, tuba_widgets_follow_request_row_signals[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_DECLINED_SIGNAL], 0, _tmp9_);
	_g_object_unref0 (_tmp9_);
	_g_free0 (_tmp3_);
}

static void
tuba_widgets_follow_request_row_on_accept (TubaWidgetsFollowRequestRow* self)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	TubaAccountStore* _tmp4_;
	TubaInstanceAccount* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaRequestV2* _tmp8_ = NULL;
	TubaRequestV2* _tmp9_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_id;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("/api/v1/follow_requests/", _tmp1_, "/authorize", NULL);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_accounts;
	_tmp5_ = tuba_account_store_get_active (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = _g_object_ref0 (_tmp6_);
	_tmp8_ = tuba_request_v2_new (_tmp3_, TUBA_REQUEST_V2_METHOD_POST);
	tuba_request_v2_set_account (_tmp8_, _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp9_ = _tmp8_;
	g_signal_emit (self, tuba_widgets_follow_request_row_signals[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ACCEPTED_SIGNAL], 0, _tmp9_);
	_g_object_unref0 (_tmp9_);
	_g_free0 (_tmp3_);
}

TubaWidgetsFollowRequestRow*
tuba_widgets_follow_request_row_construct (GType object_type,
                                           const gchar* t_id)
{
	TubaWidgetsFollowRequestRow * self = NULL;
	g_return_val_if_fail (t_id != NULL, NULL);
	self = (TubaWidgetsFollowRequestRow*) g_object_new (object_type, "id", t_id, NULL);
	return self;
}

TubaWidgetsFollowRequestRow*
tuba_widgets_follow_request_row_new (const gchar* t_id)
{
	return tuba_widgets_follow_request_row_construct (TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, t_id);
}

const gchar*
tuba_widgets_follow_request_row_get_id (TubaWidgetsFollowRequestRow* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_widgets_follow_request_row_set_id (TubaWidgetsFollowRequestRow* self,
                                        const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_widgets_follow_request_row_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_widgets_follow_request_row_properties[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY]);
	}
}

static void
_tuba_widgets_follow_request_row_on_decline_gtk_button_clicked (GtkButton* _sender,
                                                                gpointer self)
{
	tuba_widgets_follow_request_row_on_decline ((TubaWidgetsFollowRequestRow*) self);
}

static void
_tuba_widgets_follow_request_row_on_accept_gtk_button_clicked (GtkButton* _sender,
                                                               gpointer self)
{
	tuba_widgets_follow_request_row_on_accept ((TubaWidgetsFollowRequestRow*) self);
}

static GObject *
tuba_widgets_follow_request_row_constructor (GType type,
                                             guint n_construct_properties,
                                             GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaWidgetsFollowRequestRow * self;
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	GtkButton* _tmp3_;
	parent_class = G_OBJECT_CLASS (tuba_widgets_follow_request_row_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow);
	gtk_widget_add_css_class ((GtkWidget*) self, "ttl-post-actions");
	gtk_box_set_spacing ((GtkBox*) self, 0);
	gtk_box_set_homogeneous ((GtkBox*) self, TRUE);
	_tmp0_ = self->priv->decline_fr_button;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp0_);
	_tmp1_ = self->priv->accept_fr_button;
	gtk_box_append ((GtkBox*) self, (GtkWidget*) _tmp1_);
	_tmp2_ = self->priv->decline_fr_button;
	g_signal_connect_object (_tmp2_, "clicked", (GCallback) _tuba_widgets_follow_request_row_on_decline_gtk_button_clicked, self, 0);
	_tmp3_ = self->priv->accept_fr_button;
	g_signal_connect_object (_tmp3_, "clicked", (GCallback) _tuba_widgets_follow_request_row_on_accept_gtk_button_clicked, self, 0);
	return obj;
}

static void
tuba_widgets_follow_request_row_class_init (TubaWidgetsFollowRequestRowClass * klass,
                                            gpointer klass_data)
{
	tuba_widgets_follow_request_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsFollowRequestRow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_widgets_follow_request_row_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_widgets_follow_request_row_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_widgets_follow_request_row_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_follow_request_row_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY, tuba_widgets_follow_request_row_properties[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_widgets_follow_request_row_signals[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_DECLINED_SIGNAL] = g_signal_new ("declined", TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_TYPE_REQUEST_V2);
	tuba_widgets_follow_request_row_signals[TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ACCEPTED_SIGNAL] = g_signal_new ("accepted", TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_TYPE_REQUEST_V2);
}

static void
tuba_widgets_follow_request_row_instance_init (TubaWidgetsFollowRequestRow * self,
                                               gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_;
	GtkButton* _tmp5_ = NULL;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar** _tmp10_;
	GtkButton* _tmp11_ = NULL;
	self->priv = tuba_widgets_follow_request_row_get_instance_private (self);
	_tmp0_ = g_strdup (_ ("Decline"));
	_tmp1_ = g_strdup ("flat");
	_tmp2_ = g_strdup ("circular");
	_tmp3_ = g_strdup ("error");
	_tmp4_ = g_new0 (gchar*, 3 + 1);
	_tmp4_[0] = _tmp1_;
	_tmp4_[1] = _tmp2_;
	_tmp4_[2] = _tmp3_;
	_tmp5_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-cross-large-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp5_, _tmp0_);
	_g_free0 (_tmp0_);
	gtk_widget_set_halign ((GtkWidget*) _tmp5_, GTK_ALIGN_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp5_, _tmp4_);
	_tmp4_ = (_vala_array_free (_tmp4_, 3, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp5_);
	self->priv->decline_fr_button = _tmp5_;
	_tmp6_ = g_strdup (_ ("Accept"));
	_tmp7_ = g_strdup ("flat");
	_tmp8_ = g_strdup ("circular");
	_tmp9_ = g_strdup ("success");
	_tmp10_ = g_new0 (gchar*, 3 + 1);
	_tmp10_[0] = _tmp7_;
	_tmp10_[1] = _tmp8_;
	_tmp10_[2] = _tmp9_;
	_tmp11_ = (GtkButton*) gtk_button_new_from_icon_name ("tuba-check-round-outline-symbolic");
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp11_, _tmp6_);
	_g_free0 (_tmp6_);
	gtk_widget_set_halign ((GtkWidget*) _tmp11_, GTK_ALIGN_CENTER);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp11_, _tmp10_);
	_tmp10_ = (_vala_array_free (_tmp10_, 3, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp11_);
	self->priv->accept_fr_button = _tmp11_;
}

static void
tuba_widgets_follow_request_row_finalize (GObject * obj)
{
	TubaWidgetsFollowRequestRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow);
	_g_free0 (self->priv->_id);
	_g_object_unref0 (self->priv->decline_fr_button);
	_g_object_unref0 (self->priv->accept_fr_button);
	G_OBJECT_CLASS (tuba_widgets_follow_request_row_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_follow_request_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsFollowRequestRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_follow_request_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsFollowRequestRow), 0, (GInstanceInitFunc) tuba_widgets_follow_request_row_instance_init, NULL };
	GType tuba_widgets_follow_request_row_type_id;
	tuba_widgets_follow_request_row_type_id = g_type_register_static (gtk_box_get_type (), "TubaWidgetsFollowRequestRow", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsFollowRequestRow_private_offset = g_type_add_instance_private (tuba_widgets_follow_request_row_type_id, sizeof (TubaWidgetsFollowRequestRowPrivate));
	return tuba_widgets_follow_request_row_type_id;
}

GType
tuba_widgets_follow_request_row_get_type (void)
{
	static GType tuba_widgets_follow_request_row_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_follow_request_row_type_id__once)) {
		GType tuba_widgets_follow_request_row_type_id;
		tuba_widgets_follow_request_row_type_id = tuba_widgets_follow_request_row_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_follow_request_row_type_id__once, tuba_widgets_follow_request_row_type_id);
	}
	return tuba_widgets_follow_request_row_type_id__once;
}

static void
_vala_tuba_widgets_follow_request_row_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec)
{
	TubaWidgetsFollowRequestRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow);
	switch (property_id) {
		case TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY:
		g_value_set_string (value, tuba_widgets_follow_request_row_get_id (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_widgets_follow_request_row_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec)
{
	TubaWidgetsFollowRequestRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_TYPE_FOLLOW_REQUEST_ROW, TubaWidgetsFollowRequestRow);
	switch (property_id) {
		case TUBA_WIDGETS_FOLLOW_REQUEST_ROW_ID_PROPERTY:
		tuba_widgets_follow_request_row_set_id (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

