/* FeaturedTag.c generated by valac 0.56.19, the Vala compiler
 * generated from FeaturedTag.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <adwaita.h>
#include <glib/gi18n-lib.h>
#include <pango/pango.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_FEATURED_TAG (tuba_api_featured_tag_get_type ())
#define TUBA_API_FEATURED_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTag))
#define TUBA_API_FEATURED_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTagClass))
#define TUBA_API_IS_FEATURED_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_FEATURED_TAG))
#define TUBA_API_IS_FEATURED_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_FEATURED_TAG))
#define TUBA_API_FEATURED_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTagClass))

typedef struct _TubaAPIFeaturedTag TubaAPIFeaturedTag;
typedef struct _TubaAPIFeaturedTagClass TubaAPIFeaturedTagClass;
typedef struct _TubaAPIFeaturedTagPrivate TubaAPIFeaturedTagPrivate;
enum  {
	TUBA_API_FEATURED_TAG_0_PROPERTY,
	TUBA_API_FEATURED_TAG_NAME_PROPERTY,
	TUBA_API_FEATURED_TAG_URL_PROPERTY,
	TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY,
	TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY,
	TUBA_API_FEATURED_TAG_NUM_PROPERTIES
};
static GParamSpec* tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;

#define TUBA_VIEWS_TYPE_HASHTAG (tuba_views_hashtag_get_type ())
#define TUBA_VIEWS_HASHTAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtag))
#define TUBA_VIEWS_HASHTAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtagClass))
#define TUBA_VIEWS_IS_HASHTAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_HASHTAG))
#define TUBA_VIEWS_IS_HASHTAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_HASHTAG))
#define TUBA_VIEWS_HASHTAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtagClass))

typedef struct _TubaViewsHashtag TubaViewsHashtag;
typedef struct _TubaViewsHashtagClass TubaViewsHashtagClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIFeaturedTag {
	TubaEntity parent_instance;
	TubaAPIFeaturedTagPrivate * priv;
};

struct _TubaAPIFeaturedTagClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIFeaturedTagPrivate {
	gchar* _name;
	gchar* _url;
	gchar* _last_status_at;
	gchar* _statuses_count;
};

static gint TubaAPIFeaturedTag_private_offset;
static gpointer tuba_api_featured_tag_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;
static TubaWidgetizableIface * tuba_api_featured_tag_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_featured_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIFeaturedTag, g_object_unref)
VALA_EXTERN TubaAPIFeaturedTag* tuba_api_featured_tag_from (JsonNode* node,
                                                GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
static void tuba_api_featured_tag_real_open (TubaWidgetizable* base);
static GtkWidget* tuba_api_featured_tag_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN const gchar* tuba_api_featured_tag_get_name (TubaAPIFeaturedTag* self);
VALA_EXTERN const gchar* tuba_api_featured_tag_get_statuses_count (TubaAPIFeaturedTag* self);
VALA_EXTERN const gchar* tuba_api_featured_tag_get_last_status_at (TubaAPIFeaturedTag* self);
VALA_EXTERN void tuba_api_featured_tag_on_activated (TubaAPIFeaturedTag* self);
static void _tuba_api_featured_tag_on_activated_adw_action_row_activated (AdwActionRow* _sender,
                                                                   gpointer self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN const gchar* tuba_api_featured_tag_get_url (TubaAPIFeaturedTag* self);
VALA_EXTERN TubaViewsHashtag* tuba_views_hashtag_new (const gchar* tag,
                                          gboolean* following,
                                          const gchar* url_basename,
                                          gboolean* featured);
VALA_EXTERN TubaViewsHashtag* tuba_views_hashtag_construct (GType object_type,
                                                const gchar* tag,
                                                gboolean* following,
                                                const gchar* url_basename,
                                                gboolean* featured);
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_hashtag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtag, g_object_unref)
VALA_EXTERN TubaAPIFeaturedTag* tuba_api_featured_tag_new (void);
VALA_EXTERN TubaAPIFeaturedTag* tuba_api_featured_tag_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN void tuba_api_featured_tag_set_name (TubaAPIFeaturedTag* self,
                                     const gchar* value);
VALA_EXTERN void tuba_api_featured_tag_set_url (TubaAPIFeaturedTag* self,
                                    const gchar* value);
VALA_EXTERN void tuba_api_featured_tag_set_last_status_at (TubaAPIFeaturedTag* self,
                                               const gchar* value);
VALA_EXTERN void tuba_api_featured_tag_set_statuses_count (TubaAPIFeaturedTag* self,
                                               const gchar* value);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
static void tuba_api_featured_tag_finalize (GObject * obj);
static GType tuba_api_featured_tag_get_type_once (void);
static void _vala_tuba_api_featured_tag_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_tuba_api_featured_tag_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);

static inline gpointer
tuba_api_featured_tag_get_instance_private (TubaAPIFeaturedTag* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIFeaturedTag_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIFeaturedTag*
tuba_api_featured_tag_from (JsonNode* node,
                            GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIFeaturedTag* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIFeaturedTag* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_FEATURED_TAG, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_FEATURED_TAG (_tmp0_) ? ((TubaAPIFeaturedTag*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static void
tuba_api_featured_tag_real_open (TubaWidgetizable* base)
{
	TubaAPIFeaturedTag * self;
	self = (TubaAPIFeaturedTag*) base;
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static gint64
int64_parse (const gchar* str,
             guint _base)
{
	gint64 result;
	g_return_val_if_fail (str != NULL, -1LL);
	result = g_ascii_strtoll (str, NULL, _base);
	return result;
}

static void
_tuba_api_featured_tag_on_activated_adw_action_row_activated (AdwActionRow* _sender,
                                                              gpointer self)
{
	tuba_api_featured_tag_on_activated ((TubaAPIFeaturedTag*) self);
}

static GtkWidget*
tuba_api_featured_tag_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIFeaturedTag * self;
	AdwActionRow* w = NULL;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	AdwActionRow* _tmp3_ = NULL;
	AdwActionRow* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	GtkLabel* _tmp10_ = NULL;
	GtkLabel* _tmp11_;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_;
	AdwActionRow* _tmp19_;
	GtkWidget* result;
	self = (TubaAPIFeaturedTag*) base;
	_tmp0_ = self->priv->_name;
	_tmp1_ = string_to_string (_tmp0_);
	_tmp2_ = g_strconcat ("#", _tmp1_, NULL);
	_tmp3_ = (AdwActionRow*) adw_action_row_new ();
	adw_preferences_row_set_title ((AdwPreferencesRow*) _tmp3_, _tmp2_);
	_g_free0 (_tmp2_);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp3_, TRUE);
	g_object_ref_sink (_tmp3_);
	w = _tmp3_;
	_tmp4_ = w;
	_tmp5_ = self->priv->_statuses_count;
	_tmp6_ = self->priv->_statuses_count;
	_tmp7_ = g_strdup_printf (ngettext ("%s Post", "%s Posts", (gulong) int64_parse (_tmp5_, (guint) 0)), _tmp6_);
	_tmp8_ = _tmp7_;
	_tmp9_ = g_strdup (_ ("Posts Including this Hashtag"));
	_tmp10_ = (GtkLabel*) gtk_label_new (_tmp8_);
	gtk_label_set_ellipsize (_tmp10_, PANGO_ELLIPSIZE_END);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp10_, _tmp9_);
	_g_free0 (_tmp9_);
	g_object_ref_sink (_tmp10_);
	_tmp11_ = _tmp10_;
	adw_action_row_add_suffix (_tmp4_, (GtkWidget*) _tmp11_);
	_g_object_unref0 (_tmp11_);
	_g_free0 (_tmp8_);
	_tmp13_ = self->priv->_statuses_count;
	if (g_strcmp0 (_tmp13_, "0") != 0) {
		const gchar* _tmp14_;
		_tmp14_ = self->priv->_last_status_at;
		_tmp12_ = g_strcmp0 (_tmp14_, "") != 0;
	} else {
		_tmp12_ = FALSE;
	}
	if (_tmp12_) {
		AdwActionRow* _tmp15_;
		const gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		_tmp15_ = w;
		_tmp16_ = self->priv->_last_status_at;
		_tmp17_ = g_strdup_printf (_ ("Last post on %s"), _tmp16_);
		_tmp18_ = _tmp17_;
		adw_action_row_set_subtitle (_tmp15_, _tmp18_);
		_g_free0 (_tmp18_);
	}
	_tmp19_ = w;
	g_signal_connect_object (_tmp19_, "activated", (GCallback) _tuba_api_featured_tag_on_activated_adw_action_row_activated, self, 0);
	result = (GtkWidget*) w;
	return result;
}

void
tuba_api_featured_tag_on_activated (TubaAPIFeaturedTag* self)
{
	TubaApplication* _tmp0_;
	TubaDialogsMainWindow* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gboolean _tmp7_;
	TubaViewsHashtag* _tmp8_;
	TubaViewsHashtag* _tmp9_;
	TubaViewsBase* _tmp10_;
	TubaViewsBase* _tmp11_;
	g_return_if_fail (self != NULL);
	_tmp0_ = tuba_app;
	_tmp1_ = tuba_application_get_main_window (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->priv->_name;
	_tmp4_ = self->priv->_url;
	_tmp5_ = g_path_get_basename (_tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = TRUE;
	_tmp8_ = tuba_views_hashtag_new (_tmp3_, NULL, _tmp6_, &_tmp7_);
	g_object_ref_sink (_tmp8_);
	_tmp9_ = _tmp8_;
	_tmp10_ = tuba_dialogs_main_window_open_view (_tmp2_, (TubaViewsBase*) _tmp9_);
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp11_);
	_g_object_unref0 (_tmp9_);
	_g_free0 (_tmp6_);
}

TubaAPIFeaturedTag*
tuba_api_featured_tag_construct (GType object_type)
{
	TubaAPIFeaturedTag * self = NULL;
	self = (TubaAPIFeaturedTag*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIFeaturedTag*
tuba_api_featured_tag_new (void)
{
	return tuba_api_featured_tag_construct (TUBA_API_TYPE_FEATURED_TAG);
}

const gchar*
tuba_api_featured_tag_get_name (TubaAPIFeaturedTag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_featured_tag_set_name (TubaAPIFeaturedTag* self,
                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_featured_tag_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_NAME_PROPERTY]);
	}
}

const gchar*
tuba_api_featured_tag_get_url (TubaAPIFeaturedTag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_featured_tag_set_url (TubaAPIFeaturedTag* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_featured_tag_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_URL_PROPERTY]);
	}
}

const gchar*
tuba_api_featured_tag_get_last_status_at (TubaAPIFeaturedTag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_last_status_at;
	result = _tmp0_;
	return result;
}

void
tuba_api_featured_tag_set_last_status_at (TubaAPIFeaturedTag* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_featured_tag_get_last_status_at (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_last_status_at);
		self->priv->_last_status_at = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY]);
	}
}

const gchar*
tuba_api_featured_tag_get_statuses_count (TubaAPIFeaturedTag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_statuses_count;
	result = _tmp0_;
	return result;
}

void
tuba_api_featured_tag_set_statuses_count (TubaAPIFeaturedTag* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_featured_tag_get_statuses_count (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_statuses_count);
		self->priv->_statuses_count = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY]);
	}
}

static void
tuba_api_featured_tag_class_init (TubaAPIFeaturedTagClass * klass,
                                  gpointer klass_data)
{
	tuba_api_featured_tag_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIFeaturedTag_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_featured_tag_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_featured_tag_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_featured_tag_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_FEATURED_TAG_NAME_PROPERTY, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_FEATURED_TAG_URL_PROPERTY, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY] = g_param_spec_string ("last-status-at", "last-status-at", "last-status-at", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY, tuba_api_featured_tag_properties[TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY] = g_param_spec_string ("statuses-count", "statuses-count", "statuses-count", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_featured_tag_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                        gpointer iface_data)
{
	tuba_api_featured_tag_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_featured_tag_real_open;
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_featured_tag_real_to_widget;
}

static void
tuba_api_featured_tag_instance_init (TubaAPIFeaturedTag * self,
                                     gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	self->priv = tuba_api_featured_tag_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_last_status_at = _tmp0_;
	_tmp1_ = g_strdup ("0");
	self->priv->_statuses_count = _tmp1_;
}

static void
tuba_api_featured_tag_finalize (GObject * obj)
{
	TubaAPIFeaturedTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTag);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_last_status_at);
	_g_free0 (self->priv->_statuses_count);
	G_OBJECT_CLASS (tuba_api_featured_tag_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_featured_tag_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIFeaturedTagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_featured_tag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIFeaturedTag), 0, (GInstanceInitFunc) tuba_api_featured_tag_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_featured_tag_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_featured_tag_type_id;
	tuba_api_featured_tag_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIFeaturedTag", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_featured_tag_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIFeaturedTag_private_offset = g_type_add_instance_private (tuba_api_featured_tag_type_id, sizeof (TubaAPIFeaturedTagPrivate));
	return tuba_api_featured_tag_type_id;
}

GType
tuba_api_featured_tag_get_type (void)
{
	static GType tuba_api_featured_tag_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_featured_tag_type_id__once)) {
		GType tuba_api_featured_tag_type_id;
		tuba_api_featured_tag_type_id = tuba_api_featured_tag_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_featured_tag_type_id__once, tuba_api_featured_tag_type_id);
	}
	return tuba_api_featured_tag_type_id__once;
}

static void
_vala_tuba_api_featured_tag_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPIFeaturedTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTag);
	switch (property_id) {
		case TUBA_API_FEATURED_TAG_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_featured_tag_get_name (self));
		break;
		case TUBA_API_FEATURED_TAG_URL_PROPERTY:
		g_value_set_string (value, tuba_api_featured_tag_get_url (self));
		break;
		case TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY:
		g_value_set_string (value, tuba_api_featured_tag_get_last_status_at (self));
		break;
		case TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY:
		g_value_set_string (value, tuba_api_featured_tag_get_statuses_count (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_featured_tag_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPIFeaturedTag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTag);
	switch (property_id) {
		case TUBA_API_FEATURED_TAG_NAME_PROPERTY:
		tuba_api_featured_tag_set_name (self, g_value_get_string (value));
		break;
		case TUBA_API_FEATURED_TAG_URL_PROPERTY:
		tuba_api_featured_tag_set_url (self, g_value_get_string (value));
		break;
		case TUBA_API_FEATURED_TAG_LAST_STATUS_AT_PROPERTY:
		tuba_api_featured_tag_set_last_status_at (self, g_value_get_string (value));
		break;
		case TUBA_API_FEATURED_TAG_STATUSES_COUNT_PROPERTY:
		tuba_api_featured_tag_set_statuses_count (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

