/* DropOverlay.c generated by valac 0.56.19, the Vala compiler
 * generated from DropOverlay.vala, do not modify */

/* Inspired by https://gitlab.gnome.org/World/amberol/-/blob/638eef0ba2b8ac6fac32a51241161fa25317fa18/src/drag_overlay.rs*/

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY (tuba_dialogs_composer_components_drop_overlay_get_type ())
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlay))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlayClass))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_IS_DROP_OVERLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_IS_DROP_OVERLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlayClass))

typedef struct _TubaDialogsComposerComponentsDropOverlay TubaDialogsComposerComponentsDropOverlay;
typedef struct _TubaDialogsComposerComponentsDropOverlayClass TubaDialogsComposerComponentsDropOverlayClass;
typedef struct _TubaDialogsComposerComponentsDropOverlayPrivate TubaDialogsComposerComponentsDropOverlayPrivate;
enum  {
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_0_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY,
	TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_NUM_PROPERTIES
};
static GParamSpec* tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

struct _TubaDialogsComposerComponentsDropOverlay {
	AdwBin parent_instance;
	TubaDialogsComposerComponentsDropOverlayPrivate * priv;
};

struct _TubaDialogsComposerComponentsDropOverlayClass {
	AdwBinClass parent_class;
};

struct _TubaDialogsComposerComponentsDropOverlayPrivate {
	GtkOverlay* overlay;
	GtkRevealer* revealer;
	AdwStatusPage* status_page;
};

static gint TubaDialogsComposerComponentsDropOverlay_private_offset;
static gpointer tuba_dialogs_composer_components_drop_overlay_parent_class = NULL;

VALA_EXTERN GType tuba_dialogs_composer_components_drop_overlay_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerComponentsDropOverlay, g_object_unref)
VALA_EXTERN TubaDialogsComposerComponentsDropOverlay* tuba_dialogs_composer_components_drop_overlay_new (void);
VALA_EXTERN TubaDialogsComposerComponentsDropOverlay* tuba_dialogs_composer_components_drop_overlay_construct (GType object_type);
VALA_EXTERN GtkWidget* tuba_dialogs_composer_components_drop_overlay_get_overlay_child (TubaDialogsComposerComponentsDropOverlay* self);
VALA_EXTERN void tuba_dialogs_composer_components_drop_overlay_set_overlay_child (TubaDialogsComposerComponentsDropOverlay* self,
                                                                      GtkWidget* value);
VALA_EXTERN gboolean tuba_dialogs_composer_components_drop_overlay_get_dropping (TubaDialogsComposerComponentsDropOverlay* self);
VALA_EXTERN void tuba_dialogs_composer_components_drop_overlay_set_dropping (TubaDialogsComposerComponentsDropOverlay* self,
                                                                 gboolean value);
VALA_EXTERN const gchar* tuba_dialogs_composer_components_drop_overlay_get_title (TubaDialogsComposerComponentsDropOverlay* self);
VALA_EXTERN void tuba_dialogs_composer_components_drop_overlay_set_title (TubaDialogsComposerComponentsDropOverlay* self,
                                                              const gchar* value);
VALA_EXTERN gboolean tuba_dialogs_composer_components_drop_overlay_get_compact (TubaDialogsComposerComponentsDropOverlay* self);
VALA_EXTERN void tuba_dialogs_composer_components_drop_overlay_set_compact (TubaDialogsComposerComponentsDropOverlay* self,
                                                                gboolean value);
VALA_EXTERN const gchar* tuba_dialogs_composer_components_drop_overlay_get_icon_name (TubaDialogsComposerComponentsDropOverlay* self);
VALA_EXTERN void tuba_dialogs_composer_components_drop_overlay_set_icon_name (TubaDialogsComposerComponentsDropOverlay* self,
                                                                  const gchar* value);
static GObject * tuba_dialogs_composer_components_drop_overlay_constructor (GType type,
                                                                     guint n_construct_properties,
                                                                     GObjectConstructParam * construct_properties);
static void tuba_dialogs_composer_components_drop_overlay_finalize (GObject * obj);
static GType tuba_dialogs_composer_components_drop_overlay_get_type_once (void);
static void _vala_tuba_dialogs_composer_components_drop_overlay_get_property (GObject * object,
                                                                       guint property_id,
                                                                       GValue * value,
                                                                       GParamSpec * pspec);
static void _vala_tuba_dialogs_composer_components_drop_overlay_set_property (GObject * object,
                                                                       guint property_id,
                                                                       const GValue * value,
                                                                       GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_dialogs_composer_components_drop_overlay_get_instance_private (TubaDialogsComposerComponentsDropOverlay* self)
{
	return G_STRUCT_MEMBER_P (self, TubaDialogsComposerComponentsDropOverlay_private_offset);
}

TubaDialogsComposerComponentsDropOverlay*
tuba_dialogs_composer_components_drop_overlay_construct (GType object_type)
{
	TubaDialogsComposerComponentsDropOverlay * self = NULL;
	self = (TubaDialogsComposerComponentsDropOverlay*) g_object_new (object_type, NULL);
	return self;
}

TubaDialogsComposerComponentsDropOverlay*
tuba_dialogs_composer_components_drop_overlay_new (void)
{
	return tuba_dialogs_composer_components_drop_overlay_construct (TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY);
}

GtkWidget*
tuba_dialogs_composer_components_drop_overlay_get_overlay_child (TubaDialogsComposerComponentsDropOverlay* self)
{
	GtkWidget* result;
	GtkOverlay* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->overlay;
	_tmp1_ = gtk_overlay_get_child (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_dialogs_composer_components_drop_overlay_set_overlay_child (TubaDialogsComposerComponentsDropOverlay* self,
                                                                 GtkWidget* value)
{
	GtkOverlay* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->overlay;
	gtk_overlay_set_child (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY]);
}

gboolean
tuba_dialogs_composer_components_drop_overlay_get_dropping (TubaDialogsComposerComponentsDropOverlay* self)
{
	gboolean result;
	GtkRevealer* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->revealer;
	_tmp1_ = gtk_revealer_get_reveal_child (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_dialogs_composer_components_drop_overlay_set_dropping (TubaDialogsComposerComponentsDropOverlay* self,
                                                            gboolean value)
{
	GtkRevealer* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->revealer;
	gtk_revealer_set_reveal_child (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY]);
}

const gchar*
tuba_dialogs_composer_components_drop_overlay_get_title (TubaDialogsComposerComponentsDropOverlay* self)
{
	const gchar* result;
	AdwStatusPage* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->status_page;
	_tmp1_ = adw_status_page_get_title (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_dialogs_composer_components_drop_overlay_set_title (TubaDialogsComposerComponentsDropOverlay* self,
                                                         const gchar* value)
{
	AdwStatusPage* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->status_page;
	adw_status_page_set_title (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY]);
}

gboolean
tuba_dialogs_composer_components_drop_overlay_get_compact (TubaDialogsComposerComponentsDropOverlay* self)
{
	gboolean result;
	AdwStatusPage* _tmp0_;
	g_return_val_if_fail (self != NULL, FALSE);
	_tmp0_ = self->priv->status_page;
	result = gtk_widget_has_css_class ((GtkWidget*) _tmp0_, "compact");
	return result;
}

void
tuba_dialogs_composer_components_drop_overlay_set_compact (TubaDialogsComposerComponentsDropOverlay* self,
                                                           gboolean value)
{
	gboolean _tmp0_;
	gboolean _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp0_ = tuba_dialogs_composer_components_drop_overlay_get_compact (self);
	_tmp1_ = _tmp0_;
	if (_tmp1_ != value) {
		if (value) {
			AdwStatusPage* _tmp2_;
			_tmp2_ = self->priv->status_page;
			gtk_widget_add_css_class ((GtkWidget*) _tmp2_, "compact");
		} else {
			AdwStatusPage* _tmp3_;
			_tmp3_ = self->priv->status_page;
			gtk_widget_remove_css_class ((GtkWidget*) _tmp3_, "compact");
		}
	}
	g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY]);
}

const gchar*
tuba_dialogs_composer_components_drop_overlay_get_icon_name (TubaDialogsComposerComponentsDropOverlay* self)
{
	const gchar* result;
	AdwStatusPage* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->status_page;
	_tmp1_ = adw_status_page_get_icon_name (_tmp0_);
	_tmp2_ = _tmp1_;
	result = _tmp2_;
	return result;
}

void
tuba_dialogs_composer_components_drop_overlay_set_icon_name (TubaDialogsComposerComponentsDropOverlay* self,
                                                             const gchar* value)
{
	AdwStatusPage* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->status_page;
	adw_status_page_set_icon_name (_tmp0_, value);
	g_object_notify_by_pspec ((GObject *) self, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY]);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static GObject *
tuba_dialogs_composer_components_drop_overlay_constructor (GType type,
                                                           guint n_construct_properties,
                                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaDialogsComposerComponentsDropOverlay * self;
	GtkOverlay* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar** _tmp3_;
	AdwStatusPage* _tmp4_ = NULL;
	AdwStatusPage* _tmp5_;
	GtkWidget* _tmp6_;
	GtkRevealer* _tmp7_ = NULL;
	GtkOverlay* _tmp8_;
	GtkRevealer* _tmp9_;
	GtkOverlay* _tmp10_;
	parent_class = G_OBJECT_CLASS (tuba_dialogs_composer_components_drop_overlay_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlay);
	_tmp0_ = (GtkOverlay*) gtk_overlay_new ();
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->overlay);
	self->priv->overlay = _tmp0_;
	_tmp1_ = g_strdup ("tuba-image-round-symbolic");
	_tmp2_ = g_strdup ("status");
	_tmp3_ = g_new0 (gchar*, 1 + 1);
	_tmp3_[0] = _tmp2_;
	_tmp4_ = (AdwStatusPage*) adw_status_page_new ();
	adw_status_page_set_icon_name (_tmp4_, _tmp1_);
	_g_free0 (_tmp1_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp4_, _tmp3_);
	_tmp3_ = (_vala_array_free (_tmp3_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp4_);
	_g_object_unref0 (self->priv->status_page);
	self->priv->status_page = _tmp4_;
	_tmp5_ = self->priv->status_page;
	_tmp6_ = _g_object_ref0 ((GtkWidget*) _tmp5_);
	_tmp7_ = (GtkRevealer*) gtk_revealer_new ();
	gtk_revealer_set_child (_tmp7_, _tmp6_);
	_g_object_unref0 (_tmp6_);
	gtk_widget_set_can_target ((GtkWidget*) _tmp7_, FALSE);
	gtk_revealer_set_transition_type (_tmp7_, GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
	gtk_revealer_set_transition_duration (_tmp7_, (guint) 800);
	g_object_ref_sink (_tmp7_);
	_g_object_unref0 (self->priv->revealer);
	self->priv->revealer = _tmp7_;
	_tmp8_ = self->priv->overlay;
	_tmp9_ = self->priv->revealer;
	gtk_overlay_add_overlay (_tmp8_, (GtkWidget*) _tmp9_);
	_tmp10_ = self->priv->overlay;
	adw_bin_set_child ((AdwBin*) self, (GtkWidget*) _tmp10_);
	return obj;
}

static void
tuba_dialogs_composer_components_drop_overlay_class_init (TubaDialogsComposerComponentsDropOverlayClass * klass,
                                                          gpointer klass_data)
{
	tuba_dialogs_composer_components_drop_overlay_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaDialogsComposerComponentsDropOverlay_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_dialogs_composer_components_drop_overlay_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_dialogs_composer_components_drop_overlay_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_dialogs_composer_components_drop_overlay_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_dialogs_composer_components_drop_overlay_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY] = g_param_spec_object ("overlay-child", "overlay-child", "overlay-child", gtk_widget_get_type (), G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY] = g_param_spec_boolean ("dropping", "dropping", "dropping", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY] = g_param_spec_boolean ("compact", "compact", "compact", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY, tuba_dialogs_composer_components_drop_overlay_properties[TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY] = g_param_spec_string ("icon-name", "icon-name", "icon-name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	gtk_widget_class_set_css_name (GTK_WIDGET_CLASS (klass), "dropoverlay");
}

static void
tuba_dialogs_composer_components_drop_overlay_instance_init (TubaDialogsComposerComponentsDropOverlay * self,
                                                             gpointer klass)
{
	self->priv = tuba_dialogs_composer_components_drop_overlay_get_instance_private (self);
}

static void
tuba_dialogs_composer_components_drop_overlay_finalize (GObject * obj)
{
	TubaDialogsComposerComponentsDropOverlay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlay);
	g_debug ("DropOverlay.vala:4: Destroying Composer DropOverlay");
	_g_object_unref0 (self->priv->overlay);
	_g_object_unref0 (self->priv->revealer);
	_g_object_unref0 (self->priv->status_page);
	G_OBJECT_CLASS (tuba_dialogs_composer_components_drop_overlay_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_dialogs_composer_components_drop_overlay_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaDialogsComposerComponentsDropOverlayClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_dialogs_composer_components_drop_overlay_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaDialogsComposerComponentsDropOverlay), 0, (GInstanceInitFunc) tuba_dialogs_composer_components_drop_overlay_instance_init, NULL };
	GType tuba_dialogs_composer_components_drop_overlay_type_id;
	tuba_dialogs_composer_components_drop_overlay_type_id = g_type_register_static (adw_bin_get_type (), "TubaDialogsComposerComponentsDropOverlay", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaDialogsComposerComponentsDropOverlay_private_offset = g_type_add_instance_private (tuba_dialogs_composer_components_drop_overlay_type_id, sizeof (TubaDialogsComposerComponentsDropOverlayPrivate));
	return tuba_dialogs_composer_components_drop_overlay_type_id;
}

GType
tuba_dialogs_composer_components_drop_overlay_get_type (void)
{
	static GType tuba_dialogs_composer_components_drop_overlay_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_dialogs_composer_components_drop_overlay_type_id__once)) {
		GType tuba_dialogs_composer_components_drop_overlay_type_id;
		tuba_dialogs_composer_components_drop_overlay_type_id = tuba_dialogs_composer_components_drop_overlay_get_type_once ();
		g_once_init_leave_pointer (&tuba_dialogs_composer_components_drop_overlay_type_id__once, tuba_dialogs_composer_components_drop_overlay_type_id);
	}
	return tuba_dialogs_composer_components_drop_overlay_type_id__once;
}

static void
_vala_tuba_dialogs_composer_components_drop_overlay_get_property (GObject * object,
                                                                  guint property_id,
                                                                  GValue * value,
                                                                  GParamSpec * pspec)
{
	TubaDialogsComposerComponentsDropOverlay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlay);
	switch (property_id) {
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY:
		g_value_set_object (value, tuba_dialogs_composer_components_drop_overlay_get_overlay_child (self));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY:
		g_value_set_boolean (value, tuba_dialogs_composer_components_drop_overlay_get_dropping (self));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY:
		g_value_set_string (value, tuba_dialogs_composer_components_drop_overlay_get_title (self));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY:
		g_value_set_boolean (value, tuba_dialogs_composer_components_drop_overlay_get_compact (self));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY:
		g_value_set_string (value, tuba_dialogs_composer_components_drop_overlay_get_icon_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_dialogs_composer_components_drop_overlay_set_property (GObject * object,
                                                                  guint property_id,
                                                                  const GValue * value,
                                                                  GParamSpec * pspec)
{
	TubaDialogsComposerComponentsDropOverlay * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_DIALOGS_COMPOSER_COMPONENTS_TYPE_DROP_OVERLAY, TubaDialogsComposerComponentsDropOverlay);
	switch (property_id) {
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_OVERLAY_CHILD_PROPERTY:
		tuba_dialogs_composer_components_drop_overlay_set_overlay_child (self, g_value_get_object (value));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_DROPPING_PROPERTY:
		tuba_dialogs_composer_components_drop_overlay_set_dropping (self, g_value_get_boolean (value));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_TITLE_PROPERTY:
		tuba_dialogs_composer_components_drop_overlay_set_title (self, g_value_get_string (value));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_COMPACT_PROPERTY:
		tuba_dialogs_composer_components_drop_overlay_set_compact (self, g_value_get_boolean (value));
		break;
		case TUBA_DIALOGS_COMPOSER_COMPONENTS_DROP_OVERLAY_ICON_NAME_PROPERTY:
		tuba_dialogs_composer_components_drop_overlay_set_icon_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

