/* Configuration.c generated by valac 0.56.19, the Vala compiler
 * generated from Configuration.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_MASTODON_TYPE_CONFIGURATIONS (tuba_api_mastodon_configurations_get_type ())
#define TUBA_API_MASTODON_CONFIGURATIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurations))
#define TUBA_API_MASTODON_CONFIGURATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurationsClass))
#define TUBA_API_MASTODON_IS_CONFIGURATIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS))
#define TUBA_API_MASTODON_IS_CONFIGURATIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_TYPE_CONFIGURATIONS))
#define TUBA_API_MASTODON_CONFIGURATIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurationsClass))

typedef struct _TubaAPIMastodonConfigurations TubaAPIMastodonConfigurations;
typedef struct _TubaAPIMastodonConfigurationsClass TubaAPIMastodonConfigurationsClass;
typedef struct _TubaAPIMastodonConfigurationsPrivate TubaAPIMastodonConfigurationsPrivate;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES (tuba_api_mastodon_configuration_statuses_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatuses))
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatusesClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES))
#define TUBA_API_MASTODON_CONFIGURATION_IS_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES))
#define TUBA_API_MASTODON_CONFIGURATION_STATUSES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, TubaAPIMastodonConfigurationStatusesClass))

typedef struct _TubaAPIMastodonConfigurationStatuses TubaAPIMastodonConfigurationStatuses;
typedef struct _TubaAPIMastodonConfigurationStatusesClass TubaAPIMastodonConfigurationStatusesClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS (tuba_api_mastodon_configuration_media_attachments_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachments))
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachmentsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_MEDIA_ATTACHMENTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_MEDIA_ATTACHMENTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS))
#define TUBA_API_MASTODON_CONFIGURATION_MEDIA_ATTACHMENTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, TubaAPIMastodonConfigurationMediaAttachmentsClass))

typedef struct _TubaAPIMastodonConfigurationMediaAttachments TubaAPIMastodonConfigurationMediaAttachments;
typedef struct _TubaAPIMastodonConfigurationMediaAttachmentsClass TubaAPIMastodonConfigurationMediaAttachmentsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS (tuba_api_mastodon_configuration_polls_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_POLLS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))

typedef struct _TubaAPIMastodonConfigurationPolls TubaAPIMastodonConfigurationPolls;
typedef struct _TubaAPIMastodonConfigurationPollsClass TubaAPIMastodonConfigurationPollsClass;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS (tuba_api_mastodon_configuration_reactions_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactions))
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactionsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_REACTIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_REACTIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS))
#define TUBA_API_MASTODON_CONFIGURATION_REACTIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, TubaAPIMastodonConfigurationReactionsClass))

typedef struct _TubaAPIMastodonConfigurationReactions TubaAPIMastodonConfigurationReactions;
typedef struct _TubaAPIMastodonConfigurationReactionsClass TubaAPIMastodonConfigurationReactionsClass;
enum  {
	TUBA_API_MASTODON_CONFIGURATIONS_0_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATIONS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIMastodonConfigurations {
	TubaEntity parent_instance;
	TubaAPIMastodonConfigurationsPrivate * priv;
};

struct _TubaAPIMastodonConfigurationsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIMastodonConfigurationsPrivate {
	TubaAPIMastodonConfigurationStatuses* _statuses;
	TubaAPIMastodonConfigurationMediaAttachments* _media_attachments;
	TubaAPIMastodonConfigurationPolls* _polls;
	TubaAPIMastodonConfigurationReactions* _reactions;
};

static gint TubaAPIMastodonConfigurations_private_offset;
static gpointer tuba_api_mastodon_configurations_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configurations_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurations, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_statuses_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationStatuses, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_media_attachments_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationMediaAttachments, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_polls_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationPolls, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_reactions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationReactions, g_object_unref)
VALA_EXTERN TubaAPIMastodonConfigurations* tuba_api_mastodon_configurations_new (void);
VALA_EXTERN TubaAPIMastodonConfigurations* tuba_api_mastodon_configurations_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN TubaAPIMastodonConfigurationStatuses* tuba_api_mastodon_configurations_get_statuses (TubaAPIMastodonConfigurations* self);
VALA_EXTERN void tuba_api_mastodon_configurations_set_statuses (TubaAPIMastodonConfigurations* self,
                                                    TubaAPIMastodonConfigurationStatuses* value);
VALA_EXTERN TubaAPIMastodonConfigurationMediaAttachments* tuba_api_mastodon_configurations_get_media_attachments (TubaAPIMastodonConfigurations* self);
VALA_EXTERN void tuba_api_mastodon_configurations_set_media_attachments (TubaAPIMastodonConfigurations* self,
                                                             TubaAPIMastodonConfigurationMediaAttachments* value);
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_mastodon_configurations_get_polls (TubaAPIMastodonConfigurations* self);
VALA_EXTERN void tuba_api_mastodon_configurations_set_polls (TubaAPIMastodonConfigurations* self,
                                                 TubaAPIMastodonConfigurationPolls* value);
VALA_EXTERN TubaAPIMastodonConfigurationReactions* tuba_api_mastodon_configurations_get_reactions (TubaAPIMastodonConfigurations* self);
VALA_EXTERN void tuba_api_mastodon_configurations_set_reactions (TubaAPIMastodonConfigurations* self,
                                                     TubaAPIMastodonConfigurationReactions* value);
static void tuba_api_mastodon_configurations_finalize (GObject * obj);
static GType tuba_api_mastodon_configurations_get_type_once (void);
static void _vala_tuba_api_mastodon_configurations_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_tuba_api_mastodon_configurations_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);

static inline gpointer
tuba_api_mastodon_configurations_get_instance_private (TubaAPIMastodonConfigurations* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIMastodonConfigurations_private_offset);
}

TubaAPIMastodonConfigurations*
tuba_api_mastodon_configurations_construct (GType object_type)
{
	TubaAPIMastodonConfigurations * self = NULL;
	self = (TubaAPIMastodonConfigurations*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIMastodonConfigurations*
tuba_api_mastodon_configurations_new (void)
{
	return tuba_api_mastodon_configurations_construct (TUBA_API_MASTODON_TYPE_CONFIGURATIONS);
}

TubaAPIMastodonConfigurationStatuses*
tuba_api_mastodon_configurations_get_statuses (TubaAPIMastodonConfigurations* self)
{
	TubaAPIMastodonConfigurationStatuses* result;
	TubaAPIMastodonConfigurationStatuses* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_statuses;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_api_mastodon_configurations_set_statuses (TubaAPIMastodonConfigurations* self,
                                               TubaAPIMastodonConfigurationStatuses* value)
{
	TubaAPIMastodonConfigurationStatuses* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configurations_get_statuses (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurationStatuses* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_statuses);
		self->priv->_statuses = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY]);
	}
}

TubaAPIMastodonConfigurationMediaAttachments*
tuba_api_mastodon_configurations_get_media_attachments (TubaAPIMastodonConfigurations* self)
{
	TubaAPIMastodonConfigurationMediaAttachments* result;
	TubaAPIMastodonConfigurationMediaAttachments* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_media_attachments;
	result = _tmp0_;
	return result;
}

void
tuba_api_mastodon_configurations_set_media_attachments (TubaAPIMastodonConfigurations* self,
                                                        TubaAPIMastodonConfigurationMediaAttachments* value)
{
	TubaAPIMastodonConfigurationMediaAttachments* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configurations_get_media_attachments (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurationMediaAttachments* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_media_attachments);
		self->priv->_media_attachments = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY]);
	}
}

TubaAPIMastodonConfigurationPolls*
tuba_api_mastodon_configurations_get_polls (TubaAPIMastodonConfigurations* self)
{
	TubaAPIMastodonConfigurationPolls* result;
	TubaAPIMastodonConfigurationPolls* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_polls;
	result = _tmp0_;
	return result;
}

void
tuba_api_mastodon_configurations_set_polls (TubaAPIMastodonConfigurations* self,
                                            TubaAPIMastodonConfigurationPolls* value)
{
	TubaAPIMastodonConfigurationPolls* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configurations_get_polls (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurationPolls* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_polls);
		self->priv->_polls = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY]);
	}
}

TubaAPIMastodonConfigurationReactions*
tuba_api_mastodon_configurations_get_reactions (TubaAPIMastodonConfigurations* self)
{
	TubaAPIMastodonConfigurationReactions* result;
	TubaAPIMastodonConfigurationReactions* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_reactions;
	result = _tmp0_;
	return result;
}

void
tuba_api_mastodon_configurations_set_reactions (TubaAPIMastodonConfigurations* self,
                                                TubaAPIMastodonConfigurationReactions* value)
{
	TubaAPIMastodonConfigurationReactions* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configurations_get_reactions (self);
	if (old_value != value) {
		TubaAPIMastodonConfigurationReactions* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_reactions);
		self->priv->_reactions = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY]);
	}
}

static void
tuba_api_mastodon_configurations_class_init (TubaAPIMastodonConfigurationsClass * klass,
                                             gpointer klass_data)
{
	tuba_api_mastodon_configurations_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIMastodonConfigurations_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_mastodon_configurations_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_mastodon_configurations_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_mastodon_configurations_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY] = g_param_spec_object ("statuses", "statuses", "statuses", TUBA_API_MASTODON_CONFIGURATION_TYPE_STATUSES, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY] = g_param_spec_object ("media-attachments", "media-attachments", "media-attachments", TUBA_API_MASTODON_CONFIGURATION_TYPE_MEDIA_ATTACHMENTS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY] = g_param_spec_object ("polls", "polls", "polls", TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY, tuba_api_mastodon_configurations_properties[TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY] = g_param_spec_object ("reactions", "reactions", "reactions", TUBA_API_MASTODON_CONFIGURATION_TYPE_REACTIONS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_mastodon_configurations_instance_init (TubaAPIMastodonConfigurations * self,
                                                gpointer klass)
{
	self->priv = tuba_api_mastodon_configurations_get_instance_private (self);
	self->priv->_reactions = NULL;
}

static void
tuba_api_mastodon_configurations_finalize (GObject * obj)
{
	TubaAPIMastodonConfigurations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurations);
	_g_object_unref0 (self->priv->_statuses);
	_g_object_unref0 (self->priv->_media_attachments);
	_g_object_unref0 (self->priv->_polls);
	_g_object_unref0 (self->priv->_reactions);
	G_OBJECT_CLASS (tuba_api_mastodon_configurations_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_mastodon_configurations_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIMastodonConfigurationsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_mastodon_configurations_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIMastodonConfigurations), 0, (GInstanceInitFunc) tuba_api_mastodon_configurations_instance_init, NULL };
	GType tuba_api_mastodon_configurations_type_id;
	tuba_api_mastodon_configurations_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIMastodonConfigurations", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIMastodonConfigurations_private_offset = g_type_add_instance_private (tuba_api_mastodon_configurations_type_id, sizeof (TubaAPIMastodonConfigurationsPrivate));
	return tuba_api_mastodon_configurations_type_id;
}

GType
tuba_api_mastodon_configurations_get_type (void)
{
	static GType tuba_api_mastodon_configurations_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_mastodon_configurations_type_id__once)) {
		GType tuba_api_mastodon_configurations_type_id;
		tuba_api_mastodon_configurations_type_id = tuba_api_mastodon_configurations_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_mastodon_configurations_type_id__once, tuba_api_mastodon_configurations_type_id);
	}
	return tuba_api_mastodon_configurations_type_id__once;
}

static void
_vala_tuba_api_mastodon_configurations_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	TubaAPIMastodonConfigurations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurations);
	switch (property_id) {
		case TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY:
		g_value_set_object (value, tuba_api_mastodon_configurations_get_statuses (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY:
		g_value_set_object (value, tuba_api_mastodon_configurations_get_media_attachments (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY:
		g_value_set_object (value, tuba_api_mastodon_configurations_get_polls (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY:
		g_value_set_object (value, tuba_api_mastodon_configurations_get_reactions (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_mastodon_configurations_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	TubaAPIMastodonConfigurations * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_MASTODON_TYPE_CONFIGURATIONS, TubaAPIMastodonConfigurations);
	switch (property_id) {
		case TUBA_API_MASTODON_CONFIGURATIONS_STATUSES_PROPERTY:
		tuba_api_mastodon_configurations_set_statuses (self, g_value_get_object (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_MEDIA_ATTACHMENTS_PROPERTY:
		tuba_api_mastodon_configurations_set_media_attachments (self, g_value_get_object (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_POLLS_PROPERTY:
		tuba_api_mastodon_configurations_set_polls (self, g_value_get_object (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATIONS_REACTIONS_PROPERTY:
		tuba_api_mastodon_configurations_set_reactions (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

