/* AssignedRow.c generated by valac 0.56.19, the Vala compiler
 * generated from AssignedRow.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <libsoup/soup.h>
#include <json-glib/json-glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW (tuba_widgets_admin_assigned_to_row_get_type ())
#define TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRow))
#define TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRowClass))
#define TUBA_WIDGETS_ADMIN_IS_ASSIGNED_TO_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW))
#define TUBA_WIDGETS_ADMIN_IS_ASSIGNED_TO_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW))
#define TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRowClass))

typedef struct _TubaWidgetsAdminAssignedToRow TubaWidgetsAdminAssignedToRow;
typedef struct _TubaWidgetsAdminAssignedToRowClass TubaWidgetsAdminAssignedToRowClass;
typedef struct _TubaWidgetsAdminAssignedToRowPrivate TubaWidgetsAdminAssignedToRowPrivate;
enum  {
	TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_0_PROPERTY,
	TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_admin_assigned_to_row_properties[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_ADMIN_TYPE_ACCOUNT (tuba_api_admin_account_get_type ())
#define TUBA_API_ADMIN_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccount))
#define TUBA_API_ADMIN_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))
#define TUBA_API_ADMIN_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_ACCOUNT))
#define TUBA_API_ADMIN_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_ACCOUNT, TubaAPIAdminAccountClass))

typedef struct _TubaAPIAdminAccount TubaAPIAdminAccount;
typedef struct _TubaAPIAdminAccountClass TubaAPIAdminAccountClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())

#define TUBA_TYPE_NETWORK (tuba_network_get_type ())
#define TUBA_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_NETWORK, TubaNetwork))
#define TUBA_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_NETWORK, TubaNetworkClass))
#define TUBA_IS_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_NETWORK))
#define TUBA_IS_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_NETWORK))
#define TUBA_NETWORK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_NETWORK, TubaNetworkClass))

typedef struct _TubaNetwork TubaNetwork;
typedef struct _TubaNetworkClass TubaNetworkClass;

#define TUBA_API_ADMIN_TYPE_REPORT (tuba_api_admin_report_get_type ())
#define TUBA_API_ADMIN_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReport))
#define TUBA_API_ADMIN_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))
#define TUBA_API_ADMIN_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_REPORT))
#define TUBA_API_ADMIN_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_REPORT, TubaAPIAdminReportClass))

typedef struct _TubaAPIAdminReport TubaAPIAdminReport;
typedef struct _TubaAPIAdminReportClass TubaAPIAdminReportClass;
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaWidgetsAdminAssignedToRowDoAssignRealData TubaWidgetsAdminAssignedToRowDoAssignRealData;
enum  {
	TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ASSIGNMENT_CHANGED_SIGNAL,
	TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ON_ERROR_SIGNAL,
	TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_NUM_SIGNALS
};
static guint tuba_widgets_admin_assigned_to_row_signals[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_NUM_SIGNALS] = {0};

struct _TubaWidgetsAdminAssignedToRow {
	AdwActionRow parent_instance;
	TubaWidgetsAdminAssignedToRowPrivate * priv;
};

struct _TubaWidgetsAdminAssignedToRowClass {
	AdwActionRowClass parent_class;
};

struct _TubaWidgetsAdminAssignedToRowPrivate {
	GtkButton* assign_button;
	gchar* report_id;
	gboolean _is_assigned;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaWidgetsAdminAssignedToRowDoAssignRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaWidgetsAdminAssignedToRow* self;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	gchar* endpoint;
	gchar* _tmp3_;
	GtkButton* _tmp4_;
	TubaRequestV2* req;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	TubaAccountStore* _tmp11_;
	TubaInstanceAccount* _tmp12_;
	TubaInstanceAccount* _tmp13_;
	TubaInstanceAccount* _tmp14_;
	TubaRequestV2* _tmp15_;
	TubaRequestV2* _tmp16_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp17_;
	GInputStream* _tmp18_;
	JsonParser* parser;
	GInputStream* _tmp19_;
	JsonParser* _tmp20_;
	JsonNode* node;
	TubaNetwork* _tmp21_;
	JsonParser* _tmp22_;
	JsonNode* _tmp23_;
	TubaAPIAdminReport* _tmp24_;
	JsonNode* _tmp25_;
	TubaAPIAdminReport* _tmp26_;
	TubaAPIAdminAccount* _tmp27_;
	TubaAPIAdminAccount* _tmp28_;
	GtkButton* _tmp29_;
	GError* e;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	GError* _tmp32_;
	const gchar* _tmp33_;
	const gchar* _tmp34_;
	GError* _tmp35_;
	gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	gchar* _tmp39_;
	GError* _tmp40_;
	const gchar* _tmp41_;
	const gchar* _tmp42_;
	GError* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar* _tmp47_;
	GtkButton* _tmp48_;
	GError* _inner_error0_;
};

static gint TubaWidgetsAdminAssignedToRow_private_offset;
static gpointer tuba_widgets_admin_assigned_to_row_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaNetwork* tuba_network;

VALA_EXTERN GType tuba_widgets_admin_assigned_to_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminAssignedToRow, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_admin_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminAccount, g_object_unref)
VALA_EXTERN TubaWidgetsAdminAssignedToRow* tuba_widgets_admin_assigned_to_row_new (const gchar* report_id,
                                                                       TubaAPIAdminAccount* assigned_account);
VALA_EXTERN TubaWidgetsAdminAssignedToRow* tuba_widgets_admin_assigned_to_row_construct (GType object_type,
                                                                             const gchar* report_id,
                                                                             TubaAPIAdminAccount* assigned_account);
static void tuba_widgets_admin_assigned_to_row_update_account (TubaWidgetsAdminAssignedToRow* self,
                                                        TubaAPIAdminAccount* assigned_account);
static void tuba_widgets_admin_assigned_to_row_set_is_assigned (TubaWidgetsAdminAssignedToRow* self,
                                                         gboolean value);
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN TubaAPIAccount* tuba_api_admin_account_get_account (TubaAPIAdminAccount* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
static void tuba_widgets_admin_assigned_to_row_do_assign (TubaWidgetsAdminAssignedToRow* self);
static void tuba_widgets_admin_assigned_to_row_do_assign_real (TubaWidgetsAdminAssignedToRow* self,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
static void tuba_widgets_admin_assigned_to_row_do_assign_real_finish (TubaWidgetsAdminAssignedToRow* self,
                                                               GAsyncResult* _res_);
static void tuba_widgets_admin_assigned_to_row_do_assign_real_data_free (gpointer _data);
static gboolean tuba_widgets_admin_assigned_to_row_do_assign_real_co (TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_);
static gboolean tuba_widgets_admin_assigned_to_row_get_is_assigned (TubaWidgetsAdminAssignedToRow* self);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_widgets_admin_assigned_to_row_do_assign_real_ready (GObject* source_object,
                                                              GAsyncResult* _res_,
                                                              gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN GType tuba_network_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaNetwork, g_object_unref)
VALA_EXTERN JsonNode* tuba_network_parse_node (TubaNetwork* self,
                                   JsonParser* parser);
VALA_EXTERN GType tuba_api_admin_report_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminReport, g_object_unref)
VALA_EXTERN TubaAPIAdminReport* tuba_api_admin_report_from (JsonNode* node,
                                                GError** error);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN TubaAPIAdminAccount* tuba_api_admin_report_get_assigned_account (TubaAPIAdminReport* self);
static GObject * tuba_widgets_admin_assigned_to_row_constructor (GType type,
                                                          guint n_construct_properties,
                                                          GObjectConstructParam * construct_properties);
static void _tuba_widgets_admin_assigned_to_row_do_assign_gtk_button_clicked (GtkButton* _sender,
                                                                       gpointer self);
static void tuba_widgets_admin_assigned_to_row_finalize (GObject * obj);
static GType tuba_widgets_admin_assigned_to_row_get_type_once (void);
static void _vala_tuba_widgets_admin_assigned_to_row_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec);
static void _vala_tuba_widgets_admin_assigned_to_row_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec);

static inline gpointer
tuba_widgets_admin_assigned_to_row_get_instance_private (TubaWidgetsAdminAssignedToRow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaWidgetsAdminAssignedToRow_private_offset);
}

TubaWidgetsAdminAssignedToRow*
tuba_widgets_admin_assigned_to_row_construct (GType object_type,
                                              const gchar* report_id,
                                              TubaAPIAdminAccount* assigned_account)
{
	TubaWidgetsAdminAssignedToRow * self = NULL;
	gchar* _tmp0_;
	g_return_val_if_fail (report_id != NULL, NULL);
	self = (TubaWidgetsAdminAssignedToRow*) g_object_new (object_type, NULL);
	_tmp0_ = g_strdup (report_id);
	_g_free0 (self->priv->report_id);
	self->priv->report_id = _tmp0_;
	tuba_widgets_admin_assigned_to_row_update_account (self, assigned_account);
	return self;
}

TubaWidgetsAdminAssignedToRow*
tuba_widgets_admin_assigned_to_row_new (const gchar* report_id,
                                        TubaAPIAdminAccount* assigned_account)
{
	return tuba_widgets_admin_assigned_to_row_construct (TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, report_id, assigned_account);
}

static void
tuba_widgets_admin_assigned_to_row_update_account (TubaWidgetsAdminAssignedToRow* self,
                                                   TubaAPIAdminAccount* assigned_account)
{
	const gchar* _tmp16_;
	const gchar* _tmp17_;
	g_return_if_fail (self != NULL);
	if (assigned_account == NULL) {
		GtkButton* _tmp0_;
		adw_action_row_set_subtitle ((AdwActionRow*) self, _ ("Nobody"));
		_tmp0_ = self->priv->assign_button;
		gtk_widget_set_visible ((GtkWidget*) _tmp0_, TRUE);
		tuba_widgets_admin_assigned_to_row_set_is_assigned (self, FALSE);
	} else {
		GtkButton* _tmp1_;
		TubaAPIAccount* _tmp2_;
		TubaAPIAccount* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		TubaAccountStore* _tmp6_;
		TubaInstanceAccount* _tmp7_;
		TubaInstanceAccount* _tmp8_;
		const gchar* _tmp9_;
		const gchar* _tmp10_;
		TubaAPIAccount* _tmp11_;
		TubaAPIAccount* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		_tmp1_ = self->priv->assign_button;
		_tmp2_ = tuba_api_admin_account_get_account (assigned_account);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_account_get_id (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = tuba_accounts;
		_tmp7_ = tuba_account_store_get_active (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp8_);
		_tmp10_ = _tmp9_;
		gtk_widget_set_visible ((GtkWidget*) _tmp1_, g_strcmp0 (_tmp5_, _tmp10_) == 0);
		_tmp11_ = tuba_api_admin_account_get_account (assigned_account);
		_tmp12_ = _tmp11_;
		_tmp13_ = tuba_api_account_get_full_handle (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = _tmp14_;
		adw_action_row_set_subtitle ((AdwActionRow*) self, _tmp15_);
		_g_free0 (_tmp15_);
		tuba_widgets_admin_assigned_to_row_set_is_assigned (self, TRUE);
	}
	_tmp16_ = adw_action_row_get_subtitle ((AdwActionRow*) self);
	_tmp17_ = _tmp16_;
	g_signal_emit (self, tuba_widgets_admin_assigned_to_row_signals[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ASSIGNMENT_CHANGED_SIGNAL], 0, _tmp17_);
}

static void
tuba_widgets_admin_assigned_to_row_do_assign (TubaWidgetsAdminAssignedToRow* self)
{
	g_return_if_fail (self != NULL);
	tuba_widgets_admin_assigned_to_row_do_assign_real (self, NULL, NULL);
}

static void
tuba_widgets_admin_assigned_to_row_do_assign_real_data_free (gpointer _data)
{
	TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaWidgetsAdminAssignedToRowDoAssignRealData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
tuba_widgets_admin_assigned_to_row_do_assign_real (TubaWidgetsAdminAssignedToRow* self,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_)
{
	TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_;
	TubaWidgetsAdminAssignedToRow* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaWidgetsAdminAssignedToRowDoAssignRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_widgets_admin_assigned_to_row_do_assign_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_widgets_admin_assigned_to_row_do_assign_real_co (_data_);
}

static void
tuba_widgets_admin_assigned_to_row_do_assign_real_finish (TubaWidgetsAdminAssignedToRow* self,
                                                          GAsyncResult* _res_)
{
	TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
tuba_widgets_admin_assigned_to_row_do_assign_real_ready (GObject* source_object,
                                                         GAsyncResult* _res_,
                                                         gpointer _user_data_)
{
	TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_widgets_admin_assigned_to_row_do_assign_real_co (_data_);
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

static gboolean
tuba_widgets_admin_assigned_to_row_do_assign_real_co (TubaWidgetsAdminAssignedToRowDoAssignRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp1_ = tuba_widgets_admin_assigned_to_row_get_is_assigned (_data_->self);
	_data_->_tmp2_ = _data_->_tmp1_;
	if (_data_->_tmp2_) {
		_data_->_tmp0_ = "unassign";
	} else {
		_data_->_tmp0_ = "assign_to_self";
	}
	_data_->_tmp3_ = g_strdup (_data_->_tmp0_);
	_data_->endpoint = _data_->_tmp3_;
	_data_->_tmp4_ = _data_->self->priv->assign_button;
	gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp4_, FALSE);
	_data_->_tmp5_ = _data_->self->priv->report_id;
	_data_->_tmp6_ = string_to_string (_data_->_tmp5_);
	_data_->_tmp7_ = _data_->endpoint;
	_data_->_tmp8_ = string_to_string (_data_->_tmp7_);
	_data_->_tmp9_ = g_strconcat ("/api/v1/admin/reports/", _data_->_tmp6_, "/", _data_->_tmp8_, NULL);
	_data_->_tmp10_ = _data_->_tmp9_;
	_data_->_tmp11_ = tuba_accounts;
	_data_->_tmp12_ = tuba_account_store_get_active (_data_->_tmp11_);
	_data_->_tmp13_ = _data_->_tmp12_;
	_data_->_tmp14_ = _g_object_ref0 (_data_->_tmp13_);
	_data_->_tmp15_ = NULL;
	_data_->_tmp15_ = tuba_request_v2_new (_data_->_tmp10_, TUBA_REQUEST_V2_METHOD_POST);
	tuba_request_v2_set_account (_data_->_tmp15_, _data_->_tmp14_);
	_g_object_unref0 (_data_->_tmp14_);
	_data_->_tmp16_ = _data_->_tmp15_;
	_g_free0 (_data_->_tmp10_);
	_data_->req = _data_->_tmp16_;
	{
		_data_->_tmp17_ = _data_->req;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp17_, tuba_widgets_admin_assigned_to_row_do_assign_real_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp18_ = tuba_request_v2_exec_finish (_data_->_tmp17_, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->in_stream = _data_->_tmp18_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp19_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp19_, NULL, tuba_widgets_admin_assigned_to_row_do_assign_real_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp20_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp20_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->in_stream);
			goto __catch0_g_error;
		}
		_data_->_tmp21_ = tuba_network;
		_data_->_tmp22_ = _data_->parser;
		_data_->_tmp23_ = tuba_network_parse_node (_data_->_tmp21_, _data_->_tmp22_);
		_data_->node = _data_->_tmp23_;
		_data_->_tmp25_ = _data_->node;
		_data_->_tmp26_ = tuba_api_admin_report_from (_data_->_tmp25_, &_data_->_inner_error0_);
		_data_->_tmp24_ = _data_->_tmp26_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			__vala_JsonNode_free0 (_data_->node);
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			goto __catch0_g_error;
		}
		_data_->_tmp27_ = tuba_api_admin_report_get_assigned_account (_data_->_tmp24_);
		_data_->_tmp28_ = _data_->_tmp27_;
		tuba_widgets_admin_assigned_to_row_update_account (_data_->self, _data_->_tmp28_);
		_data_->_tmp29_ = _data_->self->priv->assign_button;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp29_, TRUE);
		_g_object_unref0 (_data_->_tmp24_);
		__vala_JsonNode_free0 (_data_->node);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp30_ = _data_->self->priv->report_id;
		_data_->_tmp31_ = string_to_string (_data_->_tmp30_);
		_data_->_tmp32_ = _data_->e;
		_data_->_tmp33_ = _data_->_tmp32_->message;
		_data_->_tmp34_ = string_to_string (_data_->_tmp33_);
		_data_->_tmp35_ = _data_->e;
		_data_->_tmp36_ = g_strdup_printf ("%i", _data_->_tmp35_->code);
		_data_->_tmp37_ = _data_->_tmp36_;
		_data_->_tmp38_ = g_strconcat ("Error trying to re-assign ", _data_->_tmp31_, ": ", _data_->_tmp34_, " ", _data_->_tmp37_, NULL);
		_data_->_tmp39_ = _data_->_tmp38_;
		g_warning ("AssignedRow.vala:77: %s", _data_->_tmp39_);
		_g_free0 (_data_->_tmp39_);
		_g_free0 (_data_->_tmp37_);
		_data_->_tmp40_ = _data_->e;
		_data_->_tmp41_ = _data_->_tmp40_->message;
		_data_->_tmp42_ = string_to_string (_data_->_tmp41_);
		_data_->_tmp43_ = _data_->e;
		_data_->_tmp44_ = g_strdup_printf ("%i", _data_->_tmp43_->code);
		_data_->_tmp45_ = _data_->_tmp44_;
		_data_->_tmp46_ = g_strconcat (_data_->_tmp42_, " ", _data_->_tmp45_, NULL);
		_data_->_tmp47_ = _data_->_tmp46_;
		g_signal_emit (_data_->self, tuba_widgets_admin_assigned_to_row_signals[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ON_ERROR_SIGNAL], 0, _data_->_tmp47_);
		_g_free0 (_data_->_tmp47_);
		_g_free0 (_data_->_tmp45_);
		_data_->_tmp48_ = _data_->self->priv->assign_button;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp48_, TRUE);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		_g_free0 (_data_->endpoint);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_g_object_unref0 (_data_->req);
	_g_free0 (_data_->endpoint);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gboolean
tuba_widgets_admin_assigned_to_row_get_is_assigned (TubaWidgetsAdminAssignedToRow* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_is_assigned;
	return result;
}

static void
tuba_widgets_admin_assigned_to_row_set_is_assigned (TubaWidgetsAdminAssignedToRow* self,
                                                    gboolean value)
{
	g_return_if_fail (self != NULL);
	self->priv->_is_assigned = value;
	if (value) {
		GtkButton* _tmp0_;
		GtkButton* _tmp1_;
		GtkButton* _tmp2_;
		_tmp0_ = self->priv->assign_button;
		gtk_widget_add_css_class ((GtkWidget*) _tmp0_, "destructive-action");
		_tmp1_ = self->priv->assign_button;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp1_, "suggested-action");
		_tmp2_ = self->priv->assign_button;
		gtk_button_set_label (_tmp2_, _ ("Unassign"));
	} else {
		GtkButton* _tmp3_;
		GtkButton* _tmp4_;
		GtkButton* _tmp5_;
		_tmp3_ = self->priv->assign_button;
		gtk_widget_add_css_class ((GtkWidget*) _tmp3_, "suggested-action");
		_tmp4_ = self->priv->assign_button;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp4_, "destructive-action");
		_tmp5_ = self->priv->assign_button;
		gtk_button_set_label (_tmp5_, _ ("Assign"));
	}
}

static void
_tuba_widgets_admin_assigned_to_row_do_assign_gtk_button_clicked (GtkButton* _sender,
                                                                  gpointer self)
{
	tuba_widgets_admin_assigned_to_row_do_assign ((TubaWidgetsAdminAssignedToRow*) self);
}

static GObject *
tuba_widgets_admin_assigned_to_row_constructor (GType type,
                                                guint n_construct_properties,
                                                GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaWidgetsAdminAssignedToRow * self;
	GtkButton* _tmp0_ = NULL;
	GtkButton* _tmp1_;
	GtkButton* _tmp2_;
	parent_class = G_OBJECT_CLASS (tuba_widgets_admin_assigned_to_row_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRow);
	adw_preferences_row_set_title ((AdwPreferencesRow*) self, _ ("Assigned to"));
	adw_action_row_set_subtitle_selectable ((AdwActionRow*) self, TRUE);
	_tmp0_ = (GtkButton*) gtk_button_new ();
	gtk_widget_set_valign ((GtkWidget*) _tmp0_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp0_);
	_g_object_unref0 (self->priv->assign_button);
	self->priv->assign_button = _tmp0_;
	_tmp1_ = self->priv->assign_button;
	g_signal_connect_object (_tmp1_, "clicked", (GCallback) _tuba_widgets_admin_assigned_to_row_do_assign_gtk_button_clicked, self, 0);
	_tmp2_ = self->priv->assign_button;
	adw_action_row_add_suffix ((AdwActionRow*) self, (GtkWidget*) _tmp2_);
	return obj;
}

static void
tuba_widgets_admin_assigned_to_row_class_init (TubaWidgetsAdminAssignedToRowClass * klass,
                                               gpointer klass_data)
{
	tuba_widgets_admin_assigned_to_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaWidgetsAdminAssignedToRow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_widgets_admin_assigned_to_row_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_widgets_admin_assigned_to_row_set_property;
	G_OBJECT_CLASS (klass)->constructor = tuba_widgets_admin_assigned_to_row_constructor;
	G_OBJECT_CLASS (klass)->finalize = tuba_widgets_admin_assigned_to_row_finalize;
	tuba_widgets_admin_assigned_to_row_signals[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ASSIGNMENT_CHANGED_SIGNAL] = g_signal_new ("assignment-changed", TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
	tuba_widgets_admin_assigned_to_row_signals[TUBA_WIDGETS_ADMIN_ASSIGNED_TO_ROW_ON_ERROR_SIGNAL] = g_signal_new ("on-error", TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
}

static void
tuba_widgets_admin_assigned_to_row_instance_init (TubaWidgetsAdminAssignedToRow * self,
                                                  gpointer klass)
{
	self->priv = tuba_widgets_admin_assigned_to_row_get_instance_private (self);
	self->priv->_is_assigned = FALSE;
}

static void
tuba_widgets_admin_assigned_to_row_finalize (GObject * obj)
{
	TubaWidgetsAdminAssignedToRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRow);
	g_debug ("AssignedRow.vala:6: Destroying AssignedToRow");
	_g_object_unref0 (self->priv->assign_button);
	_g_free0 (self->priv->report_id);
	G_OBJECT_CLASS (tuba_widgets_admin_assigned_to_row_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_admin_assigned_to_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsAdminAssignedToRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_admin_assigned_to_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsAdminAssignedToRow), 0, (GInstanceInitFunc) tuba_widgets_admin_assigned_to_row_instance_init, NULL };
	GType tuba_widgets_admin_assigned_to_row_type_id;
	tuba_widgets_admin_assigned_to_row_type_id = g_type_register_static (adw_action_row_get_type (), "TubaWidgetsAdminAssignedToRow", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaWidgetsAdminAssignedToRow_private_offset = g_type_add_instance_private (tuba_widgets_admin_assigned_to_row_type_id, sizeof (TubaWidgetsAdminAssignedToRowPrivate));
	return tuba_widgets_admin_assigned_to_row_type_id;
}

GType
tuba_widgets_admin_assigned_to_row_get_type (void)
{
	static GType tuba_widgets_admin_assigned_to_row_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_admin_assigned_to_row_type_id__once)) {
		GType tuba_widgets_admin_assigned_to_row_type_id;
		tuba_widgets_admin_assigned_to_row_type_id = tuba_widgets_admin_assigned_to_row_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_admin_assigned_to_row_type_id__once, tuba_widgets_admin_assigned_to_row_type_id);
	}
	return tuba_widgets_admin_assigned_to_row_type_id__once;
}

static void
_vala_tuba_widgets_admin_assigned_to_row_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec)
{
	TubaWidgetsAdminAssignedToRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRow);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_widgets_admin_assigned_to_row_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec)
{
	TubaWidgetsAdminAssignedToRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_WIDGETS_ADMIN_TYPE_ASSIGNED_TO_ROW, TubaWidgetsAdminAssignedToRow);
	switch (property_id) {
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

