/* BookWyrm.c generated by valac 0.56.19, the Vala compiler
 * generated from BookWyrm.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_BOOK_WYRM (tuba_api_book_wyrm_get_type ())
#define TUBA_API_BOOK_WYRM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrm))
#define TUBA_API_BOOK_WYRM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrmClass))
#define TUBA_API_IS_BOOK_WYRM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_BOOK_WYRM))
#define TUBA_API_IS_BOOK_WYRM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_BOOK_WYRM))
#define TUBA_API_BOOK_WYRM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrmClass))

typedef struct _TubaAPIBookWyrm TubaAPIBookWyrm;
typedef struct _TubaAPIBookWyrmClass TubaAPIBookWyrmClass;
typedef struct _TubaAPIBookWyrmPrivate TubaAPIBookWyrmPrivate;

#define TUBA_API_TYPE_BOOK_WYRM_COVER (tuba_api_book_wyrm_cover_get_type ())
#define TUBA_API_BOOK_WYRM_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_BOOK_WYRM_COVER, TubaAPIBookWyrmCover))
#define TUBA_API_BOOK_WYRM_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_BOOK_WYRM_COVER, TubaAPIBookWyrmCoverClass))
#define TUBA_API_IS_BOOK_WYRM_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_BOOK_WYRM_COVER))
#define TUBA_API_IS_BOOK_WYRM_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_BOOK_WYRM_COVER))
#define TUBA_API_BOOK_WYRM_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_BOOK_WYRM_COVER, TubaAPIBookWyrmCoverClass))

typedef struct _TubaAPIBookWyrmCover TubaAPIBookWyrmCover;
typedef struct _TubaAPIBookWyrmCoverClass TubaAPIBookWyrmCoverClass;
enum  {
	TUBA_API_BOOK_WYRM_0_PROPERTY,
	TUBA_API_BOOK_WYRM_ID_PROPERTY,
	TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY,
	TUBA_API_BOOK_WYRM_TITLE_PROPERTY,
	TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY,
	TUBA_API_BOOK_WYRM_ISBN13_PROPERTY,
	TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY,
	TUBA_API_BOOK_WYRM_COVER_PROPERTY,
	TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY,
	TUBA_API_BOOK_WYRM_NUM_PROPERTIES
};
static GParamSpec* tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE (tuba_widgets_book_wyrm_page_get_type ())
#define TUBA_WIDGETS_BOOK_WYRM_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE, TubaWidgetsBookWyrmPage))
#define TUBA_WIDGETS_BOOK_WYRM_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE, TubaWidgetsBookWyrmPageClass))
#define TUBA_WIDGETS_IS_BOOK_WYRM_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE))
#define TUBA_WIDGETS_IS_BOOK_WYRM_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE))
#define TUBA_WIDGETS_BOOK_WYRM_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_BOOK_WYRM_PAGE, TubaWidgetsBookWyrmPageClass))

typedef struct _TubaWidgetsBookWyrmPage TubaWidgetsBookWyrmPage;
typedef struct _TubaWidgetsBookWyrmPageClass TubaWidgetsBookWyrmPageClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIBookWyrm {
	TubaEntity parent_instance;
	TubaAPIBookWyrmPrivate * priv;
};

struct _TubaAPIBookWyrmClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIBookWyrmPrivate {
	gchar* _id;
	gchar* _openlibraryKey;
	gchar* _title;
	gchar* _description;
	gchar* _isbn13;
	gchar* _publishedDate;
	TubaAPIBookWyrmCover* _cover;
	GeeArrayList* _authors;
};

static gint TubaAPIBookWyrm_private_offset;
static gpointer tuba_api_book_wyrm_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_book_wyrm_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_book_wyrm_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIBookWyrm, g_object_unref)
VALA_EXTERN GType tuba_api_book_wyrm_cover_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIBookWyrmCover, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_book_wyrm_real_deserialize_array_type (TubaEntity* base,
                                                      const gchar* prop);
VALA_EXTERN TubaAPIBookWyrm* tuba_api_book_wyrm_from (JsonNode* node,
                                          GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
static GtkWidget* tuba_api_book_wyrm_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaWidgetsBookWyrmPage* tuba_widgets_book_wyrm_page_new (TubaAPIBookWyrm* t_obj);
VALA_EXTERN TubaWidgetsBookWyrmPage* tuba_widgets_book_wyrm_page_construct (GType object_type,
                                                                TubaAPIBookWyrm* t_obj);
VALA_EXTERN GType tuba_widgets_book_wyrm_page_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsBookWyrmPage, g_object_unref)
static void tuba_api_book_wyrm_real_open (TubaWidgetizable* base);
VALA_EXTERN TubaAPIBookWyrm* tuba_api_book_wyrm_new (void);
VALA_EXTERN TubaAPIBookWyrm* tuba_api_book_wyrm_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_id (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_id (TubaAPIBookWyrm* self,
                                const gchar* value);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_openlibraryKey (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_openlibraryKey (TubaAPIBookWyrm* self,
                                            const gchar* value);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_title (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_title (TubaAPIBookWyrm* self,
                                   const gchar* value);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_description (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_description (TubaAPIBookWyrm* self,
                                         const gchar* value);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_isbn13 (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_isbn13 (TubaAPIBookWyrm* self,
                                    const gchar* value);
VALA_EXTERN const gchar* tuba_api_book_wyrm_get_publishedDate (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_publishedDate (TubaAPIBookWyrm* self,
                                           const gchar* value);
VALA_EXTERN TubaAPIBookWyrmCover* tuba_api_book_wyrm_get_cover (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_cover (TubaAPIBookWyrm* self,
                                   TubaAPIBookWyrmCover* value);
VALA_EXTERN GeeArrayList* tuba_api_book_wyrm_get_authors (TubaAPIBookWyrm* self);
VALA_EXTERN void tuba_api_book_wyrm_set_authors (TubaAPIBookWyrm* self,
                                     GeeArrayList* value);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
static void tuba_api_book_wyrm_finalize (GObject * obj);
static GType tuba_api_book_wyrm_get_type_once (void);
static void _vala_tuba_api_book_wyrm_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec);
static void _vala_tuba_api_book_wyrm_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec);

static inline gpointer
tuba_api_book_wyrm_get_instance_private (TubaAPIBookWyrm* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIBookWyrm_private_offset);
}

static GType
tuba_api_book_wyrm_real_deserialize_array_type (TubaEntity* base,
                                                const gchar* prop)
{
	TubaAPIBookWyrm * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIBookWyrm*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("authors")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_book_wyrm_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIBookWyrm*
tuba_api_book_wyrm_from (JsonNode* node,
                         GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIBookWyrm* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIBookWyrm* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_BOOK_WYRM, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_BOOK_WYRM (_tmp0_) ? ((TubaAPIBookWyrm*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static GtkWidget*
tuba_api_book_wyrm_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIBookWyrm * self;
	TubaWidgetsBookWyrmPage* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIBookWyrm*) base;
	_tmp0_ = tuba_widgets_book_wyrm_page_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

static void
tuba_api_book_wyrm_real_open (TubaWidgetizable* base)
{
	TubaAPIBookWyrm * self;
	self = (TubaAPIBookWyrm*) base;
}

TubaAPIBookWyrm*
tuba_api_book_wyrm_construct (GType object_type)
{
	TubaAPIBookWyrm * self = NULL;
	self = (TubaAPIBookWyrm*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIBookWyrm*
tuba_api_book_wyrm_new (void)
{
	return tuba_api_book_wyrm_construct (TUBA_API_TYPE_BOOK_WYRM);
}

const gchar*
tuba_api_book_wyrm_get_id (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_id (TubaAPIBookWyrm* self,
                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_book_wyrm_get_openlibraryKey (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_openlibraryKey;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_openlibraryKey (TubaAPIBookWyrm* self,
                                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_openlibraryKey (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_openlibraryKey);
		self->priv->_openlibraryKey = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY]);
	}
}

const gchar*
tuba_api_book_wyrm_get_title (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_title;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_title (TubaAPIBookWyrm* self,
                              const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_title (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_title);
		self->priv->_title = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_TITLE_PROPERTY]);
	}
}

const gchar*
tuba_api_book_wyrm_get_description (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_description;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_description (TubaAPIBookWyrm* self,
                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_description (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_description);
		self->priv->_description = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY]);
	}
}

const gchar*
tuba_api_book_wyrm_get_isbn13 (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_isbn13;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_isbn13 (TubaAPIBookWyrm* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_isbn13 (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_isbn13);
		self->priv->_isbn13 = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_ISBN13_PROPERTY]);
	}
}

const gchar*
tuba_api_book_wyrm_get_publishedDate (TubaAPIBookWyrm* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_publishedDate;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_publishedDate (TubaAPIBookWyrm* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_publishedDate (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_publishedDate);
		self->priv->_publishedDate = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY]);
	}
}

TubaAPIBookWyrmCover*
tuba_api_book_wyrm_get_cover (TubaAPIBookWyrm* self)
{
	TubaAPIBookWyrmCover* result;
	TubaAPIBookWyrmCover* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_cover;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_cover (TubaAPIBookWyrm* self,
                              TubaAPIBookWyrmCover* value)
{
	TubaAPIBookWyrmCover* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_cover (self);
	if (old_value != value) {
		TubaAPIBookWyrmCover* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_cover);
		self->priv->_cover = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_COVER_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_book_wyrm_get_authors (TubaAPIBookWyrm* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_authors;
	result = _tmp0_;
	return result;
}

void
tuba_api_book_wyrm_set_authors (TubaAPIBookWyrm* self,
                                GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_book_wyrm_get_authors (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_authors);
		self->priv->_authors = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY]);
	}
}

static void
tuba_api_book_wyrm_class_init (TubaAPIBookWyrmClass * klass,
                               gpointer klass_data)
{
	tuba_api_book_wyrm_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIBookWyrm_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_book_wyrm_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_book_wyrm_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_book_wyrm_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_book_wyrm_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_ID_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY] = g_param_spec_string ("openlibraryKey", "openlibraryKey", "openlibraryKey", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_TITLE_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_TITLE_PROPERTY] = g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_ISBN13_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_ISBN13_PROPERTY] = g_param_spec_string ("isbn13", "isbn13", "isbn13", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY] = g_param_spec_string ("publishedDate", "publishedDate", "publishedDate", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_COVER_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_COVER_PROPERTY] = g_param_spec_object ("cover", "cover", "cover", TUBA_API_TYPE_BOOK_WYRM_COVER, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY, tuba_api_book_wyrm_properties[TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY] = g_param_spec_object ("authors", "authors", "authors", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_book_wyrm_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                     gpointer iface_data)
{
	tuba_api_book_wyrm_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_book_wyrm_real_to_widget;
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_book_wyrm_real_open;
}

static void
tuba_api_book_wyrm_instance_init (TubaAPIBookWyrm * self,
                                  gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	self->priv = tuba_api_book_wyrm_get_instance_private (self);
	_tmp0_ = g_strdup ("");
	self->priv->_id = _tmp0_;
	_tmp1_ = g_strdup ("");
	self->priv->_openlibraryKey = _tmp1_;
	_tmp2_ = g_strdup ("");
	self->priv->_title = _tmp2_;
	_tmp3_ = g_strdup ("");
	self->priv->_description = _tmp3_;
	_tmp4_ = g_strdup ("");
	self->priv->_isbn13 = _tmp4_;
	_tmp5_ = g_strdup ("");
	self->priv->_publishedDate = _tmp5_;
	self->priv->_cover = NULL;
	self->priv->_authors = NULL;
}

static void
tuba_api_book_wyrm_finalize (GObject * obj)
{
	TubaAPIBookWyrm * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrm);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_openlibraryKey);
	_g_free0 (self->priv->_title);
	_g_free0 (self->priv->_description);
	_g_free0 (self->priv->_isbn13);
	_g_free0 (self->priv->_publishedDate);
	_g_object_unref0 (self->priv->_cover);
	_g_object_unref0 (self->priv->_authors);
	G_OBJECT_CLASS (tuba_api_book_wyrm_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_book_wyrm_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIBookWyrmClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_book_wyrm_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIBookWyrm), 0, (GInstanceInitFunc) tuba_api_book_wyrm_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_book_wyrm_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_book_wyrm_type_id;
	tuba_api_book_wyrm_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIBookWyrm", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_book_wyrm_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIBookWyrm_private_offset = g_type_add_instance_private (tuba_api_book_wyrm_type_id, sizeof (TubaAPIBookWyrmPrivate));
	return tuba_api_book_wyrm_type_id;
}

GType
tuba_api_book_wyrm_get_type (void)
{
	static GType tuba_api_book_wyrm_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_book_wyrm_type_id__once)) {
		GType tuba_api_book_wyrm_type_id;
		tuba_api_book_wyrm_type_id = tuba_api_book_wyrm_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_book_wyrm_type_id__once, tuba_api_book_wyrm_type_id);
	}
	return tuba_api_book_wyrm_type_id__once;
}

static void
_vala_tuba_api_book_wyrm_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec)
{
	TubaAPIBookWyrm * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrm);
	switch (property_id) {
		case TUBA_API_BOOK_WYRM_ID_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_id (self));
		break;
		case TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_openlibraryKey (self));
		break;
		case TUBA_API_BOOK_WYRM_TITLE_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_title (self));
		break;
		case TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_description (self));
		break;
		case TUBA_API_BOOK_WYRM_ISBN13_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_isbn13 (self));
		break;
		case TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY:
		g_value_set_string (value, tuba_api_book_wyrm_get_publishedDate (self));
		break;
		case TUBA_API_BOOK_WYRM_COVER_PROPERTY:
		g_value_set_object (value, tuba_api_book_wyrm_get_cover (self));
		break;
		case TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY:
		g_value_set_object (value, tuba_api_book_wyrm_get_authors (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_book_wyrm_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec)
{
	TubaAPIBookWyrm * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_BOOK_WYRM, TubaAPIBookWyrm);
	switch (property_id) {
		case TUBA_API_BOOK_WYRM_ID_PROPERTY:
		tuba_api_book_wyrm_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_OPENLIBRARY_KEY_PROPERTY:
		tuba_api_book_wyrm_set_openlibraryKey (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_TITLE_PROPERTY:
		tuba_api_book_wyrm_set_title (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_DESCRIPTION_PROPERTY:
		tuba_api_book_wyrm_set_description (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_ISBN13_PROPERTY:
		tuba_api_book_wyrm_set_isbn13 (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_PUBLISHED_DATE_PROPERTY:
		tuba_api_book_wyrm_set_publishedDate (self, g_value_get_string (value));
		break;
		case TUBA_API_BOOK_WYRM_COVER_PROPERTY:
		tuba_api_book_wyrm_set_cover (self, g_value_get_object (value));
		break;
		case TUBA_API_BOOK_WYRM_AUTHORS_PROPERTY:
		tuba_api_book_wyrm_set_authors (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

