/* Tag.c generated by valac 0.56.19, the Vala compiler
 * generated from Tag.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <glib/gi18n-lib.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_TAG (tuba_api_tag_get_type ())
#define TUBA_API_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_TAG, TubaAPITag))
#define TUBA_API_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_TAG, TubaAPITagClass))
#define TUBA_API_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_TAG))
#define TUBA_API_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_TAG))
#define TUBA_API_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_TAG, TubaAPITagClass))

typedef struct _TubaAPITag TubaAPITag;
typedef struct _TubaAPITagClass TubaAPITagClass;
typedef struct _TubaAPITagPrivate TubaAPITagPrivate;

#define TUBA_API_TYPE_TAG_HISTORY (tuba_api_tag_history_get_type ())
#define TUBA_API_TAG_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_TAG_HISTORY, TubaAPITagHistory))
#define TUBA_API_TAG_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_TAG_HISTORY, TubaAPITagHistoryClass))
#define TUBA_API_IS_TAG_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_TAG_HISTORY))
#define TUBA_API_IS_TAG_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_TAG_HISTORY))
#define TUBA_API_TAG_HISTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_TAG_HISTORY, TubaAPITagHistoryClass))

typedef struct _TubaAPITagHistory TubaAPITagHistory;
typedef struct _TubaAPITagHistoryClass TubaAPITagHistoryClass;
enum  {
	TUBA_API_TAG_0_PROPERTY,
	TUBA_API_TAG_NAME_PROPERTY,
	TUBA_API_TAG_URL_PROPERTY,
	TUBA_API_TAG_HISTORY_PROPERTY,
	TUBA_API_TAG_FOLLOWING_PROPERTY,
	TUBA_API_TAG_FEATURING_PROPERTY,
	TUBA_API_TAG_NUM_PROPERTIES
};
static GParamSpec* tuba_api_tag_properties[TUBA_API_TAG_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_WIDGETS_TYPE_TAG (tuba_widgets_tag_get_type ())
#define TUBA_WIDGETS_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_TAG, TubaWidgetsTag))
#define TUBA_WIDGETS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_TAG, TubaWidgetsTagClass))
#define TUBA_WIDGETS_IS_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_TAG))
#define TUBA_WIDGETS_IS_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_TAG))
#define TUBA_WIDGETS_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_TAG, TubaWidgetsTagClass))

typedef struct _TubaWidgetsTag TubaWidgetsTag;
typedef struct _TubaWidgetsTagClass TubaWidgetsTagClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;

#define TUBA_VIEWS_TYPE_HASHTAG (tuba_views_hashtag_get_type ())
#define TUBA_VIEWS_HASHTAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtag))
#define TUBA_VIEWS_HASHTAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtagClass))
#define TUBA_VIEWS_IS_HASHTAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_HASHTAG))
#define TUBA_VIEWS_IS_HASHTAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_HASHTAG))
#define TUBA_VIEWS_HASHTAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_HASHTAG, TubaViewsHashtagClass))

typedef struct _TubaViewsHashtag TubaViewsHashtag;
typedef struct _TubaViewsHashtagClass TubaViewsHashtagClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPITag {
	TubaEntity parent_instance;
	TubaAPITagPrivate * priv;
};

struct _TubaAPITagClass {
	TubaEntityClass parent_class;
	void (*on_activated) (TubaAPITag* self);
};

struct _TubaAPITagPrivate {
	gchar* _name;
	gchar* _url;
	GeeArrayList* _history;
	gboolean _following;
	gboolean _featuring;
};

static gint TubaAPITag_private_offset;
static gpointer tuba_api_tag_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaApplication* tuba_app;
static TubaWidgetizableIface * tuba_api_tag_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPITag, g_object_unref)
VALA_EXTERN GType tuba_api_tag_history_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPITagHistory, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
VALA_EXTERN void tuba_api_tag_on_activated (TubaAPITag* self);
static GType tuba_api_tag_real_deserialize_array_type (TubaEntity* base,
                                                const gchar* prop);
VALA_EXTERN TubaAPITag* tuba_api_tag_from (JsonNode* node,
                               GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN TubaRequestV2* tuba_api_tag_search (const gchar* query,
                                    GError** error);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_add_parameter (TubaRequestV2* self,
                                    const gchar* key,
                                    const gchar* value);
static void tuba_api_tag_real_open (TubaWidgetizable* base);
VALA_EXTERN gchar* tuba_api_tag_weekly_use (TubaAPITag* self);
VALA_EXTERN GeeArrayList* tuba_api_tag_get_history (TubaAPITag* self);
VALA_EXTERN const gchar* tuba_api_tag_history_get_uses (TubaAPITagHistory* self);
static GtkWidget* tuba_api_tag_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN GType tuba_widgets_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsTag, g_object_unref)
VALA_EXTERN TubaWidgetsTag* tuba_widgets_tag_new (TubaAPITag* tag);
VALA_EXTERN TubaWidgetsTag* tuba_widgets_tag_construct (GType object_type,
                                            TubaAPITag* tag);
static void _tuba_api_tag_on_activated_adw_action_row_activated (AdwActionRow* _sender,
                                                          gpointer self);
static void tuba_api_tag_real_on_activated (TubaAPITag* self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN const gchar* tuba_api_tag_get_name (TubaAPITag* self);
VALA_EXTERN gboolean tuba_api_tag_get_following (TubaAPITag* self);
VALA_EXTERN const gchar* tuba_api_tag_get_url (TubaAPITag* self);
VALA_EXTERN gboolean tuba_api_tag_get_featuring (TubaAPITag* self);
VALA_EXTERN TubaViewsHashtag* tuba_views_hashtag_new (const gchar* tag,
                                          gboolean* following,
                                          const gchar* url_basename,
                                          gboolean* featured);
VALA_EXTERN TubaViewsHashtag* tuba_views_hashtag_construct (GType object_type,
                                                const gchar* tag,
                                                gboolean* following,
                                                const gchar* url_basename,
                                                gboolean* featured);
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_views_hashtag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsHashtag, g_object_unref)
VALA_EXTERN TubaAPITag* tuba_api_tag_new (void);
VALA_EXTERN TubaAPITag* tuba_api_tag_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN void tuba_api_tag_set_name (TubaAPITag* self,
                            const gchar* value);
VALA_EXTERN void tuba_api_tag_set_url (TubaAPITag* self,
                           const gchar* value);
VALA_EXTERN void tuba_api_tag_set_history (TubaAPITag* self,
                               GeeArrayList* value);
VALA_EXTERN void tuba_api_tag_set_following (TubaAPITag* self,
                                 gboolean value);
VALA_EXTERN void tuba_api_tag_set_featuring (TubaAPITag* self,
                                 gboolean value);
VALA_EXTERN void tuba_widgetizable_open (TubaWidgetizable* self);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
static void tuba_api_tag_finalize (GObject * obj);
static GType tuba_api_tag_get_type_once (void);
static void _vala_tuba_api_tag_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec);
static void _vala_tuba_api_tag_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec);

static inline gpointer
tuba_api_tag_get_instance_private (TubaAPITag* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPITag_private_offset);
}

static GType
tuba_api_tag_real_deserialize_array_type (TubaEntity* base,
                                          const gchar* prop)
{
	TubaAPITag * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPITag*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("history")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_TAG_HISTORY;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_tag_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPITag*
tuba_api_tag_from (JsonNode* node,
                   GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPITag* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPITag* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_TAG, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_TAG (_tmp0_) ? ((TubaAPITag*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaRequestV2*
tuba_api_tag_search (const gchar* query,
                     GError** error)
{
	TubaRequestV2* req = NULL;
	TubaAccountStore* _tmp0_;
	TubaInstanceAccount* _tmp1_;
	TubaInstanceAccount* _tmp2_;
	TubaInstanceAccount* _tmp3_;
	TubaRequestV2* _tmp4_ = NULL;
	TubaRequestV2* result;
	g_return_val_if_fail (query != NULL, NULL);
	_tmp0_ = tuba_accounts;
	_tmp1_ = tuba_account_store_get_active (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = _g_object_ref0 (_tmp2_);
	_tmp4_ = tuba_request_v2_new ("/api/v2/search", TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_tmp4_, _tmp3_);
	_g_object_unref0 (_tmp3_);
	req = _tmp4_;
	tuba_request_v2_add_parameter (req, "q", query);
	tuba_request_v2_add_parameter (req, "type", "hashtags");
	tuba_request_v2_add_parameter (req, "limit", "4");
	tuba_request_v2_add_parameter (req, "exclude_unreviewed", "true");
	result = req;
	return result;
}

static void
tuba_api_tag_real_open (TubaWidgetizable* base)
{
	TubaAPITag * self;
	self = (TubaAPITag*) base;
}

gchar*
tuba_api_tag_weekly_use (TubaAPITag* self)
{
	gint used_times = 0;
	gboolean _tmp0_ = FALSE;
	GeeArrayList* _tmp1_;
	gchar* _tmp12_;
	gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	used_times = 0;
	_tmp1_ = self->priv->_history;
	if (_tmp1_ != NULL) {
		GeeArrayList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		_tmp2_ = self->priv->_history;
		_tmp3_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp2_);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ >= 7;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		{
			gint i = 0;
			i = 0;
			{
				gboolean _tmp5_ = FALSE;
				_tmp5_ = TRUE;
				while (TRUE) {
					GeeArrayList* _tmp7_;
					gpointer _tmp8_;
					TubaAPITagHistory* _tmp9_;
					const gchar* _tmp10_;
					const gchar* _tmp11_;
					if (!_tmp5_) {
						gint _tmp6_;
						_tmp6_ = i;
						i = _tmp6_ + 1;
					}
					_tmp5_ = FALSE;
					if (!(i < 7)) {
						break;
					}
					_tmp7_ = self->priv->_history;
					_tmp8_ = gee_abstract_list_get ((GeeAbstractList*) _tmp7_, i);
					_tmp9_ = (TubaAPITagHistory*) _tmp8_;
					_tmp10_ = tuba_api_tag_history_get_uses (_tmp9_);
					_tmp11_ = _tmp10_;
					used_times += atoi (_tmp11_);
					_g_object_unref0 (_tmp9_);
				}
			}
		}
	}
	_tmp12_ = g_strdup_printf (ngettext ("%d per week", "%d per week", (gulong) used_times), used_times);
	result = _tmp12_;
	return result;
}

static void
_tuba_api_tag_on_activated_adw_action_row_activated (AdwActionRow* _sender,
                                                     gpointer self)
{
	tuba_api_tag_on_activated ((TubaAPITag*) self);
}

static GtkWidget*
tuba_api_tag_real_to_widget (TubaWidgetizable* base)
{
	TubaAPITag * self;
	TubaWidgetsTag* w = NULL;
	TubaWidgetsTag* _tmp0_;
	GtkWidget* result;
	self = (TubaAPITag*) base;
	_tmp0_ = tuba_widgets_tag_new (self);
	g_object_ref_sink (_tmp0_);
	w = _tmp0_;
	g_signal_connect_object ((AdwActionRow*) w, "activated", (GCallback) _tuba_api_tag_on_activated_adw_action_row_activated, self, 0);
	result = (GtkWidget*) w;
	return result;
}

static void
tuba_api_tag_real_on_activated (TubaAPITag* self)
{
	TubaApplication* _tmp0_;
	TubaDialogsMainWindow* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	const gchar* _tmp3_;
	gboolean _tmp4_;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gboolean _tmp8_;
	TubaViewsHashtag* _tmp9_;
	TubaViewsHashtag* _tmp10_;
	TubaViewsBase* _tmp11_;
	TubaViewsBase* _tmp12_;
	_tmp0_ = tuba_app;
	_tmp1_ = tuba_application_get_main_window (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->priv->_name;
	_tmp4_ = self->priv->_following;
	_tmp5_ = self->priv->_url;
	_tmp6_ = g_path_get_basename (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = self->priv->_featuring;
	_tmp9_ = tuba_views_hashtag_new (_tmp3_, &_tmp4_, _tmp7_, &_tmp8_);
	g_object_ref_sink (_tmp9_);
	_tmp10_ = _tmp9_;
	_tmp11_ = tuba_dialogs_main_window_open_view (_tmp2_, (TubaViewsBase*) _tmp10_);
	_tmp12_ = _tmp11_;
	_g_object_unref0 (_tmp12_);
	_g_object_unref0 (_tmp10_);
	_g_free0 (_tmp7_);
}

void
tuba_api_tag_on_activated (TubaAPITag* self)
{
	TubaAPITagClass* _klass_;
	g_return_if_fail (self != NULL);
	_klass_ = TUBA_API_TAG_GET_CLASS (self);
	if (_klass_->on_activated) {
		_klass_->on_activated (self);
	}
}

TubaAPITag*
tuba_api_tag_construct (GType object_type)
{
	TubaAPITag * self = NULL;
	self = (TubaAPITag*) tuba_entity_construct (object_type);
	return self;
}

TubaAPITag*
tuba_api_tag_new (void)
{
	return tuba_api_tag_construct (TUBA_API_TYPE_TAG);
}

const gchar*
tuba_api_tag_get_name (TubaAPITag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_tag_set_name (TubaAPITag* self,
                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_tag_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_tag_properties[TUBA_API_TAG_NAME_PROPERTY]);
	}
}

const gchar*
tuba_api_tag_get_url (TubaAPITag* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_tag_set_url (TubaAPITag* self,
                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_tag_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_tag_properties[TUBA_API_TAG_URL_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_tag_get_history (TubaAPITag* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_history;
	result = _tmp0_;
	return result;
}

void
tuba_api_tag_set_history (TubaAPITag* self,
                          GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_tag_get_history (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_history);
		self->priv->_history = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_tag_properties[TUBA_API_TAG_HISTORY_PROPERTY]);
	}
}

gboolean
tuba_api_tag_get_following (TubaAPITag* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_following;
	return result;
}

void
tuba_api_tag_set_following (TubaAPITag* self,
                            gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_tag_get_following (self);
	if (old_value != value) {
		self->priv->_following = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_tag_properties[TUBA_API_TAG_FOLLOWING_PROPERTY]);
	}
}

gboolean
tuba_api_tag_get_featuring (TubaAPITag* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_featuring;
	return result;
}

void
tuba_api_tag_set_featuring (TubaAPITag* self,
                            gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_tag_get_featuring (self);
	if (old_value != value) {
		self->priv->_featuring = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_tag_properties[TUBA_API_TAG_FEATURING_PROPERTY]);
	}
}

static void
tuba_api_tag_class_init (TubaAPITagClass * klass,
                         gpointer klass_data)
{
	tuba_api_tag_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPITag_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_tag_real_deserialize_array_type;
	((TubaAPITagClass *) klass)->on_activated = (void (*) (TubaAPITag*)) tuba_api_tag_real_on_activated;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_tag_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_tag_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_tag_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_TAG_NAME_PROPERTY, tuba_api_tag_properties[TUBA_API_TAG_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_TAG_URL_PROPERTY, tuba_api_tag_properties[TUBA_API_TAG_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_TAG_HISTORY_PROPERTY, tuba_api_tag_properties[TUBA_API_TAG_HISTORY_PROPERTY] = g_param_spec_object ("history", "history", "history", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_TAG_FOLLOWING_PROPERTY, tuba_api_tag_properties[TUBA_API_TAG_FOLLOWING_PROPERTY] = g_param_spec_boolean ("following", "following", "following", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_TAG_FEATURING_PROPERTY, tuba_api_tag_properties[TUBA_API_TAG_FEATURING_PROPERTY] = g_param_spec_boolean ("featuring", "featuring", "featuring", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_tag_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                               gpointer iface_data)
{
	tuba_api_tag_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->open = (void (*) (TubaWidgetizable*)) tuba_api_tag_real_open;
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_tag_real_to_widget;
}

static void
tuba_api_tag_instance_init (TubaAPITag * self,
                            gpointer klass)
{
	self->priv = tuba_api_tag_get_instance_private (self);
	self->priv->_history = NULL;
	self->priv->_following = FALSE;
	self->priv->_featuring = FALSE;
}

static void
tuba_api_tag_finalize (GObject * obj)
{
	TubaAPITag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_TAG, TubaAPITag);
	_g_free0 (self->priv->_name);
	_g_free0 (self->priv->_url);
	_g_object_unref0 (self->priv->_history);
	G_OBJECT_CLASS (tuba_api_tag_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_tag_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPITagClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_tag_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPITag), 0, (GInstanceInitFunc) tuba_api_tag_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_tag_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_tag_type_id;
	tuba_api_tag_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPITag", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_tag_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPITag_private_offset = g_type_add_instance_private (tuba_api_tag_type_id, sizeof (TubaAPITagPrivate));
	return tuba_api_tag_type_id;
}

GType
tuba_api_tag_get_type (void)
{
	static GType tuba_api_tag_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_tag_type_id__once)) {
		GType tuba_api_tag_type_id;
		tuba_api_tag_type_id = tuba_api_tag_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_tag_type_id__once, tuba_api_tag_type_id);
	}
	return tuba_api_tag_type_id__once;
}

static void
_vala_tuba_api_tag_get_property (GObject * object,
                                 guint property_id,
                                 GValue * value,
                                 GParamSpec * pspec)
{
	TubaAPITag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_TAG, TubaAPITag);
	switch (property_id) {
		case TUBA_API_TAG_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_tag_get_name (self));
		break;
		case TUBA_API_TAG_URL_PROPERTY:
		g_value_set_string (value, tuba_api_tag_get_url (self));
		break;
		case TUBA_API_TAG_HISTORY_PROPERTY:
		g_value_set_object (value, tuba_api_tag_get_history (self));
		break;
		case TUBA_API_TAG_FOLLOWING_PROPERTY:
		g_value_set_boolean (value, tuba_api_tag_get_following (self));
		break;
		case TUBA_API_TAG_FEATURING_PROPERTY:
		g_value_set_boolean (value, tuba_api_tag_get_featuring (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_tag_set_property (GObject * object,
                                 guint property_id,
                                 const GValue * value,
                                 GParamSpec * pspec)
{
	TubaAPITag * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_TAG, TubaAPITag);
	switch (property_id) {
		case TUBA_API_TAG_NAME_PROPERTY:
		tuba_api_tag_set_name (self, g_value_get_string (value));
		break;
		case TUBA_API_TAG_URL_PROPERTY:
		tuba_api_tag_set_url (self, g_value_get_string (value));
		break;
		case TUBA_API_TAG_HISTORY_PROPERTY:
		tuba_api_tag_set_history (self, g_value_get_object (value));
		break;
		case TUBA_API_TAG_FOLLOWING_PROPERTY:
		tuba_api_tag_set_following (self, g_value_get_boolean (value));
		break;
		case TUBA_API_TAG_FEATURING_PROPERTY:
		tuba_api_tag_set_featuring (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

