/* Entity.c generated by valac 0.56.19, the Vala compiler
 * generated from Entity.vala, do not modify */

#include <glib-object.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_HELPER_TYPE_ENTITY (tuba_helper_entity_get_type ())
#define TUBA_HELPER_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_HELPER_TYPE_ENTITY, TubaHelperEntity))
#define TUBA_HELPER_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_HELPER_TYPE_ENTITY, TubaHelperEntityClass))
#define TUBA_HELPER_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_HELPER_TYPE_ENTITY))
#define TUBA_HELPER_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_HELPER_TYPE_ENTITY))
#define TUBA_HELPER_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_HELPER_TYPE_ENTITY, TubaHelperEntityClass))

typedef struct _TubaHelperEntity TubaHelperEntity;
typedef struct _TubaHelperEntityClass TubaHelperEntityClass;
typedef struct _TubaHelperEntityPrivate TubaHelperEntityPrivate;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))
typedef struct _TubaHelperParamSpecEntity TubaHelperParamSpecEntity;

struct _TubaHelperEntity {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TubaHelperEntityPrivate * priv;
};

struct _TubaHelperEntityClass {
	GTypeClass parent_class;
	void (*finalize) (TubaHelperEntity *self);
};

struct _TubaHelperParamSpecEntity {
	GParamSpec parent_instance;
};

static gpointer tuba_helper_entity_parent_class = NULL;

VALA_EXTERN gpointer tuba_helper_entity_ref (gpointer instance);
VALA_EXTERN void tuba_helper_entity_unref (gpointer instance);
VALA_EXTERN GParamSpec* tuba_helper_param_spec_entity (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
VALA_EXTERN void tuba_helper_value_set_entity (GValue* value,
                                   gpointer v_object);
VALA_EXTERN void tuba_helper_value_take_entity (GValue* value,
                                    gpointer v_object);
VALA_EXTERN gpointer tuba_helper_value_get_entity (const GValue* value);
VALA_EXTERN GType tuba_helper_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaHelperEntity, tuba_helper_entity_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN TubaEntity* tuba_helper_entity_from_json (JsonNode* node,
                                          GType type,
                                          gboolean force);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN TubaHelperEntity* tuba_helper_entity_new (void);
VALA_EXTERN TubaHelperEntity* tuba_helper_entity_construct (GType object_type);
static void tuba_helper_entity_finalize (TubaHelperEntity * obj);
static GType tuba_helper_entity_get_type_once (void);

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

TubaEntity*
tuba_helper_entity_from_json (JsonNode* node,
                              GType type,
                              gboolean force)
{
	TubaEntity* entity = NULL;
	GError* _inner_error0_ = NULL;
	TubaEntity* result;
	g_return_val_if_fail (node != NULL, NULL);
	entity = NULL;
	{
		TubaEntity* _tmp0_ = NULL;
		TubaEntity* _tmp1_;
		TubaEntity* _tmp2_;
		_tmp1_ = tuba_entity_from_json (type, node, &_inner_error0_);
		_tmp0_ = _tmp1_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_tmp2_ = _tmp0_;
		_tmp0_ = NULL;
		_g_object_unref0 (entity);
		entity = _tmp2_;
		_g_object_unref0 (_tmp0_);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp3_ = e;
		_tmp4_ = _tmp3_->message;
		_tmp5_ = string_to_string (_tmp4_);
		_tmp6_ = g_strconcat ("Error getting Entity from json: ", _tmp5_, NULL);
		_tmp7_ = _tmp6_;
		g_warning ("Entity.vala:8: %s", _tmp7_);
		_g_free0 (_tmp7_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		_g_object_unref0 (entity);
		__vala_JsonNode_free0 (node);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return NULL;
	}
	result = entity;
	__vala_JsonNode_free0 (node);
	return result;
}

TubaHelperEntity*
tuba_helper_entity_construct (GType object_type)
{
	TubaHelperEntity* self = NULL;
	self = (TubaHelperEntity*) g_type_create_instance (object_type);
	return self;
}

TubaHelperEntity*
tuba_helper_entity_new (void)
{
	return tuba_helper_entity_construct (TUBA_HELPER_TYPE_ENTITY);
}

static void
tuba_helper_value_entity_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
tuba_helper_value_entity_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		tuba_helper_entity_unref (value->data[0].v_pointer);
	}
}

static void
tuba_helper_value_entity_copy_value (const GValue* src_value,
                                     GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = tuba_helper_entity_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
tuba_helper_value_entity_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
tuba_helper_value_entity_collect_value (GValue* value,
                                        guint n_collect_values,
                                        GTypeCValue* collect_values,
                                        guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		TubaHelperEntity * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = tuba_helper_entity_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
tuba_helper_value_entity_lcopy_value (const GValue* value,
                                      guint n_collect_values,
                                      GTypeCValue* collect_values,
                                      guint collect_flags)
{
	TubaHelperEntity ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = tuba_helper_entity_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
tuba_helper_param_spec_entity (const gchar* name,
                               const gchar* nick,
                               const gchar* blurb,
                               GType object_type,
                               GParamFlags flags)
{
	TubaHelperParamSpecEntity* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TUBA_HELPER_TYPE_ENTITY), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
tuba_helper_value_get_entity (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_HELPER_TYPE_ENTITY), NULL);
	return value->data[0].v_pointer;
}

void
tuba_helper_value_set_entity (GValue* value,
                              gpointer v_object)
{
	TubaHelperEntity * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_HELPER_TYPE_ENTITY));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_HELPER_TYPE_ENTITY));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		tuba_helper_entity_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_helper_entity_unref (old);
	}
}

void
tuba_helper_value_take_entity (GValue* value,
                               gpointer v_object)
{
	TubaHelperEntity * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_HELPER_TYPE_ENTITY));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_HELPER_TYPE_ENTITY));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_helper_entity_unref (old);
	}
}

static void
tuba_helper_entity_class_init (TubaHelperEntityClass * klass,
                               gpointer klass_data)
{
	tuba_helper_entity_parent_class = g_type_class_peek_parent (klass);
	((TubaHelperEntityClass *) klass)->finalize = tuba_helper_entity_finalize;
}

static void
tuba_helper_entity_instance_init (TubaHelperEntity * self,
                                  gpointer klass)
{
	self->ref_count = 1;
}

static void
tuba_helper_entity_finalize (TubaHelperEntity * obj)
{
	TubaHelperEntity * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_HELPER_TYPE_ENTITY, TubaHelperEntity);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
tuba_helper_entity_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { tuba_helper_value_entity_init, tuba_helper_value_entity_free_value, tuba_helper_value_entity_copy_value, tuba_helper_value_entity_peek_pointer, "p", tuba_helper_value_entity_collect_value, "p", tuba_helper_value_entity_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (TubaHelperEntityClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_helper_entity_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaHelperEntity), 0, (GInstanceInitFunc) tuba_helper_entity_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType tuba_helper_entity_type_id;
	tuba_helper_entity_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TubaHelperEntity", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_NONE);
	return tuba_helper_entity_type_id;
}

GType
tuba_helper_entity_get_type (void)
{
	static GType tuba_helper_entity_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_helper_entity_type_id__once)) {
		GType tuba_helper_entity_type_id;
		tuba_helper_entity_type_id = tuba_helper_entity_get_type_once ();
		g_once_init_leave_pointer (&tuba_helper_entity_type_id__once, tuba_helper_entity_type_id);
	}
	return tuba_helper_entity_type_id__once;
}

gpointer
tuba_helper_entity_ref (gpointer instance)
{
	TubaHelperEntity * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
tuba_helper_entity_unref (gpointer instance)
{
	TubaHelperEntity * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		TUBA_HELPER_ENTITY_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

