/* WebApHandler.c generated by valac 0.56.19, the Vala compiler
 * generated from WebApHandler.vala, do not modify */

/* https://fedilinks.org/spec/en/6-The-web-ap-URI*/

#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_UTILS_TYPE_WEB_AP_HANDLER (tuba_utils_web_ap_handler_get_type ())
#define TUBA_UTILS_WEB_AP_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_UTILS_TYPE_WEB_AP_HANDLER, TubaUtilsWebApHandler))
#define TUBA_UTILS_WEB_AP_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_UTILS_TYPE_WEB_AP_HANDLER, TubaUtilsWebApHandlerClass))
#define TUBA_UTILS_IS_WEB_AP_HANDLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_UTILS_TYPE_WEB_AP_HANDLER))
#define TUBA_UTILS_IS_WEB_AP_HANDLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_UTILS_TYPE_WEB_AP_HANDLER))
#define TUBA_UTILS_WEB_AP_HANDLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_UTILS_TYPE_WEB_AP_HANDLER, TubaUtilsWebApHandlerClass))

typedef struct _TubaUtilsWebApHandler TubaUtilsWebApHandler;
typedef struct _TubaUtilsWebApHandlerClass TubaUtilsWebApHandlerClass;
typedef struct _TubaUtilsWebApHandlerPrivate TubaUtilsWebApHandlerPrivate;
typedef struct _TubaUtilsParamSpecWebApHandler TubaUtilsParamSpecWebApHandler;

struct _TubaUtilsWebApHandler {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TubaUtilsWebApHandlerPrivate * priv;
};

struct _TubaUtilsWebApHandlerClass {
	GTypeClass parent_class;
	void (*finalize) (TubaUtilsWebApHandler *self);
};

struct _TubaUtilsParamSpecWebApHandler {
	GParamSpec parent_instance;
};

static gpointer tuba_utils_web_ap_handler_parent_class = NULL;

VALA_EXTERN gpointer tuba_utils_web_ap_handler_ref (gpointer instance);
VALA_EXTERN void tuba_utils_web_ap_handler_unref (gpointer instance);
VALA_EXTERN GParamSpec* tuba_utils_param_spec_web_ap_handler (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
VALA_EXTERN void tuba_utils_value_set_web_ap_handler (GValue* value,
                                          gpointer v_object);
VALA_EXTERN void tuba_utils_value_take_web_ap_handler (GValue* value,
                                           gpointer v_object);
VALA_EXTERN gpointer tuba_utils_value_get_web_ap_handler (const GValue* value);
VALA_EXTERN GType tuba_utils_web_ap_handler_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaUtilsWebApHandler, tuba_utils_web_ap_handler_unref)
VALA_EXTERN gchar* tuba_utils_web_ap_handler_from_uri (GUri* uri);
VALA_EXTERN TubaUtilsWebApHandler* tuba_utils_web_ap_handler_new (void);
VALA_EXTERN TubaUtilsWebApHandler* tuba_utils_web_ap_handler_construct (GType object_type);
static void tuba_utils_web_ap_handler_finalize (TubaUtilsWebApHandler * obj);
static GType tuba_utils_web_ap_handler_get_type_once (void);

gchar*
tuba_utils_web_ap_handler_from_uri (GUri* uri)
{
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* result;
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = g_uri_get_host (uri);
	_tmp1_ = g_uri_get_path (uri);
	_tmp2_ = g_uri_get_query (uri);
	_tmp3_ = g_uri_get_fragment (uri);
	_tmp4_ = g_uri_join (g_uri_get_flags (uri), "https", NULL, _tmp0_, g_uri_get_port (uri), _tmp1_, _tmp2_, _tmp3_);
	result = _tmp4_;
	return result;
}

TubaUtilsWebApHandler*
tuba_utils_web_ap_handler_construct (GType object_type)
{
	TubaUtilsWebApHandler* self = NULL;
	self = (TubaUtilsWebApHandler*) g_type_create_instance (object_type);
	return self;
}

TubaUtilsWebApHandler*
tuba_utils_web_ap_handler_new (void)
{
	return tuba_utils_web_ap_handler_construct (TUBA_UTILS_TYPE_WEB_AP_HANDLER);
}

static void
tuba_utils_value_web_ap_handler_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
tuba_utils_value_web_ap_handler_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		tuba_utils_web_ap_handler_unref (value->data[0].v_pointer);
	}
}

static void
tuba_utils_value_web_ap_handler_copy_value (const GValue* src_value,
                                            GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = tuba_utils_web_ap_handler_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
tuba_utils_value_web_ap_handler_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
tuba_utils_value_web_ap_handler_collect_value (GValue* value,
                                               guint n_collect_values,
                                               GTypeCValue* collect_values,
                                               guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		TubaUtilsWebApHandler * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = tuba_utils_web_ap_handler_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
tuba_utils_value_web_ap_handler_lcopy_value (const GValue* value,
                                             guint n_collect_values,
                                             GTypeCValue* collect_values,
                                             guint collect_flags)
{
	TubaUtilsWebApHandler ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = tuba_utils_web_ap_handler_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
tuba_utils_param_spec_web_ap_handler (const gchar* name,
                                      const gchar* nick,
                                      const gchar* blurb,
                                      GType object_type,
                                      GParamFlags flags)
{
	TubaUtilsParamSpecWebApHandler* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TUBA_UTILS_TYPE_WEB_AP_HANDLER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
tuba_utils_value_get_web_ap_handler (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_WEB_AP_HANDLER), NULL);
	return value->data[0].v_pointer;
}

void
tuba_utils_value_set_web_ap_handler (GValue* value,
                                     gpointer v_object)
{
	TubaUtilsWebApHandler * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_WEB_AP_HANDLER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_WEB_AP_HANDLER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		tuba_utils_web_ap_handler_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_web_ap_handler_unref (old);
	}
}

void
tuba_utils_value_take_web_ap_handler (GValue* value,
                                      gpointer v_object)
{
	TubaUtilsWebApHandler * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_UTILS_TYPE_WEB_AP_HANDLER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_UTILS_TYPE_WEB_AP_HANDLER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_utils_web_ap_handler_unref (old);
	}
}

static void
tuba_utils_web_ap_handler_class_init (TubaUtilsWebApHandlerClass * klass,
                                      gpointer klass_data)
{
	tuba_utils_web_ap_handler_parent_class = g_type_class_peek_parent (klass);
	((TubaUtilsWebApHandlerClass *) klass)->finalize = tuba_utils_web_ap_handler_finalize;
}

static void
tuba_utils_web_ap_handler_instance_init (TubaUtilsWebApHandler * self,
                                         gpointer klass)
{
	self->ref_count = 1;
}

static void
tuba_utils_web_ap_handler_finalize (TubaUtilsWebApHandler * obj)
{
	TubaUtilsWebApHandler * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_UTILS_TYPE_WEB_AP_HANDLER, TubaUtilsWebApHandler);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
tuba_utils_web_ap_handler_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { tuba_utils_value_web_ap_handler_init, tuba_utils_value_web_ap_handler_free_value, tuba_utils_value_web_ap_handler_copy_value, tuba_utils_value_web_ap_handler_peek_pointer, "p", tuba_utils_value_web_ap_handler_collect_value, "p", tuba_utils_value_web_ap_handler_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (TubaUtilsWebApHandlerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_utils_web_ap_handler_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaUtilsWebApHandler), 0, (GInstanceInitFunc) tuba_utils_web_ap_handler_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType tuba_utils_web_ap_handler_type_id;
	tuba_utils_web_ap_handler_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TubaUtilsWebApHandler", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_NONE);
	return tuba_utils_web_ap_handler_type_id;
}

GType
tuba_utils_web_ap_handler_get_type (void)
{
	static GType tuba_utils_web_ap_handler_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_utils_web_ap_handler_type_id__once)) {
		GType tuba_utils_web_ap_handler_type_id;
		tuba_utils_web_ap_handler_type_id = tuba_utils_web_ap_handler_get_type_once ();
		g_once_init_leave_pointer (&tuba_utils_web_ap_handler_type_id__once, tuba_utils_web_ap_handler_type_id);
	}
	return tuba_utils_web_ap_handler_type_id__once;
}

gpointer
tuba_utils_web_ap_handler_ref (gpointer instance)
{
	TubaUtilsWebApHandler * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
tuba_utils_web_ap_handler_unref (gpointer instance)
{
	TubaUtilsWebApHandler * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		TUBA_UTILS_WEB_AP_HANDLER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

