/* NotificationRequests.c generated by valac 0.56.19, the Vala compiler
 * generated from NotificationRequests.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS (tuba_views_notification_requests_get_type ())
#define TUBA_VIEWS_NOTIFICATION_REQUESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS, TubaViewsNotificationRequests))
#define TUBA_VIEWS_NOTIFICATION_REQUESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS, TubaViewsNotificationRequestsClass))
#define TUBA_VIEWS_IS_NOTIFICATION_REQUESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS))
#define TUBA_VIEWS_IS_NOTIFICATION_REQUESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS))
#define TUBA_VIEWS_NOTIFICATION_REQUESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS, TubaViewsNotificationRequestsClass))

typedef struct _TubaViewsNotificationRequests TubaViewsNotificationRequests;
typedef struct _TubaViewsNotificationRequestsClass TubaViewsNotificationRequestsClass;
typedef struct _TubaViewsNotificationRequestsPrivate TubaViewsNotificationRequestsPrivate;
enum  {
	TUBA_VIEWS_NOTIFICATION_REQUESTS_0_PROPERTY,
	TUBA_VIEWS_NOTIFICATION_REQUESTS_NUM_PROPERTIES
};
static GParamSpec* tuba_views_notification_requests_properties[TUBA_VIEWS_NOTIFICATION_REQUESTS_NUM_PROPERTIES];

#define TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST (tuba_widgets_notification_request_get_type ())
#define TUBA_WIDGETS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequest))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))

typedef struct _TubaWidgetsNotificationRequest TubaWidgetsNotificationRequest;
typedef struct _TubaWidgetsNotificationRequestClass TubaWidgetsNotificationRequestClass;

#define TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST (tuba_api_notification_filter_request_get_type ())
#define TUBA_API_NOTIFICATION_FILTER_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequest))
#define TUBA_API_NOTIFICATION_FILTER_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequestClass))
#define TUBA_API_NOTIFICATION_FILTER_IS_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST))
#define TUBA_API_NOTIFICATION_FILTER_IS_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST))
#define TUBA_API_NOTIFICATION_FILTER_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequestClass))

typedef struct _TubaAPINotificationFilterRequest TubaAPINotificationFilterRequest;
typedef struct _TubaAPINotificationFilterRequestClass TubaAPINotificationFilterRequestClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TubaWidgetsNotificationRequestPrivate TubaWidgetsNotificationRequestPrivate;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;
typedef struct _TubaViewsNotificationRequestsOnResponseRealData TubaViewsNotificationRequestsOnResponseRealData;

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsNotificationRequests {
	TubaViewsTimeline parent_instance;
	TubaViewsNotificationRequestsPrivate * priv;
};

struct _TubaViewsNotificationRequestsClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaWidgetsNotificationRequest {
	GtkListBoxRow parent_instance;
	TubaWidgetsNotificationRequestPrivate * priv;
	GtkBox* btns_box;
};

struct _TubaWidgetsNotificationRequestClass {
	GtkListBoxRowClass parent_class;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsNotificationRequestsOnResponseRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsNotificationRequests* self;
	TubaWidgetsNotificationRequest* wdg;
	TubaRequestV2* req;
	TubaAPINotificationFilterRequest* api_req;
	GInputStream* _tmp0_;
	GInputStream* _tmp1_;
	guint indx;
	gboolean found;
	GListStore* _tmp2_;
	guint _tmp3_;
	gboolean _tmp4_;
	TubaAccountStore* _tmp5_;
	TubaInstanceAccount* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	gint _tmp8_;
	gint _tmp9_;
	gint to_remove;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	TubaAccountStore* _tmp12_;
	TubaInstanceAccount* _tmp13_;
	TubaInstanceAccount* _tmp14_;
	TubaAccountStore* _tmp15_;
	TubaInstanceAccount* _tmp16_;
	TubaInstanceAccount* _tmp17_;
	gint _tmp18_;
	gint _tmp19_;
	GtkBox* _tmp20_;
	GtkBox* _tmp21_;
	GError* _inner_error0_;
};

static gpointer tuba_views_notification_requests_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_notification_requests_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsNotificationRequests, g_object_unref)
VALA_EXTERN GtkWidget* tuba_views_content_base_on_create_model_widget (TubaViewsContentBase* self,
                                                           GObject* obj);
VALA_EXTERN void tuba_views_content_base_on_content_item_activated (TubaViewsContentBase* self,
                                                        GtkListBoxRow* row);
VALA_EXTERN TubaViewsNotificationRequests* tuba_views_notification_requests_new (void);
VALA_EXTERN TubaViewsNotificationRequests* tuba_views_notification_requests_construct (GType object_type);
static GtkWidget* tuba_views_notification_requests_real_on_create_model_widget (TubaViewsContentBase* base,
                                                                         GObject* obj);
VALA_EXTERN GType tuba_widgets_notification_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotificationRequest, g_object_unref)
VALA_EXTERN GType tuba_api_notification_filter_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationFilterRequest, g_object_unref)
static void tuba_views_notification_requests_on_response (TubaViewsNotificationRequests* self,
                                                   TubaWidgetsNotificationRequest* wdg,
                                                   TubaRequestV2* req,
                                                   TubaAPINotificationFilterRequest* api_req);
static void _tuba_views_notification_requests_on_response_tuba_widgets_notification_request_dismissed (TubaWidgetsNotificationRequest* _sender,
                                                                                                TubaRequestV2* req,
                                                                                                TubaAPINotificationFilterRequest* api_req,
                                                                                                gpointer self);
static void _tuba_views_notification_requests_on_response_tuba_widgets_notification_request_accepted (TubaWidgetsNotificationRequest* _sender,
                                                                                               TubaRequestV2* req,
                                                                                               TubaAPINotificationFilterRequest* api_req,
                                                                                               gpointer self);
static void tuba_views_notification_requests_on_response_real (TubaViewsNotificationRequests* self,
                                                        TubaWidgetsNotificationRequest* wdg,
                                                        TubaRequestV2* req,
                                                        TubaAPINotificationFilterRequest* api_req,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
static void tuba_views_notification_requests_on_response_real_finish (TubaViewsNotificationRequests* self,
                                                               GAsyncResult* _res_);
static void tuba_views_notification_requests_on_response_real_data_free (gpointer _data);
static gboolean tuba_views_notification_requests_on_response_real_co (TubaViewsNotificationRequestsOnResponseRealData* _data_);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_views_notification_requests_on_response_real_ready (GObject* source_object,
                                                              GAsyncResult* _res_,
                                                              gpointer _user_data_);
VALA_EXTERN void tuba_views_timeline_safely_remove (TubaViewsTimeline* self,
                                        gint i);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN gint tuba_instance_account_get_filtered_notifications_count (TubaInstanceAccount* self);
VALA_EXTERN const gchar* tuba_api_notification_filter_request_get_notifications_count (TubaAPINotificationFilterRequest* self);
VALA_EXTERN void tuba_instance_account_set_filtered_notifications_count (TubaInstanceAccount* self,
                                                             gint value);
static void tuba_views_notification_requests_real_on_content_item_activated (TubaViewsContentBase* base,
                                                                      GtkListBoxRow* row);
VALA_EXTERN void tuba_widgets_notification_request_open (TubaWidgetsNotificationRequest* self);
static GObject * tuba_views_notification_requests_constructor (GType type,
                                                        guint n_construct_properties,
                                                        GObjectConstructParam * construct_properties);
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
static GType tuba_views_notification_requests_get_type_once (void);

TubaViewsNotificationRequests*
tuba_views_notification_requests_construct (GType object_type)
{
	TubaViewsNotificationRequests * self = NULL;
	self = (TubaViewsNotificationRequests*) g_object_new (object_type, "url", "/api/v1/notifications/requests", "label", _ ("Filtered Notifications"), "icon", "tuba-bell-outline-symbolic", "empty-state-title", _ ("No Filtered Notifications"), "batch-size-min", 20, NULL);
	return self;
}

TubaViewsNotificationRequests*
tuba_views_notification_requests_new (void)
{
	return tuba_views_notification_requests_construct (TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_views_notification_requests_on_response_tuba_widgets_notification_request_dismissed (TubaWidgetsNotificationRequest* _sender,
                                                                                           TubaRequestV2* req,
                                                                                           TubaAPINotificationFilterRequest* api_req,
                                                                                           gpointer self)
{
	tuba_views_notification_requests_on_response ((TubaViewsNotificationRequests*) self, _sender, req, api_req);
}

static void
_tuba_views_notification_requests_on_response_tuba_widgets_notification_request_accepted (TubaWidgetsNotificationRequest* _sender,
                                                                                          TubaRequestV2* req,
                                                                                          TubaAPINotificationFilterRequest* api_req,
                                                                                          gpointer self)
{
	tuba_views_notification_requests_on_response ((TubaViewsNotificationRequests*) self, _sender, req, api_req);
}

static GtkWidget*
tuba_views_notification_requests_real_on_create_model_widget (TubaViewsContentBase* base,
                                                              GObject* obj)
{
	TubaViewsNotificationRequests * self;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	TubaWidgetsNotificationRequest* widget_notification_req = NULL;
	GtkWidget* _tmp1_;
	TubaWidgetsNotificationRequest* _tmp2_;
	TubaWidgetsNotificationRequest* _tmp3_;
	GtkWidget* result;
	self = (TubaViewsNotificationRequests*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_views_notification_requests_parent_class)->on_create_model_widget ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline), obj);
	widget = _tmp0_;
	_tmp1_ = widget;
	_tmp2_ = _g_object_ref0 (TUBA_WIDGETS_IS_NOTIFICATION_REQUEST (_tmp1_) ? ((TubaWidgetsNotificationRequest*) _tmp1_) : NULL);
	widget_notification_req = _tmp2_;
	_tmp3_ = widget_notification_req;
	if (_tmp3_ != NULL) {
		TubaWidgetsNotificationRequest* _tmp4_;
		TubaWidgetsNotificationRequest* _tmp5_;
		_tmp4_ = widget_notification_req;
		g_signal_connect_object (_tmp4_, "dismissed", (GCallback) _tuba_views_notification_requests_on_response_tuba_widgets_notification_request_dismissed, self, 0);
		_tmp5_ = widget_notification_req;
		g_signal_connect_object (_tmp5_, "accepted", (GCallback) _tuba_views_notification_requests_on_response_tuba_widgets_notification_request_accepted, self, 0);
	}
	result = widget;
	_g_object_unref0 (widget_notification_req);
	return result;
}

static void
tuba_views_notification_requests_on_response (TubaViewsNotificationRequests* self,
                                              TubaWidgetsNotificationRequest* wdg,
                                              TubaRequestV2* req,
                                              TubaAPINotificationFilterRequest* api_req)
{
	GtkBox* _tmp0_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (wdg != NULL);
	g_return_if_fail (req != NULL);
	g_return_if_fail (api_req != NULL);
	_tmp0_ = wdg->btns_box;
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, FALSE);
	tuba_views_notification_requests_on_response_real (self, wdg, req, api_req, NULL, NULL);
}

static void
tuba_views_notification_requests_on_response_real_data_free (gpointer _data)
{
	TubaViewsNotificationRequestsOnResponseRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->wdg);
	_g_object_unref0 (_data_->req);
	_g_object_unref0 (_data_->api_req);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsNotificationRequestsOnResponseRealData, _data_);
}

static void
tuba_views_notification_requests_on_response_real (TubaViewsNotificationRequests* self,
                                                   TubaWidgetsNotificationRequest* wdg,
                                                   TubaRequestV2* req,
                                                   TubaAPINotificationFilterRequest* api_req,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_)
{
	TubaViewsNotificationRequestsOnResponseRealData* _data_;
	TubaViewsNotificationRequests* _tmp0_;
	TubaWidgetsNotificationRequest* _tmp1_;
	TubaRequestV2* _tmp2_;
	TubaAPINotificationFilterRequest* _tmp3_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (wdg != NULL);
	g_return_if_fail (req != NULL);
	g_return_if_fail (api_req != NULL);
	_data_ = g_slice_new0 (TubaViewsNotificationRequestsOnResponseRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_notification_requests_on_response_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = _g_object_ref0 (wdg);
	_g_object_unref0 (_data_->wdg);
	_data_->wdg = _tmp1_;
	_tmp2_ = _g_object_ref0 (req);
	_g_object_unref0 (_data_->req);
	_data_->req = _tmp2_;
	_tmp3_ = _g_object_ref0 (api_req);
	_g_object_unref0 (_data_->api_req);
	_data_->api_req = _tmp3_;
	tuba_views_notification_requests_on_response_real_co (_data_);
}

static void
tuba_views_notification_requests_on_response_real_finish (TubaViewsNotificationRequests* self,
                                                          GAsyncResult* _res_)
{
	TubaViewsNotificationRequestsOnResponseRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_notification_requests_on_response_real_ready (GObject* source_object,
                                                         GAsyncResult* _res_,
                                                         gpointer _user_data_)
{
	TubaViewsNotificationRequestsOnResponseRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_notification_requests_on_response_real_co (_data_);
}

static gboolean
tuba_views_notification_requests_on_response_real_co (TubaViewsNotificationRequestsOnResponseRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	{
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->req, tuba_views_notification_requests_on_response_real_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp0_ = tuba_request_v2_exec_finish (_data_->req, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->_tmp1_ = _data_->_tmp0_;
		_g_object_unref0 (_data_->_tmp1_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp2_ = ((TubaViewsContentBase*) _data_->self)->model;
		_data_->_tmp3_ = 0U;
		_data_->_tmp4_ = g_list_store_find (_data_->_tmp2_, (GObject*) _data_->api_req, &_data_->_tmp3_);
		_data_->indx = _data_->_tmp3_;
		_data_->found = _data_->_tmp4_;
		if (_data_->found) {
			tuba_views_timeline_safely_remove ((TubaViewsTimeline*) _data_->self, (gint) _data_->indx);
			_data_->_tmp5_ = tuba_accounts;
			_data_->_tmp6_ = tuba_account_store_get_active (_data_->_tmp5_);
			_data_->_tmp7_ = _data_->_tmp6_;
			_data_->_tmp8_ = tuba_instance_account_get_filtered_notifications_count (_data_->_tmp7_);
			_data_->_tmp9_ = _data_->_tmp8_;
			if (_data_->_tmp9_ > 0) {
				_data_->_tmp10_ = tuba_api_notification_filter_request_get_notifications_count (_data_->api_req);
				_data_->_tmp11_ = _data_->_tmp10_;
				_data_->to_remove = atoi (_data_->_tmp11_);
				if (_data_->to_remove < 1) {
					_data_->to_remove = 1;
				}
				_data_->_tmp12_ = tuba_accounts;
				_data_->_tmp13_ = tuba_account_store_get_active (_data_->_tmp12_);
				_data_->_tmp14_ = _data_->_tmp13_;
				_data_->_tmp15_ = tuba_accounts;
				_data_->_tmp16_ = tuba_account_store_get_active (_data_->_tmp15_);
				_data_->_tmp17_ = _data_->_tmp16_;
				_data_->_tmp18_ = tuba_instance_account_get_filtered_notifications_count (_data_->_tmp17_);
				_data_->_tmp19_ = _data_->_tmp18_;
				tuba_instance_account_set_filtered_notifications_count (_data_->_tmp17_, _data_->_tmp19_ - _data_->to_remove);
			}
		} else {
			_data_->_tmp20_ = _data_->wdg->btns_box;
			gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp20_, TRUE);
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		g_clear_error (&_data_->_inner_error0_);
		_data_->_tmp21_ = _data_->wdg->btns_box;
		gtk_widget_set_sensitive ((GtkWidget*) _data_->_tmp21_, TRUE);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_views_notification_requests_real_on_content_item_activated (TubaViewsContentBase* base,
                                                                 GtkListBoxRow* row)
{
	TubaViewsNotificationRequests * self;
	self = (TubaViewsNotificationRequests*) base;
	g_return_if_fail (row != NULL);
	tuba_widgets_notification_request_open (G_TYPE_CHECK_INSTANCE_CAST (row, TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequest));
}

static GObject *
tuba_views_notification_requests_constructor (GType type,
                                              guint n_construct_properties,
                                              GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsNotificationRequests * self;
	parent_class = G_OBJECT_CLASS (tuba_views_notification_requests_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_NOTIFICATION_REQUESTS, TubaViewsNotificationRequests);
	tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST);
	return obj;
}

static void
tuba_views_notification_requests_class_init (TubaViewsNotificationRequestsClass * klass,
                                             gpointer klass_data)
{
	tuba_views_notification_requests_parent_class = g_type_class_peek_parent (klass);
	((TubaViewsContentBaseClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsContentBase*, GObject*)) tuba_views_notification_requests_real_on_create_model_widget;
	((TubaViewsContentBaseClass *) klass)->on_content_item_activated = (void (*) (TubaViewsContentBase*, GtkListBoxRow*)) tuba_views_notification_requests_real_on_content_item_activated;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_notification_requests_constructor;
}

static void
tuba_views_notification_requests_instance_init (TubaViewsNotificationRequests * self,
                                                gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_views_notification_requests_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsNotificationRequestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_notification_requests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsNotificationRequests), 0, (GInstanceInitFunc) tuba_views_notification_requests_instance_init, NULL };
	GType tuba_views_notification_requests_type_id;
	tuba_views_notification_requests_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsNotificationRequests", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_views_notification_requests_type_id;
}

GType
tuba_views_notification_requests_get_type (void)
{
	static GType tuba_views_notification_requests_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_notification_requests_type_id__once)) {
		GType tuba_views_notification_requests_type_id;
		tuba_views_notification_requests_type_id = tuba_views_notification_requests_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_notification_requests_type_id__once, tuba_views_notification_requests_type_id);
	}
	return tuba_views_notification_requests_type_id__once;
}

