/* ScheduledStatus.c generated by valac 0.56.19, the Vala compiler
 * generated from ScheduledStatus.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>

#define TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR (2000 + 3000)
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_SCHEDULED_STATUS (tuba_api_scheduled_status_get_type ())
#define TUBA_API_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus))
#define TUBA_API_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))
#define TUBA_API_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))

typedef struct _TubaAPIScheduledStatus TubaAPIScheduledStatus;
typedef struct _TubaAPIScheduledStatusClass TubaAPIScheduledStatusClass;
typedef struct _TubaAPIScheduledStatusPrivate TubaAPIScheduledStatusPrivate;

#define TUBA_API_TYPE_ATTACHMENT (tuba_api_attachment_get_type ())
#define TUBA_API_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachment))
#define TUBA_API_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))
#define TUBA_API_IS_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_IS_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_ATTACHMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))

typedef struct _TubaAPIAttachment TubaAPIAttachment;
typedef struct _TubaAPIAttachmentClass TubaAPIAttachmentClass;

#define TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS (tuba_api_scheduled_status_params_get_type ())
#define TUBA_API_SCHEDULED_STATUS_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParams))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParamsClass))
#define TUBA_API_SCHEDULED_STATUS_IS_PARAMS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS))
#define TUBA_API_SCHEDULED_STATUS_IS_PARAMS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParamsClass))

typedef struct _TubaAPIScheduledStatusParams TubaAPIScheduledStatusParams;
typedef struct _TubaAPIScheduledStatusParamsClass TubaAPIScheduledStatusParamsClass;
enum  {
	TUBA_API_SCHEDULED_STATUS_0_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_ID_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_WIDGETS_TYPE_SCHEDULED_STATUS (tuba_widgets_scheduled_status_get_type ())
#define TUBA_WIDGETS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus))
#define TUBA_WIDGETS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))

typedef struct _TubaWidgetsScheduledStatus TubaWidgetsScheduledStatus;
typedef struct _TubaWidgetsScheduledStatusClass TubaWidgetsScheduledStatusClass;
typedef struct _TubaAPIScheduledStatusParamsPrivate TubaAPIScheduledStatusParamsPrivate;

#define TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL (tuba_api_scheduled_status_params_poll_get_type ())
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPoll))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPollClass))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_IS_POLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_IS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL))
#define TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPollClass))

typedef struct _TubaAPIScheduledStatusParamsPoll TubaAPIScheduledStatusParamsPoll;
typedef struct _TubaAPIScheduledStatusParamsPollClass TubaAPIScheduledStatusParamsPollClass;
enum  {
	TUBA_API_SCHEDULED_STATUS_PARAMS_0_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_NUM_PROPERTIES];

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;
typedef struct _TubaAPIScheduledStatusParamsPollPrivate TubaAPIScheduledStatusParamsPollPrivate;
enum  {
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_0_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY,
	TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_NUM_PROPERTIES
};
static GParamSpec* tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIScheduledStatus {
	TubaEntity parent_instance;
	TubaAPIScheduledStatusPrivate * priv;
};

struct _TubaAPIScheduledStatusClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIScheduledStatusPrivate {
	gchar* _id;
	gchar* _scheduled_at;
	GeeArrayList* _media_attachments;
	TubaAPIScheduledStatusParams* _props;
};

struct _TubaAPIScheduledStatusParams {
	TubaEntity parent_instance;
	TubaAPIScheduledStatusParamsPrivate * priv;
};

struct _TubaAPIScheduledStatusParamsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIScheduledStatusParamsPrivate {
	gchar* _text;
	TubaAPIScheduledStatusParamsPoll* _poll;
	GeeArrayList* _media_ids;
	gboolean _sensitive;
	gchar* _spoiler_text;
	gchar* _visibility;
	gchar* _language;
	gint64 _in_reply_to_id;
	gboolean _local_only;
	gchar* _quoted_status_id;
	gchar* _quote_approval_policy;
};

struct _TubaAPIScheduledStatusParamsPoll {
	TubaEntity parent_instance;
	TubaAPIScheduledStatusParamsPollPrivate * priv;
};

struct _TubaAPIScheduledStatusParamsPollClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIScheduledStatusParamsPollPrivate {
	GeeArrayList* _options;
	gint64 _expires_in;
	gboolean _multiple;
	gboolean _hide_totals;
};

static gint TubaAPIScheduledStatus_private_offset;
static gpointer tuba_api_scheduled_status_parent_class = NULL;
static gint TubaAPIScheduledStatusParams_private_offset;
static gpointer tuba_api_scheduled_status_params_parent_class = NULL;
VALA_EXTERN TubaSettings* tuba_settings;
static gint TubaAPIScheduledStatusParamsPoll_private_offset;
static gpointer tuba_api_scheduled_status_params_poll_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_scheduled_status_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatus, g_object_unref)
VALA_EXTERN GType tuba_api_attachment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAttachment, g_object_unref)
VALA_EXTERN GType tuba_api_scheduled_status_params_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatusParams, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
VALA_EXTERN TubaAPIScheduledStatus* tuba_api_scheduled_status_from (JsonNode* node,
                                                        GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
static GType tuba_api_scheduled_status_real_deserialize_array_type (TubaEntity* base,
                                                             const gchar* prop);
static GtkWidget* tuba_api_scheduled_status_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaWidgetsScheduledStatus* tuba_widgets_scheduled_status_new (TubaAPIScheduledStatus* scheduled_status);
VALA_EXTERN TubaWidgetsScheduledStatus* tuba_widgets_scheduled_status_construct (GType object_type,
                                                                     TubaAPIScheduledStatus* scheduled_status);
VALA_EXTERN GType tuba_widgets_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsScheduledStatus, g_object_unref)
VALA_EXTERN TubaAPIScheduledStatus* tuba_api_scheduled_status_new (void);
VALA_EXTERN TubaAPIScheduledStatus* tuba_api_scheduled_status_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_id (TubaAPIScheduledStatus* self);
VALA_EXTERN void tuba_api_scheduled_status_set_id (TubaAPIScheduledStatus* self,
                                       const gchar* value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_scheduled_at (TubaAPIScheduledStatus* self);
VALA_EXTERN void tuba_api_scheduled_status_set_scheduled_at (TubaAPIScheduledStatus* self,
                                                 const gchar* value);
VALA_EXTERN GeeArrayList* tuba_api_scheduled_status_get_media_attachments (TubaAPIScheduledStatus* self);
VALA_EXTERN void tuba_api_scheduled_status_set_media_attachments (TubaAPIScheduledStatus* self,
                                                      GeeArrayList* value);
VALA_EXTERN TubaAPIScheduledStatusParams* tuba_api_scheduled_status_get_props (TubaAPIScheduledStatus* self);
VALA_EXTERN void tuba_api_scheduled_status_set_props (TubaAPIScheduledStatus* self,
                                          TubaAPIScheduledStatusParams* value);
VALA_EXTERN GType tuba_api_scheduled_status_params_poll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatusParamsPoll, g_object_unref)
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN const gchar* tuba_settings_get_default_quote_policy (TubaSettings* self);
static GType tuba_api_scheduled_status_params_real_deserialize_array_type (TubaEntity* base,
                                                                    const gchar* prop);
VALA_EXTERN TubaAPIScheduledStatusParams* tuba_api_scheduled_status_params_new (void);
VALA_EXTERN TubaAPIScheduledStatusParams* tuba_api_scheduled_status_params_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_text (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_text (TubaAPIScheduledStatusParams* self,
                                                const gchar* value);
VALA_EXTERN TubaAPIScheduledStatusParamsPoll* tuba_api_scheduled_status_params_get_poll (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_poll (TubaAPIScheduledStatusParams* self,
                                                TubaAPIScheduledStatusParamsPoll* value);
VALA_EXTERN GeeArrayList* tuba_api_scheduled_status_params_get_media_ids (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_media_ids (TubaAPIScheduledStatusParams* self,
                                                     GeeArrayList* value);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_get_sensitive (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_sensitive (TubaAPIScheduledStatusParams* self,
                                                     gboolean value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_spoiler_text (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_spoiler_text (TubaAPIScheduledStatusParams* self,
                                                        const gchar* value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_visibility (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_visibility (TubaAPIScheduledStatusParams* self,
                                                      const gchar* value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_language (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_language (TubaAPIScheduledStatusParams* self,
                                                    const gchar* value);
VALA_EXTERN gint64 tuba_api_scheduled_status_params_get_in_reply_to_id (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_in_reply_to_id (TubaAPIScheduledStatusParams* self,
                                                          gint64 value);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_get_local_only (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_local_only (TubaAPIScheduledStatusParams* self,
                                                      gboolean value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_quoted_status_id (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_quoted_status_id (TubaAPIScheduledStatusParams* self,
                                                            const gchar* value);
VALA_EXTERN const gchar* tuba_api_scheduled_status_params_get_quote_approval_policy (TubaAPIScheduledStatusParams* self);
VALA_EXTERN void tuba_api_scheduled_status_params_set_quote_approval_policy (TubaAPIScheduledStatusParams* self,
                                                                 const gchar* value);
static GType tuba_api_scheduled_status_params_poll_real_deserialize_array_type (TubaEntity* base,
                                                                         const gchar* prop);
VALA_EXTERN TubaAPIScheduledStatusParamsPoll* tuba_api_scheduled_status_params_poll_new (void);
VALA_EXTERN TubaAPIScheduledStatusParamsPoll* tuba_api_scheduled_status_params_poll_construct (GType object_type);
VALA_EXTERN GeeArrayList* tuba_api_scheduled_status_params_poll_get_options (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN void tuba_api_scheduled_status_params_poll_set_options (TubaAPIScheduledStatusParamsPoll* self,
                                                        GeeArrayList* value);
VALA_EXTERN gint64 tuba_api_scheduled_status_params_poll_get_expires_in (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN void tuba_api_scheduled_status_params_poll_set_expires_in (TubaAPIScheduledStatusParamsPoll* self,
                                                           gint64 value);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_poll_get_multiple (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN void tuba_api_scheduled_status_params_poll_set_multiple (TubaAPIScheduledStatusParamsPoll* self,
                                                         gboolean value);
VALA_EXTERN gboolean tuba_api_scheduled_status_params_poll_get_hide_totals (TubaAPIScheduledStatusParamsPoll* self);
VALA_EXTERN void tuba_api_scheduled_status_params_poll_set_hide_totals (TubaAPIScheduledStatusParamsPoll* self,
                                                            gboolean value);
static void tuba_api_scheduled_status_params_poll_finalize (GObject * obj);
static GType tuba_api_scheduled_status_params_poll_get_type_once (void);
static void _vala_tuba_api_scheduled_status_params_poll_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec);
static void _vala_tuba_api_scheduled_status_params_poll_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec);
static void tuba_api_scheduled_status_params_finalize (GObject * obj);
static GType tuba_api_scheduled_status_params_get_type_once (void);
static void _vala_tuba_api_scheduled_status_params_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec);
static void _vala_tuba_api_scheduled_status_params_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
static void tuba_api_scheduled_status_finalize (GObject * obj);
static GType tuba_api_scheduled_status_get_type_once (void);
static void _vala_tuba_api_scheduled_status_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec);
static void _vala_tuba_api_scheduled_status_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec);

static inline gpointer
tuba_api_scheduled_status_get_instance_private (TubaAPIScheduledStatus* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIScheduledStatus_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIScheduledStatus*
tuba_api_scheduled_status_from (JsonNode* node,
                                GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIScheduledStatus* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIScheduledStatus* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_SCHEDULED_STATUS, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_SCHEDULED_STATUS (_tmp0_) ? ((TubaAPIScheduledStatus*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

static GType
tuba_api_scheduled_status_real_deserialize_array_type (TubaEntity* base,
                                                       const gchar* prop)
{
	TubaAPIScheduledStatus * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIScheduledStatus*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("media-attachments")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_ATTACHMENT;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_scheduled_status_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static GtkWidget*
tuba_api_scheduled_status_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIScheduledStatus * self;
	TubaWidgetsScheduledStatus* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIScheduledStatus*) base;
	_tmp0_ = tuba_widgets_scheduled_status_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

TubaAPIScheduledStatus*
tuba_api_scheduled_status_construct (GType object_type)
{
	TubaAPIScheduledStatus * self = NULL;
	self = (TubaAPIScheduledStatus*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIScheduledStatus*
tuba_api_scheduled_status_new (void)
{
	return tuba_api_scheduled_status_construct (TUBA_API_TYPE_SCHEDULED_STATUS);
}

const gchar*
tuba_api_scheduled_status_get_id (TubaAPIScheduledStatus* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_set_id (TubaAPIScheduledStatus* self,
                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_get_scheduled_at (TubaAPIScheduledStatus* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_scheduled_at;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_set_scheduled_at (TubaAPIScheduledStatus* self,
                                            const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_get_scheduled_at (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_scheduled_at);
		self->priv->_scheduled_at = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_scheduled_status_get_media_attachments (TubaAPIScheduledStatus* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_media_attachments;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_set_media_attachments (TubaAPIScheduledStatus* self,
                                                 GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_get_media_attachments (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_media_attachments);
		self->priv->_media_attachments = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY]);
	}
}

TubaAPIScheduledStatusParams*
tuba_api_scheduled_status_get_props (TubaAPIScheduledStatus* self)
{
	TubaAPIScheduledStatusParams* result;
	TubaAPIScheduledStatusParams* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_props;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_set_props (TubaAPIScheduledStatus* self,
                                     TubaAPIScheduledStatusParams* value)
{
	TubaAPIScheduledStatusParams* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_get_props (self);
	if (old_value != value) {
		TubaAPIScheduledStatusParams* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_props);
		self->priv->_props = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY]);
	}
}

static inline gpointer
tuba_api_scheduled_status_params_get_instance_private (TubaAPIScheduledStatusParams* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIScheduledStatusParams_private_offset);
}

static GType
tuba_api_scheduled_status_params_real_deserialize_array_type (TubaEntity* base,
                                                              const gchar* prop)
{
	TubaAPIScheduledStatusParams * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIScheduledStatusParams*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("media-ids")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_scheduled_status_params_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

TubaAPIScheduledStatusParams*
tuba_api_scheduled_status_params_construct (GType object_type)
{
	TubaAPIScheduledStatusParams * self = NULL;
	self = (TubaAPIScheduledStatusParams*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIScheduledStatusParams*
tuba_api_scheduled_status_params_new (void)
{
	return tuba_api_scheduled_status_params_construct (TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS);
}

const gchar*
tuba_api_scheduled_status_params_get_text (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_text;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_text (TubaAPIScheduledStatusParams* self,
                                           const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_text);
		self->priv->_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY]);
	}
}

TubaAPIScheduledStatusParamsPoll*
tuba_api_scheduled_status_params_get_poll (TubaAPIScheduledStatusParams* self)
{
	TubaAPIScheduledStatusParamsPoll* result;
	TubaAPIScheduledStatusParamsPoll* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_poll;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_poll (TubaAPIScheduledStatusParams* self,
                                           TubaAPIScheduledStatusParamsPoll* value)
{
	TubaAPIScheduledStatusParamsPoll* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_poll (self);
	if (old_value != value) {
		TubaAPIScheduledStatusParamsPoll* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_poll);
		self->priv->_poll = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_scheduled_status_params_get_media_ids (TubaAPIScheduledStatusParams* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_media_ids;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_media_ids (TubaAPIScheduledStatusParams* self,
                                                GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_media_ids (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_media_ids);
		self->priv->_media_ids = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY]);
	}
}

gboolean
tuba_api_scheduled_status_params_get_sensitive (TubaAPIScheduledStatusParams* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_sensitive;
	return result;
}

void
tuba_api_scheduled_status_params_set_sensitive (TubaAPIScheduledStatusParams* self,
                                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_sensitive (self);
	if (old_value != value) {
		self->priv->_sensitive = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_params_get_spoiler_text (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_spoiler_text;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_spoiler_text (TubaAPIScheduledStatusParams* self,
                                                   const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_spoiler_text (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_spoiler_text);
		self->priv->_spoiler_text = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_params_get_visibility (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_visibility;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_visibility (TubaAPIScheduledStatusParams* self,
                                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_visibility (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_visibility);
		self->priv->_visibility = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_params_get_language (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_language;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_language (TubaAPIScheduledStatusParams* self,
                                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_language (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_language);
		self->priv->_language = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY]);
	}
}

gint64
tuba_api_scheduled_status_params_get_in_reply_to_id (TubaAPIScheduledStatusParams* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_in_reply_to_id;
	return result;
}

void
tuba_api_scheduled_status_params_set_in_reply_to_id (TubaAPIScheduledStatusParams* self,
                                                     gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_in_reply_to_id (self);
	if (old_value != value) {
		self->priv->_in_reply_to_id = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY]);
	}
}

gboolean
tuba_api_scheduled_status_params_get_local_only (TubaAPIScheduledStatusParams* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_local_only;
	return result;
}

void
tuba_api_scheduled_status_params_set_local_only (TubaAPIScheduledStatusParams* self,
                                                 gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_local_only (self);
	if (old_value != value) {
		self->priv->_local_only = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_params_get_quoted_status_id (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_quoted_status_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_quoted_status_id (TubaAPIScheduledStatusParams* self,
                                                       const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_quoted_status_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_quoted_status_id);
		self->priv->_quoted_status_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_scheduled_status_params_get_quote_approval_policy (TubaAPIScheduledStatusParams* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_quote_approval_policy;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_set_quote_approval_policy (TubaAPIScheduledStatusParams* self,
                                                            const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_get_quote_approval_policy (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_quote_approval_policy);
		self->priv->_quote_approval_policy = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY]);
	}
}

static inline gpointer
tuba_api_scheduled_status_params_poll_get_instance_private (TubaAPIScheduledStatusParamsPoll* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIScheduledStatusParamsPoll_private_offset);
}

static GType
tuba_api_scheduled_status_params_poll_real_deserialize_array_type (TubaEntity* base,
                                                                   const gchar* prop)
{
	TubaAPIScheduledStatusParamsPoll * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIScheduledStatusParamsPoll*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("options")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_scheduled_status_params_poll_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

TubaAPIScheduledStatusParamsPoll*
tuba_api_scheduled_status_params_poll_construct (GType object_type)
{
	TubaAPIScheduledStatusParamsPoll * self = NULL;
	self = (TubaAPIScheduledStatusParamsPoll*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIScheduledStatusParamsPoll*
tuba_api_scheduled_status_params_poll_new (void)
{
	return tuba_api_scheduled_status_params_poll_construct (TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL);
}

GeeArrayList*
tuba_api_scheduled_status_params_poll_get_options (TubaAPIScheduledStatusParamsPoll* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_options;
	result = _tmp0_;
	return result;
}

void
tuba_api_scheduled_status_params_poll_set_options (TubaAPIScheduledStatusParamsPoll* self,
                                                   GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_poll_get_options (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_options);
		self->priv->_options = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY]);
	}
}

gint64
tuba_api_scheduled_status_params_poll_get_expires_in (TubaAPIScheduledStatusParamsPoll* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_expires_in;
	return result;
}

void
tuba_api_scheduled_status_params_poll_set_expires_in (TubaAPIScheduledStatusParamsPoll* self,
                                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_poll_get_expires_in (self);
	if (old_value != value) {
		self->priv->_expires_in = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY]);
	}
}

gboolean
tuba_api_scheduled_status_params_poll_get_multiple (TubaAPIScheduledStatusParamsPoll* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_multiple;
	return result;
}

void
tuba_api_scheduled_status_params_poll_set_multiple (TubaAPIScheduledStatusParamsPoll* self,
                                                    gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_poll_get_multiple (self);
	if (old_value != value) {
		self->priv->_multiple = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY]);
	}
}

gboolean
tuba_api_scheduled_status_params_poll_get_hide_totals (TubaAPIScheduledStatusParamsPoll* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_hide_totals;
	return result;
}

void
tuba_api_scheduled_status_params_poll_set_hide_totals (TubaAPIScheduledStatusParamsPoll* self,
                                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_scheduled_status_params_poll_get_hide_totals (self);
	if (old_value != value) {
		self->priv->_hide_totals = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY]);
	}
}

static void
tuba_api_scheduled_status_params_poll_class_init (TubaAPIScheduledStatusParamsPollClass * klass,
                                                  gpointer klass_data)
{
	tuba_api_scheduled_status_params_poll_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIScheduledStatusParamsPoll_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_scheduled_status_params_poll_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_scheduled_status_params_poll_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_scheduled_status_params_poll_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_scheduled_status_params_poll_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY] = g_param_spec_object ("options", "options", "options", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY] = g_param_spec_int64 ("expires-in", "expires-in", "expires-in", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY] = g_param_spec_boolean ("multiple", "multiple", "multiple", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY, tuba_api_scheduled_status_params_poll_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY] = g_param_spec_boolean ("hide-totals", "hide-totals", "hide-totals", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_scheduled_status_params_poll_instance_init (TubaAPIScheduledStatusParamsPoll * self,
                                                     gpointer klass)
{
	GeeArrayList* _tmp0_;
	self->priv = tuba_api_scheduled_status_params_poll_get_instance_private (self);
	_tmp0_ = gee_array_list_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, NULL, NULL, NULL);
	self->priv->_options = _tmp0_;
	self->priv->_expires_in = (gint64) 0;
	self->priv->_multiple = FALSE;
	self->priv->_hide_totals = FALSE;
}

static void
tuba_api_scheduled_status_params_poll_finalize (GObject * obj)
{
	TubaAPIScheduledStatusParamsPoll * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPoll);
	_g_object_unref0 (self->priv->_options);
	G_OBJECT_CLASS (tuba_api_scheduled_status_params_poll_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_scheduled_status_params_poll_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIScheduledStatusParamsPollClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_scheduled_status_params_poll_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIScheduledStatusParamsPoll), 0, (GInstanceInitFunc) tuba_api_scheduled_status_params_poll_instance_init, NULL };
	GType tuba_api_scheduled_status_params_poll_type_id;
	tuba_api_scheduled_status_params_poll_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIScheduledStatusParamsPoll", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIScheduledStatusParamsPoll_private_offset = g_type_add_instance_private (tuba_api_scheduled_status_params_poll_type_id, sizeof (TubaAPIScheduledStatusParamsPollPrivate));
	return tuba_api_scheduled_status_params_poll_type_id;
}

GType
tuba_api_scheduled_status_params_poll_get_type (void)
{
	static GType tuba_api_scheduled_status_params_poll_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_scheduled_status_params_poll_type_id__once)) {
		GType tuba_api_scheduled_status_params_poll_type_id;
		tuba_api_scheduled_status_params_poll_type_id = tuba_api_scheduled_status_params_poll_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_scheduled_status_params_poll_type_id__once, tuba_api_scheduled_status_params_poll_type_id);
	}
	return tuba_api_scheduled_status_params_poll_type_id__once;
}

static void
_vala_tuba_api_scheduled_status_params_poll_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec)
{
	TubaAPIScheduledStatusParamsPoll * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPoll);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY:
		g_value_set_object (value, tuba_api_scheduled_status_params_poll_get_options (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY:
		g_value_set_int64 (value, tuba_api_scheduled_status_params_poll_get_expires_in (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY:
		g_value_set_boolean (value, tuba_api_scheduled_status_params_poll_get_multiple (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY:
		g_value_set_boolean (value, tuba_api_scheduled_status_params_poll_get_hide_totals (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_scheduled_status_params_poll_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec)
{
	TubaAPIScheduledStatusParamsPoll * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, TubaAPIScheduledStatusParamsPoll);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_OPTIONS_PROPERTY:
		tuba_api_scheduled_status_params_poll_set_options (self, g_value_get_object (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_EXPIRES_IN_PROPERTY:
		tuba_api_scheduled_status_params_poll_set_expires_in (self, g_value_get_int64 (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_MULTIPLE_PROPERTY:
		tuba_api_scheduled_status_params_poll_set_multiple (self, g_value_get_boolean (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_HIDE_TOTALS_PROPERTY:
		tuba_api_scheduled_status_params_poll_set_hide_totals (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_scheduled_status_params_class_init (TubaAPIScheduledStatusParamsClass * klass,
                                             gpointer klass_data)
{
	tuba_api_scheduled_status_params_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIScheduledStatusParams_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_scheduled_status_params_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_scheduled_status_params_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_scheduled_status_params_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_scheduled_status_params_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY] = g_param_spec_string ("text", "text", "text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY] = g_param_spec_object ("poll", "poll", "poll", TUBA_API_SCHEDULED_STATUS_PARAMS_TYPE_POLL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY] = g_param_spec_object ("media-ids", "media-ids", "media-ids", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY] = g_param_spec_boolean ("sensitive", "sensitive", "sensitive", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY] = g_param_spec_string ("spoiler-text", "spoiler-text", "spoiler-text", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY] = g_param_spec_string ("visibility", "visibility", "visibility", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY] = g_param_spec_string ("language", "language", "language", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY] = g_param_spec_int64 ("in-reply-to-id", "in-reply-to-id", "in-reply-to-id", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY] = g_param_spec_boolean ("local-only", "local-only", "local-only", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY] = g_param_spec_string ("quoted-status-id", "quoted-status-id", "quoted-status-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY, tuba_api_scheduled_status_params_properties[TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY] = g_param_spec_string ("quote-approval-policy", "quote-approval-policy", "quote-approval-policy", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_scheduled_status_params_instance_init (TubaAPIScheduledStatusParams * self,
                                                gpointer klass)
{
	TubaSettings* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	self->priv = tuba_api_scheduled_status_params_get_instance_private (self);
	self->priv->_sensitive = FALSE;
	self->priv->_spoiler_text = NULL;
	self->priv->_language = NULL;
	self->priv->_in_reply_to_id = (gint64) 0;
	self->priv->_local_only = FALSE;
	self->priv->_quoted_status_id = NULL;
	_tmp0_ = tuba_settings;
	_tmp1_ = tuba_settings_get_default_quote_policy (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strdup (_tmp2_);
	self->priv->_quote_approval_policy = _tmp3_;
}

static void
tuba_api_scheduled_status_params_finalize (GObject * obj)
{
	TubaAPIScheduledStatusParams * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParams);
	_g_free0 (self->priv->_text);
	_g_object_unref0 (self->priv->_poll);
	_g_object_unref0 (self->priv->_media_ids);
	_g_free0 (self->priv->_spoiler_text);
	_g_free0 (self->priv->_visibility);
	_g_free0 (self->priv->_language);
	_g_free0 (self->priv->_quoted_status_id);
	_g_free0 (self->priv->_quote_approval_policy);
	G_OBJECT_CLASS (tuba_api_scheduled_status_params_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_scheduled_status_params_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIScheduledStatusParamsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_scheduled_status_params_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIScheduledStatusParams), 0, (GInstanceInitFunc) tuba_api_scheduled_status_params_instance_init, NULL };
	GType tuba_api_scheduled_status_params_type_id;
	tuba_api_scheduled_status_params_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIScheduledStatusParams", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIScheduledStatusParams_private_offset = g_type_add_instance_private (tuba_api_scheduled_status_params_type_id, sizeof (TubaAPIScheduledStatusParamsPrivate));
	return tuba_api_scheduled_status_params_type_id;
}

GType
tuba_api_scheduled_status_params_get_type (void)
{
	static GType tuba_api_scheduled_status_params_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_scheduled_status_params_type_id__once)) {
		GType tuba_api_scheduled_status_params_type_id;
		tuba_api_scheduled_status_params_type_id = tuba_api_scheduled_status_params_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_scheduled_status_params_type_id__once, tuba_api_scheduled_status_params_type_id);
	}
	return tuba_api_scheduled_status_params_type_id__once;
}

static void
_vala_tuba_api_scheduled_status_params_get_property (GObject * object,
                                                     guint property_id,
                                                     GValue * value,
                                                     GParamSpec * pspec)
{
	TubaAPIScheduledStatusParams * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParams);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_text (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY:
		g_value_set_object (value, tuba_api_scheduled_status_params_get_poll (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY:
		g_value_set_object (value, tuba_api_scheduled_status_params_get_media_ids (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY:
		g_value_set_boolean (value, tuba_api_scheduled_status_params_get_sensitive (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_spoiler_text (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_visibility (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_language (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY:
		g_value_set_int64 (value, tuba_api_scheduled_status_params_get_in_reply_to_id (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY:
		g_value_set_boolean (value, tuba_api_scheduled_status_params_get_local_only (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_quoted_status_id (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_params_get_quote_approval_policy (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_scheduled_status_params_set_property (GObject * object,
                                                     guint property_id,
                                                     const GValue * value,
                                                     GParamSpec * pspec)
{
	TubaAPIScheduledStatusParams * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, TubaAPIScheduledStatusParams);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_PARAMS_TEXT_PROPERTY:
		tuba_api_scheduled_status_params_set_text (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_POLL_PROPERTY:
		tuba_api_scheduled_status_params_set_poll (self, g_value_get_object (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_MEDIA_IDS_PROPERTY:
		tuba_api_scheduled_status_params_set_media_ids (self, g_value_get_object (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_SENSITIVE_PROPERTY:
		tuba_api_scheduled_status_params_set_sensitive (self, g_value_get_boolean (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_SPOILER_TEXT_PROPERTY:
		tuba_api_scheduled_status_params_set_spoiler_text (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_VISIBILITY_PROPERTY:
		tuba_api_scheduled_status_params_set_visibility (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_LANGUAGE_PROPERTY:
		tuba_api_scheduled_status_params_set_language (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_IN_REPLY_TO_ID_PROPERTY:
		tuba_api_scheduled_status_params_set_in_reply_to_id (self, g_value_get_int64 (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_LOCAL_ONLY_PROPERTY:
		tuba_api_scheduled_status_params_set_local_only (self, g_value_get_boolean (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTED_STATUS_ID_PROPERTY:
		tuba_api_scheduled_status_params_set_quoted_status_id (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PARAMS_QUOTE_APPROVAL_POLICY_PROPERTY:
		tuba_api_scheduled_status_params_set_quote_approval_policy (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_scheduled_status_class_init (TubaAPIScheduledStatusClass * klass,
                                      gpointer klass_data)
{
	tuba_api_scheduled_status_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIScheduledStatus_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_scheduled_status_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_scheduled_status_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_scheduled_status_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_scheduled_status_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_ID_PROPERTY, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY] = g_param_spec_string ("scheduled-at", "scheduled-at", "scheduled-at", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY] = g_param_spec_object ("media-attachments", "media-attachments", "media-attachments", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY, tuba_api_scheduled_status_properties[TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY] = g_param_spec_object ("props", "props", "props", TUBA_API_SCHEDULED_STATUS_TYPE_PARAMS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_scheduled_status_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                            gpointer iface_data)
{
	tuba_api_scheduled_status_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_scheduled_status_real_to_widget;
}

static void
tuba_api_scheduled_status_instance_init (TubaAPIScheduledStatus * self,
                                         gpointer klass)
{
	self->priv = tuba_api_scheduled_status_get_instance_private (self);
	self->priv->_media_attachments = NULL;
}

static void
tuba_api_scheduled_status_finalize (GObject * obj)
{
	TubaAPIScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_scheduled_at);
	_g_object_unref0 (self->priv->_media_attachments);
	_g_object_unref0 (self->priv->_props);
	G_OBJECT_CLASS (tuba_api_scheduled_status_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_scheduled_status_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIScheduledStatusClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_scheduled_status_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIScheduledStatus), 0, (GInstanceInitFunc) tuba_api_scheduled_status_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_scheduled_status_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_scheduled_status_type_id;
	tuba_api_scheduled_status_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIScheduledStatus", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_scheduled_status_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIScheduledStatus_private_offset = g_type_add_instance_private (tuba_api_scheduled_status_type_id, sizeof (TubaAPIScheduledStatusPrivate));
	return tuba_api_scheduled_status_type_id;
}

GType
tuba_api_scheduled_status_get_type (void)
{
	static GType tuba_api_scheduled_status_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_scheduled_status_type_id__once)) {
		GType tuba_api_scheduled_status_type_id;
		tuba_api_scheduled_status_type_id = tuba_api_scheduled_status_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_scheduled_status_type_id__once, tuba_api_scheduled_status_type_id);
	}
	return tuba_api_scheduled_status_type_id__once;
}

static void
_vala_tuba_api_scheduled_status_get_property (GObject * object,
                                              guint property_id,
                                              GValue * value,
                                              GParamSpec * pspec)
{
	TubaAPIScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_ID_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_get_id (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY:
		g_value_set_string (value, tuba_api_scheduled_status_get_scheduled_at (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY:
		g_value_set_object (value, tuba_api_scheduled_status_get_media_attachments (self));
		break;
		case TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY:
		g_value_set_object (value, tuba_api_scheduled_status_get_props (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_scheduled_status_set_property (GObject * object,
                                              guint property_id,
                                              const GValue * value,
                                              GParamSpec * pspec)
{
	TubaAPIScheduledStatus * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus);
	switch (property_id) {
		case TUBA_API_SCHEDULED_STATUS_ID_PROPERTY:
		tuba_api_scheduled_status_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_SCHEDULED_AT_PROPERTY:
		tuba_api_scheduled_status_set_scheduled_at (self, g_value_get_string (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_MEDIA_ATTACHMENTS_PROPERTY:
		tuba_api_scheduled_status_set_media_attachments (self, g_value_get_object (value));
		break;
		case TUBA_API_SCHEDULED_STATUS_PROPS_PROPERTY:
		tuba_api_scheduled_status_set_props (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

