/* File.c generated by valac 0.56.19, the Vala compiler
 * generated from File.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_ICESHRIMP_TYPE_FILE (tuba_api_iceshrimp_file_get_type ())
#define TUBA_API_ICESHRIMP_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFile))
#define TUBA_API_ICESHRIMP_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFileClass))
#define TUBA_API_ICESHRIMP_IS_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ICESHRIMP_TYPE_FILE))
#define TUBA_API_ICESHRIMP_IS_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ICESHRIMP_TYPE_FILE))
#define TUBA_API_ICESHRIMP_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFileClass))

typedef struct _TubaAPIIceshrimpFile TubaAPIIceshrimpFile;
typedef struct _TubaAPIIceshrimpFileClass TubaAPIIceshrimpFileClass;
typedef struct _TubaAPIIceshrimpFilePrivate TubaAPIIceshrimpFilePrivate;
enum  {
	TUBA_API_ICESHRIMP_FILE_0_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_ID_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_URL_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY,
	TUBA_API_ICESHRIMP_FILE_NUM_PROPERTIES
};
static GParamSpec* tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIIceshrimpFile {
	TubaEntity parent_instance;
	TubaAPIIceshrimpFilePrivate * priv;
};

struct _TubaAPIIceshrimpFileClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIIceshrimpFilePrivate {
	gchar* _id;
	gchar* _url;
	gchar* _thumbnailUrl;
	gchar* _filename;
	gchar* _contentType;
	gboolean _sensitive;
	gchar* _description;
	gboolean _isAvatar;
	gboolean _isBanner;
};

static gint TubaAPIIceshrimpFile_private_offset;
static gpointer tuba_api_iceshrimp_file_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_iceshrimp_file_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIIceshrimpFile, g_object_unref)
VALA_EXTERN TubaAPIIceshrimpFile* tuba_api_iceshrimp_file_new (void);
VALA_EXTERN TubaAPIIceshrimpFile* tuba_api_iceshrimp_file_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_id (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_id (TubaAPIIceshrimpFile* self,
                                     const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_url (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_url (TubaAPIIceshrimpFile* self,
                                      const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_thumbnailUrl (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_thumbnailUrl (TubaAPIIceshrimpFile* self,
                                               const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_filename (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_filename (TubaAPIIceshrimpFile* self,
                                           const gchar* value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_contentType (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_contentType (TubaAPIIceshrimpFile* self,
                                              const gchar* value);
VALA_EXTERN gboolean tuba_api_iceshrimp_file_get_sensitive (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_sensitive (TubaAPIIceshrimpFile* self,
                                            gboolean value);
VALA_EXTERN const gchar* tuba_api_iceshrimp_file_get_description (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_description (TubaAPIIceshrimpFile* self,
                                              const gchar* value);
VALA_EXTERN gboolean tuba_api_iceshrimp_file_get_isAvatar (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_isAvatar (TubaAPIIceshrimpFile* self,
                                           gboolean value);
VALA_EXTERN gboolean tuba_api_iceshrimp_file_get_isBanner (TubaAPIIceshrimpFile* self);
VALA_EXTERN void tuba_api_iceshrimp_file_set_isBanner (TubaAPIIceshrimpFile* self,
                                           gboolean value);
static void tuba_api_iceshrimp_file_finalize (GObject * obj);
static GType tuba_api_iceshrimp_file_get_type_once (void);
static void _vala_tuba_api_iceshrimp_file_get_property (GObject * object,
                                                 guint property_id,
                                                 GValue * value,
                                                 GParamSpec * pspec);
static void _vala_tuba_api_iceshrimp_file_set_property (GObject * object,
                                                 guint property_id,
                                                 const GValue * value,
                                                 GParamSpec * pspec);

static inline gpointer
tuba_api_iceshrimp_file_get_instance_private (TubaAPIIceshrimpFile* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIIceshrimpFile_private_offset);
}

TubaAPIIceshrimpFile*
tuba_api_iceshrimp_file_construct (GType object_type)
{
	TubaAPIIceshrimpFile * self = NULL;
	self = (TubaAPIIceshrimpFile*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIIceshrimpFile*
tuba_api_iceshrimp_file_new (void)
{
	return tuba_api_iceshrimp_file_construct (TUBA_API_ICESHRIMP_TYPE_FILE);
}

const gchar*
tuba_api_iceshrimp_file_get_id (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_id (TubaAPIIceshrimpFile* self,
                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_file_get_url (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_url;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_url (TubaAPIIceshrimpFile* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_url (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_url);
		self->priv->_url = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_URL_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_file_get_thumbnailUrl (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_thumbnailUrl;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_thumbnailUrl (TubaAPIIceshrimpFile* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_thumbnailUrl (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_thumbnailUrl);
		self->priv->_thumbnailUrl = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_file_get_filename (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_filename;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_filename (TubaAPIIceshrimpFile* self,
                                      const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_filename (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_filename);
		self->priv->_filename = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_file_get_contentType (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_contentType;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_contentType (TubaAPIIceshrimpFile* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_contentType (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_contentType);
		self->priv->_contentType = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY]);
	}
}

gboolean
tuba_api_iceshrimp_file_get_sensitive (TubaAPIIceshrimpFile* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_sensitive;
	return result;
}

void
tuba_api_iceshrimp_file_set_sensitive (TubaAPIIceshrimpFile* self,
                                       gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_sensitive (self);
	if (old_value != value) {
		self->priv->_sensitive = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY]);
	}
}

const gchar*
tuba_api_iceshrimp_file_get_description (TubaAPIIceshrimpFile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_description;
	result = _tmp0_;
	return result;
}

void
tuba_api_iceshrimp_file_set_description (TubaAPIIceshrimpFile* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_description (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_description);
		self->priv->_description = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY]);
	}
}

gboolean
tuba_api_iceshrimp_file_get_isAvatar (TubaAPIIceshrimpFile* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_isAvatar;
	return result;
}

void
tuba_api_iceshrimp_file_set_isAvatar (TubaAPIIceshrimpFile* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_isAvatar (self);
	if (old_value != value) {
		self->priv->_isAvatar = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY]);
	}
}

gboolean
tuba_api_iceshrimp_file_get_isBanner (TubaAPIIceshrimpFile* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_isBanner;
	return result;
}

void
tuba_api_iceshrimp_file_set_isBanner (TubaAPIIceshrimpFile* self,
                                      gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_iceshrimp_file_get_isBanner (self);
	if (old_value != value) {
		self->priv->_isBanner = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY]);
	}
}

static void
tuba_api_iceshrimp_file_class_init (TubaAPIIceshrimpFileClass * klass,
                                    gpointer klass_data)
{
	tuba_api_iceshrimp_file_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIIceshrimpFile_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_iceshrimp_file_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_iceshrimp_file_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_iceshrimp_file_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_ID_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_URL_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_URL_PROPERTY] = g_param_spec_string ("url", "url", "url", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY] = g_param_spec_string ("thumbnailUrl", "thumbnailUrl", "thumbnailUrl", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY] = g_param_spec_string ("filename", "filename", "filename", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY] = g_param_spec_string ("contentType", "contentType", "contentType", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY] = g_param_spec_boolean ("sensitive", "sensitive", "sensitive", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY] = g_param_spec_string ("description", "description", "description", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY] = g_param_spec_boolean ("isAvatar", "isAvatar", "isAvatar", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY, tuba_api_iceshrimp_file_properties[TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY] = g_param_spec_boolean ("isBanner", "isBanner", "isBanner", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_iceshrimp_file_instance_init (TubaAPIIceshrimpFile * self,
                                       gpointer klass)
{
	self->priv = tuba_api_iceshrimp_file_get_instance_private (self);
}

static void
tuba_api_iceshrimp_file_finalize (GObject * obj)
{
	TubaAPIIceshrimpFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFile);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_url);
	_g_free0 (self->priv->_thumbnailUrl);
	_g_free0 (self->priv->_filename);
	_g_free0 (self->priv->_contentType);
	_g_free0 (self->priv->_description);
	G_OBJECT_CLASS (tuba_api_iceshrimp_file_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_iceshrimp_file_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIIceshrimpFileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_iceshrimp_file_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIIceshrimpFile), 0, (GInstanceInitFunc) tuba_api_iceshrimp_file_instance_init, NULL };
	GType tuba_api_iceshrimp_file_type_id;
	tuba_api_iceshrimp_file_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIIceshrimpFile", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIIceshrimpFile_private_offset = g_type_add_instance_private (tuba_api_iceshrimp_file_type_id, sizeof (TubaAPIIceshrimpFilePrivate));
	return tuba_api_iceshrimp_file_type_id;
}

GType
tuba_api_iceshrimp_file_get_type (void)
{
	static GType tuba_api_iceshrimp_file_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_iceshrimp_file_type_id__once)) {
		GType tuba_api_iceshrimp_file_type_id;
		tuba_api_iceshrimp_file_type_id = tuba_api_iceshrimp_file_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_iceshrimp_file_type_id__once, tuba_api_iceshrimp_file_type_id);
	}
	return tuba_api_iceshrimp_file_type_id__once;
}

static void
_vala_tuba_api_iceshrimp_file_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec)
{
	TubaAPIIceshrimpFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFile);
	switch (property_id) {
		case TUBA_API_ICESHRIMP_FILE_ID_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_id (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_URL_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_url (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_thumbnailUrl (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_filename (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_contentType (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY:
		g_value_set_boolean (value, tuba_api_iceshrimp_file_get_sensitive (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY:
		g_value_set_string (value, tuba_api_iceshrimp_file_get_description (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY:
		g_value_set_boolean (value, tuba_api_iceshrimp_file_get_isAvatar (self));
		break;
		case TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY:
		g_value_set_boolean (value, tuba_api_iceshrimp_file_get_isBanner (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_iceshrimp_file_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec)
{
	TubaAPIIceshrimpFile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ICESHRIMP_TYPE_FILE, TubaAPIIceshrimpFile);
	switch (property_id) {
		case TUBA_API_ICESHRIMP_FILE_ID_PROPERTY:
		tuba_api_iceshrimp_file_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_URL_PROPERTY:
		tuba_api_iceshrimp_file_set_url (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_THUMBNAIL_URL_PROPERTY:
		tuba_api_iceshrimp_file_set_thumbnailUrl (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_FILENAME_PROPERTY:
		tuba_api_iceshrimp_file_set_filename (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_CONTENT_TYPE_PROPERTY:
		tuba_api_iceshrimp_file_set_contentType (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_SENSITIVE_PROPERTY:
		tuba_api_iceshrimp_file_set_sensitive (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_DESCRIPTION_PROPERTY:
		tuba_api_iceshrimp_file_set_description (self, g_value_get_string (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_IS_AVATAR_PROPERTY:
		tuba_api_iceshrimp_file_set_isAvatar (self, g_value_get_boolean (value));
		break;
		case TUBA_API_ICESHRIMP_FILE_IS_BANNER_PROPERTY:
		tuba_api_iceshrimp_file_set_isBanner (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

