/* ScheduledStatuses.c generated by valac 0.56.19, the Vala compiler
 * generated from ScheduledStatuses.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>

#define TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR (2000 + 3000)
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_SCHEDULED_STATUSES (tuba_views_scheduled_statuses_get_type ())
#define TUBA_VIEWS_SCHEDULED_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_SCHEDULED_STATUSES, TubaViewsScheduledStatuses))
#define TUBA_VIEWS_SCHEDULED_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_SCHEDULED_STATUSES, TubaViewsScheduledStatusesClass))
#define TUBA_VIEWS_IS_SCHEDULED_STATUSES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_SCHEDULED_STATUSES))
#define TUBA_VIEWS_IS_SCHEDULED_STATUSES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_SCHEDULED_STATUSES))
#define TUBA_VIEWS_SCHEDULED_STATUSES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_SCHEDULED_STATUSES, TubaViewsScheduledStatusesClass))

typedef struct _TubaViewsScheduledStatuses TubaViewsScheduledStatuses;
typedef struct _TubaViewsScheduledStatusesClass TubaViewsScheduledStatusesClass;
typedef struct _TubaViewsScheduledStatusesPrivate TubaViewsScheduledStatusesPrivate;
enum  {
	TUBA_VIEWS_SCHEDULED_STATUSES_0_PROPERTY,
	TUBA_VIEWS_SCHEDULED_STATUSES_NUM_PROPERTIES
};
static GParamSpec* tuba_views_scheduled_statuses_properties[TUBA_VIEWS_SCHEDULED_STATUSES_NUM_PROPERTIES];

#define TUBA_WIDGETS_TYPE_SCHEDULED_STATUS (tuba_widgets_scheduled_status_get_type ())
#define TUBA_WIDGETS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatus))
#define TUBA_WIDGETS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS))
#define TUBA_WIDGETS_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_SCHEDULED_STATUS, TubaWidgetsScheduledStatusClass))

typedef struct _TubaWidgetsScheduledStatus TubaWidgetsScheduledStatus;
typedef struct _TubaWidgetsScheduledStatusClass TubaWidgetsScheduledStatusClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_TYPE_SCHEDULED_STATUS (tuba_api_scheduled_status_get_type ())
#define TUBA_API_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus))
#define TUBA_API_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))
#define TUBA_API_IS_SCHEDULED_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_IS_SCHEDULED_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SCHEDULED_STATUS))
#define TUBA_API_SCHEDULED_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatusClass))

typedef struct _TubaAPIScheduledStatus TubaAPIScheduledStatus;
typedef struct _TubaAPIScheduledStatusClass TubaAPIScheduledStatusClass;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsScheduledStatuses {
	TubaViewsTimeline parent_instance;
	TubaViewsScheduledStatusesPrivate * priv;
};

struct _TubaViewsScheduledStatusesClass {
	TubaViewsTimelineClass parent_class;
};

static gpointer tuba_views_scheduled_statuses_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_scheduled_statuses_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsScheduledStatuses, g_object_unref)
VALA_EXTERN GtkWidget* tuba_views_content_base_on_create_model_widget (TubaViewsContentBase* self,
                                                           GObject* obj);
VALA_EXTERN gboolean tuba_views_timeline_should_hide (TubaViewsTimeline* self,
                                          TubaEntity* entity);
VALA_EXTERN TubaViewsScheduledStatuses* tuba_views_scheduled_statuses_new (void);
VALA_EXTERN TubaViewsScheduledStatuses* tuba_views_scheduled_statuses_construct (GType object_type);
static GtkWidget* tuba_views_scheduled_statuses_real_on_create_model_widget (TubaViewsContentBase* base,
                                                                      GObject* obj);
VALA_EXTERN GType tuba_widgets_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsScheduledStatus, g_object_unref)
static void tuba_views_scheduled_statuses_on_deleted_scheduled (TubaViewsScheduledStatuses* self,
                                                         const gchar* scheduled_status_id);
static void _tuba_views_scheduled_statuses_on_deleted_scheduled_tuba_widgets_scheduled_status_deleted (TubaWidgetsScheduledStatus* _sender,
                                                                                                const gchar* scheduled_status_id,
                                                                                                gpointer self);
VALA_EXTERN void tuba_views_timeline_refresh_if_mapped (TubaViewsTimeline* self);
static void _tuba_views_timeline_refresh_if_mapped_tuba_widgets_scheduled_status_refresh (TubaWidgetsScheduledStatus* _sender,
                                                                                   gpointer self);
VALA_EXTERN GType tuba_api_scheduled_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIScheduledStatus, g_object_unref)
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_id (TubaAPIScheduledStatus* self);
VALA_EXTERN void tuba_views_timeline_safely_remove (TubaViewsTimeline* self,
                                        gint i);
static gboolean tuba_views_scheduled_statuses_real_should_hide (TubaViewsTimeline* base,
                                                         TubaEntity* entity);
VALA_EXTERN const gchar* tuba_api_scheduled_status_get_scheduled_at (TubaAPIScheduledStatus* self);
static GObject * tuba_views_scheduled_statuses_constructor (GType type,
                                                     guint n_construct_properties,
                                                     GObjectConstructParam * construct_properties);
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
static void _tuba_views_timeline_refresh_if_mapped_tuba_application_refresh_scheduled_statuses (TubaApplication* _sender,
                                                                                         gpointer self);
static GType tuba_views_scheduled_statuses_get_type_once (void);

TubaViewsScheduledStatuses*
tuba_views_scheduled_statuses_construct (GType object_type)
{
	TubaViewsScheduledStatuses * self = NULL;
	self = (TubaViewsScheduledStatuses*) g_object_new (object_type, "url", "/api/v1/scheduled_statuses", "label", _ ("Scheduled Posts"), "icon", "tuba-clock-alt-symbolic", "empty-state-title", _ ("No Scheduled Posts"), "batch-size-min", 20, "allow-nesting", TRUE, "force-at-least-min", TRUE, NULL);
	return self;
}

TubaViewsScheduledStatuses*
tuba_views_scheduled_statuses_new (void)
{
	return tuba_views_scheduled_statuses_construct (TUBA_VIEWS_TYPE_SCHEDULED_STATUSES);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_tuba_views_scheduled_statuses_on_deleted_scheduled_tuba_widgets_scheduled_status_deleted (TubaWidgetsScheduledStatus* _sender,
                                                                                           const gchar* scheduled_status_id,
                                                                                           gpointer self)
{
	tuba_views_scheduled_statuses_on_deleted_scheduled ((TubaViewsScheduledStatuses*) self, scheduled_status_id);
}

static void
_tuba_views_timeline_refresh_if_mapped_tuba_widgets_scheduled_status_refresh (TubaWidgetsScheduledStatus* _sender,
                                                                              gpointer self)
{
	tuba_views_timeline_refresh_if_mapped ((TubaViewsTimeline*) self);
}

static GtkWidget*
tuba_views_scheduled_statuses_real_on_create_model_widget (TubaViewsContentBase* base,
                                                           GObject* obj)
{
	TubaViewsScheduledStatuses * self;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	TubaWidgetsScheduledStatus* widget_scheduled = NULL;
	GtkWidget* _tmp1_;
	TubaWidgetsScheduledStatus* _tmp2_;
	TubaWidgetsScheduledStatus* _tmp3_;
	GtkWidget* result;
	self = (TubaViewsScheduledStatuses*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_views_scheduled_statuses_parent_class)->on_create_model_widget ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline), obj);
	widget = _tmp0_;
	_tmp1_ = widget;
	_tmp2_ = _g_object_ref0 (TUBA_WIDGETS_IS_SCHEDULED_STATUS (_tmp1_) ? ((TubaWidgetsScheduledStatus*) _tmp1_) : NULL);
	widget_scheduled = _tmp2_;
	_tmp3_ = widget_scheduled;
	if (_tmp3_ != NULL) {
		TubaWidgetsScheduledStatus* _tmp4_;
		TubaWidgetsScheduledStatus* _tmp5_;
		_tmp4_ = widget_scheduled;
		g_signal_connect_object (_tmp4_, "deleted", (GCallback) _tuba_views_scheduled_statuses_on_deleted_scheduled_tuba_widgets_scheduled_status_deleted, self, 0);
		_tmp5_ = widget_scheduled;
		g_signal_connect_object (_tmp5_, "refresh", (GCallback) _tuba_views_timeline_refresh_if_mapped_tuba_widgets_scheduled_status_refresh, (TubaViewsTimeline*) self, 0);
	}
	result = widget;
	_g_object_unref0 (widget_scheduled);
	return result;
}

static void
tuba_views_scheduled_statuses_on_deleted_scheduled (TubaViewsScheduledStatuses* self,
                                                    const gchar* scheduled_status_id)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (scheduled_status_id != NULL);
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				GListStore* _tmp2_;
				TubaAPIScheduledStatus* status_obj = NULL;
				GListStore* _tmp3_;
				GObject* _tmp4_;
				TubaAPIScheduledStatus* _tmp5_;
				const gchar* _tmp6_;
				const gchar* _tmp7_;
				if (!_tmp0_) {
					guint _tmp1_;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = ((TubaViewsContentBase*) self)->model;
				if (!(i < g_list_model_get_n_items ((GListModel*) _tmp2_))) {
					break;
				}
				_tmp3_ = ((TubaViewsContentBase*) self)->model;
				_tmp4_ = g_list_model_get_item ((GListModel*) _tmp3_, i);
				status_obj = G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, TUBA_API_TYPE_SCHEDULED_STATUS, TubaAPIScheduledStatus);
				_tmp5_ = status_obj;
				_tmp6_ = tuba_api_scheduled_status_get_id (_tmp5_);
				_tmp7_ = _tmp6_;
				if (g_strcmp0 (_tmp7_, scheduled_status_id) == 0) {
					tuba_views_timeline_safely_remove ((TubaViewsTimeline*) self, (gint) i);
					_g_object_unref0 (status_obj);
					break;
				}
				_g_object_unref0 (status_obj);
			}
		}
	}
}

static gboolean
tuba_views_scheduled_statuses_real_should_hide (TubaViewsTimeline* base,
                                                TubaEntity* entity)
{
	TubaViewsScheduledStatuses * self;
	TubaAPIScheduledStatus* scheduled_entity = NULL;
	TubaAPIScheduledStatus* _tmp0_;
	gboolean _tmp1_ = FALSE;
	TubaAPIScheduledStatus* _tmp2_;
	gboolean result;
	self = (TubaViewsScheduledStatuses*) base;
	g_return_val_if_fail (entity != NULL, FALSE);
	_tmp0_ = _g_object_ref0 (TUBA_API_IS_SCHEDULED_STATUS (entity) ? ((TubaAPIScheduledStatus*) entity) : NULL);
	scheduled_entity = _tmp0_;
	_tmp2_ = scheduled_entity;
	if (_tmp2_ != NULL) {
		TubaAPIScheduledStatus* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		GDateTime* _tmp6_;
		GDateTime* _tmp7_;
		_tmp3_ = scheduled_entity;
		_tmp4_ = tuba_api_scheduled_status_get_scheduled_at (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = g_date_time_new_from_iso8601 (_tmp5_, NULL);
		_tmp7_ = _tmp6_;
		_tmp1_ = g_date_time_get_year (_tmp7_) > TUBA_API_SCHEDULED_STATUS_DRAFT_YEAR;
		_g_date_time_unref0 (_tmp7_);
	} else {
		_tmp1_ = FALSE;
	}
	result = _tmp1_;
	_g_object_unref0 (scheduled_entity);
	return result;
}

static void
_tuba_views_timeline_refresh_if_mapped_tuba_application_refresh_scheduled_statuses (TubaApplication* _sender,
                                                                                    gpointer self)
{
	tuba_views_timeline_refresh_if_mapped ((TubaViewsTimeline*) self);
}

static GObject *
tuba_views_scheduled_statuses_constructor (GType type,
                                           guint n_construct_properties,
                                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	TubaViewsScheduledStatuses * self;
	TubaApplication* _tmp0_;
	parent_class = G_OBJECT_CLASS (tuba_views_scheduled_statuses_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_SCHEDULED_STATUSES, TubaViewsScheduledStatuses);
	tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_SCHEDULED_STATUS);
	_tmp0_ = tuba_app;
	g_signal_connect_object (_tmp0_, "refresh-scheduled-statuses", (GCallback) _tuba_views_timeline_refresh_if_mapped_tuba_application_refresh_scheduled_statuses, (TubaViewsTimeline*) self, 0);
	return obj;
}

static void
tuba_views_scheduled_statuses_class_init (TubaViewsScheduledStatusesClass * klass,
                                          gpointer klass_data)
{
	tuba_views_scheduled_statuses_parent_class = g_type_class_peek_parent (klass);
	((TubaViewsContentBaseClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsContentBase*, GObject*)) tuba_views_scheduled_statuses_real_on_create_model_widget;
	((TubaViewsTimelineClass *) klass)->should_hide = (gboolean (*) (TubaViewsTimeline*, TubaEntity*)) tuba_views_scheduled_statuses_real_should_hide;
	G_OBJECT_CLASS (klass)->constructor = tuba_views_scheduled_statuses_constructor;
}

static void
tuba_views_scheduled_statuses_instance_init (TubaViewsScheduledStatuses * self,
                                             gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_views_scheduled_statuses_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsScheduledStatusesClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_scheduled_statuses_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsScheduledStatuses), 0, (GInstanceInitFunc) tuba_views_scheduled_statuses_instance_init, NULL };
	GType tuba_views_scheduled_statuses_type_id;
	tuba_views_scheduled_statuses_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsScheduledStatuses", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_views_scheduled_statuses_type_id;
}

GType
tuba_views_scheduled_statuses_get_type (void)
{
	static GType tuba_views_scheduled_statuses_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_scheduled_statuses_type_id__once)) {
		GType tuba_views_scheduled_statuses_type_id;
		tuba_views_scheduled_statuses_type_id = tuba_views_scheduled_statuses_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_scheduled_statuses_type_id__once, tuba_views_scheduled_statuses_type_id);
	}
	return tuba_views_scheduled_statuses_type_id__once;
}

