/* Accounts.c generated by valac 0.56.19, the Vala compiler
 * generated from Accounts.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_ACCOUNTS (tuba_views_accounts_get_type ())
#define TUBA_VIEWS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts))
#define TUBA_VIEWS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))
#define TUBA_VIEWS_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))

typedef struct _TubaViewsAccounts TubaViewsAccounts;
typedef struct _TubaViewsAccountsClass TubaViewsAccountsClass;
typedef struct _TubaViewsAccountsPrivate TubaViewsAccountsPrivate;
enum  {
	TUBA_VIEWS_ACCOUNTS_0_PROPERTY,
	TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY,
	TUBA_VIEWS_ACCOUNTS_NUM_PROPERTIES
};
static GParamSpec* tuba_views_accounts_properties[TUBA_VIEWS_ACCOUNTS_NUM_PROPERTIES];

#define TUBA_API_TYPE_SUGGESTION (tuba_api_suggestion_get_type ())
#define TUBA_API_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestion))
#define TUBA_API_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestionClass))
#define TUBA_API_IS_SUGGESTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_SUGGESTION))
#define TUBA_API_IS_SUGGESTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_SUGGESTION))
#define TUBA_API_SUGGESTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_SUGGESTION, TubaAPISuggestionClass))

typedef struct _TubaAPISuggestion TubaAPISuggestion;
typedef struct _TubaAPISuggestionClass TubaAPISuggestionClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsAccounts {
	TubaViewsTimeline parent_instance;
	TubaViewsAccountsPrivate * priv;
};

struct _TubaViewsAccountsClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaViewsAccountsPrivate {
	gboolean _tuba_row;
};

static gint TubaViewsAccounts_private_offset;
static gpointer tuba_views_accounts_parent_class = NULL;
VALA_EXTERN TubaAccountStore* tuba_accounts;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAccounts, g_object_unref)
VALA_EXTERN GtkWidget* tuba_views_content_base_on_create_model_widget (TubaViewsContentBase* self,
                                                           GObject* obj);
VALA_EXTERN void tuba_views_base_on_content_changed (TubaViewsBase* self);
VALA_EXTERN TubaViewsAccounts* tuba_views_accounts_new_prefilled (const gchar* url,
                                                      const gchar* label,
                                                      const gchar* icon,
                                                      gboolean use_rows);
VALA_EXTERN TubaViewsAccounts* tuba_views_accounts_construct_prefilled (GType object_type,
                                                            const gchar* url,
                                                            const gchar* label,
                                                            const gchar* icon,
                                                            gboolean use_rows);
VALA_EXTERN void tuba_views_accounts_set_tuba_row (TubaViewsAccounts* self,
                                       gboolean value);
static GtkWidget* tuba_views_accounts_real_on_create_model_widget (TubaViewsContentBase* base,
                                                            GObject* obj);
VALA_EXTERN gboolean tuba_views_accounts_get_tuba_row (TubaViewsAccounts* self);
VALA_EXTERN void tuba_api_account_set_tuba_row (TubaAPIAccount* self,
                                    gboolean value);
static void tuba_views_accounts_real_on_content_changed (TubaViewsBase* base);
VALA_EXTERN GType tuba_views_timeline_get_accepts (TubaViewsTimeline* self);
VALA_EXTERN GType tuba_api_suggestion_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPISuggestion, g_object_unref)
VALA_EXTERN TubaAPIAccount* tuba_api_suggestion_get_account (TubaAPISuggestion* self);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN TubaAPIRelationship* tuba_api_account_get_tuba_rs (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
static void _vala_array_add61 (gchar** * array,
                        gint* length,
                        gint* size,
                        gchar* value);
VALA_EXTERN void tuba_api_relationship_request_many (gchar** ids,
                                         gint ids_length1,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
VALA_EXTERN GeeHashMap* tuba_api_relationship_request_many_finish (GAsyncResult* _res_,
                                                       GError** error);
static void ____lambda143_ (TubaViewsAccounts* self,
                     GObject* obj,
                     GAsyncResult* res);
VALA_EXTERN void tuba_api_account_set_tuba_rs (TubaAPIAccount* self,
                                   TubaAPIRelationship* value);
static void _____lambda143__gasync_ready_callback (GObject* source_object,
                                            GAsyncResult* res,
                                            gpointer self);
VALA_EXTERN TubaViewsAccounts* tuba_views_accounts_new (void);
VALA_EXTERN TubaViewsAccounts* tuba_views_accounts_construct (GType object_type);
VALA_EXTERN TubaViewsTimeline* tuba_views_timeline_new (void);
VALA_EXTERN TubaViewsTimeline* tuba_views_timeline_construct (GType object_type);
static void tuba_views_accounts_finalize (GObject * obj);
static GType tuba_views_accounts_get_type_once (void);
static void _vala_tuba_views_accounts_get_property (GObject * object,
                                             guint property_id,
                                             GValue * value,
                                             GParamSpec * pspec);
static void _vala_tuba_views_accounts_set_property (GObject * object,
                                             guint property_id,
                                             const GValue * value,
                                             GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_views_accounts_get_instance_private (TubaViewsAccounts* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsAccounts_private_offset);
}

TubaViewsAccounts*
tuba_views_accounts_construct_prefilled (GType object_type,
                                         const gchar* url,
                                         const gchar* label,
                                         const gchar* icon,
                                         gboolean use_rows)
{
	TubaViewsAccounts * self = NULL;
	g_return_val_if_fail (url != NULL, NULL);
	g_return_val_if_fail (label != NULL, NULL);
	g_return_val_if_fail (icon != NULL, NULL);
	self = (TubaViewsAccounts*) g_object_new (object_type, "url", url, "label", label, "icon", icon, NULL);
	tuba_views_accounts_set_tuba_row (self, use_rows);
	return self;
}

TubaViewsAccounts*
tuba_views_accounts_new_prefilled (const gchar* url,
                                   const gchar* label,
                                   const gchar* icon,
                                   gboolean use_rows)
{
	return tuba_views_accounts_construct_prefilled (TUBA_VIEWS_TYPE_ACCOUNTS, url, label, icon, use_rows);
}

static GtkWidget*
tuba_views_accounts_real_on_create_model_widget (TubaViewsContentBase* base,
                                                 GObject* obj)
{
	TubaViewsAccounts * self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	GtkWidget* _tmp2_;
	GtkWidget* result;
	self = (TubaViewsAccounts*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp1_ = self->priv->_tuba_row;
	if (_tmp1_) {
		_tmp0_ = TUBA_API_IS_ACCOUNT (obj);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		tuba_api_account_set_tuba_row (G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_ACCOUNT, TubaAPIAccount), TRUE);
	}
	_tmp2_ = TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_views_accounts_parent_class)->on_create_model_widget ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline), obj);
	result = _tmp2_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

static void
_vala_array_add61 (gchar** * array,
                   gint* length,
                   gint* size,
                   gchar* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
____lambda143_ (TubaViewsAccounts* self,
                GObject* obj,
                GAsyncResult* res)
{
	GError* _inner_error0_ = NULL;
	g_return_if_fail (res != NULL);
	{
		GeeHashMap* relationships = NULL;
		GeeHashMap* _tmp0_;
		GeeHashMap* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		_tmp0_ = tuba_api_relationship_request_many_finish (res, &_inner_error0_);
		relationships = _tmp0_;
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_tmp1_ = relationships;
		_tmp2_ = gee_abstract_map_get_size ((GeeAbstractMap*) _tmp1_);
		_tmp3_ = _tmp2_;
		if (_tmp3_ > 0) {
			{
				guint i = 0U;
				i = (guint) 0;
				{
					gboolean _tmp4_ = FALSE;
					_tmp4_ = TRUE;
					while (TRUE) {
						GListStore* _tmp6_;
						guint _tmp7_;
						guint _tmp8_;
						TubaAPIAccount* acc_obj = NULL;
						GObject* model_obj = NULL;
						GListStore* _tmp9_;
						GObject* _tmp10_;
						GType _tmp11_;
						GType _tmp12_;
						TubaAPIAccount* _tmp22_;
						GeeHashMap* _tmp23_;
						TubaAPIAccount* _tmp24_;
						const gchar* _tmp25_;
						const gchar* _tmp26_;
						if (!_tmp4_) {
							guint _tmp5_;
							_tmp5_ = i;
							i = _tmp5_ + 1;
						}
						_tmp4_ = FALSE;
						_tmp6_ = ((TubaViewsContentBase*) self)->model;
						g_object_get (_tmp6_, "n-items", &_tmp7_, NULL);
						_tmp8_ = _tmp7_;
						if (!(i < _tmp8_)) {
							break;
						}
						acc_obj = NULL;
						_tmp9_ = ((TubaViewsContentBase*) self)->model;
						_tmp10_ = g_list_model_get_item ((GListModel*) _tmp9_, i);
						model_obj = _tmp10_;
						_tmp11_ = tuba_views_timeline_get_accepts ((TubaViewsTimeline*) self);
						_tmp12_ = _tmp11_;
						if (_tmp12_ == TUBA_API_TYPE_SUGGESTION) {
							TubaAPISuggestion* suggestion = NULL;
							GObject* _tmp13_;
							TubaAPISuggestion* _tmp14_;
							TubaAPISuggestion* _tmp15_;
							_tmp13_ = model_obj;
							_tmp14_ = _g_object_ref0 (TUBA_API_IS_SUGGESTION (_tmp13_) ? ((TubaAPISuggestion*) _tmp13_) : NULL);
							suggestion = _tmp14_;
							_tmp15_ = suggestion;
							if (_tmp15_ != NULL) {
								TubaAPISuggestion* _tmp16_;
								TubaAPIAccount* _tmp17_;
								TubaAPIAccount* _tmp18_;
								TubaAPIAccount* _tmp19_;
								_tmp16_ = suggestion;
								_tmp17_ = tuba_api_suggestion_get_account (_tmp16_);
								_tmp18_ = _tmp17_;
								_tmp19_ = _g_object_ref0 (TUBA_API_IS_ACCOUNT (_tmp18_) ? ((TubaAPIAccount*) _tmp18_) : NULL);
								_g_object_unref0 (acc_obj);
								acc_obj = _tmp19_;
							}
							_g_object_unref0 (suggestion);
						} else {
							GObject* _tmp20_;
							TubaAPIAccount* _tmp21_;
							_tmp20_ = model_obj;
							_tmp21_ = _g_object_ref0 (TUBA_API_IS_ACCOUNT (_tmp20_) ? ((TubaAPIAccount*) _tmp20_) : NULL);
							_g_object_unref0 (acc_obj);
							acc_obj = _tmp21_;
						}
						_tmp22_ = acc_obj;
						if (_tmp22_ == NULL) {
							_g_object_unref0 (model_obj);
							_g_object_unref0 (acc_obj);
							continue;
						}
						_tmp23_ = relationships;
						_tmp24_ = acc_obj;
						_tmp25_ = tuba_api_account_get_id (_tmp24_);
						_tmp26_ = _tmp25_;
						if (gee_abstract_map_has_key ((GeeAbstractMap*) _tmp23_, _tmp26_)) {
							TubaAPIAccount* _tmp27_;
							GeeHashMap* _tmp28_;
							TubaAPIAccount* _tmp29_;
							const gchar* _tmp30_;
							const gchar* _tmp31_;
							gpointer _tmp32_;
							TubaAPIRelationship* _tmp33_;
							_tmp27_ = acc_obj;
							_tmp28_ = relationships;
							_tmp29_ = acc_obj;
							_tmp30_ = tuba_api_account_get_id (_tmp29_);
							_tmp31_ = _tmp30_;
							_tmp32_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp28_, _tmp31_);
							_tmp33_ = (TubaAPIRelationship*) _tmp32_;
							tuba_api_account_set_tuba_rs (_tmp27_, _tmp33_);
							_g_object_unref0 (_tmp33_);
						}
						_g_object_unref0 (model_obj);
						_g_object_unref0 (acc_obj);
					}
				}
			}
		}
		_g_object_unref0 (relationships);
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* e = NULL;
		GError* _tmp34_;
		const gchar* _tmp35_;
		e = _inner_error0_;
		_inner_error0_ = NULL;
		_tmp34_ = e;
		_tmp35_ = _tmp34_->message;
		g_warning ("Accounts.vala:65: %s", _tmp35_);
		_g_error_free0 (e);
	}
	__finally0:
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
		g_clear_error (&_inner_error0_);
		return;
	}
}

static void
_____lambda143__gasync_ready_callback (GObject* source_object,
                                       GAsyncResult* res,
                                       gpointer self)
{
	____lambda143_ ((TubaViewsAccounts*) self, source_object, res);
	g_object_unref (self);
}

static void
tuba_views_accounts_real_on_content_changed (TubaViewsBase* base)
{
	TubaViewsAccounts * self;
	gboolean _tmp0_ = FALSE;
	GType _tmp1_;
	GType _tmp2_;
	self = (TubaViewsAccounts*) base;
	_tmp1_ = tuba_views_timeline_get_accepts ((TubaViewsTimeline*) self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == TUBA_API_TYPE_ACCOUNT) {
		_tmp0_ = TRUE;
	} else {
		GType _tmp3_;
		GType _tmp4_;
		_tmp3_ = tuba_views_timeline_get_accepts ((TubaViewsTimeline*) self);
		_tmp4_ = _tmp3_;
		_tmp0_ = _tmp4_ == TUBA_API_TYPE_SUGGESTION;
	}
	if (_tmp0_) {
		gchar** ids_to_rs = NULL;
		gchar** _tmp5_;
		gint ids_to_rs_length1;
		gint _ids_to_rs_size_;
		gchar** _tmp41_;
		gint _tmp41__length1;
		_tmp5_ = g_new0 (gchar*, 0 + 1);
		ids_to_rs = _tmp5_;
		ids_to_rs_length1 = 0;
		_ids_to_rs_size_ = ids_to_rs_length1;
		{
			guint i = 0U;
			i = (guint) 0;
			{
				gboolean _tmp6_ = FALSE;
				_tmp6_ = TRUE;
				while (TRUE) {
					GListStore* _tmp8_;
					guint _tmp9_;
					guint _tmp10_;
					TubaAPIAccount* acc_obj = NULL;
					GObject* model_obj = NULL;
					GListStore* _tmp11_;
					GObject* _tmp12_;
					GType _tmp13_;
					GType _tmp14_;
					TubaAPIAccount* _tmp24_;
					gboolean _tmp25_ = FALSE;
					TubaAPIAccount* _tmp26_;
					TubaAPIRelationship* _tmp27_;
					TubaAPIRelationship* _tmp28_;
					if (!_tmp6_) {
						guint _tmp7_;
						_tmp7_ = i;
						i = _tmp7_ + 1;
					}
					_tmp6_ = FALSE;
					_tmp8_ = ((TubaViewsContentBase*) self)->model;
					g_object_get (_tmp8_, "n-items", &_tmp9_, NULL);
					_tmp10_ = _tmp9_;
					if (!(i < _tmp10_)) {
						break;
					}
					acc_obj = NULL;
					_tmp11_ = ((TubaViewsContentBase*) self)->model;
					_tmp12_ = g_list_model_get_item ((GListModel*) _tmp11_, i);
					model_obj = _tmp12_;
					_tmp13_ = tuba_views_timeline_get_accepts ((TubaViewsTimeline*) self);
					_tmp14_ = _tmp13_;
					if (_tmp14_ == TUBA_API_TYPE_SUGGESTION) {
						TubaAPISuggestion* suggestion = NULL;
						GObject* _tmp15_;
						TubaAPISuggestion* _tmp16_;
						TubaAPISuggestion* _tmp17_;
						_tmp15_ = model_obj;
						_tmp16_ = _g_object_ref0 (TUBA_API_IS_SUGGESTION (_tmp15_) ? ((TubaAPISuggestion*) _tmp15_) : NULL);
						suggestion = _tmp16_;
						_tmp17_ = suggestion;
						if (_tmp17_ != NULL) {
							TubaAPISuggestion* _tmp18_;
							TubaAPIAccount* _tmp19_;
							TubaAPIAccount* _tmp20_;
							TubaAPIAccount* _tmp21_;
							_tmp18_ = suggestion;
							_tmp19_ = tuba_api_suggestion_get_account (_tmp18_);
							_tmp20_ = _tmp19_;
							_tmp21_ = _g_object_ref0 (TUBA_API_IS_ACCOUNT (_tmp20_) ? ((TubaAPIAccount*) _tmp20_) : NULL);
							_g_object_unref0 (acc_obj);
							acc_obj = _tmp21_;
						}
						_g_object_unref0 (suggestion);
					} else {
						GObject* _tmp22_;
						TubaAPIAccount* _tmp23_;
						_tmp22_ = model_obj;
						_tmp23_ = _g_object_ref0 (TUBA_API_IS_ACCOUNT (_tmp22_) ? ((TubaAPIAccount*) _tmp22_) : NULL);
						_g_object_unref0 (acc_obj);
						acc_obj = _tmp23_;
					}
					_tmp24_ = acc_obj;
					if (_tmp24_ == NULL) {
						_g_object_unref0 (model_obj);
						_g_object_unref0 (acc_obj);
						continue;
					}
					_tmp26_ = acc_obj;
					_tmp27_ = tuba_api_account_get_tuba_rs (_tmp26_);
					_tmp28_ = _tmp27_;
					if (_tmp28_ == NULL) {
						TubaAPIAccount* _tmp29_;
						const gchar* _tmp30_;
						const gchar* _tmp31_;
						TubaAccountStore* _tmp32_;
						TubaInstanceAccount* _tmp33_;
						TubaInstanceAccount* _tmp34_;
						const gchar* _tmp35_;
						const gchar* _tmp36_;
						_tmp29_ = acc_obj;
						_tmp30_ = tuba_api_account_get_id (_tmp29_);
						_tmp31_ = _tmp30_;
						_tmp32_ = tuba_accounts;
						_tmp33_ = tuba_account_store_get_active (_tmp32_);
						_tmp34_ = _tmp33_;
						_tmp35_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp34_);
						_tmp36_ = _tmp35_;
						_tmp25_ = g_strcmp0 (_tmp31_, _tmp36_) != 0;
					} else {
						_tmp25_ = FALSE;
					}
					if (_tmp25_) {
						TubaAPIAccount* _tmp37_;
						const gchar* _tmp38_;
						const gchar* _tmp39_;
						gchar* _tmp40_;
						_tmp37_ = acc_obj;
						_tmp38_ = tuba_api_account_get_id (_tmp37_);
						_tmp39_ = _tmp38_;
						_tmp40_ = g_strdup (_tmp39_);
						_vala_array_add61 (&ids_to_rs, &ids_to_rs_length1, &_ids_to_rs_size_, _tmp40_);
					}
					_g_object_unref0 (model_obj);
					_g_object_unref0 (acc_obj);
				}
			}
		}
		_tmp41_ = ids_to_rs;
		_tmp41__length1 = ids_to_rs_length1;
		if (_tmp41__length1 > 0) {
			gchar** _tmp42_;
			gint _tmp42__length1;
			_tmp42_ = ids_to_rs;
			_tmp42__length1 = ids_to_rs_length1;
			tuba_api_relationship_request_many (_tmp42_, (gint) _tmp42__length1, _____lambda143__gasync_ready_callback, g_object_ref (self));
		}
		ids_to_rs = (_vala_array_free (ids_to_rs, ids_to_rs_length1, (GDestroyNotify) g_free), NULL);
	}
	TUBA_VIEWS_BASE_CLASS (tuba_views_accounts_parent_class)->on_content_changed ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline));
}

TubaViewsAccounts*
tuba_views_accounts_construct (GType object_type)
{
	TubaViewsAccounts * self = NULL;
	self = (TubaViewsAccounts*) tuba_views_timeline_construct (object_type);
	return self;
}

TubaViewsAccounts*
tuba_views_accounts_new (void)
{
	return tuba_views_accounts_construct (TUBA_VIEWS_TYPE_ACCOUNTS);
}

gboolean
tuba_views_accounts_get_tuba_row (TubaViewsAccounts* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_tuba_row;
	return result;
}

void
tuba_views_accounts_set_tuba_row (TubaViewsAccounts* self,
                                  gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_accounts_get_tuba_row (self);
	if (old_value != value) {
		self->priv->_tuba_row = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_accounts_properties[TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY]);
	}
}

static void
tuba_views_accounts_class_init (TubaViewsAccountsClass * klass,
                                gpointer klass_data)
{
	tuba_views_accounts_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsAccounts_private_offset);
	((TubaViewsContentBaseClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsContentBase*, GObject*)) tuba_views_accounts_real_on_create_model_widget;
	((TubaViewsBaseClass *) klass)->on_content_changed = (void (*) (TubaViewsBase*)) tuba_views_accounts_real_on_content_changed;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_accounts_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_accounts_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_accounts_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY, tuba_views_accounts_properties[TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY] = g_param_spec_boolean ("tuba-row", "tuba-row", "tuba-row", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_accounts_instance_init (TubaViewsAccounts * self,
                                   gpointer klass)
{
	self->priv = tuba_views_accounts_get_instance_private (self);
	self->priv->_tuba_row = FALSE;
}

static void
tuba_views_accounts_finalize (GObject * obj)
{
	TubaViewsAccounts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts);
	G_OBJECT_CLASS (tuba_views_accounts_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_accounts_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsAccountsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_accounts_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsAccounts), 0, (GInstanceInitFunc) tuba_views_accounts_instance_init, NULL };
	GType tuba_views_accounts_type_id;
	tuba_views_accounts_type_id = g_type_register_static (TUBA_VIEWS_TYPE_TIMELINE, "TubaViewsAccounts", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsAccounts_private_offset = g_type_add_instance_private (tuba_views_accounts_type_id, sizeof (TubaViewsAccountsPrivate));
	return tuba_views_accounts_type_id;
}

GType
tuba_views_accounts_get_type (void)
{
	static GType tuba_views_accounts_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_accounts_type_id__once)) {
		GType tuba_views_accounts_type_id;
		tuba_views_accounts_type_id = tuba_views_accounts_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_accounts_type_id__once, tuba_views_accounts_type_id);
	}
	return tuba_views_accounts_type_id__once;
}

static void
_vala_tuba_views_accounts_get_property (GObject * object,
                                        guint property_id,
                                        GValue * value,
                                        GParamSpec * pspec)
{
	TubaViewsAccounts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts);
	switch (property_id) {
		case TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY:
		g_value_set_boolean (value, tuba_views_accounts_get_tuba_row (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_accounts_set_property (GObject * object,
                                        guint property_id,
                                        const GValue * value,
                                        GParamSpec * pspec)
{
	TubaViewsAccounts * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts);
	switch (property_id) {
		case TUBA_VIEWS_ACCOUNTS_TUBA_ROW_PROPERTY:
		tuba_views_accounts_set_tuba_row (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

