/* Polls.c generated by valac 0.56.19, the Vala compiler
 * generated from Polls.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS (tuba_api_mastodon_configuration_polls_get_type ())
#define TUBA_API_MASTODON_CONFIGURATION_POLLS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_IS_POLLS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS))
#define TUBA_API_MASTODON_CONFIGURATION_POLLS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPollsClass))

typedef struct _TubaAPIMastodonConfigurationPolls TubaAPIMastodonConfigurationPolls;
typedef struct _TubaAPIMastodonConfigurationPollsClass TubaAPIMastodonConfigurationPollsClass;
typedef struct _TubaAPIMastodonConfigurationPollsPrivate TubaAPIMastodonConfigurationPollsPrivate;
enum  {
	TUBA_API_MASTODON_CONFIGURATION_POLLS_0_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY,
	TUBA_API_MASTODON_CONFIGURATION_POLLS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIMastodonConfigurationPolls {
	TubaEntity parent_instance;
	TubaAPIMastodonConfigurationPollsPrivate * priv;
};

struct _TubaAPIMastodonConfigurationPollsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIMastodonConfigurationPollsPrivate {
	gint64 _max_options;
	gint64 _max_characters_per_option;
	gint64 _max_option_chars;
	gint64 _min_expiration;
	gint64 _max_expiration;
};

static gint TubaAPIMastodonConfigurationPolls_private_offset;
static gpointer tuba_api_mastodon_configuration_polls_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_mastodon_configuration_polls_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMastodonConfigurationPolls, g_object_unref)
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_mastodon_configuration_polls_new (void);
VALA_EXTERN TubaAPIMastodonConfigurationPolls* tuba_api_mastodon_configuration_polls_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_options (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN void tuba_api_mastodon_configuration_polls_set_max_options (TubaAPIMastodonConfigurationPolls* self,
                                                            gint64 value);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_characters_per_option (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN void tuba_api_mastodon_configuration_polls_set_max_characters_per_option (TubaAPIMastodonConfigurationPolls* self,
                                                                          gint64 value);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_option_chars (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN void tuba_api_mastodon_configuration_polls_set_max_option_chars (TubaAPIMastodonConfigurationPolls* self,
                                                                 gint64 value);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_min_expiration (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN void tuba_api_mastodon_configuration_polls_set_min_expiration (TubaAPIMastodonConfigurationPolls* self,
                                                               gint64 value);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_max_expiration (TubaAPIMastodonConfigurationPolls* self);
VALA_EXTERN void tuba_api_mastodon_configuration_polls_set_max_expiration (TubaAPIMastodonConfigurationPolls* self,
                                                               gint64 value);
VALA_EXTERN gint64 tuba_api_mastodon_configuration_polls_get_compat_status_poll_max_characters (TubaAPIMastodonConfigurationPolls* self);
static void tuba_api_mastodon_configuration_polls_finalize (GObject * obj);
static GType tuba_api_mastodon_configuration_polls_get_type_once (void);
static void _vala_tuba_api_mastodon_configuration_polls_get_property (GObject * object,
                                                               guint property_id,
                                                               GValue * value,
                                                               GParamSpec * pspec);
static void _vala_tuba_api_mastodon_configuration_polls_set_property (GObject * object,
                                                               guint property_id,
                                                               const GValue * value,
                                                               GParamSpec * pspec);

static inline gpointer
tuba_api_mastodon_configuration_polls_get_instance_private (TubaAPIMastodonConfigurationPolls* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIMastodonConfigurationPolls_private_offset);
}

TubaAPIMastodonConfigurationPolls*
tuba_api_mastodon_configuration_polls_construct (GType object_type)
{
	TubaAPIMastodonConfigurationPolls * self = NULL;
	self = (TubaAPIMastodonConfigurationPolls*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIMastodonConfigurationPolls*
tuba_api_mastodon_configuration_polls_new (void)
{
	return tuba_api_mastodon_configuration_polls_construct (TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS);
}

gint64
tuba_api_mastodon_configuration_polls_get_max_options (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_options;
	return result;
}

void
tuba_api_mastodon_configuration_polls_set_max_options (TubaAPIMastodonConfigurationPolls* self,
                                                       gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configuration_polls_get_max_options (self);
	if (old_value != value) {
		self->priv->_max_options = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY]);
	}
}

gint64
tuba_api_mastodon_configuration_polls_get_max_characters_per_option (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_characters_per_option;
	return result;
}

void
tuba_api_mastodon_configuration_polls_set_max_characters_per_option (TubaAPIMastodonConfigurationPolls* self,
                                                                     gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configuration_polls_get_max_characters_per_option (self);
	if (old_value != value) {
		self->priv->_max_characters_per_option = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY]);
	}
}

gint64
tuba_api_mastodon_configuration_polls_get_max_option_chars (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_option_chars;
	return result;
}

void
tuba_api_mastodon_configuration_polls_set_max_option_chars (TubaAPIMastodonConfigurationPolls* self,
                                                            gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configuration_polls_get_max_option_chars (self);
	if (old_value != value) {
		self->priv->_max_option_chars = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY]);
	}
}

gint64
tuba_api_mastodon_configuration_polls_get_min_expiration (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_min_expiration;
	return result;
}

void
tuba_api_mastodon_configuration_polls_set_min_expiration (TubaAPIMastodonConfigurationPolls* self,
                                                          gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configuration_polls_get_min_expiration (self);
	if (old_value != value) {
		self->priv->_min_expiration = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY]);
	}
}

gint64
tuba_api_mastodon_configuration_polls_get_max_expiration (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_max_expiration;
	return result;
}

void
tuba_api_mastodon_configuration_polls_set_max_expiration (TubaAPIMastodonConfigurationPolls* self,
                                                          gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_mastodon_configuration_polls_get_max_expiration (self);
	if (old_value != value) {
		self->priv->_max_expiration = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY]);
	}
}

gint64
tuba_api_mastodon_configuration_polls_get_compat_status_poll_max_characters (TubaAPIMastodonConfigurationPolls* self)
{
	gint64 result;
	gint64 _tmp0_ = 0LL;
	gint64 _tmp1_;
	g_return_val_if_fail (self != NULL, -1LL);
	_tmp1_ = self->priv->_max_characters_per_option;
	if (_tmp1_ != ((gint64) -1)) {
		gint64 _tmp2_;
		_tmp2_ = self->priv->_max_characters_per_option;
		_tmp0_ = _tmp2_;
	} else {
		gint64 _tmp3_;
		_tmp3_ = self->priv->_max_option_chars;
		_tmp0_ = _tmp3_;
	}
	result = _tmp0_;
	return result;
}

static void
tuba_api_mastodon_configuration_polls_class_init (TubaAPIMastodonConfigurationPollsClass * klass,
                                                  gpointer klass_data)
{
	tuba_api_mastodon_configuration_polls_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIMastodonConfigurationPolls_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_mastodon_configuration_polls_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_mastodon_configuration_polls_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_mastodon_configuration_polls_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY] = g_param_spec_int64 ("max-options", "max-options", "max-options", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY] = g_param_spec_int64 ("max-characters-per-option", "max-characters-per-option", "max-characters-per-option", G_MININT64, G_MAXINT64, (gint64) -1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY] = g_param_spec_int64 ("max-option-chars", "max-option-chars", "max-option-chars", G_MININT64, G_MAXINT64, (gint64) -1, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY] = g_param_spec_int64 ("min-expiration", "min-expiration", "min-expiration", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY] = g_param_spec_int64 ("max-expiration", "max-expiration", "max-expiration", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_MASTODON_CONFIGURATION_POLLS_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY, tuba_api_mastodon_configuration_polls_properties[TUBA_API_MASTODON_CONFIGURATION_POLLS_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY] = g_param_spec_int64 ("compat-status-poll-max-characters", "compat-status-poll-max-characters", "compat-status-poll-max-characters", G_MININT64, G_MAXINT64, 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
}

static void
tuba_api_mastodon_configuration_polls_instance_init (TubaAPIMastodonConfigurationPolls * self,
                                                     gpointer klass)
{
	self->priv = tuba_api_mastodon_configuration_polls_get_instance_private (self);
	self->priv->_max_characters_per_option = (gint64) -1;
	self->priv->_max_option_chars = (gint64) -1;
}

static void
tuba_api_mastodon_configuration_polls_finalize (GObject * obj)
{
	TubaAPIMastodonConfigurationPolls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls);
	G_OBJECT_CLASS (tuba_api_mastodon_configuration_polls_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_mastodon_configuration_polls_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIMastodonConfigurationPollsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_mastodon_configuration_polls_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIMastodonConfigurationPolls), 0, (GInstanceInitFunc) tuba_api_mastodon_configuration_polls_instance_init, NULL };
	GType tuba_api_mastodon_configuration_polls_type_id;
	tuba_api_mastodon_configuration_polls_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIMastodonConfigurationPolls", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIMastodonConfigurationPolls_private_offset = g_type_add_instance_private (tuba_api_mastodon_configuration_polls_type_id, sizeof (TubaAPIMastodonConfigurationPollsPrivate));
	return tuba_api_mastodon_configuration_polls_type_id;
}

GType
tuba_api_mastodon_configuration_polls_get_type (void)
{
	static GType tuba_api_mastodon_configuration_polls_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_mastodon_configuration_polls_type_id__once)) {
		GType tuba_api_mastodon_configuration_polls_type_id;
		tuba_api_mastodon_configuration_polls_type_id = tuba_api_mastodon_configuration_polls_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_mastodon_configuration_polls_type_id__once, tuba_api_mastodon_configuration_polls_type_id);
	}
	return tuba_api_mastodon_configuration_polls_type_id__once;
}

static void
_vala_tuba_api_mastodon_configuration_polls_get_property (GObject * object,
                                                          guint property_id,
                                                          GValue * value,
                                                          GParamSpec * pspec)
{
	TubaAPIMastodonConfigurationPolls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls);
	switch (property_id) {
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_max_options (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_max_characters_per_option (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_max_option_chars (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_min_expiration (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_max_expiration (self));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_COMPAT_STATUS_POLL_MAX_CHARACTERS_PROPERTY:
		g_value_set_int64 (value, tuba_api_mastodon_configuration_polls_get_compat_status_poll_max_characters (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_mastodon_configuration_polls_set_property (GObject * object,
                                                          guint property_id,
                                                          const GValue * value,
                                                          GParamSpec * pspec)
{
	TubaAPIMastodonConfigurationPolls * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_MASTODON_CONFIGURATION_TYPE_POLLS, TubaAPIMastodonConfigurationPolls);
	switch (property_id) {
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTIONS_PROPERTY:
		tuba_api_mastodon_configuration_polls_set_max_options (self, g_value_get_int64 (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_CHARACTERS_PER_OPTION_PROPERTY:
		tuba_api_mastodon_configuration_polls_set_max_characters_per_option (self, g_value_get_int64 (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_OPTION_CHARS_PROPERTY:
		tuba_api_mastodon_configuration_polls_set_max_option_chars (self, g_value_get_int64 (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MIN_EXPIRATION_PROPERTY:
		tuba_api_mastodon_configuration_polls_set_min_expiration (self, g_value_get_int64 (value));
		break;
		case TUBA_API_MASTODON_CONFIGURATION_POLLS_MAX_EXPIRATION_PROPERTY:
		tuba_api_mastodon_configuration_polls_set_max_expiration (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

