/* GroupedNotificationsResults.c generated by valac 0.56.19, the Vala compiler
 * generated from GroupedNotificationsResults.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>

#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW "follow"
#define TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP "admin.sign_up"
#define TUBA_INSTANCE_ACCOUNT_KIND_FAVOURITE "favourite"
#define TUBA_INSTANCE_ACCOUNT_KIND_REBLOG "reblog"
#define TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST "follow_request"
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS (tuba_api_grouped_notifications_results_get_type ())
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResults))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResultsClass))
#define TUBA_API_IS_GROUPED_NOTIFICATIONS_RESULTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS))
#define TUBA_API_IS_GROUPED_NOTIFICATIONS_RESULTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResultsClass))

typedef struct _TubaAPIGroupedNotificationsResults TubaAPIGroupedNotificationsResults;
typedef struct _TubaAPIGroupedNotificationsResultsClass TubaAPIGroupedNotificationsResultsClass;
typedef struct _TubaAPIGroupedNotificationsResultsPrivate TubaAPIGroupedNotificationsResultsPrivate;

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;

#define TUBA_API_TYPE_NOTIFICATION (tuba_api_notification_get_type ())
#define TUBA_API_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotification))
#define TUBA_API_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))
#define TUBA_API_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NOTIFICATION))
#define TUBA_API_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NOTIFICATION, TubaAPINotificationClass))

typedef struct _TubaAPINotification TubaAPINotification;
typedef struct _TubaAPINotificationClass TubaAPINotificationClass;

#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP (tuba_api_grouped_notifications_results_notification_group_get_type ())
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroup))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroupClass))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_IS_NOTIFICATION_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_IS_NOTIFICATION_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP))
#define TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroupClass))

typedef struct _TubaAPIGroupedNotificationsResultsNotificationGroup TubaAPIGroupedNotificationsResultsNotificationGroup;
typedef struct _TubaAPIGroupedNotificationsResultsNotificationGroupClass TubaAPIGroupedNotificationsResultsNotificationGroupClass;
enum  {
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_0_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NUM_PROPERTIES
};
static GParamSpec* tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TubaAPINotificationPrivate TubaAPINotificationPrivate;
typedef struct _TubaAPIGroupedNotificationsResultsNotificationGroupPrivate TubaAPIGroupedNotificationsResultsNotificationGroupPrivate;
enum  {
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_0_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY,
	TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_NUM_PROPERTIES
};
static GParamSpec* tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_WIDGETS_TYPE_STATUS (tuba_widgets_status_get_type ())
#define TUBA_WIDGETS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatus))
#define TUBA_WIDGETS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))
#define TUBA_WIDGETS_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))

typedef struct _TubaWidgetsStatus TubaWidgetsStatus;
typedef struct _TubaWidgetsStatusClass TubaWidgetsStatusClass;

#define TUBA_WIDGETS_TYPE_NOTIFICATION (tuba_widgets_notification_get_type ())
#define TUBA_WIDGETS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotification))
#define TUBA_WIDGETS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))
#define TUBA_WIDGETS_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION))
#define TUBA_WIDGETS_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION, TubaWidgetsNotificationClass))

typedef struct _TubaWidgetsNotification TubaWidgetsNotification;
typedef struct _TubaWidgetsNotificationClass TubaWidgetsNotificationClass;

#define TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION (tuba_widgets_grouped_notification_get_type ())
#define TUBA_WIDGETS_GROUPED_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotification))
#define TUBA_WIDGETS_GROUPED_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotificationClass))
#define TUBA_WIDGETS_IS_GROUPED_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION))
#define TUBA_WIDGETS_IS_GROUPED_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION))
#define TUBA_WIDGETS_GROUPED_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_GROUPED_NOTIFICATION, TubaWidgetsGroupedNotificationClass))

typedef struct _TubaWidgetsGroupedNotification TubaWidgetsGroupedNotification;
typedef struct _TubaWidgetsGroupedNotificationClass TubaWidgetsGroupedNotificationClass;

#define TUBA_INSTANCE_ACCOUNT_TYPE_KIND (tuba_instance_account_kind_get_type ())
typedef struct _TubaInstanceAccountKind TubaInstanceAccountKind;

#define TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER (tuba_widgets_list_box_row_wrapper_get_type ())
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapper))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))

typedef struct _TubaWidgetsListBoxRowWrapper TubaWidgetsListBoxRowWrapper;
typedef struct _TubaWidgetsListBoxRowWrapperClass TubaWidgetsListBoxRowWrapperClass;

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIGroupedNotificationsResults {
	TubaEntity parent_instance;
	TubaAPIGroupedNotificationsResultsPrivate * priv;
};

struct _TubaAPIGroupedNotificationsResultsClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIGroupedNotificationsResultsPrivate {
	GeeArrayList* _accounts;
	GeeArrayList* _statuses;
	GeeArrayList* _notification_groups;
};

struct _TubaAPINotification {
	TubaEntity parent_instance;
	TubaAPINotificationPrivate * priv;
};

struct _TubaAPINotificationClass {
	TubaEntityClass parent_class;
	void (*to_toast) (TubaAPINotification* self, TubaInstanceAccount* issuer, gint others, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GNotification* (*to_toast_finish) (TubaAPINotification* self, GAsyncResult* _res_);
};

struct _TubaAPIGroupedNotificationsResultsNotificationGroup {
	TubaAPINotification parent_instance;
	TubaAPIGroupedNotificationsResultsNotificationGroupPrivate * priv;
};

struct _TubaAPIGroupedNotificationsResultsNotificationGroupClass {
	TubaAPINotificationClass parent_class;
};

struct _TubaAPIGroupedNotificationsResultsNotificationGroupPrivate {
	GeeArrayList* _sample_account_ids;
	gchar* _status_id;
	GeeArrayList* _tuba_accounts;
};

struct _TubaInstanceAccountKind {
	gchar* icon;
	gchar* description;
	gchar* url;
};

static gint TubaAPIGroupedNotificationsResults_private_offset;
static gpointer tuba_api_grouped_notifications_results_parent_class = NULL;
static gint TubaAPIGroupedNotificationsResultsNotificationGroup_private_offset;
static gpointer tuba_api_grouped_notifications_results_notification_group_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_grouped_notifications_results_notification_group_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_grouped_notifications_results_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIGroupedNotificationsResults, g_object_unref)
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN GType tuba_api_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotification, g_object_unref)
VALA_EXTERN GType tuba_api_grouped_notifications_results_notification_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIGroupedNotificationsResultsNotificationGroup, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_grouped_notifications_results_real_deserialize_array_type (TubaEntity* base,
                                                                          const gchar* prop);
VALA_EXTERN TubaAPIGroupedNotificationsResults* tuba_api_grouped_notifications_results_from (JsonNode* node,
                                                                                 GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN TubaAPIGroupedNotificationsResults* tuba_api_grouped_notifications_results_new (void);
VALA_EXTERN TubaAPIGroupedNotificationsResults* tuba_api_grouped_notifications_results_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_get_accounts (TubaAPIGroupedNotificationsResults* self);
VALA_EXTERN void tuba_api_grouped_notifications_results_set_accounts (TubaAPIGroupedNotificationsResults* self,
                                                          GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_get_statuses (TubaAPIGroupedNotificationsResults* self);
VALA_EXTERN void tuba_api_grouped_notifications_results_set_statuses (TubaAPIGroupedNotificationsResults* self,
                                                          GeeArrayList* value);
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_get_notification_groups (TubaAPIGroupedNotificationsResults* self);
VALA_EXTERN void tuba_api_grouped_notifications_results_set_notification_groups (TubaAPIGroupedNotificationsResults* self,
                                                                     GeeArrayList* value);
static GType tuba_api_grouped_notifications_results_notification_group_real_deserialize_array_type (TubaEntity* base,
                                                                                             const gchar* prop);
VALA_EXTERN TubaAPIGroupedNotificationsResultsNotificationGroup* tuba_api_grouped_notifications_results_notification_group_new_from_notification (TubaAPINotification* notification);
VALA_EXTERN TubaAPIGroupedNotificationsResultsNotificationGroup* tuba_api_grouped_notifications_results_notification_group_construct_from_notification (GType object_type,
                                                                                                                                            TubaAPINotification* notification);
VALA_EXTERN TubaAPINotification* tuba_api_notification_new (void);
VALA_EXTERN TubaAPINotification* tuba_api_notification_construct (GType object_type);
VALA_EXTERN void tuba_entity_patch (TubaEntity* self,
                        GObject* with);
VALA_EXTERN TubaAPIAccount* tuba_api_notification_get_account (TubaAPINotification* self);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_grouped_notifications_results_notification_group_set_sample_account_ids (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                                       GeeArrayList* value);
VALA_EXTERN TubaAPIStatus* tuba_api_notification_get_status (TubaAPINotification* self);
VALA_EXTERN const gchar* tuba_api_status_get_id (TubaAPIStatus* self);
VALA_EXTERN void tuba_api_grouped_notifications_results_notification_group_set_status_id (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                              const gchar* value);
VALA_EXTERN void tuba_api_grouped_notifications_results_notification_group_set_tuba_accounts (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                                  GeeArrayList* value);
static GtkWidget* tuba_api_grouped_notifications_results_notification_group_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (TubaAPIGroupedNotificationsResultsNotificationGroup* self);
VALA_EXTERN const gchar* tuba_api_notification_get_group_key (TubaAPINotification* self);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
VALA_EXTERN const gchar* tuba_api_notification_get_kind (TubaAPINotification* self);
static GtkWidget* tuba_api_grouped_notifications_results_notification_group_create_basic_card (TubaAPIGroupedNotificationsResultsNotificationGroup* self);
VALA_EXTERN TubaWidgetsGroupedNotification* tuba_widgets_grouped_notification_new (TubaAPIGroupedNotificationsResultsNotificationGroup* obj);
VALA_EXTERN TubaWidgetsGroupedNotification* tuba_widgets_grouped_notification_construct (GType object_type,
                                                                             TubaAPIGroupedNotificationsResultsNotificationGroup* obj);
VALA_EXTERN GType tuba_widgets_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatus, g_object_unref)
VALA_EXTERN GType tuba_widgets_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotification, g_object_unref)
VALA_EXTERN GType tuba_widgets_grouped_notification_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsGroupedNotification, g_object_unref)
VALA_EXTERN GType tuba_instance_account_kind_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaInstanceAccountKind* tuba_instance_account_kind_dup (const TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_free (TubaInstanceAccountKind* self);
VALA_EXTERN void tuba_instance_account_kind_copy (const TubaInstanceAccountKind* self,
                                      TubaInstanceAccountKind* dest);
VALA_EXTERN void tuba_instance_account_kind_destroy (TubaInstanceAccountKind* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaInstanceAccountKind, tuba_instance_account_kind_destroy)
VALA_EXTERN GtkBox* tuba_widgets_grouped_notification_group_box (TubaAPIGroupedNotificationsResultsNotificationGroup* obj,
                                                     const gchar* old_kind,
                                                     TubaInstanceAccountKind* res_kind);
VALA_EXTERN GType tuba_widgets_list_box_row_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsListBoxRowWrapper, g_object_unref)
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_new (void);
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_construct (GType object_type);
VALA_EXTERN TubaAPIGroupedNotificationsResultsNotificationGroup* tuba_api_grouped_notifications_results_notification_group_new (void);
VALA_EXTERN TubaAPIGroupedNotificationsResultsNotificationGroup* tuba_api_grouped_notifications_results_notification_group_construct (GType object_type);
VALA_EXTERN GeeArrayList* tuba_api_grouped_notifications_results_notification_group_get_sample_account_ids (TubaAPIGroupedNotificationsResultsNotificationGroup* self);
VALA_EXTERN const gchar* tuba_api_grouped_notifications_results_notification_group_get_status_id (TubaAPIGroupedNotificationsResultsNotificationGroup* self);
static void tuba_api_grouped_notifications_results_notification_group_finalize (GObject * obj);
static GType tuba_api_grouped_notifications_results_notification_group_get_type_once (void);
static void _vala_tuba_api_grouped_notifications_results_notification_group_get_property (GObject * object,
                                                                                   guint property_id,
                                                                                   GValue * value,
                                                                                   GParamSpec * pspec);
static void _vala_tuba_api_grouped_notifications_results_notification_group_set_property (GObject * object,
                                                                                   guint property_id,
                                                                                   const GValue * value,
                                                                                   GParamSpec * pspec);
static void tuba_api_grouped_notifications_results_finalize (GObject * obj);
static GType tuba_api_grouped_notifications_results_get_type_once (void);
static void _vala_tuba_api_grouped_notifications_results_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec);
static void _vala_tuba_api_grouped_notifications_results_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_api_grouped_notifications_results_get_instance_private (TubaAPIGroupedNotificationsResults* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIGroupedNotificationsResults_private_offset);
}

static GType
tuba_api_grouped_notifications_results_real_deserialize_array_type (TubaEntity* base,
                                                                    const gchar* prop)
{
	TubaAPIGroupedNotificationsResults * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	GType result;
	self = (TubaAPIGroupedNotificationsResults*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("accounts")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_ACCOUNT;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("statuses")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_TYPE_STATUS;
				return result;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("notification-groups")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_grouped_notifications_results_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPIGroupedNotificationsResults*
tuba_api_grouped_notifications_results_from (JsonNode* node,
                                             GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPIGroupedNotificationsResults* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPIGroupedNotificationsResults* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_IS_GROUPED_NOTIFICATIONS_RESULTS (_tmp0_) ? ((TubaAPIGroupedNotificationsResults*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPIGroupedNotificationsResults*
tuba_api_grouped_notifications_results_construct (GType object_type)
{
	TubaAPIGroupedNotificationsResults * self = NULL;
	self = (TubaAPIGroupedNotificationsResults*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIGroupedNotificationsResults*
tuba_api_grouped_notifications_results_new (void)
{
	return tuba_api_grouped_notifications_results_construct (TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS);
}

GeeArrayList*
tuba_api_grouped_notifications_results_get_accounts (TubaAPIGroupedNotificationsResults* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_accounts;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_set_accounts (TubaAPIGroupedNotificationsResults* self,
                                                     GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_get_accounts (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_accounts);
		self->priv->_accounts = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_grouped_notifications_results_get_statuses (TubaAPIGroupedNotificationsResults* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_statuses;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_set_statuses (TubaAPIGroupedNotificationsResults* self,
                                                     GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_get_statuses (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_statuses);
		self->priv->_statuses = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_grouped_notifications_results_get_notification_groups (TubaAPIGroupedNotificationsResults* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_notification_groups;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_set_notification_groups (TubaAPIGroupedNotificationsResults* self,
                                                                GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_get_notification_groups (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_notification_groups);
		self->priv->_notification_groups = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY]);
	}
}

static inline gpointer
tuba_api_grouped_notifications_results_notification_group_get_instance_private (TubaAPIGroupedNotificationsResultsNotificationGroup* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIGroupedNotificationsResultsNotificationGroup_private_offset);
}

static GType
tuba_api_grouped_notifications_results_notification_group_real_deserialize_array_type (TubaEntity* base,
                                                                                       const gchar* prop)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIGroupedNotificationsResultsNotificationGroup*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("sample-account-ids")))) {
		switch (0) {
			default:
			{
				result = G_TYPE_STRING;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_grouped_notifications_results_notification_group_parent_class)->deserialize_array_type ((TubaEntity*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_API_TYPE_NOTIFICATION, TubaAPINotification), prop);
	return result;
}

TubaAPIGroupedNotificationsResultsNotificationGroup*
tuba_api_grouped_notifications_results_notification_group_construct_from_notification (GType object_type,
                                                                                       TubaAPINotification* notification)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self = NULL;
	TubaAPIAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar** _tmp5_;
	GeeArrayList* _tmp6_;
	GeeArrayList* _tmp7_;
	TubaAPIStatus* _tmp8_;
	TubaAPIStatus* _tmp9_;
	TubaAPIAccount* _tmp14_;
	TubaAPIAccount* _tmp15_;
	TubaAPIAccount* _tmp16_;
	TubaAPIAccount** _tmp17_;
	GeeArrayList* _tmp18_;
	GeeArrayList* _tmp19_;
	g_return_val_if_fail (notification != NULL, NULL);
	self = (TubaAPIGroupedNotificationsResultsNotificationGroup*) tuba_api_notification_construct (object_type);
	tuba_entity_patch ((TubaEntity*) self, (GObject*) notification);
	_tmp0_ = tuba_api_notification_get_account (notification);
	_tmp1_ = _tmp0_;
	_tmp2_ = tuba_api_account_get_id (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = g_strdup (_tmp3_);
	_tmp5_ = g_new0 (gchar*, 1 + 1);
	_tmp5_[0] = _tmp4_;
	_tmp6_ = gee_array_list_new_wrap (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, (GDestroyNotify) g_free, _tmp5_, 1, NULL, NULL, NULL);
	_tmp7_ = _tmp6_;
	tuba_api_grouped_notifications_results_notification_group_set_sample_account_ids (self, _tmp7_);
	_g_object_unref0 (_tmp7_);
	_tmp8_ = tuba_api_notification_get_status (notification);
	_tmp9_ = _tmp8_;
	if (_tmp9_ != NULL) {
		TubaAPIStatus* _tmp10_;
		TubaAPIStatus* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		_tmp10_ = tuba_api_notification_get_status (notification);
		_tmp11_ = _tmp10_;
		_tmp12_ = tuba_api_status_get_id (_tmp11_);
		_tmp13_ = _tmp12_;
		tuba_api_grouped_notifications_results_notification_group_set_status_id (self, _tmp13_);
	}
	_tmp14_ = tuba_api_notification_get_account (notification);
	_tmp15_ = _tmp14_;
	_tmp16_ = _g_object_ref0 (_tmp15_);
	_tmp17_ = g_new0 (TubaAPIAccount*, 1 + 1);
	_tmp17_[0] = _tmp16_;
	_tmp18_ = gee_array_list_new_wrap (TUBA_API_TYPE_ACCOUNT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _tmp17_, 1, NULL, NULL, NULL);
	_tmp19_ = _tmp18_;
	tuba_api_grouped_notifications_results_notification_group_set_tuba_accounts (self, _tmp19_);
	_g_object_unref0 (_tmp19_);
	return self;
}

TubaAPIGroupedNotificationsResultsNotificationGroup*
tuba_api_grouped_notifications_results_notification_group_new_from_notification (TubaAPINotification* notification)
{
	return tuba_api_grouped_notifications_results_notification_group_construct_from_notification (TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, notification);
}

static GtkWidget*
tuba_api_grouped_notifications_results_notification_group_real_to_widget (TubaWidgetizable* base)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self;
	gboolean _tmp0_ = FALSE;
	GeeArrayList* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	GQuark _tmp11_ = 0U;
	static GQuark _tmp10_label0 = 0;
	static GQuark _tmp10_label1 = 0;
	GtkWidget* result;
	self = (TubaAPIGroupedNotificationsResultsNotificationGroup*) base;
	_tmp1_ = self->priv->_tuba_accounts;
	_tmp2_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_ == 1) {
		_tmp0_ = TRUE;
	} else {
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp4_ = tuba_api_notification_get_group_key ((TubaAPINotification*) self);
		_tmp5_ = _tmp4_;
		_tmp0_ = g_str_has_prefix (_tmp5_, "ungrouped-");
	}
	if (_tmp0_) {
		GtkWidget* _tmp6_;
		_tmp6_ = tuba_api_grouped_notifications_results_notification_group_tuba_widgetizable_parent_iface->to_widget ((TubaWidgetizable*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_API_TYPE_NOTIFICATION, TubaAPINotification));
		result = _tmp6_;
		return result;
	}
	_tmp7_ = tuba_api_notification_get_kind ((TubaAPINotification*) self);
	_tmp8_ = _tmp7_;
	_tmp9_ = _tmp8_;
	_tmp11_ = (NULL == _tmp9_) ? 0 : g_quark_from_string (_tmp9_);
	if ((_tmp11_ == ((0 != _tmp10_label0) ? _tmp10_label0 : (_tmp10_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW)))) || (_tmp11_ == ((0 != _tmp10_label1) ? _tmp10_label1 : (_tmp10_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP))))) {
		switch (0) {
			default:
			{
				GtkWidget* _tmp12_;
				_tmp12_ = tuba_api_grouped_notifications_results_notification_group_create_basic_card (self);
				result = _tmp12_;
				return result;
			}
		}
	} else {
		switch (0) {
			default:
			{
				TubaWidgetsGroupedNotification* _tmp13_;
				_tmp13_ = tuba_widgets_grouped_notification_new (self);
				g_object_ref_sink (_tmp13_);
				result = (GtkWidget*) _tmp13_;
				return result;
			}
		}
	}
}

static GtkWidget*
tuba_api_grouped_notifications_results_notification_group_create_basic_card (TubaAPIGroupedNotificationsResultsNotificationGroup* self)
{
	GtkBox* box = NULL;
	GtkBox* _tmp0_ = NULL;
	TubaInstanceAccountKind res_kind = {0};
	GtkBox* sub_box = NULL;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	TubaInstanceAccountKind _tmp3_ = {0};
	GtkBox* _tmp4_;
	GtkImage* group_icon = NULL;
	TubaInstanceAccountKind _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar** _tmp8_;
	GtkImage* _tmp9_ = NULL;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	GQuark _tmp14_ = 0U;
	static GQuark _tmp13_label0 = 0;
	static GQuark _tmp13_label1 = 0;
	static GQuark _tmp13_label2 = 0;
	static GQuark _tmp13_label3 = 0;
	static GQuark _tmp13_label4 = 0;
	GtkBox* _tmp19_;
	GtkImage* _tmp20_;
	GtkBox* _tmp21_;
	GtkBox* _tmp22_;
	TubaWidgetsListBoxRowWrapper* row = NULL;
	GtkBox* _tmp23_;
	GtkWidget* _tmp24_;
	TubaWidgetsListBoxRowWrapper* _tmp25_ = NULL;
	GtkWidget* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 16);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp0_, 8);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp0_, 8);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp0_, 16);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp0_, 16);
	g_object_ref_sink (_tmp0_);
	box = _tmp0_;
	_tmp1_ = tuba_api_notification_get_kind ((TubaAPINotification*) self);
	_tmp2_ = _tmp1_;
	_tmp4_ = tuba_widgets_grouped_notification_group_box (self, _tmp2_, &_tmp3_);
	tuba_instance_account_kind_destroy (&res_kind);
	res_kind = _tmp3_;
	sub_box = _tmp4_;
	_tmp5_ = res_kind;
	_tmp6_ = _tmp5_.icon;
	_tmp7_ = g_strdup ("grouped-icon");
	_tmp8_ = g_new0 (gchar*, 1 + 1);
	_tmp8_[0] = _tmp7_;
	_tmp9_ = (GtkImage*) gtk_image_new_from_icon_name (_tmp6_);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp9_, 22);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp9_, 3);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp9_, _tmp8_);
	_tmp8_ = (_vala_array_free (_tmp8_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_halign ((GtkWidget*) _tmp9_, GTK_ALIGN_CENTER);
	g_object_ref_sink (_tmp9_);
	group_icon = _tmp9_;
	_tmp10_ = tuba_api_notification_get_kind ((TubaAPINotification*) self);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp14_ = (NULL == _tmp12_) ? 0 : g_quark_from_string (_tmp12_);
	if (_tmp14_ == ((0 != _tmp13_label0) ? _tmp13_label0 : (_tmp13_label0 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FAVOURITE)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp15_;
				_tmp15_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp15_, "star");
				break;
			}
		}
	} else if (_tmp14_ == ((0 != _tmp13_label1) ? _tmp13_label1 : (_tmp13_label1 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_REBLOG)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp16_;
				_tmp16_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp16_, "reblog");
				break;
			}
		}
	} else if (_tmp14_ == ((0 != _tmp13_label2) ? _tmp13_label2 : (_tmp13_label2 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_ADMIN_SIGNUP)))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp17_;
				_tmp17_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp17_, "sign-up");
				break;
			}
		}
	} else if ((_tmp14_ == ((0 != _tmp13_label3) ? _tmp13_label3 : (_tmp13_label3 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW)))) || (_tmp14_ == ((0 != _tmp13_label4) ? _tmp13_label4 : (_tmp13_label4 = g_quark_from_static_string (TUBA_INSTANCE_ACCOUNT_KIND_FOLLOW_REQUEST))))) {
		switch (0) {
			default:
			{
				GtkImage* _tmp18_;
				_tmp18_ = group_icon;
				gtk_widget_add_css_class ((GtkWidget*) _tmp18_, "follow");
				break;
			}
		}
	}
	_tmp19_ = box;
	_tmp20_ = group_icon;
	gtk_box_append (_tmp19_, (GtkWidget*) _tmp20_);
	_tmp21_ = box;
	_tmp22_ = sub_box;
	gtk_box_append (_tmp21_, (GtkWidget*) _tmp22_);
	_tmp23_ = box;
	_tmp24_ = _g_object_ref0 ((GtkWidget*) _tmp23_);
	_tmp25_ = tuba_widgets_list_box_row_wrapper_new ();
	gtk_list_box_row_set_child ((GtkListBoxRow*) _tmp25_, _tmp24_);
	_g_object_unref0 (_tmp24_);
	gtk_list_box_row_set_activatable ((GtkListBoxRow*) _tmp25_, FALSE);
	g_object_ref_sink (_tmp25_);
	row = _tmp25_;
	result = (GtkWidget*) row;
	_g_object_unref0 (group_icon);
	_g_object_unref0 (sub_box);
	tuba_instance_account_kind_destroy (&res_kind);
	_g_object_unref0 (box);
	return result;
}

TubaAPIGroupedNotificationsResultsNotificationGroup*
tuba_api_grouped_notifications_results_notification_group_construct (GType object_type)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self = NULL;
	self = (TubaAPIGroupedNotificationsResultsNotificationGroup*) tuba_api_notification_construct (object_type);
	return self;
}

TubaAPIGroupedNotificationsResultsNotificationGroup*
tuba_api_grouped_notifications_results_notification_group_new (void)
{
	return tuba_api_grouped_notifications_results_notification_group_construct (TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP);
}

GeeArrayList*
tuba_api_grouped_notifications_results_notification_group_get_sample_account_ids (TubaAPIGroupedNotificationsResultsNotificationGroup* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_sample_account_ids;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_notification_group_set_sample_account_ids (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                                  GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_notification_group_get_sample_account_ids (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_sample_account_ids);
		self->priv->_sample_account_ids = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY]);
	}
}

const gchar*
tuba_api_grouped_notifications_results_notification_group_get_status_id (TubaAPIGroupedNotificationsResultsNotificationGroup* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_status_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_notification_group_set_status_id (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_notification_group_get_status_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_status_id);
		self->priv->_status_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (TubaAPIGroupedNotificationsResultsNotificationGroup* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_tuba_accounts;
	result = _tmp0_;
	return result;
}

void
tuba_api_grouped_notifications_results_notification_group_set_tuba_accounts (TubaAPIGroupedNotificationsResultsNotificationGroup* self,
                                                                             GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_tuba_accounts);
		self->priv->_tuba_accounts = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY]);
	}
}

static void
tuba_api_grouped_notifications_results_notification_group_class_init (TubaAPIGroupedNotificationsResultsNotificationGroupClass * klass,
                                                                      gpointer klass_data)
{
	tuba_api_grouped_notifications_results_notification_group_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIGroupedNotificationsResultsNotificationGroup_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_grouped_notifications_results_notification_group_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_grouped_notifications_results_notification_group_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_grouped_notifications_results_notification_group_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_grouped_notifications_results_notification_group_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY] = g_param_spec_object ("sample-account-ids", "sample-account-ids", "sample-account-ids", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY] = g_param_spec_string ("status-id", "status-id", "status-id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY, tuba_api_grouped_notifications_results_notification_group_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY] = g_param_spec_object ("tuba-accounts", "tuba-accounts", "tuba-accounts", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_grouped_notifications_results_notification_group_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                                            gpointer iface_data)
{
	tuba_api_grouped_notifications_results_notification_group_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_grouped_notifications_results_notification_group_real_to_widget;
}

static void
tuba_api_grouped_notifications_results_notification_group_instance_init (TubaAPIGroupedNotificationsResultsNotificationGroup * self,
                                                                         gpointer klass)
{
	self->priv = tuba_api_grouped_notifications_results_notification_group_get_instance_private (self);
	self->priv->_status_id = NULL;
}

static void
tuba_api_grouped_notifications_results_notification_group_finalize (GObject * obj)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroup);
	_g_object_unref0 (self->priv->_sample_account_ids);
	_g_free0 (self->priv->_status_id);
	_g_object_unref0 (self->priv->_tuba_accounts);
	G_OBJECT_CLASS (tuba_api_grouped_notifications_results_notification_group_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_grouped_notifications_results_notification_group_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIGroupedNotificationsResultsNotificationGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_grouped_notifications_results_notification_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIGroupedNotificationsResultsNotificationGroup), 0, (GInstanceInitFunc) tuba_api_grouped_notifications_results_notification_group_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_grouped_notifications_results_notification_group_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_grouped_notifications_results_notification_group_type_id;
	tuba_api_grouped_notifications_results_notification_group_type_id = g_type_register_static (TUBA_API_TYPE_NOTIFICATION, "TubaAPIGroupedNotificationsResultsNotificationGroup", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_grouped_notifications_results_notification_group_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPIGroupedNotificationsResultsNotificationGroup_private_offset = g_type_add_instance_private (tuba_api_grouped_notifications_results_notification_group_type_id, sizeof (TubaAPIGroupedNotificationsResultsNotificationGroupPrivate));
	return tuba_api_grouped_notifications_results_notification_group_type_id;
}

GType
tuba_api_grouped_notifications_results_notification_group_get_type (void)
{
	static GType tuba_api_grouped_notifications_results_notification_group_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_grouped_notifications_results_notification_group_type_id__once)) {
		GType tuba_api_grouped_notifications_results_notification_group_type_id;
		tuba_api_grouped_notifications_results_notification_group_type_id = tuba_api_grouped_notifications_results_notification_group_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_grouped_notifications_results_notification_group_type_id__once, tuba_api_grouped_notifications_results_notification_group_type_id);
	}
	return tuba_api_grouped_notifications_results_notification_group_type_id__once;
}

static void
_vala_tuba_api_grouped_notifications_results_notification_group_get_property (GObject * object,
                                                                              guint property_id,
                                                                              GValue * value,
                                                                              GParamSpec * pspec)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroup);
	switch (property_id) {
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY:
		g_value_set_object (value, tuba_api_grouped_notifications_results_notification_group_get_sample_account_ids (self));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY:
		g_value_set_string (value, tuba_api_grouped_notifications_results_notification_group_get_status_id (self));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY:
		g_value_set_object (value, tuba_api_grouped_notifications_results_notification_group_get_tuba_accounts (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_grouped_notifications_results_notification_group_set_property (GObject * object,
                                                                              guint property_id,
                                                                              const GValue * value,
                                                                              GParamSpec * pspec)
{
	TubaAPIGroupedNotificationsResultsNotificationGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_TYPE_NOTIFICATION_GROUP, TubaAPIGroupedNotificationsResultsNotificationGroup);
	switch (property_id) {
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_SAMPLE_ACCOUNT_IDS_PROPERTY:
		tuba_api_grouped_notifications_results_notification_group_set_sample_account_ids (self, g_value_get_object (value));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_STATUS_ID_PROPERTY:
		tuba_api_grouped_notifications_results_notification_group_set_status_id (self, g_value_get_string (value));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUP_TUBA_ACCOUNTS_PROPERTY:
		tuba_api_grouped_notifications_results_notification_group_set_tuba_accounts (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_grouped_notifications_results_class_init (TubaAPIGroupedNotificationsResultsClass * klass,
                                                   gpointer klass_data)
{
	tuba_api_grouped_notifications_results_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIGroupedNotificationsResults_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_grouped_notifications_results_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_grouped_notifications_results_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_grouped_notifications_results_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_grouped_notifications_results_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY] = g_param_spec_object ("accounts", "accounts", "accounts", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY] = g_param_spec_object ("statuses", "statuses", "statuses", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY, tuba_api_grouped_notifications_results_properties[TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY] = g_param_spec_object ("notification-groups", "notification-groups", "notification-groups", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_grouped_notifications_results_instance_init (TubaAPIGroupedNotificationsResults * self,
                                                      gpointer klass)
{
	self->priv = tuba_api_grouped_notifications_results_get_instance_private (self);
}

static void
tuba_api_grouped_notifications_results_finalize (GObject * obj)
{
	TubaAPIGroupedNotificationsResults * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResults);
	_g_object_unref0 (self->priv->_accounts);
	_g_object_unref0 (self->priv->_statuses);
	_g_object_unref0 (self->priv->_notification_groups);
	G_OBJECT_CLASS (tuba_api_grouped_notifications_results_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_grouped_notifications_results_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIGroupedNotificationsResultsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_grouped_notifications_results_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIGroupedNotificationsResults), 0, (GInstanceInitFunc) tuba_api_grouped_notifications_results_instance_init, NULL };
	GType tuba_api_grouped_notifications_results_type_id;
	tuba_api_grouped_notifications_results_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIGroupedNotificationsResults", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIGroupedNotificationsResults_private_offset = g_type_add_instance_private (tuba_api_grouped_notifications_results_type_id, sizeof (TubaAPIGroupedNotificationsResultsPrivate));
	return tuba_api_grouped_notifications_results_type_id;
}

GType
tuba_api_grouped_notifications_results_get_type (void)
{
	static GType tuba_api_grouped_notifications_results_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_grouped_notifications_results_type_id__once)) {
		GType tuba_api_grouped_notifications_results_type_id;
		tuba_api_grouped_notifications_results_type_id = tuba_api_grouped_notifications_results_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_grouped_notifications_results_type_id__once, tuba_api_grouped_notifications_results_type_id);
	}
	return tuba_api_grouped_notifications_results_type_id__once;
}

static void
_vala_tuba_api_grouped_notifications_results_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec)
{
	TubaAPIGroupedNotificationsResults * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResults);
	switch (property_id) {
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY:
		g_value_set_object (value, tuba_api_grouped_notifications_results_get_accounts (self));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY:
		g_value_set_object (value, tuba_api_grouped_notifications_results_get_statuses (self));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY:
		g_value_set_object (value, tuba_api_grouped_notifications_results_get_notification_groups (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_grouped_notifications_results_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec)
{
	TubaAPIGroupedNotificationsResults * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_GROUPED_NOTIFICATIONS_RESULTS, TubaAPIGroupedNotificationsResults);
	switch (property_id) {
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_ACCOUNTS_PROPERTY:
		tuba_api_grouped_notifications_results_set_accounts (self, g_value_get_object (value));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_STATUSES_PROPERTY:
		tuba_api_grouped_notifications_results_set_statuses (self, g_value_get_object (value));
		break;
		case TUBA_API_GROUPED_NOTIFICATIONS_RESULTS_NOTIFICATION_GROUPS_PROPERTY:
		tuba_api_grouped_notifications_results_set_notification_groups (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

