/* Resolution.c generated by valac 0.56.19, the Vala compiler
 * generated from Resolution.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_PEER_TUBE_RESOLUTION (tuba_api_peer_tube_resolution_get_type ())
#define TUBA_API_PEER_TUBE_RESOLUTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolution))
#define TUBA_API_PEER_TUBE_RESOLUTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolutionClass))
#define TUBA_API_IS_PEER_TUBE_RESOLUTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_PEER_TUBE_RESOLUTION))
#define TUBA_API_IS_PEER_TUBE_RESOLUTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_PEER_TUBE_RESOLUTION))
#define TUBA_API_PEER_TUBE_RESOLUTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolutionClass))

typedef struct _TubaAPIPeerTubeResolution TubaAPIPeerTubeResolution;
typedef struct _TubaAPIPeerTubeResolutionClass TubaAPIPeerTubeResolutionClass;
typedef struct _TubaAPIPeerTubeResolutionPrivate TubaAPIPeerTubeResolutionPrivate;
enum  {
	TUBA_API_PEER_TUBE_RESOLUTION_0_PROPERTY,
	TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY,
	TUBA_API_PEER_TUBE_RESOLUTION_NUM_PROPERTIES
};
static GParamSpec* tuba_api_peer_tube_resolution_properties[TUBA_API_PEER_TUBE_RESOLUTION_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPIPeerTubeResolution {
	TubaEntity parent_instance;
	TubaAPIPeerTubeResolutionPrivate * priv;
};

struct _TubaAPIPeerTubeResolutionClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIPeerTubeResolutionPrivate {
	gint64 _id;
};

static gint TubaAPIPeerTubeResolution_private_offset;
static gpointer tuba_api_peer_tube_resolution_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_peer_tube_resolution_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPeerTubeResolution, g_object_unref)
VALA_EXTERN TubaAPIPeerTubeResolution* tuba_api_peer_tube_resolution_new (void);
VALA_EXTERN TubaAPIPeerTubeResolution* tuba_api_peer_tube_resolution_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN gint64 tuba_api_peer_tube_resolution_get_id (TubaAPIPeerTubeResolution* self);
VALA_EXTERN void tuba_api_peer_tube_resolution_set_id (TubaAPIPeerTubeResolution* self,
                                           gint64 value);
static void tuba_api_peer_tube_resolution_finalize (GObject * obj);
static GType tuba_api_peer_tube_resolution_get_type_once (void);
static void _vala_tuba_api_peer_tube_resolution_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec);
static void _vala_tuba_api_peer_tube_resolution_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec);

static inline gpointer
tuba_api_peer_tube_resolution_get_instance_private (TubaAPIPeerTubeResolution* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIPeerTubeResolution_private_offset);
}

TubaAPIPeerTubeResolution*
tuba_api_peer_tube_resolution_construct (GType object_type)
{
	TubaAPIPeerTubeResolution * self = NULL;
	self = (TubaAPIPeerTubeResolution*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIPeerTubeResolution*
tuba_api_peer_tube_resolution_new (void)
{
	return tuba_api_peer_tube_resolution_construct (TUBA_API_TYPE_PEER_TUBE_RESOLUTION);
}

gint64
tuba_api_peer_tube_resolution_get_id (TubaAPIPeerTubeResolution* self)
{
	gint64 result;
	g_return_val_if_fail (self != NULL, -1LL);
	result = self->priv->_id;
	return result;
}

void
tuba_api_peer_tube_resolution_set_id (TubaAPIPeerTubeResolution* self,
                                      gint64 value)
{
	gint64 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_peer_tube_resolution_get_id (self);
	if (old_value != value) {
		self->priv->_id = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_peer_tube_resolution_properties[TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY]);
	}
}

static void
tuba_api_peer_tube_resolution_class_init (TubaAPIPeerTubeResolutionClass * klass,
                                          gpointer klass_data)
{
	tuba_api_peer_tube_resolution_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIPeerTubeResolution_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_peer_tube_resolution_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_peer_tube_resolution_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_peer_tube_resolution_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY, tuba_api_peer_tube_resolution_properties[TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY] = g_param_spec_int64 ("id", "id", "id", G_MININT64, G_MAXINT64, (gint64) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_peer_tube_resolution_instance_init (TubaAPIPeerTubeResolution * self,
                                             gpointer klass)
{
	self->priv = tuba_api_peer_tube_resolution_get_instance_private (self);
	self->priv->_id = (gint64) 0;
}

static void
tuba_api_peer_tube_resolution_finalize (GObject * obj)
{
	TubaAPIPeerTubeResolution * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolution);
	G_OBJECT_CLASS (tuba_api_peer_tube_resolution_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_peer_tube_resolution_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIPeerTubeResolutionClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_peer_tube_resolution_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIPeerTubeResolution), 0, (GInstanceInitFunc) tuba_api_peer_tube_resolution_instance_init, NULL };
	GType tuba_api_peer_tube_resolution_type_id;
	tuba_api_peer_tube_resolution_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIPeerTubeResolution", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIPeerTubeResolution_private_offset = g_type_add_instance_private (tuba_api_peer_tube_resolution_type_id, sizeof (TubaAPIPeerTubeResolutionPrivate));
	return tuba_api_peer_tube_resolution_type_id;
}

GType
tuba_api_peer_tube_resolution_get_type (void)
{
	static GType tuba_api_peer_tube_resolution_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_peer_tube_resolution_type_id__once)) {
		GType tuba_api_peer_tube_resolution_type_id;
		tuba_api_peer_tube_resolution_type_id = tuba_api_peer_tube_resolution_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_peer_tube_resolution_type_id__once, tuba_api_peer_tube_resolution_type_id);
	}
	return tuba_api_peer_tube_resolution_type_id__once;
}

static void
_vala_tuba_api_peer_tube_resolution_get_property (GObject * object,
                                                  guint property_id,
                                                  GValue * value,
                                                  GParamSpec * pspec)
{
	TubaAPIPeerTubeResolution * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolution);
	switch (property_id) {
		case TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY:
		g_value_set_int64 (value, tuba_api_peer_tube_resolution_get_id (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_peer_tube_resolution_set_property (GObject * object,
                                                  guint property_id,
                                                  const GValue * value,
                                                  GParamSpec * pspec)
{
	TubaAPIPeerTubeResolution * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_PEER_TUBE_RESOLUTION, TubaAPIPeerTubeResolution);
	switch (property_id) {
		case TUBA_API_PEER_TUBE_RESOLUTION_ID_PROPERTY:
		tuba_api_peer_tube_resolution_set_id (self, g_value_get_int64 (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

