/* Nodeinfo.c generated by valac 0.56.19, the Vala compiler
 * generated from Nodeinfo.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_TYPE_NODEINFO (tuba_api_nodeinfo_get_type ())
#define TUBA_API_NODEINFO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NODEINFO, TubaAPINodeinfo))
#define TUBA_API_NODEINFO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NODEINFO, TubaAPINodeinfoClass))
#define TUBA_API_IS_NODEINFO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NODEINFO))
#define TUBA_API_IS_NODEINFO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NODEINFO))
#define TUBA_API_NODEINFO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NODEINFO, TubaAPINodeinfoClass))

typedef struct _TubaAPINodeinfo TubaAPINodeinfo;
typedef struct _TubaAPINodeinfoClass TubaAPINodeinfoClass;
typedef struct _TubaAPINodeinfoPrivate TubaAPINodeinfoPrivate;

#define TUBA_API_NODEINFO_TYPE_LINK (tuba_api_nodeinfo_link_get_type ())
#define TUBA_API_NODEINFO_LINK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLink))
#define TUBA_API_NODEINFO_LINK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLinkClass))
#define TUBA_API_NODEINFO_IS_LINK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NODEINFO_TYPE_LINK))
#define TUBA_API_NODEINFO_IS_LINK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NODEINFO_TYPE_LINK))
#define TUBA_API_NODEINFO_LINK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLinkClass))

typedef struct _TubaAPINodeinfoLink TubaAPINodeinfoLink;
typedef struct _TubaAPINodeinfoLinkClass TubaAPINodeinfoLinkClass;
enum  {
	TUBA_API_NODEINFO_0_PROPERTY,
	TUBA_API_NODEINFO_LINKS_PROPERTY,
	TUBA_API_NODEINFO_NUM_PROPERTIES
};
static GParamSpec* tuba_api_nodeinfo_properties[TUBA_API_NODEINFO_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_API_NODEINFO_TYPE_V20 (tuba_api_nodeinfo_v20_get_type ())
#define TUBA_API_NODEINFO_V20(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20))
#define TUBA_API_NODEINFO_V20_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20Class))
#define TUBA_API_NODEINFO_IS_V20(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NODEINFO_TYPE_V20))
#define TUBA_API_NODEINFO_IS_V20_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NODEINFO_TYPE_V20))
#define TUBA_API_NODEINFO_V20_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20Class))

typedef struct _TubaAPINodeinfoV20 TubaAPINodeinfoV20;
typedef struct _TubaAPINodeinfoV20Class TubaAPINodeinfoV20Class;
typedef struct _TubaAPINodeinfoV20Private TubaAPINodeinfoV20Private;

#define TUBA_API_NODEINFO_V20_TYPE_SOFTWARE (tuba_api_nodeinfo_v20_software_get_type ())
#define TUBA_API_NODEINFO_V20_SOFTWARE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20Software))
#define TUBA_API_NODEINFO_V20_SOFTWARE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20SoftwareClass))
#define TUBA_API_NODEINFO_V20_IS_SOFTWARE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NODEINFO_V20_TYPE_SOFTWARE))
#define TUBA_API_NODEINFO_V20_IS_SOFTWARE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NODEINFO_V20_TYPE_SOFTWARE))
#define TUBA_API_NODEINFO_V20_SOFTWARE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20SoftwareClass))

typedef struct _TubaAPINodeinfoV20Software TubaAPINodeinfoV20Software;
typedef struct _TubaAPINodeinfoV20SoftwareClass TubaAPINodeinfoV20SoftwareClass;
enum  {
	TUBA_API_NODEINFO_V20_0_PROPERTY,
	TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY,
	TUBA_API_NODEINFO_V20_NUM_PROPERTIES
};
static GParamSpec* tuba_api_nodeinfo_v20_properties[TUBA_API_NODEINFO_V20_NUM_PROPERTIES];
typedef struct _TubaAPINodeinfoV20SoftwarePrivate TubaAPINodeinfoV20SoftwarePrivate;
enum  {
	TUBA_API_NODEINFO_V20_SOFTWARE_0_PROPERTY,
	TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY,
	TUBA_API_NODEINFO_V20_SOFTWARE_NUM_PROPERTIES
};
static GParamSpec* tuba_api_nodeinfo_v20_software_properties[TUBA_API_NODEINFO_V20_SOFTWARE_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _TubaAPINodeinfoLinkPrivate TubaAPINodeinfoLinkPrivate;
enum  {
	TUBA_API_NODEINFO_LINK_0_PROPERTY,
	TUBA_API_NODEINFO_LINK_REL_PROPERTY,
	TUBA_API_NODEINFO_LINK_HREF_PROPERTY,
	TUBA_API_NODEINFO_LINK_NUM_PROPERTIES
};
static GParamSpec* tuba_api_nodeinfo_link_properties[TUBA_API_NODEINFO_LINK_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPINodeinfo {
	TubaEntity parent_instance;
	TubaAPINodeinfoPrivate * priv;
};

struct _TubaAPINodeinfoClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINodeinfoPrivate {
	GeeArrayList* _links;
};

struct _TubaAPINodeinfoV20 {
	TubaEntity parent_instance;
	TubaAPINodeinfoV20Private * priv;
};

struct _TubaAPINodeinfoV20Class {
	TubaEntityClass parent_class;
};

struct _TubaAPINodeinfoV20Private {
	TubaAPINodeinfoV20Software* _software;
};

struct _TubaAPINodeinfoV20Software {
	TubaEntity parent_instance;
	TubaAPINodeinfoV20SoftwarePrivate * priv;
};

struct _TubaAPINodeinfoV20SoftwareClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINodeinfoV20SoftwarePrivate {
	gchar* _name;
};

struct _TubaAPINodeinfoLink {
	TubaEntity parent_instance;
	TubaAPINodeinfoLinkPrivate * priv;
};

struct _TubaAPINodeinfoLinkClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINodeinfoLinkPrivate {
	gchar* _rel;
	gchar* _href;
};

static gint TubaAPINodeinfo_private_offset;
static gpointer tuba_api_nodeinfo_parent_class = NULL;
static gint TubaAPINodeinfoV20_private_offset;
static gpointer tuba_api_nodeinfo_v20_parent_class = NULL;
static gint TubaAPINodeinfoV20Software_private_offset;
static gpointer tuba_api_nodeinfo_v20_software_parent_class = NULL;
static gint TubaAPINodeinfoLink_private_offset;
static gpointer tuba_api_nodeinfo_link_parent_class = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_nodeinfo_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINodeinfo, g_object_unref)
VALA_EXTERN GType tuba_api_nodeinfo_link_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINodeinfoLink, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_nodeinfo_real_deserialize_array_type (TubaEntity* base,
                                                     const gchar* prop);
VALA_EXTERN TubaAPINodeinfo* tuba_api_nodeinfo_new (void);
VALA_EXTERN TubaAPINodeinfo* tuba_api_nodeinfo_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN GeeArrayList* tuba_api_nodeinfo_get_links (TubaAPINodeinfo* self);
VALA_EXTERN void tuba_api_nodeinfo_set_links (TubaAPINodeinfo* self,
                                  GeeArrayList* value);
VALA_EXTERN GType tuba_api_nodeinfo_v20_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINodeinfoV20, g_object_unref)
VALA_EXTERN GType tuba_api_nodeinfo_v20_software_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINodeinfoV20Software, g_object_unref)
VALA_EXTERN TubaAPINodeinfoV20* tuba_api_nodeinfo_v20_new (void);
VALA_EXTERN TubaAPINodeinfoV20* tuba_api_nodeinfo_v20_construct (GType object_type);
VALA_EXTERN TubaAPINodeinfoV20Software* tuba_api_nodeinfo_v20_get_software (TubaAPINodeinfoV20* self);
VALA_EXTERN void tuba_api_nodeinfo_v20_set_software (TubaAPINodeinfoV20* self,
                                         TubaAPINodeinfoV20Software* value);
VALA_EXTERN TubaAPINodeinfoV20Software* tuba_api_nodeinfo_v20_software_new (void);
VALA_EXTERN TubaAPINodeinfoV20Software* tuba_api_nodeinfo_v20_software_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_nodeinfo_v20_software_get_name (TubaAPINodeinfoV20Software* self);
VALA_EXTERN void tuba_api_nodeinfo_v20_software_set_name (TubaAPINodeinfoV20Software* self,
                                              const gchar* value);
static void tuba_api_nodeinfo_v20_software_finalize (GObject * obj);
static GType tuba_api_nodeinfo_v20_software_get_type_once (void);
static void _vala_tuba_api_nodeinfo_v20_software_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec);
static void _vala_tuba_api_nodeinfo_v20_software_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec);
static void tuba_api_nodeinfo_v20_finalize (GObject * obj);
static GType tuba_api_nodeinfo_v20_get_type_once (void);
static void _vala_tuba_api_nodeinfo_v20_get_property (GObject * object,
                                               guint property_id,
                                               GValue * value,
                                               GParamSpec * pspec);
static void _vala_tuba_api_nodeinfo_v20_set_property (GObject * object,
                                               guint property_id,
                                               const GValue * value,
                                               GParamSpec * pspec);
VALA_EXTERN TubaAPINodeinfoLink* tuba_api_nodeinfo_link_new (void);
VALA_EXTERN TubaAPINodeinfoLink* tuba_api_nodeinfo_link_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_nodeinfo_link_get_rel (TubaAPINodeinfoLink* self);
VALA_EXTERN void tuba_api_nodeinfo_link_set_rel (TubaAPINodeinfoLink* self,
                                     const gchar* value);
VALA_EXTERN const gchar* tuba_api_nodeinfo_link_get_href (TubaAPINodeinfoLink* self);
VALA_EXTERN void tuba_api_nodeinfo_link_set_href (TubaAPINodeinfoLink* self,
                                      const gchar* value);
static void tuba_api_nodeinfo_link_finalize (GObject * obj);
static GType tuba_api_nodeinfo_link_get_type_once (void);
static void _vala_tuba_api_nodeinfo_link_get_property (GObject * object,
                                                guint property_id,
                                                GValue * value,
                                                GParamSpec * pspec);
static void _vala_tuba_api_nodeinfo_link_set_property (GObject * object,
                                                guint property_id,
                                                const GValue * value,
                                                GParamSpec * pspec);
static void tuba_api_nodeinfo_finalize (GObject * obj);
static GType tuba_api_nodeinfo_get_type_once (void);
static void _vala_tuba_api_nodeinfo_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec);
static void _vala_tuba_api_nodeinfo_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec);

static inline gpointer
tuba_api_nodeinfo_get_instance_private (TubaAPINodeinfo* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINodeinfo_private_offset);
}

static GType
tuba_api_nodeinfo_real_deserialize_array_type (TubaEntity* base,
                                               const gchar* prop)
{
	TubaAPINodeinfo * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPINodeinfo*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("links")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_NODEINFO_TYPE_LINK;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_nodeinfo_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

TubaAPINodeinfo*
tuba_api_nodeinfo_construct (GType object_type)
{
	TubaAPINodeinfo * self = NULL;
	self = (TubaAPINodeinfo*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINodeinfo*
tuba_api_nodeinfo_new (void)
{
	return tuba_api_nodeinfo_construct (TUBA_API_TYPE_NODEINFO);
}

GeeArrayList*
tuba_api_nodeinfo_get_links (TubaAPINodeinfo* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_links;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_api_nodeinfo_set_links (TubaAPINodeinfo* self,
                             GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_nodeinfo_get_links (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_links);
		self->priv->_links = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_nodeinfo_properties[TUBA_API_NODEINFO_LINKS_PROPERTY]);
	}
}

static inline gpointer
tuba_api_nodeinfo_v20_get_instance_private (TubaAPINodeinfoV20* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINodeinfoV20_private_offset);
}

TubaAPINodeinfoV20*
tuba_api_nodeinfo_v20_construct (GType object_type)
{
	TubaAPINodeinfoV20 * self = NULL;
	self = (TubaAPINodeinfoV20*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINodeinfoV20*
tuba_api_nodeinfo_v20_new (void)
{
	return tuba_api_nodeinfo_v20_construct (TUBA_API_NODEINFO_TYPE_V20);
}

TubaAPINodeinfoV20Software*
tuba_api_nodeinfo_v20_get_software (TubaAPINodeinfoV20* self)
{
	TubaAPINodeinfoV20Software* result;
	TubaAPINodeinfoV20Software* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_software;
	result = _tmp0_;
	return result;
}

void
tuba_api_nodeinfo_v20_set_software (TubaAPINodeinfoV20* self,
                                    TubaAPINodeinfoV20Software* value)
{
	TubaAPINodeinfoV20Software* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_nodeinfo_v20_get_software (self);
	if (old_value != value) {
		TubaAPINodeinfoV20Software* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_software);
		self->priv->_software = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_nodeinfo_v20_properties[TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY]);
	}
}

static inline gpointer
tuba_api_nodeinfo_v20_software_get_instance_private (TubaAPINodeinfoV20Software* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINodeinfoV20Software_private_offset);
}

TubaAPINodeinfoV20Software*
tuba_api_nodeinfo_v20_software_construct (GType object_type)
{
	TubaAPINodeinfoV20Software * self = NULL;
	self = (TubaAPINodeinfoV20Software*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINodeinfoV20Software*
tuba_api_nodeinfo_v20_software_new (void)
{
	return tuba_api_nodeinfo_v20_software_construct (TUBA_API_NODEINFO_V20_TYPE_SOFTWARE);
}

const gchar*
tuba_api_nodeinfo_v20_software_get_name (TubaAPINodeinfoV20Software* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_name;
	result = _tmp0_;
	return result;
}

void
tuba_api_nodeinfo_v20_software_set_name (TubaAPINodeinfoV20Software* self,
                                         const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_nodeinfo_v20_software_get_name (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_name);
		self->priv->_name = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_nodeinfo_v20_software_properties[TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY]);
	}
}

static void
tuba_api_nodeinfo_v20_software_class_init (TubaAPINodeinfoV20SoftwareClass * klass,
                                           gpointer klass_data)
{
	tuba_api_nodeinfo_v20_software_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINodeinfoV20Software_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_nodeinfo_v20_software_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_nodeinfo_v20_software_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_nodeinfo_v20_software_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY, tuba_api_nodeinfo_v20_software_properties[TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY] = g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_nodeinfo_v20_software_instance_init (TubaAPINodeinfoV20Software * self,
                                              gpointer klass)
{
	self->priv = tuba_api_nodeinfo_v20_software_get_instance_private (self);
	self->priv->_name = NULL;
}

static void
tuba_api_nodeinfo_v20_software_finalize (GObject * obj)
{
	TubaAPINodeinfoV20Software * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20Software);
	_g_free0 (self->priv->_name);
	G_OBJECT_CLASS (tuba_api_nodeinfo_v20_software_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_nodeinfo_v20_software_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINodeinfoV20SoftwareClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_nodeinfo_v20_software_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINodeinfoV20Software), 0, (GInstanceInitFunc) tuba_api_nodeinfo_v20_software_instance_init, NULL };
	GType tuba_api_nodeinfo_v20_software_type_id;
	tuba_api_nodeinfo_v20_software_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINodeinfoV20Software", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINodeinfoV20Software_private_offset = g_type_add_instance_private (tuba_api_nodeinfo_v20_software_type_id, sizeof (TubaAPINodeinfoV20SoftwarePrivate));
	return tuba_api_nodeinfo_v20_software_type_id;
}

GType
tuba_api_nodeinfo_v20_software_get_type (void)
{
	static GType tuba_api_nodeinfo_v20_software_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_nodeinfo_v20_software_type_id__once)) {
		GType tuba_api_nodeinfo_v20_software_type_id;
		tuba_api_nodeinfo_v20_software_type_id = tuba_api_nodeinfo_v20_software_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_nodeinfo_v20_software_type_id__once, tuba_api_nodeinfo_v20_software_type_id);
	}
	return tuba_api_nodeinfo_v20_software_type_id__once;
}

static void
_vala_tuba_api_nodeinfo_v20_software_get_property (GObject * object,
                                                   guint property_id,
                                                   GValue * value,
                                                   GParamSpec * pspec)
{
	TubaAPINodeinfoV20Software * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20Software);
	switch (property_id) {
		case TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY:
		g_value_set_string (value, tuba_api_nodeinfo_v20_software_get_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_nodeinfo_v20_software_set_property (GObject * object,
                                                   guint property_id,
                                                   const GValue * value,
                                                   GParamSpec * pspec)
{
	TubaAPINodeinfoV20Software * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, TubaAPINodeinfoV20Software);
	switch (property_id) {
		case TUBA_API_NODEINFO_V20_SOFTWARE_NAME_PROPERTY:
		tuba_api_nodeinfo_v20_software_set_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_nodeinfo_v20_class_init (TubaAPINodeinfoV20Class * klass,
                                  gpointer klass_data)
{
	tuba_api_nodeinfo_v20_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINodeinfoV20_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_nodeinfo_v20_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_nodeinfo_v20_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_nodeinfo_v20_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY, tuba_api_nodeinfo_v20_properties[TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY] = g_param_spec_object ("software", "software", "software", TUBA_API_NODEINFO_V20_TYPE_SOFTWARE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_nodeinfo_v20_instance_init (TubaAPINodeinfoV20 * self,
                                     gpointer klass)
{
	self->priv = tuba_api_nodeinfo_v20_get_instance_private (self);
	self->priv->_software = NULL;
}

static void
tuba_api_nodeinfo_v20_finalize (GObject * obj)
{
	TubaAPINodeinfoV20 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20);
	_g_object_unref0 (self->priv->_software);
	G_OBJECT_CLASS (tuba_api_nodeinfo_v20_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_nodeinfo_v20_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINodeinfoV20Class), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_nodeinfo_v20_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINodeinfoV20), 0, (GInstanceInitFunc) tuba_api_nodeinfo_v20_instance_init, NULL };
	GType tuba_api_nodeinfo_v20_type_id;
	tuba_api_nodeinfo_v20_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINodeinfoV20", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINodeinfoV20_private_offset = g_type_add_instance_private (tuba_api_nodeinfo_v20_type_id, sizeof (TubaAPINodeinfoV20Private));
	return tuba_api_nodeinfo_v20_type_id;
}

GType
tuba_api_nodeinfo_v20_get_type (void)
{
	static GType tuba_api_nodeinfo_v20_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_nodeinfo_v20_type_id__once)) {
		GType tuba_api_nodeinfo_v20_type_id;
		tuba_api_nodeinfo_v20_type_id = tuba_api_nodeinfo_v20_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_nodeinfo_v20_type_id__once, tuba_api_nodeinfo_v20_type_id);
	}
	return tuba_api_nodeinfo_v20_type_id__once;
}

static void
_vala_tuba_api_nodeinfo_v20_get_property (GObject * object,
                                          guint property_id,
                                          GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPINodeinfoV20 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20);
	switch (property_id) {
		case TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY:
		g_value_set_object (value, tuba_api_nodeinfo_v20_get_software (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_nodeinfo_v20_set_property (GObject * object,
                                          guint property_id,
                                          const GValue * value,
                                          GParamSpec * pspec)
{
	TubaAPINodeinfoV20 * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_TYPE_V20, TubaAPINodeinfoV20);
	switch (property_id) {
		case TUBA_API_NODEINFO_V20_SOFTWARE_PROPERTY:
		tuba_api_nodeinfo_v20_set_software (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_nodeinfo_link_get_instance_private (TubaAPINodeinfoLink* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINodeinfoLink_private_offset);
}

TubaAPINodeinfoLink*
tuba_api_nodeinfo_link_construct (GType object_type)
{
	TubaAPINodeinfoLink * self = NULL;
	self = (TubaAPINodeinfoLink*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINodeinfoLink*
tuba_api_nodeinfo_link_new (void)
{
	return tuba_api_nodeinfo_link_construct (TUBA_API_NODEINFO_TYPE_LINK);
}

const gchar*
tuba_api_nodeinfo_link_get_rel (TubaAPINodeinfoLink* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_rel;
	result = _tmp0_;
	return result;
}

void
tuba_api_nodeinfo_link_set_rel (TubaAPINodeinfoLink* self,
                                const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_nodeinfo_link_get_rel (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_rel);
		self->priv->_rel = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_nodeinfo_link_properties[TUBA_API_NODEINFO_LINK_REL_PROPERTY]);
	}
}

const gchar*
tuba_api_nodeinfo_link_get_href (TubaAPINodeinfoLink* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_href;
	result = _tmp0_;
	return result;
}

void
tuba_api_nodeinfo_link_set_href (TubaAPINodeinfoLink* self,
                                 const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_nodeinfo_link_get_href (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_href);
		self->priv->_href = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_nodeinfo_link_properties[TUBA_API_NODEINFO_LINK_HREF_PROPERTY]);
	}
}

static void
tuba_api_nodeinfo_link_class_init (TubaAPINodeinfoLinkClass * klass,
                                   gpointer klass_data)
{
	tuba_api_nodeinfo_link_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINodeinfoLink_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_nodeinfo_link_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_nodeinfo_link_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_nodeinfo_link_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NODEINFO_LINK_REL_PROPERTY, tuba_api_nodeinfo_link_properties[TUBA_API_NODEINFO_LINK_REL_PROPERTY] = g_param_spec_string ("rel", "rel", "rel", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NODEINFO_LINK_HREF_PROPERTY, tuba_api_nodeinfo_link_properties[TUBA_API_NODEINFO_LINK_HREF_PROPERTY] = g_param_spec_string ("href", "href", "href", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_nodeinfo_link_instance_init (TubaAPINodeinfoLink * self,
                                      gpointer klass)
{
	self->priv = tuba_api_nodeinfo_link_get_instance_private (self);
	self->priv->_rel = NULL;
	self->priv->_href = NULL;
}

static void
tuba_api_nodeinfo_link_finalize (GObject * obj)
{
	TubaAPINodeinfoLink * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLink);
	_g_free0 (self->priv->_rel);
	_g_free0 (self->priv->_href);
	G_OBJECT_CLASS (tuba_api_nodeinfo_link_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_nodeinfo_link_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINodeinfoLinkClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_nodeinfo_link_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINodeinfoLink), 0, (GInstanceInitFunc) tuba_api_nodeinfo_link_instance_init, NULL };
	GType tuba_api_nodeinfo_link_type_id;
	tuba_api_nodeinfo_link_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINodeinfoLink", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINodeinfoLink_private_offset = g_type_add_instance_private (tuba_api_nodeinfo_link_type_id, sizeof (TubaAPINodeinfoLinkPrivate));
	return tuba_api_nodeinfo_link_type_id;
}

GType
tuba_api_nodeinfo_link_get_type (void)
{
	static GType tuba_api_nodeinfo_link_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_nodeinfo_link_type_id__once)) {
		GType tuba_api_nodeinfo_link_type_id;
		tuba_api_nodeinfo_link_type_id = tuba_api_nodeinfo_link_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_nodeinfo_link_type_id__once, tuba_api_nodeinfo_link_type_id);
	}
	return tuba_api_nodeinfo_link_type_id__once;
}

static void
_vala_tuba_api_nodeinfo_link_get_property (GObject * object,
                                           guint property_id,
                                           GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPINodeinfoLink * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLink);
	switch (property_id) {
		case TUBA_API_NODEINFO_LINK_REL_PROPERTY:
		g_value_set_string (value, tuba_api_nodeinfo_link_get_rel (self));
		break;
		case TUBA_API_NODEINFO_LINK_HREF_PROPERTY:
		g_value_set_string (value, tuba_api_nodeinfo_link_get_href (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_nodeinfo_link_set_property (GObject * object,
                                           guint property_id,
                                           const GValue * value,
                                           GParamSpec * pspec)
{
	TubaAPINodeinfoLink * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NODEINFO_TYPE_LINK, TubaAPINodeinfoLink);
	switch (property_id) {
		case TUBA_API_NODEINFO_LINK_REL_PROPERTY:
		tuba_api_nodeinfo_link_set_rel (self, g_value_get_string (value));
		break;
		case TUBA_API_NODEINFO_LINK_HREF_PROPERTY:
		tuba_api_nodeinfo_link_set_href (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_nodeinfo_class_init (TubaAPINodeinfoClass * klass,
                              gpointer klass_data)
{
	tuba_api_nodeinfo_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINodeinfo_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_nodeinfo_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_nodeinfo_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_nodeinfo_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_nodeinfo_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NODEINFO_LINKS_PROPERTY, tuba_api_nodeinfo_properties[TUBA_API_NODEINFO_LINKS_PROPERTY] = g_param_spec_object ("links", "links", "links", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_nodeinfo_instance_init (TubaAPINodeinfo * self,
                                 gpointer klass)
{
	self->priv = tuba_api_nodeinfo_get_instance_private (self);
	self->priv->_links = NULL;
}

static void
tuba_api_nodeinfo_finalize (GObject * obj)
{
	TubaAPINodeinfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_NODEINFO, TubaAPINodeinfo);
	_g_object_unref0 (self->priv->_links);
	G_OBJECT_CLASS (tuba_api_nodeinfo_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_nodeinfo_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINodeinfoClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_nodeinfo_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINodeinfo), 0, (GInstanceInitFunc) tuba_api_nodeinfo_instance_init, NULL };
	GType tuba_api_nodeinfo_type_id;
	tuba_api_nodeinfo_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINodeinfo", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINodeinfo_private_offset = g_type_add_instance_private (tuba_api_nodeinfo_type_id, sizeof (TubaAPINodeinfoPrivate));
	return tuba_api_nodeinfo_type_id;
}

GType
tuba_api_nodeinfo_get_type (void)
{
	static GType tuba_api_nodeinfo_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_nodeinfo_type_id__once)) {
		GType tuba_api_nodeinfo_type_id;
		tuba_api_nodeinfo_type_id = tuba_api_nodeinfo_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_nodeinfo_type_id__once, tuba_api_nodeinfo_type_id);
	}
	return tuba_api_nodeinfo_type_id__once;
}

static void
_vala_tuba_api_nodeinfo_get_property (GObject * object,
                                      guint property_id,
                                      GValue * value,
                                      GParamSpec * pspec)
{
	TubaAPINodeinfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_NODEINFO, TubaAPINodeinfo);
	switch (property_id) {
		case TUBA_API_NODEINFO_LINKS_PROPERTY:
		g_value_set_object (value, tuba_api_nodeinfo_get_links (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_nodeinfo_set_property (GObject * object,
                                      guint property_id,
                                      const GValue * value,
                                      GParamSpec * pspec)
{
	TubaAPINodeinfo * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_TYPE_NODEINFO, TubaAPINodeinfo);
	switch (property_id) {
		case TUBA_API_NODEINFO_LINKS_PROPERTY:
		tuba_api_nodeinfo_set_links (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

