/* EmailDomainBlock.c generated by valac 0.56.19, the Vala compiler
 * generated from EmailDomainBlock.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <adwaita.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_TYPE_BASIC_WIDGETIZABLE (tuba_basic_widgetizable_get_type ())
#define TUBA_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizable))
#define TUBA_IS_BASIC_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE))
#define TUBA_BASIC_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_BASIC_WIDGETIZABLE, TubaBasicWidgetizableIface))

typedef struct _TubaBasicWidgetizable TubaBasicWidgetizable;
typedef struct _TubaBasicWidgetizableIface TubaBasicWidgetizableIface;

#define TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK (tuba_api_admin_email_domain_block_get_type ())
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlock))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlockClass))
#define TUBA_API_ADMIN_IS_EMAIL_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK))
#define TUBA_API_ADMIN_IS_EMAIL_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlockClass))

typedef struct _TubaAPIAdminEmailDomainBlock TubaAPIAdminEmailDomainBlock;
typedef struct _TubaAPIAdminEmailDomainBlockClass TubaAPIAdminEmailDomainBlockClass;
typedef struct _TubaAPIAdminEmailDomainBlockPrivate TubaAPIAdminEmailDomainBlockPrivate;

#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY (tuba_api_admin_email_domain_block_history_get_type ())
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistory))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistoryClass))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_IS_HISTORY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_IS_HISTORY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY))
#define TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistoryClass))

typedef struct _TubaAPIAdminEmailDomainBlockHistory TubaAPIAdminEmailDomainBlockHistory;
typedef struct _TubaAPIAdminEmailDomainBlockHistoryClass TubaAPIAdminEmailDomainBlockHistoryClass;
enum  {
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_0_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_NUM_PROPERTIES
};
static GParamSpec* tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK (tuba_widgets_admin_email_domain_block_get_type ())
#define TUBA_WIDGETS_ADMIN_EMAIL_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaWidgetsAdminEmailDomainBlock))
#define TUBA_WIDGETS_ADMIN_EMAIL_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaWidgetsAdminEmailDomainBlockClass))
#define TUBA_WIDGETS_ADMIN_IS_EMAIL_DOMAIN_BLOCK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK))
#define TUBA_WIDGETS_ADMIN_IS_EMAIL_DOMAIN_BLOCK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK))
#define TUBA_WIDGETS_ADMIN_EMAIL_DOMAIN_BLOCK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaWidgetsAdminEmailDomainBlockClass))

typedef struct _TubaWidgetsAdminEmailDomainBlock TubaWidgetsAdminEmailDomainBlock;
typedef struct _TubaWidgetsAdminEmailDomainBlockClass TubaWidgetsAdminEmailDomainBlockClass;
typedef struct _TubaAPIAdminEmailDomainBlockHistoryPrivate TubaAPIAdminEmailDomainBlockHistoryPrivate;
enum  {
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_0_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY,
	TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_NUM_PROPERTIES
};
static GParamSpec* tuba_api_admin_email_domain_block_history_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_NUM_PROPERTIES];

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaBasicWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaBasicWidgetizable* self);
};

struct _TubaAPIAdminEmailDomainBlock {
	TubaEntity parent_instance;
	TubaAPIAdminEmailDomainBlockPrivate * priv;
};

struct _TubaAPIAdminEmailDomainBlockClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAdminEmailDomainBlockPrivate {
	gchar* _id;
	gchar* _domain;
	GeeArrayList* _history;
};

struct _TubaAPIAdminEmailDomainBlockHistory {
	TubaEntity parent_instance;
	TubaAPIAdminEmailDomainBlockHistoryPrivate * priv;
};

struct _TubaAPIAdminEmailDomainBlockHistoryClass {
	TubaEntityClass parent_class;
};

struct _TubaAPIAdminEmailDomainBlockHistoryPrivate {
	gchar* _accounts;
	gchar* _uses;
};

static gint TubaAPIAdminEmailDomainBlock_private_offset;
static gpointer tuba_api_admin_email_domain_block_parent_class = NULL;
static gint TubaAPIAdminEmailDomainBlockHistory_private_offset;
static gpointer tuba_api_admin_email_domain_block_history_parent_class = NULL;
static TubaBasicWidgetizableIface * tuba_api_admin_email_domain_block_tuba_basic_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_basic_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaBasicWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_admin_email_domain_block_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminEmailDomainBlock, g_object_unref)
VALA_EXTERN GType tuba_api_admin_email_domain_block_history_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAdminEmailDomainBlockHistory, g_object_unref)
VALA_EXTERN GType tuba_entity_deserialize_array_type (TubaEntity* self,
                                          const gchar* prop);
static GType tuba_api_admin_email_domain_block_real_deserialize_array_type (TubaEntity* base,
                                                                     const gchar* prop);
static GtkWidget* tuba_api_admin_email_domain_block_real_to_widget (TubaBasicWidgetizable* base);
VALA_EXTERN TubaWidgetsAdminEmailDomainBlock* tuba_widgets_admin_email_domain_block_new (TubaAPIAdminEmailDomainBlock* email_domain_block);
VALA_EXTERN TubaWidgetsAdminEmailDomainBlock* tuba_widgets_admin_email_domain_block_construct (GType object_type,
                                                                                   TubaAPIAdminEmailDomainBlock* email_domain_block);
VALA_EXTERN GType tuba_widgets_admin_email_domain_block_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsAdminEmailDomainBlock, g_object_unref)
VALA_EXTERN TubaAPIAdminEmailDomainBlock* tuba_api_admin_email_domain_block_new (void);
VALA_EXTERN TubaAPIAdminEmailDomainBlock* tuba_api_admin_email_domain_block_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_admin_email_domain_block_get_id (TubaAPIAdminEmailDomainBlock* self);
VALA_EXTERN void tuba_api_admin_email_domain_block_set_id (TubaAPIAdminEmailDomainBlock* self,
                                               const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_email_domain_block_get_domain (TubaAPIAdminEmailDomainBlock* self);
VALA_EXTERN void tuba_api_admin_email_domain_block_set_domain (TubaAPIAdminEmailDomainBlock* self,
                                                   const gchar* value);
VALA_EXTERN GeeArrayList* tuba_api_admin_email_domain_block_get_history (TubaAPIAdminEmailDomainBlock* self);
VALA_EXTERN void tuba_api_admin_email_domain_block_set_history (TubaAPIAdminEmailDomainBlock* self,
                                                    GeeArrayList* value);
VALA_EXTERN TubaAPIAdminEmailDomainBlockHistory* tuba_api_admin_email_domain_block_history_new (void);
VALA_EXTERN TubaAPIAdminEmailDomainBlockHistory* tuba_api_admin_email_domain_block_history_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_admin_email_domain_block_history_get_accounts (TubaAPIAdminEmailDomainBlockHistory* self);
VALA_EXTERN void tuba_api_admin_email_domain_block_history_set_accounts (TubaAPIAdminEmailDomainBlockHistory* self,
                                                             const gchar* value);
VALA_EXTERN const gchar* tuba_api_admin_email_domain_block_history_get_uses (TubaAPIAdminEmailDomainBlockHistory* self);
VALA_EXTERN void tuba_api_admin_email_domain_block_history_set_uses (TubaAPIAdminEmailDomainBlockHistory* self,
                                                         const gchar* value);
static void tuba_api_admin_email_domain_block_history_finalize (GObject * obj);
static GType tuba_api_admin_email_domain_block_history_get_type_once (void);
static void _vala_tuba_api_admin_email_domain_block_history_get_property (GObject * object,
                                                                   guint property_id,
                                                                   GValue * value,
                                                                   GParamSpec * pspec);
static void _vala_tuba_api_admin_email_domain_block_history_set_property (GObject * object,
                                                                   guint property_id,
                                                                   const GValue * value,
                                                                   GParamSpec * pspec);
VALA_EXTERN GtkWidget* tuba_basic_widgetizable_to_widget (TubaBasicWidgetizable* self);
static void tuba_api_admin_email_domain_block_finalize (GObject * obj);
static GType tuba_api_admin_email_domain_block_get_type_once (void);
static void _vala_tuba_api_admin_email_domain_block_get_property (GObject * object,
                                                           guint property_id,
                                                           GValue * value,
                                                           GParamSpec * pspec);
static void _vala_tuba_api_admin_email_domain_block_set_property (GObject * object,
                                                           guint property_id,
                                                           const GValue * value,
                                                           GParamSpec * pspec);

static inline gpointer
tuba_api_admin_email_domain_block_get_instance_private (TubaAPIAdminEmailDomainBlock* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAdminEmailDomainBlock_private_offset);
}

static GType
tuba_api_admin_email_domain_block_real_deserialize_array_type (TubaEntity* base,
                                                               const gchar* prop)
{
	TubaAPIAdminEmailDomainBlock * self;
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	GType result;
	self = (TubaAPIAdminEmailDomainBlock*) base;
	g_return_val_if_fail (prop != NULL, G_TYPE_INVALID);
	_tmp0_ = prop;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("history")))) {
		switch (0) {
			default:
			{
				result = TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY;
				return result;
			}
		}
	}
	result = TUBA_ENTITY_CLASS (tuba_api_admin_email_domain_block_parent_class)->deserialize_array_type (G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_TYPE_ENTITY, TubaEntity), prop);
	return result;
}

static GtkWidget*
tuba_api_admin_email_domain_block_real_to_widget (TubaBasicWidgetizable* base)
{
	TubaAPIAdminEmailDomainBlock * self;
	TubaWidgetsAdminEmailDomainBlock* _tmp0_;
	GtkWidget* result;
	self = (TubaAPIAdminEmailDomainBlock*) base;
	_tmp0_ = tuba_widgets_admin_email_domain_block_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

TubaAPIAdminEmailDomainBlock*
tuba_api_admin_email_domain_block_construct (GType object_type)
{
	TubaAPIAdminEmailDomainBlock * self = NULL;
	self = (TubaAPIAdminEmailDomainBlock*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAdminEmailDomainBlock*
tuba_api_admin_email_domain_block_new (void)
{
	return tuba_api_admin_email_domain_block_construct (TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK);
}

const gchar*
tuba_api_admin_email_domain_block_get_id (TubaAPIAdminEmailDomainBlock* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_email_domain_block_set_id (TubaAPIAdminEmailDomainBlock* self,
                                          const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_email_domain_block_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_email_domain_block_get_domain (TubaAPIAdminEmailDomainBlock* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_domain;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_email_domain_block_set_domain (TubaAPIAdminEmailDomainBlock* self,
                                              const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_email_domain_block_get_domain (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_domain);
		self->priv->_domain = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY]);
	}
}

GeeArrayList*
tuba_api_admin_email_domain_block_get_history (TubaAPIAdminEmailDomainBlock* self)
{
	GeeArrayList* result;
	GeeArrayList* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_history;
	result = _tmp0_;
	return result;
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_api_admin_email_domain_block_set_history (TubaAPIAdminEmailDomainBlock* self,
                                               GeeArrayList* value)
{
	GeeArrayList* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_email_domain_block_get_history (self);
	if (old_value != value) {
		GeeArrayList* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_history);
		self->priv->_history = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY]);
	}
}

static inline gpointer
tuba_api_admin_email_domain_block_history_get_instance_private (TubaAPIAdminEmailDomainBlockHistory* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPIAdminEmailDomainBlockHistory_private_offset);
}

TubaAPIAdminEmailDomainBlockHistory*
tuba_api_admin_email_domain_block_history_construct (GType object_type)
{
	TubaAPIAdminEmailDomainBlockHistory * self = NULL;
	self = (TubaAPIAdminEmailDomainBlockHistory*) tuba_entity_construct (object_type);
	return self;
}

TubaAPIAdminEmailDomainBlockHistory*
tuba_api_admin_email_domain_block_history_new (void)
{
	return tuba_api_admin_email_domain_block_history_construct (TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY);
}

const gchar*
tuba_api_admin_email_domain_block_history_get_accounts (TubaAPIAdminEmailDomainBlockHistory* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_accounts;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_email_domain_block_history_set_accounts (TubaAPIAdminEmailDomainBlockHistory* self,
                                                        const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_email_domain_block_history_get_accounts (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_accounts);
		self->priv->_accounts = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_email_domain_block_history_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY]);
	}
}

const gchar*
tuba_api_admin_email_domain_block_history_get_uses (TubaAPIAdminEmailDomainBlockHistory* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_uses;
	result = _tmp0_;
	return result;
}

void
tuba_api_admin_email_domain_block_history_set_uses (TubaAPIAdminEmailDomainBlockHistory* self,
                                                    const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_admin_email_domain_block_history_get_uses (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_uses);
		self->priv->_uses = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_admin_email_domain_block_history_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY]);
	}
}

static void
tuba_api_admin_email_domain_block_history_class_init (TubaAPIAdminEmailDomainBlockHistoryClass * klass,
                                                      gpointer klass_data)
{
	tuba_api_admin_email_domain_block_history_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAdminEmailDomainBlockHistory_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_admin_email_domain_block_history_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_admin_email_domain_block_history_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_admin_email_domain_block_history_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY, tuba_api_admin_email_domain_block_history_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY] = g_param_spec_string ("accounts", "accounts", "accounts", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY, tuba_api_admin_email_domain_block_history_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY] = g_param_spec_string ("uses", "uses", "uses", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_admin_email_domain_block_history_instance_init (TubaAPIAdminEmailDomainBlockHistory * self,
                                                         gpointer klass)
{
	self->priv = tuba_api_admin_email_domain_block_history_get_instance_private (self);
}

static void
tuba_api_admin_email_domain_block_history_finalize (GObject * obj)
{
	TubaAPIAdminEmailDomainBlockHistory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistory);
	_g_free0 (self->priv->_accounts);
	_g_free0 (self->priv->_uses);
	G_OBJECT_CLASS (tuba_api_admin_email_domain_block_history_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_admin_email_domain_block_history_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAdminEmailDomainBlockHistoryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_admin_email_domain_block_history_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAdminEmailDomainBlockHistory), 0, (GInstanceInitFunc) tuba_api_admin_email_domain_block_history_instance_init, NULL };
	GType tuba_api_admin_email_domain_block_history_type_id;
	tuba_api_admin_email_domain_block_history_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAdminEmailDomainBlockHistory", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPIAdminEmailDomainBlockHistory_private_offset = g_type_add_instance_private (tuba_api_admin_email_domain_block_history_type_id, sizeof (TubaAPIAdminEmailDomainBlockHistoryPrivate));
	return tuba_api_admin_email_domain_block_history_type_id;
}

GType
tuba_api_admin_email_domain_block_history_get_type (void)
{
	static GType tuba_api_admin_email_domain_block_history_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_admin_email_domain_block_history_type_id__once)) {
		GType tuba_api_admin_email_domain_block_history_type_id;
		tuba_api_admin_email_domain_block_history_type_id = tuba_api_admin_email_domain_block_history_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_admin_email_domain_block_history_type_id__once, tuba_api_admin_email_domain_block_history_type_id);
	}
	return tuba_api_admin_email_domain_block_history_type_id__once;
}

static void
_vala_tuba_api_admin_email_domain_block_history_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec)
{
	TubaAPIAdminEmailDomainBlockHistory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistory);
	switch (property_id) {
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY:
		g_value_set_string (value, tuba_api_admin_email_domain_block_history_get_accounts (self));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY:
		g_value_set_string (value, tuba_api_admin_email_domain_block_history_get_uses (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_admin_email_domain_block_history_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec)
{
	TubaAPIAdminEmailDomainBlockHistory * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_TYPE_HISTORY, TubaAPIAdminEmailDomainBlockHistory);
	switch (property_id) {
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_ACCOUNTS_PROPERTY:
		tuba_api_admin_email_domain_block_history_set_accounts (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_USES_PROPERTY:
		tuba_api_admin_email_domain_block_history_set_uses (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_admin_email_domain_block_class_init (TubaAPIAdminEmailDomainBlockClass * klass,
                                              gpointer klass_data)
{
	tuba_api_admin_email_domain_block_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPIAdminEmailDomainBlock_private_offset);
	((TubaEntityClass *) klass)->deserialize_array_type = (GType (*) (TubaEntity*, const gchar*)) tuba_api_admin_email_domain_block_real_deserialize_array_type;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_admin_email_domain_block_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_admin_email_domain_block_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_admin_email_domain_block_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY] = g_param_spec_string ("domain", "domain", "domain", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY, tuba_api_admin_email_domain_block_properties[TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY] = g_param_spec_object ("history", "history", "history", GEE_TYPE_ARRAY_LIST, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_admin_email_domain_block_tuba_basic_widgetizable_interface_init (TubaBasicWidgetizableIface * iface,
                                                                          gpointer iface_data)
{
	tuba_api_admin_email_domain_block_tuba_basic_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaBasicWidgetizable*)) tuba_api_admin_email_domain_block_real_to_widget;
}

static void
tuba_api_admin_email_domain_block_instance_init (TubaAPIAdminEmailDomainBlock * self,
                                                 gpointer klass)
{
	self->priv = tuba_api_admin_email_domain_block_get_instance_private (self);
	self->priv->_history = NULL;
}

static void
tuba_api_admin_email_domain_block_finalize (GObject * obj)
{
	TubaAPIAdminEmailDomainBlock * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlock);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_domain);
	_g_object_unref0 (self->priv->_history);
	G_OBJECT_CLASS (tuba_api_admin_email_domain_block_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_admin_email_domain_block_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPIAdminEmailDomainBlockClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_admin_email_domain_block_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPIAdminEmailDomainBlock), 0, (GInstanceInitFunc) tuba_api_admin_email_domain_block_instance_init, NULL };
	static const GInterfaceInfo tuba_basic_widgetizable_info = { (GInterfaceInitFunc) tuba_api_admin_email_domain_block_tuba_basic_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_admin_email_domain_block_type_id;
	tuba_api_admin_email_domain_block_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPIAdminEmailDomainBlock", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_admin_email_domain_block_type_id, TUBA_TYPE_BASIC_WIDGETIZABLE, &tuba_basic_widgetizable_info);
	TubaAPIAdminEmailDomainBlock_private_offset = g_type_add_instance_private (tuba_api_admin_email_domain_block_type_id, sizeof (TubaAPIAdminEmailDomainBlockPrivate));
	return tuba_api_admin_email_domain_block_type_id;
}

GType
tuba_api_admin_email_domain_block_get_type (void)
{
	static GType tuba_api_admin_email_domain_block_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_admin_email_domain_block_type_id__once)) {
		GType tuba_api_admin_email_domain_block_type_id;
		tuba_api_admin_email_domain_block_type_id = tuba_api_admin_email_domain_block_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_admin_email_domain_block_type_id__once, tuba_api_admin_email_domain_block_type_id);
	}
	return tuba_api_admin_email_domain_block_type_id__once;
}

static void
_vala_tuba_api_admin_email_domain_block_get_property (GObject * object,
                                                      guint property_id,
                                                      GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAdminEmailDomainBlock * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlock);
	switch (property_id) {
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY:
		g_value_set_string (value, tuba_api_admin_email_domain_block_get_id (self));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY:
		g_value_set_string (value, tuba_api_admin_email_domain_block_get_domain (self));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY:
		g_value_set_object (value, tuba_api_admin_email_domain_block_get_history (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_admin_email_domain_block_set_property (GObject * object,
                                                      guint property_id,
                                                      const GValue * value,
                                                      GParamSpec * pspec)
{
	TubaAPIAdminEmailDomainBlock * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_ADMIN_TYPE_EMAIL_DOMAIN_BLOCK, TubaAPIAdminEmailDomainBlock);
	switch (property_id) {
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_ID_PROPERTY:
		tuba_api_admin_email_domain_block_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_DOMAIN_PROPERTY:
		tuba_api_admin_email_domain_block_set_domain (self, g_value_get_string (value));
		break;
		case TUBA_API_ADMIN_EMAIL_DOMAIN_BLOCK_HISTORY_PROPERTY:
		tuba_api_admin_email_domain_block_set_history (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

