/* ListBoxRowWrapper.c generated by valac 0.56.19, the Vala compiler
 * generated from ListBoxRowWrapper.vala, do not modify */

#include <gtk/gtk.h>
#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER (tuba_widgets_list_box_row_wrapper_get_type ())
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapper))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_IS_LIST_BOX_ROW_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER))
#define TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, TubaWidgetsListBoxRowWrapperClass))

typedef struct _TubaWidgetsListBoxRowWrapper TubaWidgetsListBoxRowWrapper;
typedef struct _TubaWidgetsListBoxRowWrapperClass TubaWidgetsListBoxRowWrapperClass;
typedef struct _TubaWidgetsListBoxRowWrapperPrivate TubaWidgetsListBoxRowWrapperPrivate;
enum  {
	TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_0_PROPERTY,
	TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_NUM_PROPERTIES
};
static GParamSpec* tuba_widgets_list_box_row_wrapper_properties[TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_NUM_PROPERTIES];
enum  {
	TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_OPEN_SIGNAL,
	TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_NUM_SIGNALS
};
static guint tuba_widgets_list_box_row_wrapper_signals[TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_NUM_SIGNALS] = {0};

struct _TubaWidgetsListBoxRowWrapper {
	GtkListBoxRow parent_instance;
	TubaWidgetsListBoxRowWrapperPrivate * priv;
};

struct _TubaWidgetsListBoxRowWrapperClass {
	GtkListBoxRowClass parent_class;
};

static gpointer tuba_widgets_list_box_row_wrapper_parent_class = NULL;

VALA_EXTERN GType tuba_widgets_list_box_row_wrapper_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsListBoxRowWrapper, g_object_unref)
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_new (void);
VALA_EXTERN TubaWidgetsListBoxRowWrapper* tuba_widgets_list_box_row_wrapper_construct (GType object_type);
static GType tuba_widgets_list_box_row_wrapper_get_type_once (void);

TubaWidgetsListBoxRowWrapper*
tuba_widgets_list_box_row_wrapper_construct (GType object_type)
{
	TubaWidgetsListBoxRowWrapper * self = NULL;
	self = (TubaWidgetsListBoxRowWrapper*) g_object_new (object_type, NULL);
	return self;
}

TubaWidgetsListBoxRowWrapper*
tuba_widgets_list_box_row_wrapper_new (void)
{
	return tuba_widgets_list_box_row_wrapper_construct (TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER);
}

static void
tuba_widgets_list_box_row_wrapper_class_init (TubaWidgetsListBoxRowWrapperClass * klass,
                                              gpointer klass_data)
{
	tuba_widgets_list_box_row_wrapper_parent_class = g_type_class_peek_parent (klass);
	tuba_widgets_list_box_row_wrapper_signals[TUBA_WIDGETS_LIST_BOX_ROW_WRAPPER_OPEN_SIGNAL] = g_signal_new ("open", TUBA_WIDGETS_TYPE_LIST_BOX_ROW_WRAPPER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
}

static void
tuba_widgets_list_box_row_wrapper_instance_init (TubaWidgetsListBoxRowWrapper * self,
                                                 gpointer klass)
{
}

 G_GNUC_NO_INLINE static GType
tuba_widgets_list_box_row_wrapper_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaWidgetsListBoxRowWrapperClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_widgets_list_box_row_wrapper_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaWidgetsListBoxRowWrapper), 0, (GInstanceInitFunc) tuba_widgets_list_box_row_wrapper_instance_init, NULL };
	GType tuba_widgets_list_box_row_wrapper_type_id;
	tuba_widgets_list_box_row_wrapper_type_id = g_type_register_static (gtk_list_box_row_get_type (), "TubaWidgetsListBoxRowWrapper", &g_define_type_info, G_TYPE_FLAG_NONE);
	return tuba_widgets_list_box_row_wrapper_type_id;
}

GType
tuba_widgets_list_box_row_wrapper_get_type (void)
{
	static GType tuba_widgets_list_box_row_wrapper_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_widgets_list_box_row_wrapper_type_id__once)) {
		GType tuba_widgets_list_box_row_wrapper_type_id;
		tuba_widgets_list_box_row_wrapper_type_id = tuba_widgets_list_box_row_wrapper_get_type_once ();
		g_once_init_leave_pointer (&tuba_widgets_list_box_row_wrapper_type_id__once, tuba_widgets_list_box_row_wrapper_type_id);
	}
	return tuba_widgets_list_box_row_wrapper_type_id__once;
}

