/* Profile.c generated by valac 0.56.19, the Vala compiler
 * generated from Profile.vala, do not modify */

#include <adwaita.h>
#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gee.h>
#include <json-glib/json-glib.h>
#include <glib/gi18n-lib.h>
#include <libsoup/soup.h>
#include <gtksourceview/gtksource.h>
#include <pango/pango.h>
#include <libspelling.h>

#define TUBA_VIEWS_PROFILE_TOTAL_STATIC_ITEMS 3
#define BUILD_RESOURCES "/dev/geopjr/Tuba/"
#define TUBA_VIEWS_PROFILE_NOTE_EDITOR_MAX_CHARS 2000
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_VIEWS_TYPE_BASE (tuba_views_base_get_type ())
#define TUBA_VIEWS_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBase))
#define TUBA_VIEWS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))
#define TUBA_VIEWS_IS_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_IS_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BASE))
#define TUBA_VIEWS_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BASE, TubaViewsBaseClass))

typedef struct _TubaViewsBase TubaViewsBase;
typedef struct _TubaViewsBaseClass TubaViewsBaseClass;
typedef struct _TubaViewsBasePrivate TubaViewsBasePrivate;

#define TUBA_VIEWS_TYPE_CONTENT_BASE (tuba_views_content_base_get_type ())
#define TUBA_VIEWS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBase))
#define TUBA_VIEWS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))
#define TUBA_VIEWS_IS_CONTENT_BASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_IS_CONTENT_BASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_CONTENT_BASE))
#define TUBA_VIEWS_CONTENT_BASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_CONTENT_BASE, TubaViewsContentBaseClass))

typedef struct _TubaViewsContentBase TubaViewsContentBase;
typedef struct _TubaViewsContentBaseClass TubaViewsContentBaseClass;
typedef struct _TubaViewsContentBasePrivate TubaViewsContentBasePrivate;

#define TUBA_TYPE_ACCOUNT_HOLDER (tuba_account_holder_get_type ())
#define TUBA_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolder))
#define TUBA_IS_ACCOUNT_HOLDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_HOLDER))
#define TUBA_ACCOUNT_HOLDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_ACCOUNT_HOLDER, TubaAccountHolderIface))

typedef struct _TubaAccountHolder TubaAccountHolder;
typedef struct _TubaAccountHolderIface TubaAccountHolderIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;

#define TUBA_TYPE_STREAMABLE (tuba_streamable_get_type ())
#define TUBA_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_STREAMABLE, TubaStreamable))
#define TUBA_IS_STREAMABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_STREAMABLE))
#define TUBA_STREAMABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_STREAMABLE, TubaStreamableIface))

typedef struct _TubaStreamable TubaStreamable;
typedef struct _TubaStreamableIface TubaStreamableIface;

#define TUBA_VIEWS_TYPE_TIMELINE (tuba_views_timeline_get_type ())
#define TUBA_VIEWS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimeline))
#define TUBA_VIEWS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))
#define TUBA_VIEWS_IS_TIMELINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_IS_TIMELINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_TIMELINE))
#define TUBA_VIEWS_TIMELINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_TIMELINE, TubaViewsTimelineClass))

typedef struct _TubaViewsTimeline TubaViewsTimeline;
typedef struct _TubaViewsTimelineClass TubaViewsTimelineClass;
typedef struct _TubaViewsTimelinePrivate TubaViewsTimelinePrivate;

#define TUBA_TYPE_REQUEST_V2 (tuba_request_v2_get_type ())
#define TUBA_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2))
#define TUBA_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))
#define TUBA_IS_REQUEST_V2(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_REQUEST_V2))
#define TUBA_IS_REQUEST_V2_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_REQUEST_V2))
#define TUBA_REQUEST_V2_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_REQUEST_V2, TubaRequestV2Class))

typedef struct _TubaRequestV2 TubaRequestV2;
typedef struct _TubaRequestV2Class TubaRequestV2Class;

#define TUBA_STREAMABLE_TYPE_EVENT (tuba_streamable_event_get_type ())
typedef struct _TubaStreamableEvent TubaStreamableEvent;

#define TUBA_VIEWS_TYPE_ACCOUNTS (tuba_views_accounts_get_type ())
#define TUBA_VIEWS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts))
#define TUBA_VIEWS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))
#define TUBA_VIEWS_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_IS_ACCOUNTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_ACCOUNTS))
#define TUBA_VIEWS_ACCOUNTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccountsClass))

typedef struct _TubaViewsAccounts TubaViewsAccounts;
typedef struct _TubaViewsAccountsClass TubaViewsAccountsClass;
typedef struct _TubaViewsAccountsPrivate TubaViewsAccountsPrivate;

#define TUBA_VIEWS_TYPE_PROFILE (tuba_views_profile_get_type ())
#define TUBA_VIEWS_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfile))
#define TUBA_VIEWS_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfileClass))
#define TUBA_VIEWS_IS_PROFILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_PROFILE))
#define TUBA_VIEWS_IS_PROFILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_PROFILE))
#define TUBA_VIEWS_PROFILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfileClass))

typedef struct _TubaViewsProfile TubaViewsProfile;
typedef struct _TubaViewsProfileClass TubaViewsProfileClass;
typedef struct _TubaViewsProfilePrivate TubaViewsProfilePrivate;

#define TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT (tuba_views_profile_profile_account_get_type ())
#define TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccount))
#define TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccountClass))
#define TUBA_VIEWS_PROFILE_IS_PROFILE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT))
#define TUBA_VIEWS_PROFILE_IS_PROFILE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT))
#define TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccountClass))

typedef struct _TubaViewsProfileProfileAccount TubaViewsProfileProfileAccount;
typedef struct _TubaViewsProfileProfileAccountClass TubaViewsProfileProfileAccountClass;
typedef enum  {
	TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_POSTS,
	TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_REPLIES,
	TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_MEDIA,
	TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED
} TubaWidgetsProfileFilterGroupFilter;

#define TUBA_WIDGETS_PROFILE_FILTER_GROUP_TYPE_FILTER (tuba_widgets_profile_filter_group_filter_get_type ())

#define TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP (tuba_views_profile_filter_group_get_type ())
#define TUBA_VIEWS_PROFILE_FILTER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroup))
#define TUBA_VIEWS_PROFILE_FILTER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroupClass))
#define TUBA_VIEWS_PROFILE_IS_FILTER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP))
#define TUBA_VIEWS_PROFILE_IS_FILTER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP))
#define TUBA_VIEWS_PROFILE_FILTER_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroupClass))

typedef struct _TubaViewsProfileFilterGroup TubaViewsProfileFilterGroup;
typedef struct _TubaViewsProfileFilterGroupClass TubaViewsProfileFilterGroupClass;

#define TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW (tuba_views_profile_error_message_row_get_type ())
#define TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRow))
#define TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRowClass))
#define TUBA_VIEWS_PROFILE_IS_ERROR_MESSAGE_ROW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW))
#define TUBA_VIEWS_PROFILE_IS_ERROR_MESSAGE_ROW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW))
#define TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRowClass))

typedef struct _TubaViewsProfileErrorMessageRow TubaViewsProfileErrorMessageRow;
typedef struct _TubaViewsProfileErrorMessageRowClass TubaViewsProfileErrorMessageRowClass;
enum  {
	TUBA_VIEWS_PROFILE_0_PROPERTY,
	TUBA_VIEWS_PROFILE_EMPTY_PROPERTY,
	TUBA_VIEWS_PROFILE_PROFILE_PROPERTY,
	TUBA_VIEWS_PROFILE_FILTER_PROPERTY,
	TUBA_VIEWS_PROFILE_SOURCE_PROPERTY,
	TUBA_VIEWS_PROFILE_NUM_PROPERTIES
};
static GParamSpec* tuba_views_profile_properties[TUBA_VIEWS_PROFILE_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_API_TYPE_RELATIONSHIP (tuba_api_relationship_get_type ())
#define TUBA_API_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationship))
#define TUBA_API_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))
#define TUBA_API_IS_RELATIONSHIP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_IS_RELATIONSHIP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_RELATIONSHIP))
#define TUBA_API_RELATIONSHIP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_RELATIONSHIP, TubaAPIRelationshipClass))

typedef struct _TubaAPIRelationship TubaAPIRelationship;
typedef struct _TubaAPIRelationshipClass TubaAPIRelationshipClass;

#define TUBA_TYPE_APPLICATION (tuba_application_get_type ())
#define TUBA_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_APPLICATION, TubaApplication))
#define TUBA_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_APPLICATION, TubaApplicationClass))
#define TUBA_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_APPLICATION))
#define TUBA_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_APPLICATION))
#define TUBA_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_APPLICATION, TubaApplicationClass))

typedef struct _TubaApplication TubaApplication;
typedef struct _TubaApplicationClass TubaApplicationClass;

#define TUBA_API_TYPE_STATUS (tuba_api_status_get_type ())
#define TUBA_API_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatus))
#define TUBA_API_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))
#define TUBA_API_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_STATUS))
#define TUBA_API_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_STATUS))
#define TUBA_API_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_STATUS, TubaAPIStatusClass))

typedef struct _TubaAPIStatus TubaAPIStatus;
typedef struct _TubaAPIStatusClass TubaAPIStatusClass;
typedef enum  {
	TUBA_REQUEST_V2_METHOD_GET,
	TUBA_REQUEST_V2_METHOD_POST,
	TUBA_REQUEST_V2_METHOD_PUT,
	TUBA_REQUEST_V2_METHOD_DELETE,
	TUBA_REQUEST_V2_METHOD_PATCH
} TubaRequestV2Method;

#define TUBA_REQUEST_V2_TYPE_METHOD (tuba_request_v2_method_get_type ())
typedef struct _Block73Data Block73Data;

#define TUBA_TYPE_OOPSIE (tuba_oopsie_get_type ())
typedef void (*TubaNetworkNodeCallback) (JsonNode* node, gpointer user_data, GError** error);
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _TubaViewsProfileAppendPinnedData TubaViewsProfileAppendPinnedData;

#define TUBA_WIDGETS_TYPE_COVER (tuba_widgets_cover_get_type ())
#define TUBA_WIDGETS_COVER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_COVER, TubaWidgetsCover))
#define TUBA_WIDGETS_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_COVER, TubaWidgetsCoverClass))
#define TUBA_WIDGETS_IS_COVER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_COVER))
#define TUBA_WIDGETS_IS_COVER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_COVER))
#define TUBA_WIDGETS_COVER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_COVER, TubaWidgetsCoverClass))

typedef struct _TubaWidgetsCover TubaWidgetsCover;
typedef struct _TubaWidgetsCoverClass TubaWidgetsCoverClass;
typedef struct _TubaWidgetsCoverPrivate TubaWidgetsCoverPrivate;

#define TUBA_WIDGETS_TYPE_MARKUP_VIEW (tuba_widgets_markup_view_get_type ())
#define TUBA_WIDGETS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupView))
#define TUBA_WIDGETS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))
#define TUBA_WIDGETS_IS_MARKUP_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_IS_MARKUP_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_MARKUP_VIEW))
#define TUBA_WIDGETS_MARKUP_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_MARKUP_VIEW, TubaWidgetsMarkupViewClass))

typedef struct _TubaWidgetsMarkupView TubaWidgetsMarkupView;
typedef struct _TubaWidgetsMarkupViewClass TubaWidgetsMarkupViewClass;

#define TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON (tuba_widgets_relationship_button_get_type ())
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButton))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_IS_RELATIONSHIP_BUTTON_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON))
#define TUBA_WIDGETS_RELATIONSHIP_BUTTON_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_RELATIONSHIP_BUTTON, TubaWidgetsRelationshipButtonClass))

typedef struct _TubaWidgetsRelationshipButton TubaWidgetsRelationshipButton;
typedef struct _TubaWidgetsRelationshipButtonClass TubaWidgetsRelationshipButtonClass;

#define TUBA_WIDGETS_TYPE_STATUS (tuba_widgets_status_get_type ())
#define TUBA_WIDGETS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatus))
#define TUBA_WIDGETS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))
#define TUBA_WIDGETS_IS_STATUS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_IS_STATUS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_STATUS))
#define TUBA_WIDGETS_STATUS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_STATUS, TubaWidgetsStatusClass))

typedef struct _TubaWidgetsStatus TubaWidgetsStatus;
typedef struct _TubaWidgetsStatusClass TubaWidgetsStatusClass;

#define TUBA_TYPE_ACCOUNT_STORE (tuba_account_store_get_type ())
#define TUBA_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStore))
#define TUBA_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))
#define TUBA_IS_ACCOUNT_STORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_IS_ACCOUNT_STORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ACCOUNT_STORE))
#define TUBA_ACCOUNT_STORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ACCOUNT_STORE, TubaAccountStoreClass))

typedef struct _TubaAccountStore TubaAccountStore;
typedef struct _TubaAccountStoreClass TubaAccountStoreClass;

#define TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP (tuba_widgets_profile_filter_group_get_type ())
#define TUBA_WIDGETS_PROFILE_FILTER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP, TubaWidgetsProfileFilterGroup))
#define TUBA_WIDGETS_PROFILE_FILTER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP, TubaWidgetsProfileFilterGroupClass))
#define TUBA_WIDGETS_IS_PROFILE_FILTER_GROUP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP))
#define TUBA_WIDGETS_IS_PROFILE_FILTER_GROUP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP))
#define TUBA_WIDGETS_PROFILE_FILTER_GROUP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_PROFILE_FILTER_GROUP, TubaWidgetsProfileFilterGroupClass))

typedef struct _TubaWidgetsProfileFilterGroup TubaWidgetsProfileFilterGroup;
typedef struct _TubaWidgetsProfileFilterGroupClass TubaWidgetsProfileFilterGroupClass;

#define TUBA_API_TYPE_INSTANCE (tuba_api_instance_get_type ())
#define TUBA_API_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_INSTANCE, TubaAPIInstance))
#define TUBA_API_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_INSTANCE, TubaAPIInstanceClass))
#define TUBA_API_IS_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_INSTANCE))
#define TUBA_API_IS_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_INSTANCE))
#define TUBA_API_INSTANCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_INSTANCE, TubaAPIInstanceClass))

typedef struct _TubaAPIInstance TubaAPIInstance;
typedef struct _TubaAPIInstanceClass TubaAPIInstanceClass;

#define TUBA_API_PLEROMA_TYPE_INSTANCE (tuba_api_pleroma_instance_get_type ())
#define TUBA_API_PLEROMA_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstance))
#define TUBA_API_PLEROMA_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstanceClass))
#define TUBA_API_PLEROMA_IS_INSTANCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE))
#define TUBA_API_PLEROMA_IS_INSTANCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_PLEROMA_TYPE_INSTANCE))
#define TUBA_API_PLEROMA_INSTANCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_PLEROMA_TYPE_INSTANCE, TubaAPIPleromaInstanceClass))

typedef struct _TubaAPIPleromaInstance TubaAPIPleromaInstance;
typedef struct _TubaAPIPleromaInstanceClass TubaAPIPleromaInstanceClass;
typedef enum  {
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_NONE = 1 << 0,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_QUOTE = 1 << 1,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_EMOJI_REACTIONS = 1 << 2,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_BUBBLE = 1 << 3,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_GROUP_NOTIFICATIONS = 1 << 4,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_FEATURE_TAGS = 1 << 5,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_ENDORSE_USERS = 1 << 6,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_MUTUALS = 1 << 7,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_TRANSLATION = 1 << 8,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_ICESHRIMP = 1 << 9,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_GLITCH = 1 << 10,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_LOCAL_ONLY = 1 << 11,
	TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_GOTOSOCIAL = 1 << 12
} TubaInstanceAccountInstanceFeatures;

#define TUBA_INSTANCE_ACCOUNT_TYPE_INSTANCE_FEATURES (tuba_instance_account_instance_features_get_type ())
typedef struct _Block74Data Block74Data;

#define TUBA_API_TYPE_FEATURED_TAG (tuba_api_featured_tag_get_type ())
#define TUBA_API_FEATURED_TAG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTag))
#define TUBA_API_FEATURED_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTagClass))
#define TUBA_API_IS_FEATURED_TAG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_FEATURED_TAG))
#define TUBA_API_IS_FEATURED_TAG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_FEATURED_TAG))
#define TUBA_API_FEATURED_TAG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_FEATURED_TAG, TubaAPIFeaturedTagClass))

typedef struct _TubaAPIFeaturedTag TubaAPIFeaturedTag;
typedef struct _TubaAPIFeaturedTagClass TubaAPIFeaturedTagClass;
typedef struct _TubaViewsProfileAppendFeaturedTagsData TubaViewsProfileAppendFeaturedTagsData;

#define TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE (tuba_views_base_status_message_get_type ())
#define TUBA_VIEWS_BASE_STATUS_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE, TubaViewsBaseStatusMessage))
#define TUBA_VIEWS_BASE_STATUS_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE, TubaViewsBaseStatusMessageClass))
#define TUBA_VIEWS_BASE_IS_STATUS_MESSAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE))
#define TUBA_VIEWS_BASE_IS_STATUS_MESSAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE))
#define TUBA_VIEWS_BASE_STATUS_MESSAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_BASE_TYPE_STATUS_MESSAGE, TubaViewsBaseStatusMessageClass))

typedef struct _TubaViewsBaseStatusMessage TubaViewsBaseStatusMessage;
typedef struct _TubaViewsBaseStatusMessageClass TubaViewsBaseStatusMessageClass;

#define TUBA_DIALOGS_TYPE_PROFILE_EDIT (tuba_dialogs_profile_edit_get_type ())
#define TUBA_DIALOGS_PROFILE_EDIT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_PROFILE_EDIT, TubaDialogsProfileEdit))
#define TUBA_DIALOGS_PROFILE_EDIT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_PROFILE_EDIT, TubaDialogsProfileEditClass))
#define TUBA_DIALOGS_IS_PROFILE_EDIT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_PROFILE_EDIT))
#define TUBA_DIALOGS_IS_PROFILE_EDIT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_PROFILE_EDIT))
#define TUBA_DIALOGS_PROFILE_EDIT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_PROFILE_EDIT, TubaDialogsProfileEditClass))

typedef struct _TubaDialogsProfileEdit TubaDialogsProfileEdit;
typedef struct _TubaDialogsProfileEditClass TubaDialogsProfileEditClass;

#define TUBA_DIALOGS_TYPE_MAIN_WINDOW (tuba_dialogs_main_window_get_type ())
#define TUBA_DIALOGS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindow))
#define TUBA_DIALOGS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))
#define TUBA_DIALOGS_IS_MAIN_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_IS_MAIN_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_MAIN_WINDOW))
#define TUBA_DIALOGS_MAIN_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_MAIN_WINDOW, TubaDialogsMainWindowClass))

typedef struct _TubaDialogsMainWindow TubaDialogsMainWindow;
typedef struct _TubaDialogsMainWindowClass TubaDialogsMainWindowClass;
typedef enum  {
	TUBA_APPLICATION_QUESTION_ANSWER_YES,
	TUBA_APPLICATION_QUESTION_ANSWER_NO,
	TUBA_APPLICATION_QUESTION_ANSWER_CLOSE
} TubaApplicationQuestionAnswer;

#define TUBA_APPLICATION_TYPE_QUESTION_ANSWER (tuba_application_question_answer_get_type ())

#define TUBA_APPLICATION_TYPE_QUESTION_TEXT (tuba_application_question_text_get_type ())
typedef struct _TubaApplicationQuestionText TubaApplicationQuestionText;

#define TUBA_APPLICATION_TYPE_QUESTION_BUTTONS (tuba_application_question_buttons_get_type ())
typedef struct _TubaApplicationQuestionButtons TubaApplicationQuestionButtons;

#define TUBA_APPLICATION_TYPE_QUESTION_BUTTON (tuba_application_question_button_get_type ())
typedef struct _TubaApplicationQuestionButton TubaApplicationQuestionButton;
typedef struct _TubaViewsProfileOnDomainBlockRealData TubaViewsProfileOnDomainBlockRealData;
typedef struct _Block75Data Block75Data;
#define _g_variant_unref0(var) ((var == NULL) ? NULL : (var = (g_variant_unref (var), NULL)))

#define TUBA_API_RELATIONSHIP_TYPE_MODIFY_PARAM (tuba_api_relationship_modify_param_get_type ())
typedef struct _TubaAPIRelationshipModifyParam TubaAPIRelationshipModifyParam;

#define TUBA_DIALOGS_TYPE_PROFILE_LISTS (tuba_dialogs_profile_lists_get_type ())
#define TUBA_DIALOGS_PROFILE_LISTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_PROFILE_LISTS, TubaDialogsProfileLists))
#define TUBA_DIALOGS_PROFILE_LISTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_PROFILE_LISTS, TubaDialogsProfileListsClass))
#define TUBA_DIALOGS_IS_PROFILE_LISTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_PROFILE_LISTS))
#define TUBA_DIALOGS_IS_PROFILE_LISTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_PROFILE_LISTS))
#define TUBA_DIALOGS_PROFILE_LISTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_PROFILE_LISTS, TubaDialogsProfileListsClass))

typedef struct _TubaDialogsProfileLists TubaDialogsProfileLists;
typedef struct _TubaDialogsProfileListsClass TubaDialogsProfileListsClass;

#define TUBA_DIALOGS_COMPOSER_DIALOG_TYPE_PRECOMPOSE (tuba_dialogs_composer_dialog_precompose_get_type ())
typedef struct _TubaDialogsComposerDialogPrecompose TubaDialogsComposerDialogPrecompose;

#define TUBA_API_TYPE_POLL (tuba_api_poll_get_type ())
#define TUBA_API_POLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_POLL, TubaAPIPoll))
#define TUBA_API_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_POLL, TubaAPIPollClass))
#define TUBA_API_IS_POLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_POLL))
#define TUBA_API_IS_POLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_POLL))
#define TUBA_API_POLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_POLL, TubaAPIPollClass))

typedef struct _TubaAPIPoll TubaAPIPoll;
typedef struct _TubaAPIPollClass TubaAPIPollClass;

#define TUBA_API_TYPE_ATTACHMENT (tuba_api_attachment_get_type ())
#define TUBA_API_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachment))
#define TUBA_API_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))
#define TUBA_API_IS_ATTACHMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_IS_ATTACHMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ATTACHMENT))
#define TUBA_API_ATTACHMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ATTACHMENT, TubaAPIAttachmentClass))

typedef struct _TubaAPIAttachment TubaAPIAttachment;
typedef struct _TubaAPIAttachmentClass TubaAPIAttachmentClass;

#define TUBA_TYPE_SETTINGS (tuba_settings_get_type ())
#define TUBA_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_SETTINGS, TubaSettings))
#define TUBA_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_SETTINGS, TubaSettingsClass))
#define TUBA_IS_SETTINGS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_SETTINGS))
#define TUBA_IS_SETTINGS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_SETTINGS))
#define TUBA_SETTINGS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_SETTINGS, TubaSettingsClass))

typedef struct _TubaSettings TubaSettings;
typedef struct _TubaSettingsClass TubaSettingsClass;

#define TUBA_DIALOGS_COMPOSER_TYPE_DIALOG (tuba_dialogs_composer_dialog_get_type ())
#define TUBA_DIALOGS_COMPOSER_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialog))
#define TUBA_DIALOGS_COMPOSER_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialogClass))
#define TUBA_DIALOGS_COMPOSER_IS_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG))
#define TUBA_DIALOGS_COMPOSER_IS_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG))
#define TUBA_DIALOGS_COMPOSER_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_COMPOSER_TYPE_DIALOG, TubaDialogsComposerDialogClass))

typedef struct _TubaDialogsComposerDialog TubaDialogsComposerDialog;
typedef struct _TubaDialogsComposerDialogClass TubaDialogsComposerDialogClass;

#define TUBA_VIEWS_TYPE_COLLECTION_LIST (tuba_views_collection_list_get_type ())
#define TUBA_VIEWS_COLLECTION_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_COLLECTION_LIST, TubaViewsCollectionList))
#define TUBA_VIEWS_COLLECTION_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_COLLECTION_LIST, TubaViewsCollectionListClass))
#define TUBA_VIEWS_IS_COLLECTION_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_COLLECTION_LIST))
#define TUBA_VIEWS_IS_COLLECTION_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_COLLECTION_LIST))
#define TUBA_VIEWS_COLLECTION_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_COLLECTION_LIST, TubaViewsCollectionListClass))

typedef struct _TubaViewsCollectionList TubaViewsCollectionList;
typedef struct _TubaViewsCollectionListClass TubaViewsCollectionListClass;

#define TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS (tuba_api_instance_v2_api_versions_get_type ())
#define TUBA_API_INSTANCE_V2_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersions))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_IS_API_VERSIONS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS))
#define TUBA_API_INSTANCE_V2_API_VERSIONS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_INSTANCE_V2_TYPE_API_VERSIONS, TubaAPIInstanceV2APIVersionsClass))

typedef struct _TubaAPIInstanceV2APIVersions TubaAPIInstanceV2APIVersions;
typedef struct _TubaAPIInstanceV2APIVersionsClass TubaAPIInstanceV2APIVersionsClass;

#define TUBA_VIEWS_TYPE_BROWSER (tuba_views_browser_get_type ())
#define TUBA_VIEWS_BROWSER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_TYPE_BROWSER, TubaViewsBrowser))
#define TUBA_VIEWS_BROWSER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_TYPE_BROWSER, TubaViewsBrowserClass))
#define TUBA_VIEWS_IS_BROWSER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_TYPE_BROWSER))
#define TUBA_VIEWS_IS_BROWSER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_TYPE_BROWSER))
#define TUBA_VIEWS_BROWSER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_TYPE_BROWSER, TubaViewsBrowserClass))

typedef struct _TubaViewsBrowser TubaViewsBrowser;
typedef struct _TubaViewsBrowserClass TubaViewsBrowserClass;

#define TUBA_API_TYPE_MENTION (tuba_api_mention_get_type ())
#define TUBA_API_MENTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_MENTION, TubaAPIMention))
#define TUBA_API_MENTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_MENTION, TubaAPIMentionClass))
#define TUBA_API_IS_MENTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_MENTION))
#define TUBA_API_IS_MENTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_MENTION))
#define TUBA_API_MENTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_MENTION, TubaAPIMentionClass))

typedef struct _TubaAPIMention TubaAPIMention;
typedef struct _TubaAPIMentionClass TubaAPIMentionClass;

#define TUBA_API_TYPE_COLLECTION (tuba_api_collection_get_type ())
#define TUBA_API_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollection))
#define TUBA_API_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))
#define TUBA_API_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_COLLECTION))
#define TUBA_API_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_COLLECTION, TubaAPICollectionClass))

typedef struct _TubaAPICollection TubaAPICollection;
typedef struct _TubaAPICollectionClass TubaAPICollectionClass;

#define TUBA_DIALOGS_TYPE_REPORT (tuba_dialogs_report_get_type ())
#define TUBA_DIALOGS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_TYPE_REPORT, TubaDialogsReport))
#define TUBA_DIALOGS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_TYPE_REPORT, TubaDialogsReportClass))
#define TUBA_DIALOGS_IS_REPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_TYPE_REPORT))
#define TUBA_DIALOGS_IS_REPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_TYPE_REPORT))
#define TUBA_DIALOGS_REPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_TYPE_REPORT, TubaDialogsReportClass))

typedef struct _TubaDialogsReport TubaDialogsReport;
typedef struct _TubaDialogsReportClass TubaDialogsReportClass;

#define TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR (tuba_views_profile_note_editor_get_type ())
#define TUBA_VIEWS_PROFILE_NOTE_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, TubaViewsProfileNoteEditor))
#define TUBA_VIEWS_PROFILE_NOTE_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, TubaViewsProfileNoteEditorClass))
#define TUBA_VIEWS_PROFILE_IS_NOTE_EDITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR))
#define TUBA_VIEWS_PROFILE_IS_NOTE_EDITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR))
#define TUBA_VIEWS_PROFILE_NOTE_EDITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, TubaViewsProfileNoteEditorClass))

typedef struct _TubaViewsProfileNoteEditor TubaViewsProfileNoteEditor;
typedef struct _TubaViewsProfileNoteEditorClass TubaViewsProfileNoteEditorClass;
typedef struct _TubaViewsProfileOnNoteDoneRealData TubaViewsProfileOnNoteDoneRealData;
typedef struct _TubaViewsProfileNoteEditorPrivate TubaViewsProfileNoteEditorPrivate;

#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK (tuba_dialogs_composer_components_editor_placeholder_hack_get_type ())
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_PLACEHOLDER_HACK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK, TubaDialogsComposerComponentsEditorPlaceholderHack))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_PLACEHOLDER_HACK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK, TubaDialogsComposerComponentsEditorPlaceholderHackClass))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_IS_PLACEHOLDER_HACK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_IS_PLACEHOLDER_HACK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK))
#define TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_PLACEHOLDER_HACK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_DIALOGS_COMPOSER_COMPONENTS_EDITOR_TYPE_PLACEHOLDER_HACK, TubaDialogsComposerComponentsEditorPlaceholderHackClass))

typedef struct _TubaDialogsComposerComponentsEditorPlaceholderHack TubaDialogsComposerComponentsEditorPlaceholderHack;
typedef struct _TubaDialogsComposerComponentsEditorPlaceholderHackClass TubaDialogsComposerComponentsEditorPlaceholderHackClass;
enum  {
	TUBA_VIEWS_PROFILE_NOTE_EDITOR_0_PROPERTY,
	TUBA_VIEWS_PROFILE_NOTE_EDITOR_NUM_PROPERTIES
};
static GParamSpec* tuba_views_profile_note_editor_properties[TUBA_VIEWS_PROFILE_NOTE_EDITOR_NUM_PROPERTIES];
enum  {
	TUBA_VIEWS_PROFILE_NOTE_EDITOR_NOTE_DONE_SIGNAL,
	TUBA_VIEWS_PROFILE_NOTE_EDITOR_NUM_SIGNALS
};
static guint tuba_views_profile_note_editor_signals[TUBA_VIEWS_PROFILE_NOTE_EDITOR_NUM_SIGNALS] = {0};

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;
typedef struct _TubaViewsProfileProfileAccountPrivate TubaViewsProfileProfileAccountPrivate;
enum  {
	TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_0_PROPERTY,
	TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY,
	TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY,
	TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_NUM_PROPERTIES
};
static GParamSpec* tuba_views_profile_profile_account_properties[TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_NUM_PROPERTIES];

#define TUBA_TYPE_NETWORK (tuba_network_get_type ())
#define TUBA_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_NETWORK, TubaNetwork))
#define TUBA_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_NETWORK, TubaNetworkClass))
#define TUBA_IS_NETWORK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_NETWORK))
#define TUBA_IS_NETWORK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_NETWORK))
#define TUBA_NETWORK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_NETWORK, TubaNetworkClass))

typedef struct _TubaNetwork TubaNetwork;
typedef struct _TubaNetworkClass TubaNetworkClass;
#define __vala_JsonNode_free0(var) ((var == NULL) ? NULL : (var = (_vala_JsonNode_free (var), NULL)))

#define TUBA_API_TYPE_EMOJI (tuba_api_emoji_get_type ())
#define TUBA_API_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmoji))
#define TUBA_API_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))
#define TUBA_API_IS_EMOJI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_EMOJI))
#define TUBA_API_IS_EMOJI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_EMOJI))
#define TUBA_API_EMOJI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_EMOJI, TubaAPIEmojiClass))

typedef struct _TubaAPIEmoji TubaAPIEmoji;
typedef struct _TubaAPIEmojiClass TubaAPIEmojiClass;

#define TUBA_API_TYPE_ACCOUNT_FIELD (tuba_api_account_field_get_type ())
#define TUBA_API_ACCOUNT_FIELD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountField))
#define TUBA_API_ACCOUNT_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountFieldClass))
#define TUBA_API_IS_ACCOUNT_FIELD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT_FIELD))
#define TUBA_API_IS_ACCOUNT_FIELD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT_FIELD))
#define TUBA_API_ACCOUNT_FIELD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT_FIELD, TubaAPIAccountFieldClass))

typedef struct _TubaAPIAccountField TubaAPIAccountField;
typedef struct _TubaAPIAccountFieldClass TubaAPIAccountFieldClass;
typedef struct _TubaViewsProfileProfileAccountUpdateProfileData TubaViewsProfileProfileAccountUpdateProfileData;
typedef struct _TubaViewsProfileFilterGroupPrivate TubaViewsProfileFilterGroupPrivate;
enum  {
	TUBA_VIEWS_PROFILE_FILTER_GROUP_0_PROPERTY,
	TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY,
	TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY,
	TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY,
	TUBA_VIEWS_PROFILE_FILTER_GROUP_NUM_PROPERTIES
};
static GParamSpec* tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_NUM_PROPERTIES];
typedef struct _TubaViewsProfileErrorMessageRowPrivate TubaViewsProfileErrorMessageRowPrivate;
enum  {
	TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_0_PROPERTY,
	TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY,
	TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY,
	TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_NUM_PROPERTIES
};
static GParamSpec* tuba_views_profile_error_message_row_properties[TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_NUM_PROPERTIES];
enum  {
	TUBA_VIEWS_PROFILE_COVER_PROFILE_UPDATE_SIGNAL,
	TUBA_VIEWS_PROFILE_NUM_SIGNALS
};
static guint tuba_views_profile_signals[TUBA_VIEWS_PROFILE_NUM_SIGNALS] = {0};

struct _TubaViewsBase {
	AdwBreakpointBin parent_instance;
	TubaViewsBasePrivate * priv;
	AdwHeaderBar* header;
	AdwToolbarView* toolbar_view;
	GtkScrolledWindow* scrolled;
	GtkOverlay* scrolled_overlay;
	GtkRevealer* scroll_to_top_rev;
	GtkButton* scroll_to_top;
	GtkStack* states;
	AdwClamp* content_box;
	GtkButton* status_button;
};

struct _TubaViewsBaseClass {
	AdwBreakpointBinClass parent_class;
	void (*scroll_page) (TubaViewsBase* self, gboolean up);
	void (*unbind_listboxes) (TubaViewsBase* self);
	void (*build_actions) (TubaViewsBase* self);
	void (*build_header) (TubaViewsBase* self);
	void (*clear) (TubaViewsBase* self);
	void (*on_shown) (TubaViewsBase* self);
	void (*on_hidden) (TubaViewsBase* self);
	void (*on_content_changed) (TubaViewsBase* self);
	void (*on_error) (TubaViewsBase* self, gint32 code, const gchar* reason);
};

struct _TubaViewsContentBase {
	TubaViewsBase parent_instance;
	TubaViewsContentBasePrivate * priv;
	GtkListBox* content;
	GListStore* model;
};

struct _TubaViewsContentBaseClass {
	TubaViewsBaseClass parent_class;
	void (*on_scrolled_vadjustment_value_change) (TubaViewsContentBase* self);
	void (*clear_all_but_first) (TubaViewsContentBase* self, gint i);
	void (*attempt_focus_grab) (TubaViewsContentBase* self);
	GtkWidget* (*on_create_model_widget) (TubaViewsContentBase* self, GObject* obj);
	void (*on_bottom_reached) (TubaViewsContentBase* self);
	void (*on_content_item_activated) (TubaViewsContentBase* self, GtkListBoxRow* row);
	gboolean (*get_empty) (TubaViewsContentBase* self);
};

struct _TubaAccountHolderIface {
	GTypeInterface parent_iface;
	void (*on_account_changed) (TubaAccountHolder* self, TubaInstanceAccount* acc);
	void (*on_accounts_changed) (TubaAccountHolder* self, GeeArrayList* accounts);
	TubaInstanceAccount* (*get_account) (TubaAccountHolder* self);
	void (*set_account) (TubaAccountHolder* self, TubaInstanceAccount* value);
};

struct _TubaStreamableIface {
	GTypeInterface parent_iface;
	gchar* (*get_stream_url) (TubaStreamable* self);
	void (*on_streaming_policy_changed) (TubaStreamable* self);
	const gchar* (*get_t_connection_url) (TubaStreamable* self);
	void (*set_t_connection_url) (TubaStreamable* self, const gchar* value);
	gboolean (*get_subscribed) (TubaStreamable* self);
	void (*set_subscribed) (TubaStreamable* self, gboolean value);
};

struct _TubaStreamableEvent {
	gchar* type;
	JsonNode* payload;
};

struct _TubaViewsTimeline {
	TubaViewsContentBase parent_instance;
	TubaViewsTimelinePrivate * priv;
};

struct _TubaViewsTimelineClass {
	TubaViewsContentBaseClass parent_class;
	gchar* (*get_req_url) (TubaViewsTimeline* self);
	void (*append_params_v2) (TubaViewsTimeline* self, TubaRequestV2* req);
	void (*on_request_finish) (TubaViewsTimeline* self);
	void (*request) (TubaViewsTimeline* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*request_finish) (TubaViewsTimeline* self, GAsyncResult* _res_);
	void (*on_refresh) (TubaViewsTimeline* self);
	void (*on_manual_refresh) (TubaViewsTimeline* self);
	void (*on_account_changed) (TubaViewsTimeline* self, TubaInstanceAccount* acc);
	gchar* (*get_stream_url) (TubaViewsTimeline* self);
	gboolean (*should_hide) (TubaViewsTimeline* self, TubaEntity* entity);
	void (*on_new_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_edit_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_delete_post) (TubaViewsTimeline* self, TubaStreamableEvent* ev);
	void (*on_remove_user) (TubaViewsTimeline* self, const gchar* user_id);
};

struct _TubaViewsAccounts {
	TubaViewsTimeline parent_instance;
	TubaViewsAccountsPrivate * priv;
};

struct _TubaViewsAccountsClass {
	TubaViewsTimelineClass parent_class;
};

struct _TubaViewsProfile {
	TubaViewsAccounts parent_instance;
	TubaViewsProfilePrivate * priv;
	GtkMenuButton* menu_button;
	GSimpleAction* muting_action;
	GSimpleAction* hiding_reblogs_action;
	GSimpleAction* blocking_action;
	GSimpleAction* domain_blocking_action;
	GSimpleAction* endorse_action;
	GSimpleAction* ar_list_action;
	GSimpleAction* add_note_action;
	GSimpleAction* notify_on_new_post_action;
};

struct _TubaViewsProfileClass {
	TubaViewsAccountsClass parent_class;
};

struct _TubaViewsProfilePrivate {
	TubaViewsProfileProfileAccount* _profile;
	TubaWidgetsProfileFilterGroupFilter _filter;
	gchar* _source;
	TubaViewsProfileFilterGroup* filter_group;
	TubaViewsProfileErrorMessageRow* error_message_row;
};

struct _Block73Data {
	int _ref_count_;
	TubaViewsProfile* self;
	GObject** to_add;
	gint to_add_length1;
	gint _to_add_size_;
};

typedef enum  {
	TUBA_OOPSIE_USER,
	TUBA_OOPSIE_PARSING,
	TUBA_OOPSIE_INSTANCE,
	TUBA_OOPSIE_INTERNAL,
	TUBA_OOPSIE_HTTP_401 = 401,
	TUBA_OOPSIE_HTTP_403 = 403,
	TUBA_OOPSIE_HTTP_404 = 404,
	TUBA_OOPSIE_HTTP_410 = 410,
	TUBA_OOPSIE_HTTP_422 = 422,
	TUBA_OOPSIE_HTTP_429 = 429,
	TUBA_OOPSIE_HTTP_500 = 500,
	TUBA_OOPSIE_HTTP_503 = 503
} TubaOopsie;
#define TUBA_OOPSIE tuba_oopsie_quark ()

struct _TubaViewsProfileAppendPinnedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsProfile* self;
	gboolean _tmp0_;
	const gchar* _tmp1_;
	TubaWidgetsProfileFilterGroupFilter _tmp2_;
	TubaRequestV2* req;
	TubaViewsProfileProfileAccount* _tmp3_;
	TubaAPIAccount* _tmp4_;
	TubaAPIAccount* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	TubaInstanceAccount* _tmp11_;
	TubaInstanceAccount* _tmp12_;
	TubaInstanceAccount* _tmp13_;
	TubaRequestV2* _tmp14_;
	TubaRequestV2* _tmp15_;
	TubaRequestV2* _tmp16_;
	Block73Data* _data73_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp17_;
	GInputStream* _tmp18_;
	JsonParser* parser;
	GInputStream* _tmp19_;
	JsonParser* _tmp20_;
	GObject** _tmp21_;
	JsonParser* _tmp22_;
	GListStore* _tmp23_;
	GObject** _tmp24_;
	gint _tmp24__length1;
	GError* e;
	TubaViewsProfileProfileAccount* _tmp25_;
	TubaAPIAccount* _tmp26_;
	TubaAPIAccount* _tmp27_;
	const gchar* _tmp28_;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	GError* _tmp31_;
	gchar* _tmp32_;
	gchar* _tmp33_;
	GError* _tmp34_;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	gchar* _tmp38_;
	GError* _inner_error0_;
};

struct _TubaWidgetsCover {
	GtkBox parent_instance;
	TubaWidgetsCoverPrivate * priv;
	TubaWidgetsMarkupView* note;
	TubaWidgetsRelationshipButton* rsbtn;
};

struct _TubaWidgetsCoverClass {
	GtkBoxClass parent_class;
};

struct _Block74Data {
	int _ref_count_;
	TubaViewsProfile* self;
	GObject** to_add;
	gint to_add_length1;
	gint _to_add_size_;
};

struct _TubaViewsProfileAppendFeaturedTagsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsProfile* self;
	gboolean _tmp0_;
	const gchar* _tmp1_;
	TubaWidgetsProfileFilterGroupFilter _tmp2_;
	Block74Data* _data74_;
	GObject** _tmp3_;
	TubaRequestV2* req;
	TubaViewsProfileProfileAccount* _tmp4_;
	TubaAPIAccount* _tmp5_;
	TubaAPIAccount* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	TubaInstanceAccount* _tmp12_;
	TubaInstanceAccount* _tmp13_;
	TubaInstanceAccount* _tmp14_;
	TubaRequestV2* _tmp15_;
	TubaRequestV2* _tmp16_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp17_;
	GInputStream* _tmp18_;
	JsonParser* parser;
	GInputStream* _tmp19_;
	JsonParser* _tmp20_;
	JsonParser* _tmp21_;
	GListStore* _tmp22_;
	GObject** _tmp23_;
	gint _tmp23__length1;
	GError* e;
	GError* _tmp24_;
	GError* _tmp25_;
	const gchar* _tmp26_;
	GError* _inner_error0_;
};

struct _TubaApplicationQuestionText {
	gchar* text;
	gboolean use_markup;
};

struct _TubaApplicationQuestionButton {
	gchar* label;
	AdwResponseAppearance appearance;
};

struct _TubaApplicationQuestionButtons {
	TubaApplicationQuestionButton yes;
	TubaApplicationQuestionButton no;
};

struct _TubaViewsProfileOnDomainBlockRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsProfile* self;
	gboolean block;
	const gchar* _tmp0_;
	gchar* q;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	TubaApplicationQuestionAnswer question;
	TubaApplication* _tmp3_;
	const gchar* _tmp4_;
	TubaViewsProfileProfileAccount* _tmp5_;
	TubaAPIAccount* _tmp6_;
	TubaAPIAccount* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	TubaApplicationQuestionText _tmp13_;
	TubaApplicationQuestionText _tmp14_;
	TubaApplication* _tmp15_;
	TubaDialogsMainWindow* _tmp16_;
	TubaDialogsMainWindow* _tmp17_;
	TubaApplicationQuestionButtons _tmp18_;
	TubaApplicationQuestionAnswer _tmp19_;
	TubaRequestV2Method _tmp20_;
	TubaRequestV2* req;
	TubaAccountStore* _tmp21_;
	TubaInstanceAccount* _tmp22_;
	TubaInstanceAccount* _tmp23_;
	TubaInstanceAccount* _tmp24_;
	TubaRequestV2* _tmp25_;
	TubaRequestV2* _tmp26_;
	TubaViewsProfileProfileAccount* _tmp27_;
	TubaAPIAccount* _tmp28_;
	TubaAPIAccount* _tmp29_;
	gchar* _tmp30_;
	gchar* _tmp31_;
	gchar* _tmp32_;
	TubaRequestV2* _tmp33_;
	GInputStream* _tmp34_;
	GInputStream* _tmp35_;
	TubaViewsProfileProfileAccount* _tmp36_;
	TubaAPIRelationship* _tmp37_;
	TubaAPIRelationship* _tmp38_;
	GError* e;
	TubaViewsProfileProfileAccount* _tmp39_;
	TubaAPIAccount* _tmp40_;
	TubaAPIAccount* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	const gchar* _tmp45_;
	GError* _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
	GError* _tmp49_;
	const gchar* _tmp50_;
	const gchar* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	TubaApplication* _tmp54_;
	GError* _tmp55_;
	const gchar* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	GError* _inner_error0_;
};

struct _Block75Data {
	int _ref_count_;
	TubaViewsProfile* self;
	gchar* endorse_str;
	gchar* unendorse_str;
};

struct _TubaAPIRelationshipModifyParam {
	gchar* param;
	gchar* val;
};

struct _TubaDialogsComposerDialogPrecompose {
	gchar* content;
	gchar* spoiler;
	gchar* quote_id;
	gchar* scheduled_id;
	gchar* in_reply_to_id;
	TubaAPIPoll* poll;
	GeeArrayList* media_attachments;
	gboolean sensitive_media;
	gboolean local_only;
	gboolean force_cursor_at_start;
};

struct _TubaViewsProfileOnNoteDoneRealData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsProfile* self;
	gchar* new_note;
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	GError* e;
	GError* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GError* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	TubaApplication* _tmp11_;
	GError* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	gchar* _tmp15_;
	GError* _inner_error0_;
};

struct _TubaViewsProfileNoteEditor {
	AdwDialog parent_instance;
	TubaViewsProfileNoteEditorPrivate * priv;
};

struct _TubaViewsProfileNoteEditorClass {
	AdwDialogClass parent_class;
};

struct _TubaViewsProfileNoteEditorPrivate {
	GtkSourceView* editor;
	GtkLabel* dialog_char_counter;
	TubaDialogsComposerComponentsEditorPlaceholderHack* placeholder;
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaViewsProfileProfileAccount {
	GObject parent_instance;
	TubaViewsProfileProfileAccountPrivate * priv;
};

struct _TubaViewsProfileProfileAccountClass {
	GObjectClass parent_class;
};

struct _TubaViewsProfileProfileAccountPrivate {
	TubaAPIAccount* _account;
	TubaAPIRelationship* _rs;
};

struct _TubaViewsProfileProfileAccountUpdateProfileData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	TubaViewsProfileProfileAccount* self;
	gboolean result;
	TubaRequestV2* req;
	TubaAPIAccount* _tmp0_;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	TubaAccountStore* _tmp6_;
	TubaInstanceAccount* _tmp7_;
	TubaInstanceAccount* _tmp8_;
	TubaInstanceAccount* _tmp9_;
	TubaRequestV2* _tmp10_;
	TubaRequestV2* _tmp11_;
	GInputStream* in_stream;
	TubaRequestV2* _tmp12_;
	GInputStream* _tmp13_;
	JsonParser* parser;
	GInputStream* _tmp14_;
	JsonParser* _tmp15_;
	JsonNode* node;
	TubaNetwork* _tmp16_;
	JsonParser* _tmp17_;
	JsonNode* _tmp18_;
	TubaAPIAccount* updated;
	JsonNode* _tmp19_;
	TubaAPIAccount* _tmp20_;
	TubaAPIAccount* _tmp21_;
	TubaAPIAccount* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	TubaAPIAccount* _tmp25_;
	TubaAPIAccount* _tmp26_;
	const gchar* _tmp27_;
	const gchar* _tmp28_;
	TubaAPIAccount* _tmp29_;
	TubaAPIAccount* _tmp30_;
	gboolean _tmp31_;
	gboolean _tmp32_;
	TubaAPIAccount* _tmp33_;
	TubaAPIAccount* _tmp34_;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	TubaAPIAccount* _tmp37_;
	TubaAPIAccount* _tmp38_;
	const gchar* _tmp39_;
	const gchar* _tmp40_;
	TubaAPIAccount* _tmp41_;
	TubaAPIAccount* _tmp42_;
	const gchar* _tmp43_;
	const gchar* _tmp44_;
	TubaAPIAccount* _tmp45_;
	TubaAPIAccount* _tmp46_;
	const gchar* _tmp47_;
	const gchar* _tmp48_;
	TubaAPIAccount* _tmp49_;
	TubaAPIAccount* _tmp50_;
	gboolean _tmp51_;
	gboolean _tmp52_;
	TubaAPIAccount* _tmp53_;
	TubaAPIAccount* _tmp54_;
	GeeArrayList* _tmp55_;
	GeeArrayList* _tmp56_;
	TubaAPIAccount* _tmp57_;
	TubaAPIAccount* _tmp58_;
	gint64 _tmp59_;
	gint64 _tmp60_;
	TubaAPIAccount* _tmp61_;
	TubaAPIAccount* _tmp62_;
	gint64 _tmp63_;
	gint64 _tmp64_;
	TubaAPIAccount* _tmp65_;
	TubaAPIAccount* _tmp66_;
	gint64 _tmp67_;
	gint64 _tmp68_;
	TubaAPIAccount* _tmp69_;
	TubaAPIAccount* _tmp70_;
	GeeArrayList* _tmp71_;
	GeeArrayList* _tmp72_;
	TubaAPIAccount* _tmp73_;
	TubaAPIAccount* _tmp74_;
	TubaAPIAccount* _tmp75_;
	TubaAPIAccount* _tmp76_;
	GError* e;
	TubaAPIAccount* _tmp77_;
	const gchar* _tmp78_;
	const gchar* _tmp79_;
	const gchar* _tmp80_;
	GError* _tmp81_;
	const gchar* _tmp82_;
	const gchar* _tmp83_;
	gchar* _tmp84_;
	gchar* _tmp85_;
	TubaApplication* _tmp86_;
	GError* _tmp87_;
	const gchar* _tmp88_;
	GError* _inner_error0_;
};

struct _TubaViewsProfileFilterGroup {
	GObject parent_instance;
	TubaViewsProfileFilterGroupPrivate * priv;
};

struct _TubaViewsProfileFilterGroupClass {
	GObjectClass parent_class;
};

struct _TubaViewsProfileFilterGroupPrivate {
	gboolean _visible;
	gboolean _show_media;
	gboolean _show_featured;
};

struct _TubaViewsProfileErrorMessageRow {
	GObject parent_instance;
	TubaViewsProfileErrorMessageRowPrivate * priv;
};

struct _TubaViewsProfileErrorMessageRowClass {
	GObjectClass parent_class;
};

struct _TubaViewsProfileErrorMessageRowPrivate {
	gboolean _visible;
	gchar* _message;
};

static gint TubaViewsProfile_private_offset;
static gpointer tuba_views_profile_parent_class = NULL;
VALA_EXTERN TubaApplication* tuba_app;
VALA_EXTERN TubaAccountStore* tuba_accounts;
VALA_EXTERN TubaSettings* tuba_settings;
static gint TubaViewsProfileNoteEditor_private_offset;
static gpointer tuba_views_profile_note_editor_parent_class = NULL;
static gint TubaViewsProfileProfileAccount_private_offset;
static gpointer tuba_views_profile_profile_account_parent_class = NULL;
VALA_EXTERN TubaNetwork* tuba_network;
static TubaWidgetizableIface * tuba_views_profile_profile_account_tuba_widgetizable_parent_iface = NULL;
static gint TubaViewsProfileFilterGroup_private_offset;
static gpointer tuba_views_profile_filter_group_parent_class = NULL;
static TubaWidgetizableIface * tuba_views_profile_filter_group_tuba_widgetizable_parent_iface = NULL;
static gint TubaViewsProfileErrorMessageRow_private_offset;
static gpointer tuba_views_profile_error_message_row_parent_class = NULL;
static TubaWidgetizableIface * tuba_views_profile_error_message_row_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN GType tuba_views_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBase, g_object_unref)
VALA_EXTERN GType tuba_views_content_base_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsContentBase, g_object_unref)
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_account_holder_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountHolder, g_object_unref)
VALA_EXTERN GType tuba_streamable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaStreamable, g_object_unref)
VALA_EXTERN GType tuba_views_timeline_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsTimeline, g_object_unref)
VALA_EXTERN GType tuba_request_v2_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaRequestV2, g_object_unref)
VALA_EXTERN GType tuba_streamable_event_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaStreamableEvent* tuba_streamable_event_dup (const TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_free (TubaStreamableEvent* self);
VALA_EXTERN void tuba_streamable_event_copy (const TubaStreamableEvent* self,
                                 TubaStreamableEvent* dest);
VALA_EXTERN void tuba_streamable_event_destroy (TubaStreamableEvent* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaStreamableEvent, tuba_streamable_event_destroy)
VALA_EXTERN GType tuba_views_accounts_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsAccounts, g_object_unref)
VALA_EXTERN GType tuba_views_profile_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfile, g_object_unref)
VALA_EXTERN GType tuba_views_profile_profile_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfileProfileAccount, g_object_unref)
VALA_EXTERN GType tuba_widgets_profile_filter_group_filter_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_views_profile_filter_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfileFilterGroup, g_object_unref)
VALA_EXTERN GType tuba_views_profile_error_message_row_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfileErrorMessageRow, g_object_unref)
VALA_EXTERN void tuba_views_timeline_on_request_finish (TubaViewsTimeline* self);
VALA_EXTERN GtkWidget* tuba_views_content_base_on_create_model_widget (TubaViewsContentBase* self,
                                                           GObject* obj);
VALA_EXTERN void tuba_views_timeline_on_refresh (TubaViewsTimeline* self);
VALA_EXTERN void tuba_views_timeline_on_manual_refresh (TubaViewsTimeline* self);
VALA_EXTERN void tuba_views_base_on_content_changed (TubaViewsBase* self);
VALA_EXTERN void tuba_views_base_build_header (TubaViewsBase* self);
VALA_EXTERN void tuba_views_base_clear (TubaViewsBase* self);
VALA_EXTERN void tuba_views_base_build_actions (TubaViewsBase* self);
VALA_EXTERN void tuba_views_timeline_append_params_v2 (TubaViewsTimeline* self,
                                           TubaRequestV2* req);
VALA_EXTERN gboolean tuba_views_content_base_get_empty (TubaViewsContentBase* self);
VALA_EXTERN TubaViewsProfileErrorMessageRow* tuba_views_profile_error_message_row_new (void);
VALA_EXTERN TubaViewsProfileErrorMessageRow* tuba_views_profile_error_message_row_construct (GType object_type);
VALA_EXTERN void tuba_views_profile_error_message_row_set_visible (TubaViewsProfileErrorMessageRow* self,
                                                       gboolean value);
VALA_EXTERN TubaViewsProfile* tuba_views_profile_new (TubaAPIAccount* acc);
VALA_EXTERN TubaViewsProfile* tuba_views_profile_construct (GType object_type,
                                                TubaAPIAccount* acc);
VALA_EXTERN TubaViewsProfileProfileAccount* tuba_views_profile_profile_account_new (TubaAPIAccount* t_acc);
VALA_EXTERN TubaViewsProfileProfileAccount* tuba_views_profile_profile_account_construct (GType object_type,
                                                                              TubaAPIAccount* t_acc);
VALA_EXTERN const gchar* tuba_api_account_get_id (TubaAPIAccount* self);
VALA_EXTERN gboolean tuba_api_account_get_show_featured (TubaAPIAccount* self);
VALA_EXTERN gboolean tuba_api_account_get_show_media (TubaAPIAccount* self);
VALA_EXTERN TubaViewsProfileFilterGroup* tuba_views_profile_filter_group_new (void);
VALA_EXTERN TubaViewsProfileFilterGroup* tuba_views_profile_filter_group_construct (GType object_type);
VALA_EXTERN void tuba_views_profile_filter_group_set_show_featured (TubaViewsProfileFilterGroup* self,
                                                        gboolean value);
VALA_EXTERN void tuba_views_profile_filter_group_set_show_media (TubaViewsProfileFilterGroup* self,
                                                     gboolean value);
VALA_EXTERN TubaViewsProfileProfileAccount* tuba_views_profile_get_profile (TubaViewsProfile* self);
VALA_EXTERN GType tuba_api_relationship_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIRelationship, g_object_unref)
VALA_EXTERN TubaAPIRelationship* tuba_views_profile_profile_account_get_rs (TubaViewsProfileProfileAccount* self);
static void tuba_views_profile_on_rs_updated (TubaViewsProfile* self);
static void _tuba_views_profile_on_rs_updated_tuba_api_relationship_invalidated (TubaAPIRelationship* _sender,
                                                                          gpointer self);
VALA_EXTERN gboolean tuba_api_account_is_self (TubaAPIAccount* self);
static void tuba_views_profile_update_profile_cover (TubaViewsProfile* self);
VALA_EXTERN GType tuba_application_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaApplication, g_object_unref)
static void tuba_views_profile_on_featured_refresh_request (TubaViewsProfile* self);
static void _tuba_views_profile_on_featured_refresh_request_tuba_application_refresh_featured (TubaApplication* _sender,
                                                                                        gpointer self);
static void tuba_views_profile_remove_own_status_widget (TubaViewsProfile* self,
                                                  const gchar* status_id);
static void _tuba_views_profile_remove_own_status_widget_tuba_application_remove_status_widget (TubaApplication* _sender,
                                                                                         const gchar* id,
                                                                                         gpointer self);
VALA_EXTERN GType tuba_api_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIStatus, g_object_unref)
VALA_EXTERN const gchar* tuba_api_status_get_id (TubaAPIStatus* self);
VALA_EXTERN TubaAPIStatus* tuba_api_status_get_formal (TubaAPIStatus* self);
VALA_EXTERN void tuba_views_timeline_safely_remove (TubaViewsTimeline* self,
                                        gint i);
VALA_EXTERN TubaWidgetsProfileFilterGroupFilter tuba_views_profile_get_filter (TubaViewsProfile* self);
static void tuba_views_profile_append_pinned_data_free (gpointer _data);
VALA_EXTERN void tuba_views_profile_append_pinned (TubaViewsProfile* self,
                                       GAsyncReadyCallback _callback_,
                                       gpointer _user_data_);
VALA_EXTERN void tuba_views_profile_append_pinned_finish (TubaViewsProfile* self,
                                              GAsyncResult* _res_);
static gboolean tuba_views_profile_append_pinned_co (TubaViewsProfileAppendPinnedData* _data_);
VALA_EXTERN const gchar* tuba_views_profile_get_source (TubaViewsProfile* self);
VALA_EXTERN TubaAPIAccount* tuba_views_profile_profile_account_get_account (TubaViewsProfileProfileAccount* self);
VALA_EXTERN GType tuba_request_v2_method_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaInstanceAccount* tuba_account_holder_get_account (TubaAccountHolder* self);
VALA_EXTERN TubaRequestV2* tuba_request_v2_new (const gchar* url,
                                    TubaRequestV2Method method);
VALA_EXTERN TubaRequestV2* tuba_request_v2_construct (GType object_type,
                                          const gchar* url,
                                          TubaRequestV2Method method);
VALA_EXTERN void tuba_request_v2_set_account (TubaRequestV2* self,
                                  TubaInstanceAccount* value);
VALA_EXTERN void tuba_request_v2_set_ctx (TubaRequestV2* self,
                              GtkWidget* value);
VALA_EXTERN void tuba_request_v2_add_parameter (TubaRequestV2* self,
                                    const gchar* key,
                                    const gchar* value);
static Block73Data* block73_data_ref (Block73Data* _data73_);
static void block73_data_unref (void * _userdata_);
VALA_EXTERN void tuba_request_v2_exec (TubaRequestV2* self,
                           GAsyncReadyCallback _callback_,
                           gpointer _user_data_);
VALA_EXTERN GQuark tuba_oopsie_quark (void);
VALA_EXTERN GType tuba_oopsie_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GInputStream* tuba_request_v2_exec_finish (TubaRequestV2* self,
                                           GAsyncResult* _res_,
                                           SoupMessageHeaders** response_headers,
                                           GError** error);
static void tuba_views_profile_append_pinned_ready (GObject* source_object,
                                             GAsyncResult* _res_,
                                             gpointer _user_data_);
VALA_EXTERN void tuba_network_get_parser_from_inputstream_async (GInputStream* in_stream,
                                                     GCancellable* cancellable,
                                                     GAsyncReadyCallback _callback_,
                                                     gpointer _user_data_);
VALA_EXTERN JsonParser* tuba_network_get_parser_from_inputstream_finish (GAsyncResult* _res_,
                                                             GError** error);
VALA_EXTERN void tuba_network_parse_array (JsonParser* parser,
                               TubaNetworkNodeCallback cb,
                               gpointer cb_target,
                               GDestroyNotify cb_target_destroy_notify,
                               GError** error);
static void ____lambda148_ (Block73Data* _data73_,
                     JsonNode* node,
                     GError** error);
VALA_EXTERN TubaEntity* tuba_helper_entity_from_json (JsonNode* node,
                                          GType type,
                                          gboolean force);
static JsonNode* _vala_JsonNode_copy (JsonNode* self);
VALA_EXTERN void tuba_api_status_set_pinned (TubaAPIStatus* self,
                                 gboolean value);
static void _vala_array_add92 (GObject** * array,
                        gint* length,
                        gint* size,
                        GObject* value);
static void _____lambda148__tuba_network_node_callback (JsonNode* node,
                                                 gpointer self,
                                                 GError** error);
static void tuba_views_profile_real_on_request_finish (TubaViewsTimeline* base);
VALA_EXTERN GType tuba_widgets_cover_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsCover, g_object_unref)
static void tuba_views_profile_on_cover_aria_update (TubaViewsProfile* self,
                                              TubaWidgetsCover* p_cover,
                                              const gchar* new_aria);
VALA_EXTERN GType tuba_widgets_markup_view_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsMarkupView, g_object_unref)
VALA_EXTERN GType tuba_widgets_relationship_button_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsRelationshipButton, g_object_unref)
static GtkWidget* tuba_views_profile_real_on_create_model_widget (TubaViewsContentBase* base,
                                                           GObject* obj);
static void _tuba_views_profile_on_rs_updated_tuba_widgets_cover_rs_invalidated (TubaWidgetsCover* _sender,
                                                                          gpointer self);
VALA_EXTERN void tuba_views_profile_change_timeline_source (TubaViewsProfile* self,
                                                const gchar* t_source);
static void _tuba_views_profile_change_timeline_source_tuba_widgets_cover_timeline_change (TubaWidgetsCover* _sender,
                                                                                    const gchar* timeline,
                                                                                    gpointer self);
static void _tuba_views_profile_on_cover_aria_update_tuba_widgets_cover_aria_updated (TubaWidgetsCover* _sender,
                                                                               const gchar* new_aria,
                                                                               gpointer self);
static void tuba_views_profile_on_edit_cover_note (TubaViewsProfile* self);
static void _tuba_views_profile_on_edit_cover_note_tuba_widgets_cover_edit_note (TubaWidgetsCover* _sender,
                                                                          gpointer self);
VALA_EXTERN void tuba_widgets_cover_update_cover_from_profile (TubaWidgetsCover* self,
                                                   TubaAPIAccount* profile);
static void _tuba_widgets_cover_update_cover_from_profile_tuba_views_profile_cover_profile_update (TubaViewsProfile* _sender,
                                                                                            TubaAPIAccount* acc,
                                                                                            gpointer self);
VALA_EXTERN void tuba_widgets_cover_update_aria (TubaWidgetsCover* self);
VALA_EXTERN GType tuba_widgets_status_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsStatus, g_object_unref)
VALA_EXTERN GType tuba_account_store_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAccountStore, g_object_unref)
VALA_EXTERN TubaInstanceAccount* tuba_account_store_get_active (TubaAccountStore* self);
VALA_EXTERN void tuba_widgets_status_show_toggle_pinned_action (TubaWidgetsStatus* self);
static void _tuba_views_timeline_on_refresh_tuba_widgets_status_pin_changed (TubaWidgetsStatus* _sender,
                                                                      gpointer self);
VALA_EXTERN GType tuba_widgets_profile_filter_group_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsProfileFilterGroup, g_object_unref)
VALA_EXTERN void tuba_views_profile_change_filter (TubaViewsProfile* self,
                                       TubaWidgetsProfileFilterGroupFilter filter);
static void _tuba_views_profile_change_filter_tuba_widgets_profile_filter_group_filter_change (TubaWidgetsProfileFilterGroup* _sender,
                                                                                        TubaWidgetsProfileFilterGroupFilter filter,
                                                                                        gpointer self);
static void tuba_views_profile_real_on_refresh (TubaViewsTimeline* base);
static void tuba_views_profile_append_featured_tags (TubaViewsProfile* self,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
static void tuba_views_profile_append_featured_tags_finish (TubaViewsProfile* self,
                                                     GAsyncResult* _res_);
static void tuba_views_profile_real_on_manual_refresh (TubaViewsTimeline* base);
VALA_EXTERN void tuba_views_profile_set_source (TubaViewsProfile* self,
                                    const gchar* value);
VALA_EXTERN GType tuba_api_instance_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstance, g_object_unref)
VALA_EXTERN TubaAPIInstance* tuba_instance_account_get_instance_info (TubaInstanceAccount* self);
VALA_EXTERN GType tuba_api_pleroma_instance_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPleromaInstance, g_object_unref)
VALA_EXTERN TubaAPIPleromaInstance* tuba_api_instance_get_pleroma (TubaAPIInstance* self);
VALA_EXTERN GType tuba_instance_account_instance_features_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaInstanceAccountInstanceFeatures tuba_instance_account_get_tuba_instance_features (TubaInstanceAccount* self);
VALA_EXTERN void tuba_views_profile_filter_group_set_visible (TubaViewsProfileFilterGroup* self,
                                                  gboolean value);
static void tuba_views_profile_source_meta_update (TubaViewsProfile* self,
                                            const gchar* t_source);
VALA_EXTERN void tuba_views_timeline_set_url (TubaViewsTimeline* self,
                                  const gchar* value);
static void tuba_views_profile_invalidate_actions (TubaViewsProfile* self,
                                            gboolean refresh);
VALA_EXTERN void tuba_views_timeline_set_accepts (TubaViewsTimeline* self,
                                      GType value);
VALA_EXTERN void tuba_views_base_set_empty_state_title (TubaViewsBase* self,
                                            const gchar* value);
VALA_EXTERN gint64 tuba_api_account_get_followers_count (TubaAPIAccount* self);
VALA_EXTERN gint64 tuba_api_account_get_following_count (TubaAPIAccount* self);
VALA_EXTERN void tuba_views_profile_set_filter (TubaViewsProfile* self,
                                    TubaWidgetsProfileFilterGroupFilter value);
static void tuba_views_profile_append_featured_tags_data_free (gpointer _data);
static gboolean tuba_views_profile_append_featured_tags_co (TubaViewsProfileAppendFeaturedTagsData* _data_);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
static void tuba_views_profile_append_featured_tags_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_);
static void ____lambda149_ (Block74Data* _data74_,
                     JsonNode* node,
                     GError** error);
VALA_EXTERN GType tuba_api_featured_tag_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIFeaturedTag, g_object_unref)
static void _vala_array_add93 (GObject** * array,
                        gint* length,
                        gint* size,
                        GObject* value);
static void _____lambda149__tuba_network_node_callback (JsonNode* node,
                                                 gpointer self,
                                                 GError** error);
VALA_EXTERN void tuba_views_base_on_error (TubaViewsBase* self,
                               gint32 code,
                               const gchar* reason);
static void tuba_views_profile_real_on_content_changed (TubaViewsBase* base);
VALA_EXTERN gboolean tuba_views_timeline_get_has_finished_request (TubaViewsTimeline* self);
VALA_EXTERN GType tuba_views_base_status_message_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBaseStatusMessage, g_object_unref)
VALA_EXTERN TubaViewsBaseStatusMessage* tuba_views_base_get_base_status (TubaViewsBase* self);
static void tuba_views_profile_real_build_header (TubaViewsBase* base);
static void tuba_views_profile_open_edit_page (TubaViewsProfile* self);
static void _tuba_views_profile_open_edit_page_gtk_button_clicked (GtkButton* _sender,
                                                            gpointer self);
VALA_EXTERN GType tuba_dialogs_profile_edit_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsProfileEdit, g_object_unref)
VALA_EXTERN TubaDialogsProfileEdit* tuba_dialogs_profile_edit_new (TubaAPIAccount* acc);
VALA_EXTERN TubaDialogsProfileEdit* tuba_dialogs_profile_edit_construct (GType object_type,
                                                             TubaAPIAccount* acc);
static void tuba_views_profile_on_edit_save (TubaViewsProfile* self);
static void _tuba_views_profile_on_edit_save_tuba_dialogs_profile_edit_saved (TubaDialogsProfileEdit* _sender,
                                                                       gpointer self);
VALA_EXTERN GType tuba_dialogs_main_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsMainWindow, g_object_unref)
VALA_EXTERN TubaDialogsMainWindow* tuba_application_get_main_window (TubaApplication* self);
VALA_EXTERN void tuba_views_profile_profile_account_update_profile (TubaViewsProfileProfileAccount* self,
                                                        GAsyncReadyCallback _callback_,
                                                        gpointer _user_data_);
VALA_EXTERN gboolean tuba_views_profile_profile_account_update_profile_finish (TubaViewsProfileProfileAccount* self,
                                                                   GAsyncResult* _res_);
static void __lambda150_ (TubaViewsProfile* self,
                   GObject* obj,
                   GAsyncResult* res);
static void ___lambda150__gasync_ready_callback (GObject* source_object,
                                          GAsyncResult* res,
                                          gpointer self);
static void tuba_views_profile_real_clear (TubaViewsBase* base);
VALA_EXTERN void tuba_views_content_base_clear_all_but_first (TubaViewsContentBase* self,
                                                  gint i);
static void tuba_views_profile_on_domain_block_real_data_free (gpointer _data);
static void tuba_views_profile_on_domain_block_real (TubaViewsProfile* self,
                                              gboolean block,
                                              GAsyncReadyCallback _callback_,
                                              gpointer _user_data_);
static void tuba_views_profile_on_domain_block_real_finish (TubaViewsProfile* self,
                                                     GAsyncResult* _res_);
static gboolean tuba_views_profile_on_domain_block_real_co (TubaViewsProfileOnDomainBlockRealData* _data_);
VALA_EXTERN GType tuba_application_question_answer_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_application_question_text_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaApplicationQuestionText* tuba_application_question_text_dup (const TubaApplicationQuestionText* self);
VALA_EXTERN void tuba_application_question_text_free (TubaApplicationQuestionText* self);
VALA_EXTERN void tuba_application_question_text_copy (const TubaApplicationQuestionText* self,
                                          TubaApplicationQuestionText* dest);
VALA_EXTERN void tuba_application_question_text_destroy (TubaApplicationQuestionText* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionText, tuba_application_question_text_destroy)
VALA_EXTERN GType tuba_application_question_buttons_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_application_question_button_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaApplicationQuestionButton* tuba_application_question_button_dup (const TubaApplicationQuestionButton* self);
VALA_EXTERN void tuba_application_question_button_free (TubaApplicationQuestionButton* self);
VALA_EXTERN void tuba_application_question_button_copy (const TubaApplicationQuestionButton* self,
                                            TubaApplicationQuestionButton* dest);
VALA_EXTERN void tuba_application_question_button_destroy (TubaApplicationQuestionButton* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionButton, tuba_application_question_button_destroy)
VALA_EXTERN TubaApplicationQuestionButtons* tuba_application_question_buttons_dup (const TubaApplicationQuestionButtons* self);
VALA_EXTERN void tuba_application_question_buttons_free (TubaApplicationQuestionButtons* self);
VALA_EXTERN void tuba_application_question_buttons_copy (const TubaApplicationQuestionButtons* self,
                                             TubaApplicationQuestionButtons* dest);
VALA_EXTERN void tuba_application_question_buttons_destroy (TubaApplicationQuestionButtons* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaApplicationQuestionButtons, tuba_application_question_buttons_destroy)
VALA_EXTERN void tuba_application_question (TubaApplication* self,
                                TubaApplicationQuestionText* title,
                                TubaApplicationQuestionText* msg,
                                GtkWidget* win,
                                TubaApplicationQuestionButtons* buttons,
                                GtkWidget* child,
                                gboolean skip,
                                GAsyncReadyCallback _callback_,
                                gpointer _user_data_);
VALA_EXTERN TubaApplicationQuestionAnswer tuba_application_question_finish (TubaApplication* self,
                                                                GAsyncResult* _res_);
VALA_EXTERN gchar* tuba_api_account_get_domain (TubaAPIAccount* self);
static void tuba_views_profile_on_domain_block_real_ready (GObject* source_object,
                                                    GAsyncResult* _res_,
                                                    gpointer _user_data_);
VALA_EXTERN gboolean tuba_application_question_answer_truthy (TubaApplicationQuestionAnswer self);
VALA_EXTERN void tuba_api_relationship_request (TubaAPIRelationship* self);
static void tuba_views_profile_real_build_actions (TubaViewsBase* base);
static Block75Data* block75_data_ref (Block75Data* _data75_);
static void block75_data_unref (void * _userdata_);
static GVariant* _variant_new19 (gboolean value);
static void __lambda153_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN GType tuba_api_relationship_modify_param_get_type (void) G_GNUC_CONST ;
VALA_EXTERN TubaAPIRelationshipModifyParam* tuba_api_relationship_modify_param_dup (const TubaAPIRelationshipModifyParam* self);
VALA_EXTERN void tuba_api_relationship_modify_param_free (TubaAPIRelationshipModifyParam* self);
VALA_EXTERN void tuba_api_relationship_modify_param_copy (const TubaAPIRelationshipModifyParam* self,
                                              TubaAPIRelationshipModifyParam* dest);
VALA_EXTERN void tuba_api_relationship_modify_param_destroy (TubaAPIRelationshipModifyParam* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaAPIRelationshipModifyParam, tuba_api_relationship_modify_param_destroy)
VALA_EXTERN void tuba_api_relationship_modify (TubaAPIRelationship* self,
                                   const gchar* operation,
                                   TubaAPIRelationshipModifyParam* modify_params,
                                   gint modify_params_length1);
static void _vala_TubaAPIRelationshipModifyParam_array_free (TubaAPIRelationshipModifyParam * array,
                                                      gssize array_length);
static void ___lambda153__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
VALA_EXTERN GSimpleActionGroup* tuba_views_base_get_actions (TubaViewsBase* self);
static void __lambda154_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN GType tuba_dialogs_profile_lists_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsProfileLists, g_object_unref)
VALA_EXTERN gchar* tuba_api_account_get_handle (TubaAPIAccount* self);
VALA_EXTERN TubaDialogsProfileLists* tuba_dialogs_profile_lists_new (const gchar* profile_id,
                                                         const gchar* profile_handle);
VALA_EXTERN TubaDialogsProfileLists* tuba_dialogs_profile_lists_construct (GType object_type,
                                                               const gchar* profile_id,
                                                               const gchar* profile_handle);
static void _tuba_views_base_on_error_tuba_dialogs_profile_lists_errored (TubaDialogsProfileLists* _sender,
                                                                   gint32 code,
                                                                   const gchar* message,
                                                                   gpointer self);
static void ___lambda154__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static void __lambda162_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN GType tuba_dialogs_composer_dialog_precompose_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType tuba_api_poll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIPoll, g_object_unref)
VALA_EXTERN GType tuba_api_attachment_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAttachment, g_object_unref)
VALA_EXTERN TubaDialogsComposerDialogPrecompose* tuba_dialogs_composer_dialog_precompose_dup (const TubaDialogsComposerDialogPrecompose* self);
VALA_EXTERN void tuba_dialogs_composer_dialog_precompose_free (TubaDialogsComposerDialogPrecompose* self);
VALA_EXTERN void tuba_dialogs_composer_dialog_precompose_copy (const TubaDialogsComposerDialogPrecompose* self,
                                                   TubaDialogsComposerDialogPrecompose* dest);
VALA_EXTERN void tuba_dialogs_composer_dialog_precompose_destroy (TubaDialogsComposerDialogPrecompose* self);
G_DEFINE_AUTO_CLEANUP_CLEAR_FUNC (TubaDialogsComposerDialogPrecompose, tuba_dialogs_composer_dialog_precompose_destroy)
VALA_EXTERN GType tuba_settings_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaSettings, g_object_unref)
VALA_EXTERN const gchar* tuba_settings_get_default_language (TubaSettings* self);
VALA_EXTERN const gchar* tuba_settings_get_default_quote_policy (TubaSettings* self);
VALA_EXTERN TubaDialogsComposerDialog* tuba_dialogs_composer_dialog_new (TubaDialogsComposerDialogPrecompose* precompose,
                                                             const gchar* default_visibility,
                                                             const gchar* default_language,
                                                             const gchar* post_button_label,
                                                             gboolean edit_mode,
                                                             gboolean can_schedule,
                                                             const gchar* default_quote_policy,
                                                             gboolean can_update_draft);
VALA_EXTERN TubaDialogsComposerDialog* tuba_dialogs_composer_dialog_construct (GType object_type,
                                                                   TubaDialogsComposerDialogPrecompose* precompose,
                                                                   const gchar* default_visibility,
                                                                   const gchar* default_language,
                                                                   const gchar* post_button_label,
                                                                   gboolean edit_mode,
                                                                   gboolean can_schedule,
                                                                   const gchar* default_quote_policy,
                                                                   gboolean can_update_draft);
VALA_EXTERN GType tuba_dialogs_composer_dialog_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerDialog, g_object_unref)
static void ___lambda162__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static void __lambda163_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN TubaViewsBase* tuba_dialogs_main_window_open_view (TubaDialogsMainWindow* self,
                                                   TubaViewsBase* view);
VALA_EXTERN TubaViewsCollectionList* tuba_views_collection_list_new (const gchar* for_user_id);
VALA_EXTERN TubaViewsCollectionList* tuba_views_collection_list_construct (GType object_type,
                                                               const gchar* for_user_id);
VALA_EXTERN GType tuba_views_collection_list_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsCollectionList, g_object_unref)
static void ___lambda163__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
VALA_EXTERN GType tuba_api_instance_v2_api_versions_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIInstanceV2APIVersions, g_object_unref)
VALA_EXTERN TubaAPIInstanceV2APIVersions* tuba_instance_account_get_tuba_api_versions (TubaInstanceAccount* self);
VALA_EXTERN gint8 tuba_api_instance_v2_api_versions_get_mastodon (TubaAPIInstanceV2APIVersions* self);
VALA_EXTERN gboolean tuba_api_account_get_hide_collections (TubaAPIAccount* self);
static void __lambda164_ (TubaViewsProfile* self,
                   GVariant* v);
static void tuba_views_profile_on_edit_note (TubaViewsProfile* self,
                                      const gchar* note);
static void ___lambda164__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static void __lambda165_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN void tuba_utils_host_copy (const gchar* str);
VALA_EXTERN gchar* tuba_api_account_get_full_handle (TubaAPIAccount* self);
static void ___lambda165__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static void __lambda166_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN gboolean tuba_settings_get_use_in_app_browser_if_available (TubaSettings* self);
VALA_EXTERN gboolean tuba_views_browser_can_handle_url (const gchar* url);
VALA_EXTERN const gchar* tuba_api_account_get_url (TubaAPIAccount* self);
VALA_EXTERN TubaViewsBrowser* tuba_views_browser_new_with_url (const gchar* url);
VALA_EXTERN TubaViewsBrowser* tuba_views_browser_construct_with_url (GType object_type,
                                                         const gchar* url);
VALA_EXTERN GType tuba_views_browser_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsBrowser, g_object_unref)
VALA_EXTERN void tuba_utils_host_open_url (const gchar* _uri,
                               GAsyncReadyCallback _callback_,
                               gpointer _user_data_);
VALA_EXTERN gboolean tuba_utils_host_open_url_finish (GAsyncResult* _res_);
static void ___lambda166__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static void __lambda167_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN GType tuba_api_mention_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIMention, g_object_unref)
VALA_EXTERN GType tuba_api_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPICollection, g_object_unref)
VALA_EXTERN TubaDialogsReport* tuba_dialogs_report_new (TubaAPIAccount* account,
                                            const gchar* status_id,
                                            GeeArrayList* mentions,
                                            TubaAPICollection* collection);
VALA_EXTERN TubaDialogsReport* tuba_dialogs_report_construct (GType object_type,
                                                  TubaAPIAccount* account,
                                                  const gchar* status_id,
                                                  GeeArrayList* mentions,
                                                  TubaAPICollection* collection);
VALA_EXTERN GType tuba_dialogs_report_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsReport, g_object_unref)
static void ___lambda167__g_simple_action_activate (GSimpleAction* _sender,
                                             GVariant* parameter,
                                             gpointer self);
static GVariant* _variant_new20 (gboolean value);
static void __lambda168_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN void tuba_api_relationship_question_modify_mute (TubaAPIRelationship* self,
                                                 const gchar* handle);
static void ___lambda168__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
static GVariant* _variant_new21 (gboolean value);
static void __lambda169_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN gboolean tuba_api_relationship_get_following (TubaAPIRelationship* self);
static void ___lambda169__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
static GVariant* _variant_new22 (gboolean value);
static void __lambda170_ (TubaViewsProfile* self,
                   GVariant* v);
VALA_EXTERN void tuba_api_relationship_question_modify_block (TubaAPIRelationship* self,
                                                  const gchar* handle,
                                                  gboolean block);
static void ___lambda170__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
static GVariant* _variant_new23 (gboolean value);
static void __lambda171_ (TubaViewsProfile* self,
                   GVariant* v);
static void ___lambda171__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
static GVariant* _variant_new24 (gboolean value);
static void __lambda172_ (Block75Data* _data75_,
                   GVariant* v);
static void ___lambda172__g_simple_action_change_state (GSimpleAction* _sender,
                                                 GVariant* value,
                                                 gpointer self);
VALA_EXTERN gboolean tuba_api_relationship_get_muting (TubaAPIRelationship* self);
static GVariant* _variant_new25 (gboolean value);
VALA_EXTERN gboolean tuba_api_relationship_get_endorsed (TubaAPIRelationship* self);
static GVariant* _variant_new26 (gboolean value);
VALA_EXTERN gboolean tuba_api_relationship_get_showing_reblogs (TubaAPIRelationship* self);
static GVariant* _variant_new27 (gboolean value);
VALA_EXTERN gboolean tuba_api_relationship_get_blocking (TubaAPIRelationship* self);
static GVariant* _variant_new28 (gboolean value);
VALA_EXTERN gboolean tuba_api_relationship_get_domain_blocking (TubaAPIRelationship* self);
static GVariant* _variant_new29 (gboolean value);
VALA_EXTERN gboolean tuba_api_relationship_get_notifying (TubaAPIRelationship* self);
static GVariant* _variant_new30 (gboolean value);
VALA_EXTERN void tuba_views_timeline_set_page_next (TubaViewsTimeline* self,
                                        const gchar* value);
static void tuba_views_profile_real_append_params_v2 (TubaViewsTimeline* base,
                                               TubaRequestV2* req);
VALA_EXTERN const gchar* tuba_views_timeline_get_page_next (TubaViewsTimeline* self);
VALA_EXTERN gboolean tuba_api_account_get_show_media_replies (TubaAPIAccount* self);
VALA_EXTERN const gchar* tuba_api_relationship_get_note (TubaAPIRelationship* self);
VALA_EXTERN GType tuba_views_profile_note_editor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaViewsProfileNoteEditor, g_object_unref)
VALA_EXTERN TubaViewsProfileNoteEditor* tuba_views_profile_note_editor_new (const gchar* note);
VALA_EXTERN TubaViewsProfileNoteEditor* tuba_views_profile_note_editor_construct (GType object_type,
                                                                      const gchar* note);
static void tuba_views_profile_on_note_done (TubaViewsProfile* self,
                                      const gchar* new_note);
static void _tuba_views_profile_on_note_done_tuba_views_profile_note_editor_note_done (TubaViewsProfileNoteEditor* _sender,
                                                                                const gchar* note,
                                                                                gpointer self);
static void tuba_views_profile_on_note_done_real (TubaViewsProfile* self,
                                           const gchar* new_note,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_);
static void tuba_views_profile_on_note_done_real_finish (TubaViewsProfile* self,
                                                  GAsyncResult* _res_);
static void tuba_views_profile_on_note_done_real_data_free (gpointer _data);
static gboolean tuba_views_profile_on_note_done_real_co (TubaViewsProfileOnNoteDoneRealData* _data_);
VALA_EXTERN void tuba_api_relationship_modify_note_real (TubaAPIRelationship* self,
                                             const gchar* comment,
                                             GAsyncReadyCallback _callback_,
                                             gpointer _user_data_);
VALA_EXTERN void tuba_api_relationship_modify_note_real_finish (TubaAPIRelationship* self,
                                                    GAsyncResult* _res_,
                                                    GError** error);
static void tuba_views_profile_on_note_done_real_ready (GObject* source_object,
                                                 GAsyncResult* _res_,
                                                 gpointer _user_data_);
VALA_EXTERN void tuba_views_profile_set_profile (TubaViewsProfile* self,
                                     TubaViewsProfileProfileAccount* value);
VALA_EXTERN GType tuba_dialogs_composer_components_editor_placeholder_hack_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaDialogsComposerComponentsEditorPlaceholderHack, g_object_unref)
static void tuba_views_profile_note_editor_on_cancel (TubaViewsProfileNoteEditor* self);
static void _tuba_views_profile_note_editor_on_cancel_gtk_button_clicked (GtkButton* _sender,
                                                                   gpointer self);
static void tuba_views_profile_note_editor_on_save (TubaViewsProfileNoteEditor* self);
static void _tuba_views_profile_note_editor_on_save_gtk_button_clicked (GtkButton* _sender,
                                                                 gpointer self);
VALA_EXTERN TubaDialogsComposerComponentsEditorPlaceholderHack* tuba_dialogs_composer_components_editor_placeholder_hack_new (GtkLabel* label);
VALA_EXTERN TubaDialogsComposerComponentsEditorPlaceholderHack* tuba_dialogs_composer_components_editor_placeholder_hack_construct (GType object_type,
                                                                                                                        GtkLabel* label);
static void tuba_views_profile_note_editor_update_style_scheme (TubaViewsProfileNoteEditor* self);
static void _tuba_views_profile_note_editor_update_style_scheme_g_object_notify (GObject* _sender,
                                                                          GParamSpec* pspec,
                                                                          gpointer self);
static void tuba_views_profile_note_editor_on_editor_buffer_change (TubaViewsProfileNoteEditor* self);
static void _tuba_views_profile_note_editor_on_editor_buffer_change_gtk_text_buffer_changed (GtkTextBuffer* _sender,
                                                                                      gpointer self);
VALA_EXTERN gint tuba_utils_counting_chars (const gchar* content,
                                const gchar* language);
static void tuba_views_profile_note_editor_finalize (GObject * obj);
static GType tuba_views_profile_note_editor_get_type_once (void);
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN TubaAPIRelationship* tuba_api_relationship_new_for_account (TubaAPIAccount* acc);
VALA_EXTERN TubaAPIRelationship* tuba_api_relationship_construct_for_account (GType object_type,
                                                                  TubaAPIAccount* acc);
static void tuba_views_profile_profile_account_update_profile_data_free (gpointer _data);
static gboolean tuba_views_profile_profile_account_update_profile_co (TubaViewsProfileProfileAccountUpdateProfileData* _data_);
static void tuba_views_profile_profile_account_update_profile_ready (GObject* source_object,
                                                              GAsyncResult* _res_,
                                                              gpointer _user_data_);
VALA_EXTERN GType tuba_network_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaNetwork, g_object_unref)
VALA_EXTERN JsonNode* tuba_network_parse_node (TubaNetwork* self,
                                   JsonParser* parser);
VALA_EXTERN TubaAPIAccount* tuba_api_account_from (JsonNode* node,
                                       GError** error);
static void _vala_JsonNode_free (JsonNode* self);
VALA_EXTERN const gchar* tuba_api_account_get_display_name (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_display_name (TubaAPIAccount* self,
                                        const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_note (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_note (TubaAPIAccount* self,
                                const gchar* value);
VALA_EXTERN gboolean tuba_api_account_get_locked (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_locked (TubaAPIAccount* self,
                                  gboolean value);
VALA_EXTERN const gchar* tuba_api_account_get_header (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_header (TubaAPIAccount* self,
                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_header_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_header_description (TubaAPIAccount* self,
                                              const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_avatar (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_avatar (TubaAPIAccount* self,
                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_account_get_avatar_description (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_avatar_description (TubaAPIAccount* self,
                                              const gchar* value);
VALA_EXTERN gboolean tuba_api_account_get_bot (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_bot (TubaAPIAccount* self,
                               gboolean value);
VALA_EXTERN GType tuba_api_emoji_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIEmoji, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_account_get_emojis (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_emojis (TubaAPIAccount* self,
                                  GeeArrayList* value);
VALA_EXTERN void tuba_api_account_set_followers_count (TubaAPIAccount* self,
                                           gint64 value);
VALA_EXTERN void tuba_api_account_set_following_count (TubaAPIAccount* self,
                                           gint64 value);
VALA_EXTERN gint64 tuba_api_account_get_statuses_count (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_statuses_count (TubaAPIAccount* self,
                                          gint64 value);
VALA_EXTERN GType tuba_api_account_field_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccountField, g_object_unref)
VALA_EXTERN GeeArrayList* tuba_api_account_get_fields (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_fields (TubaAPIAccount* self,
                                  GeeArrayList* value);
VALA_EXTERN TubaAPIAccount* tuba_api_account_get_moved (TubaAPIAccount* self);
VALA_EXTERN void tuba_api_account_set_moved (TubaAPIAccount* self,
                                 TubaAPIAccount* value);
static GtkWidget* tuba_views_profile_profile_account_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaWidgetsCover* tuba_widgets_cover_new (TubaViewsProfileProfileAccount* profile,
                                          gboolean mini);
VALA_EXTERN TubaWidgetsCover* tuba_widgets_cover_construct (GType object_type,
                                                TubaViewsProfileProfileAccount* profile,
                                                gboolean mini);
VALA_EXTERN GtkWidget* tuba_views_profile_profile_account_to_mini_widget (TubaViewsProfileProfileAccount* self);
VALA_EXTERN void tuba_views_profile_profile_account_set_account (TubaViewsProfileProfileAccount* self,
                                                     TubaAPIAccount* value);
VALA_EXTERN void tuba_views_profile_profile_account_set_rs (TubaViewsProfileProfileAccount* self,
                                                TubaAPIRelationship* value);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
static void tuba_views_profile_profile_account_finalize (GObject * obj);
static GType tuba_views_profile_profile_account_get_type_once (void);
static void _vala_tuba_views_profile_profile_account_get_property (GObject * object,
                                                            guint property_id,
                                                            GValue * value,
                                                            GParamSpec * pspec);
static void _vala_tuba_views_profile_profile_account_set_property (GObject * object,
                                                            guint property_id,
                                                            const GValue * value,
                                                            GParamSpec * pspec);
static GtkWidget* tuba_views_profile_filter_group_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN gboolean tuba_views_profile_filter_group_get_show_media (TubaViewsProfileFilterGroup* self);
VALA_EXTERN gboolean tuba_views_profile_filter_group_get_show_featured (TubaViewsProfileFilterGroup* self);
VALA_EXTERN TubaWidgetsProfileFilterGroup* tuba_widgets_profile_filter_group_new (gboolean show_media,
                                                                      gboolean show_featured);
VALA_EXTERN TubaWidgetsProfileFilterGroup* tuba_widgets_profile_filter_group_construct (GType object_type,
                                                                            gboolean show_media,
                                                                            gboolean show_featured);
VALA_EXTERN gboolean tuba_views_profile_filter_group_get_visible (TubaViewsProfileFilterGroup* self);
static void tuba_views_profile_filter_group_finalize (GObject * obj);
static GType tuba_views_profile_filter_group_get_type_once (void);
static void _vala_tuba_views_profile_filter_group_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec);
static void _vala_tuba_views_profile_filter_group_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec);
static GtkWidget* tuba_views_profile_error_message_row_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN const gchar* tuba_views_profile_error_message_row_get_message (TubaViewsProfileErrorMessageRow* self);
VALA_EXTERN gboolean tuba_views_profile_error_message_row_get_visible (TubaViewsProfileErrorMessageRow* self);
VALA_EXTERN void tuba_views_profile_error_message_row_set_message (TubaViewsProfileErrorMessageRow* self,
                                                       const gchar* value);
static void tuba_views_profile_error_message_row_finalize (GObject * obj);
static GType tuba_views_profile_error_message_row_get_type_once (void);
static void _vala_tuba_views_profile_error_message_row_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_tuba_views_profile_error_message_row_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static void tuba_views_profile_finalize (GObject * obj);
static GType tuba_views_profile_get_type_once (void);
static void _vala_tuba_views_profile_get_property (GObject * object,
                                            guint property_id,
                                            GValue * value,
                                            GParamSpec * pspec);
static void _vala_tuba_views_profile_set_property (GObject * object,
                                            guint property_id,
                                            const GValue * value,
                                            GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);

static inline gpointer
tuba_views_profile_get_instance_private (TubaViewsProfile* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsProfile_private_offset);
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result;
	g_return_val_if_fail (self != NULL, NULL);
	result = self;
	return result;
}

static void
_tuba_views_profile_on_rs_updated_tuba_api_relationship_invalidated (TubaAPIRelationship* _sender,
                                                                     gpointer self)
{
	tuba_views_profile_on_rs_updated ((TubaViewsProfile*) self);
}

static void
_tuba_views_profile_on_featured_refresh_request_tuba_application_refresh_featured (TubaApplication* _sender,
                                                                                   gpointer self)
{
	tuba_views_profile_on_featured_refresh_request ((TubaViewsProfile*) self);
}

static void
_tuba_views_profile_remove_own_status_widget_tuba_application_remove_status_widget (TubaApplication* _sender,
                                                                                    const gchar* id,
                                                                                    gpointer self)
{
	tuba_views_profile_remove_own_status_widget ((TubaViewsProfile*) self, id);
}

TubaViewsProfile*
tuba_views_profile_construct (GType object_type,
                              TubaAPIAccount* acc)
{
	TubaViewsProfile * self = NULL;
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaViewsProfileProfileAccount* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	TubaViewsProfileErrorMessageRow* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	TubaViewsProfileFilterGroup* _tmp12_ = NULL;
	GListStore* _tmp13_;
	TubaViewsProfileProfileAccount* _tmp14_;
	GListStore* _tmp15_;
	TubaViewsProfileFilterGroup* _tmp16_;
	GListStore* _tmp17_;
	TubaViewsProfileErrorMessageRow* _tmp18_;
	TubaViewsProfileProfileAccount* _tmp19_;
	TubaAPIRelationship* _tmp20_;
	TubaAPIRelationship* _tmp21_;
	g_return_val_if_fail (acc != NULL, NULL);
	_tmp0_ = tuba_views_profile_profile_account_new (acc);
	_tmp1_ = _tmp0_;
	_tmp2_ = tuba_api_account_get_id (acc);
	_tmp3_ = _tmp2_;
	_tmp4_ = string_to_string (_tmp3_);
	_tmp5_ = g_strconcat ("/api/v1/accounts/", _tmp4_, "/statuses", NULL);
	_tmp6_ = _tmp5_;
	self = (TubaViewsProfile*) g_object_new (object_type, "profile", _tmp1_, "label", _ ("Profile"), "allow-nesting", TRUE, "url", _tmp6_, "tuba-row", TRUE, NULL);
	_g_free0 (_tmp6_);
	_g_object_unref0 (_tmp1_);
	_tmp7_ = self->priv->error_message_row;
	g_object_bind_property_with_closures ((GObject*) self, "empty-state-title", (GObject*) _tmp7_, "message", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	_tmp8_ = tuba_api_account_get_show_featured (acc);
	_tmp9_ = _tmp8_;
	_tmp10_ = tuba_api_account_get_show_media (acc);
	_tmp11_ = _tmp10_;
	_tmp12_ = tuba_views_profile_filter_group_new ();
	tuba_views_profile_filter_group_set_show_featured (_tmp12_, _tmp9_);
	tuba_views_profile_filter_group_set_show_media (_tmp12_, _tmp11_);
	_g_object_unref0 (self->priv->filter_group);
	self->priv->filter_group = _tmp12_;
	_tmp13_ = ((TubaViewsContentBase*) self)->model;
	_tmp14_ = self->priv->_profile;
	g_list_store_insert (_tmp13_, (guint) 0, (GObject*) _tmp14_);
	_tmp15_ = ((TubaViewsContentBase*) self)->model;
	_tmp16_ = self->priv->filter_group;
	g_list_store_insert (_tmp15_, (guint) 1, (GObject*) _tmp16_);
	_tmp17_ = ((TubaViewsContentBase*) self)->model;
	_tmp18_ = self->priv->error_message_row;
	g_list_store_insert (_tmp17_, (guint) 2, (GObject*) _tmp18_);
	_tmp19_ = self->priv->_profile;
	_tmp20_ = tuba_views_profile_profile_account_get_rs (_tmp19_);
	_tmp21_ = _tmp20_;
	g_signal_connect_object (_tmp21_, "invalidated", (GCallback) _tuba_views_profile_on_rs_updated_tuba_api_relationship_invalidated, self, 0);
	if (tuba_api_account_is_self (acc)) {
		TubaApplication* _tmp22_;
		TubaApplication* _tmp23_;
		tuba_views_profile_update_profile_cover (self);
		_tmp22_ = tuba_app;
		g_signal_connect_object (_tmp22_, "refresh-featured", (GCallback) _tuba_views_profile_on_featured_refresh_request_tuba_application_refresh_featured, self, 0);
		_tmp23_ = tuba_app;
		g_signal_connect_object (_tmp23_, "remove-status-widget", (GCallback) _tuba_views_profile_remove_own_status_widget_tuba_application_remove_status_widget, self, 0);
	}
	return self;
}

TubaViewsProfile*
tuba_views_profile_new (TubaAPIAccount* acc)
{
	return tuba_views_profile_construct (TUBA_VIEWS_TYPE_PROFILE, acc);
}

static void
tuba_views_profile_remove_own_status_widget (TubaViewsProfile* self,
                                             const gchar* status_id)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (status_id != NULL);
	{
		guint i = 0U;
		i = (guint) 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				GListStore* _tmp2_;
				TubaAPIStatus* status_obj = NULL;
				GListStore* _tmp3_;
				GObject* _tmp4_;
				TubaAPIStatus* _tmp5_;
				gboolean _tmp6_ = FALSE;
				TubaAPIStatus* _tmp7_;
				if (!_tmp0_) {
					guint _tmp1_;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = ((TubaViewsContentBase*) self)->model;
				if (!(i < g_list_model_get_n_items ((GListModel*) _tmp2_))) {
					break;
				}
				_tmp3_ = ((TubaViewsContentBase*) self)->model;
				_tmp4_ = g_list_model_get_item ((GListModel*) _tmp3_, i);
				_tmp5_ = TUBA_API_IS_STATUS (_tmp4_) ? ((TubaAPIStatus*) _tmp4_) : NULL;
				if (_tmp5_ == NULL) {
					_g_object_unref0 (_tmp4_);
				}
				status_obj = _tmp5_;
				_tmp7_ = status_obj;
				if (_tmp7_ != NULL) {
					gboolean _tmp8_ = FALSE;
					TubaAPIStatus* _tmp9_;
					const gchar* _tmp10_;
					const gchar* _tmp11_;
					_tmp9_ = status_obj;
					_tmp10_ = tuba_api_status_get_id (_tmp9_);
					_tmp11_ = _tmp10_;
					if (g_strcmp0 (_tmp11_, status_id) == 0) {
						_tmp8_ = TRUE;
					} else {
						TubaAPIStatus* _tmp12_;
						TubaAPIStatus* _tmp13_;
						TubaAPIStatus* _tmp14_;
						const gchar* _tmp15_;
						const gchar* _tmp16_;
						_tmp12_ = status_obj;
						_tmp13_ = tuba_api_status_get_formal (_tmp12_);
						_tmp14_ = _tmp13_;
						_tmp15_ = tuba_api_status_get_id (_tmp14_);
						_tmp16_ = _tmp15_;
						_tmp8_ = g_strcmp0 (_tmp16_, status_id) == 0;
					}
					_tmp6_ = _tmp8_;
				} else {
					_tmp6_ = FALSE;
				}
				if (_tmp6_) {
					TubaAPIStatus* _tmp17_;
					const gchar* _tmp18_;
					const gchar* _tmp19_;
					tuba_views_timeline_safely_remove ((TubaViewsTimeline*) self, (gint) i);
					_tmp17_ = status_obj;
					_tmp18_ = tuba_api_status_get_id (_tmp17_);
					_tmp19_ = _tmp18_;
					if (g_strcmp0 (_tmp19_, status_id) == 0) {
						_g_object_unref0 (status_obj);
						break;
					}
				}
				_g_object_unref0 (status_obj);
			}
		}
	}
}

static void
tuba_views_profile_on_featured_refresh_request (TubaViewsProfile* self)
{
	gboolean _tmp0_ = FALSE;
	TubaWidgetsProfileFilterGroupFilter _tmp1_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->_filter;
	if (_tmp1_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED) {
		_tmp0_ = gtk_widget_get_mapped ((GtkWidget*) self);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		tuba_views_timeline_on_refresh ((TubaViewsTimeline*) self);
	}
}

static void
tuba_views_profile_append_pinned_data_free (gpointer _data)
{
	TubaViewsProfileAppendPinnedData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsProfileAppendPinnedData, _data_);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

void
tuba_views_profile_append_pinned (TubaViewsProfile* self,
                                  GAsyncReadyCallback _callback_,
                                  gpointer _user_data_)
{
	TubaViewsProfileAppendPinnedData* _data_;
	TubaViewsProfile* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsProfileAppendPinnedData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_profile_append_pinned_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_profile_append_pinned_co (_data_);
}

void
tuba_views_profile_append_pinned_finish (TubaViewsProfile* self,
                                         GAsyncResult* _res_)
{
	TubaViewsProfileAppendPinnedData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block73Data*
block73_data_ref (Block73Data* _data73_)
{
	g_atomic_int_inc (&_data73_->_ref_count_);
	return _data73_;
}

static void
block73_data_unref (void * _userdata_)
{
	Block73Data* _data73_;
	_data73_ = (Block73Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data73_->_ref_count_)) {
		TubaViewsProfile* self;
		self = _data73_->self;
		_data73_->to_add = (_vala_array_free (_data73_->to_add, _data73_->to_add_length1, (GDestroyNotify) g_object_unref), NULL);
		_g_object_unref0 (self);
		g_slice_free (Block73Data, _data73_);
	}
}

static void
tuba_views_profile_append_pinned_ready (GObject* source_object,
                                        GAsyncResult* _res_,
                                        gpointer _user_data_)
{
	TubaViewsProfileAppendPinnedData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_profile_append_pinned_co (_data_);
}

static JsonNode*
_vala_JsonNode_copy (JsonNode* self)
{
	return g_boxed_copy (json_node_get_type (), self);
}

static gpointer
__vala_JsonNode_copy0 (gpointer self)
{
	return self ? _vala_JsonNode_copy (self) : NULL;
}

static void
_vala_array_add92 (GObject** * array,
                   gint* length,
                   gint* size,
                   GObject* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (GObject*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
____lambda148_ (Block73Data* _data73_,
                JsonNode* node,
                GError** error)
{
	TubaViewsProfile* self;
	TubaEntity* e = NULL;
	JsonNode* _tmp0_;
	TubaEntity* _tmp1_;
	TubaAPIStatus* e_status = NULL;
	TubaEntity* _tmp2_;
	TubaAPIStatus* _tmp3_;
	TubaAPIStatus* _tmp4_;
	TubaAPIStatus* _tmp6_;
	GObject* _tmp7_;
	self = _data73_->self;
	g_return_if_fail (node != NULL);
	_tmp0_ = __vala_JsonNode_copy0 (node);
	_tmp1_ = tuba_helper_entity_from_json (_tmp0_, TUBA_API_TYPE_STATUS, FALSE);
	e = _tmp1_;
	_tmp2_ = e;
	_tmp3_ = _g_object_ref0 (TUBA_API_IS_STATUS (_tmp2_) ? ((TubaAPIStatus*) _tmp2_) : NULL);
	e_status = _tmp3_;
	_tmp4_ = e_status;
	if (_tmp4_ != NULL) {
		TubaAPIStatus* _tmp5_;
		_tmp5_ = e_status;
		tuba_api_status_set_pinned (_tmp5_, TRUE);
	}
	_tmp6_ = e_status;
	_tmp7_ = _g_object_ref0 ((GObject*) _tmp6_);
	_vala_array_add92 (&_data73_->to_add, &_data73_->to_add_length1, &_data73_->_to_add_size_, _tmp7_);
	_g_object_unref0 (e_status);
	_g_object_unref0 (e);
}

static void
_____lambda148__tuba_network_node_callback (JsonNode* node,
                                            gpointer self,
                                            GError** error)
{
	____lambda148_ (self, node, error);
}

static gboolean
tuba_views_profile_append_pinned_co (TubaViewsProfileAppendPinnedData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp1_ = _data_->self->priv->_source;
	if (g_strcmp0 (_data_->_tmp1_, "statuses") == 0) {
		_data_->_tmp2_ = _data_->self->priv->_filter;
		_data_->_tmp0_ = _data_->_tmp2_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_POSTS;
	} else {
		_data_->_tmp0_ = FALSE;
	}
	if (_data_->_tmp0_) {
		_data_->_tmp3_ = _data_->self->priv->_profile;
		_data_->_tmp4_ = tuba_views_profile_profile_account_get_account (_data_->_tmp3_);
		_data_->_tmp5_ = _data_->_tmp4_;
		_data_->_tmp6_ = tuba_api_account_get_id (_data_->_tmp5_);
		_data_->_tmp7_ = _data_->_tmp6_;
		_data_->_tmp8_ = string_to_string (_data_->_tmp7_);
		_data_->_tmp9_ = g_strconcat ("/api/v1/accounts/", _data_->_tmp8_, "/statuses", NULL);
		_data_->_tmp10_ = _data_->_tmp9_;
		_data_->_tmp11_ = tuba_account_holder_get_account ((TubaAccountHolder*) _data_->self);
		_data_->_tmp12_ = _data_->_tmp11_;
		_data_->_tmp13_ = _g_object_ref0 (_data_->_tmp12_);
		_data_->_tmp14_ = NULL;
		_data_->_tmp14_ = tuba_request_v2_new (_data_->_tmp10_, TUBA_REQUEST_V2_METHOD_GET);
		tuba_request_v2_set_account (_data_->_tmp14_, _data_->_tmp13_);
		_g_object_unref0 (_data_->_tmp13_);
		tuba_request_v2_set_ctx (_data_->_tmp14_, (GtkWidget*) _data_->self);
		_data_->_tmp15_ = _data_->_tmp14_;
		_g_free0 (_data_->_tmp10_);
		_data_->req = _data_->_tmp15_;
		_data_->_tmp16_ = _data_->req;
		tuba_request_v2_add_parameter (_data_->_tmp16_, "pinned", "true");
		{
			_data_->_data73_ = g_slice_new0 (Block73Data);
			_data_->_data73_->_ref_count_ = 1;
			_data_->_data73_->self = g_object_ref (_data_->self);
			_data_->_tmp17_ = _data_->req;
			_data_->_state_ = 1;
			tuba_request_v2_exec (_data_->_tmp17_, tuba_views_profile_append_pinned_ready, _data_);
			return FALSE;
			_state_1:
			_data_->_tmp18_ = tuba_request_v2_exec_finish (_data_->_tmp17_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->in_stream = _data_->_tmp18_;
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				block73_data_unref (_data_->_data73_);
				_data_->_data73_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp19_ = _data_->in_stream;
			_data_->_state_ = 2;
			tuba_network_get_parser_from_inputstream_async (_data_->_tmp19_, NULL, tuba_views_profile_append_pinned_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp20_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
			_data_->parser = _data_->_tmp20_;
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->in_stream);
				block73_data_unref (_data_->_data73_);
				_data_->_data73_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp21_ = g_new0 (GObject*, 0 + 1);
			_data_->_data73_->to_add = _data_->_tmp21_;
			_data_->_data73_->to_add_length1 = 0;
			_data_->_data73_->_to_add_size_ = _data_->_data73_->to_add_length1;
			_data_->_tmp22_ = _data_->parser;
			tuba_network_parse_array (_data_->_tmp22_, _____lambda148__tuba_network_node_callback, block73_data_ref (_data_->_data73_), block73_data_unref, &_data_->_inner_error0_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->parser);
				_g_object_unref0 (_data_->in_stream);
				block73_data_unref (_data_->_data73_);
				_data_->_data73_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp23_ = ((TubaViewsContentBase*) _data_->self)->model;
			_data_->_tmp24_ = _data_->_data73_->to_add;
			_data_->_tmp24__length1 = _data_->_data73_->to_add_length1;
			g_list_store_splice (_data_->_tmp23_, (guint) TUBA_VIEWS_PROFILE_TOTAL_STATIC_ITEMS, (guint) 0, _data_->_tmp24_, (guint) _data_->_tmp24__length1);
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			block73_data_unref (_data_->_data73_);
			_data_->_data73_ = NULL;
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp25_ = _data_->self->priv->_profile;
			_data_->_tmp26_ = tuba_views_profile_profile_account_get_account (_data_->_tmp25_);
			_data_->_tmp27_ = _data_->_tmp26_;
			_data_->_tmp28_ = tuba_api_account_get_id (_data_->_tmp27_);
			_data_->_tmp29_ = _data_->_tmp28_;
			_data_->_tmp30_ = string_to_string (_data_->_tmp29_);
			_data_->_tmp31_ = _data_->e;
			_data_->_tmp32_ = g_strdup_printf ("%i", _data_->_tmp31_->code);
			_data_->_tmp33_ = _data_->_tmp32_;
			_data_->_tmp34_ = _data_->e;
			_data_->_tmp35_ = _data_->_tmp34_->message;
			_data_->_tmp36_ = string_to_string (_data_->_tmp35_);
			_data_->_tmp37_ = g_strconcat ("Couldn't append pinned for ", _data_->_tmp30_, ": ", _data_->_tmp33_, " ", _data_->_tmp36_, NULL);
			_data_->_tmp38_ = _data_->_tmp37_;
			g_warning ("Profile.vala:298: %s", _data_->_tmp38_);
			_g_free0 (_data_->_tmp38_);
			_g_free0 (_data_->_tmp33_);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_views_profile_real_on_request_finish (TubaViewsTimeline* base)
{
	TubaViewsProfile * self;
	self = (TubaViewsProfile*) base;
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_profile_parent_class)->on_request_finish ((TubaViewsTimeline*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
	tuba_views_base_on_content_changed ((TubaViewsBase*) self);
}

static void
tuba_views_profile_on_cover_aria_update (TubaViewsProfile* self,
                                         TubaWidgetsCover* p_cover,
                                         const gchar* new_aria)
{
	GtkWidget* lbr = NULL;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (p_cover != NULL);
	g_return_if_fail (new_aria != NULL);
	_tmp0_ = gtk_widget_get_parent ((GtkWidget*) p_cover);
	_tmp1_ = _g_object_ref0 (_tmp0_);
	lbr = _tmp1_;
	_tmp2_ = lbr;
	if (_tmp2_ != NULL) {
		GtkWidget* _tmp3_;
		GtkWidget* _tmp4_;
		TubaWidgetsMarkupView* _tmp5_;
		_tmp3_ = lbr;
		gtk_accessible_update_property ((GtkAccessible*) _tmp3_, GTK_ACCESSIBLE_PROPERTY_LABEL, new_aria, -1, -1);
		_tmp4_ = lbr;
		_tmp5_ = p_cover->note;
		gtk_accessible_update_relation ((GtkAccessible*) _tmp4_, GTK_ACCESSIBLE_RELATION_DESCRIBED_BY, _tmp5_, NULL, -1, -1);
	}
	_g_object_unref0 (lbr);
}

static void
_tuba_views_profile_on_rs_updated_tuba_widgets_cover_rs_invalidated (TubaWidgetsCover* _sender,
                                                                     gpointer self)
{
	tuba_views_profile_on_rs_updated ((TubaViewsProfile*) self);
}

static void
_tuba_views_profile_change_timeline_source_tuba_widgets_cover_timeline_change (TubaWidgetsCover* _sender,
                                                                               const gchar* timeline,
                                                                               gpointer self)
{
	tuba_views_profile_change_timeline_source ((TubaViewsProfile*) self, timeline);
}

static void
_tuba_views_profile_on_cover_aria_update_tuba_widgets_cover_aria_updated (TubaWidgetsCover* _sender,
                                                                          const gchar* new_aria,
                                                                          gpointer self)
{
	tuba_views_profile_on_cover_aria_update ((TubaViewsProfile*) self, _sender, new_aria);
}

static void
_tuba_views_profile_on_edit_cover_note_tuba_widgets_cover_edit_note (TubaWidgetsCover* _sender,
                                                                     gpointer self)
{
	tuba_views_profile_on_edit_cover_note ((TubaViewsProfile*) self);
}

static void
_tuba_widgets_cover_update_cover_from_profile_tuba_views_profile_cover_profile_update (TubaViewsProfile* _sender,
                                                                                       TubaAPIAccount* acc,
                                                                                       gpointer self)
{
	tuba_widgets_cover_update_cover_from_profile ((TubaWidgetsCover*) self, acc);
}

static void
_tuba_views_timeline_on_refresh_tuba_widgets_status_pin_changed (TubaWidgetsStatus* _sender,
                                                                 gpointer self)
{
	tuba_views_timeline_on_refresh ((TubaViewsTimeline*) self);
}

static void
_tuba_views_profile_change_filter_tuba_widgets_profile_filter_group_filter_change (TubaWidgetsProfileFilterGroup* _sender,
                                                                                   TubaWidgetsProfileFilterGroupFilter filter,
                                                                                   gpointer self)
{
	tuba_views_profile_change_filter ((TubaViewsProfile*) self, filter);
}

static GtkWidget*
tuba_views_profile_real_on_create_model_widget (TubaViewsContentBase* base,
                                                GObject* obj)
{
	TubaViewsProfile * self;
	GtkWidget* widget = NULL;
	GtkWidget* _tmp0_;
	TubaWidgetsCover* widget_cover = NULL;
	GtkWidget* _tmp1_;
	TubaWidgetsCover* _tmp2_;
	TubaWidgetsCover* _tmp3_;
	TubaWidgetsStatus* widget_status = NULL;
	GtkWidget* _tmp19_;
	TubaWidgetsStatus* _tmp20_;
	gboolean _tmp21_ = FALSE;
	TubaWidgetsStatus* _tmp22_;
	TubaWidgetsProfileFilterGroup* widget_filter_group = NULL;
	GtkWidget* _tmp35_;
	TubaWidgetsProfileFilterGroup* _tmp36_;
	TubaWidgetsProfileFilterGroup* _tmp37_;
	GtkWidget* result;
	self = (TubaViewsProfile*) base;
	g_return_val_if_fail (obj != NULL, NULL);
	_tmp0_ = TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_views_profile_parent_class)->on_create_model_widget ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts), obj);
	widget = _tmp0_;
	_tmp1_ = widget;
	_tmp2_ = _g_object_ref0 (TUBA_WIDGETS_IS_COVER (_tmp1_) ? ((TubaWidgetsCover*) _tmp1_) : NULL);
	widget_cover = _tmp2_;
	_tmp3_ = widget_cover;
	if (_tmp3_ != NULL) {
		TubaWidgetsCover* _tmp4_;
		TubaWidgetsCover* _tmp5_;
		TubaWidgetsCover* _tmp6_;
		TubaWidgetsCover* _tmp7_;
		TubaWidgetsCover* _tmp8_;
		TubaWidgetsCover* _tmp9_;
		TubaWidgetsCover* _tmp10_;
		GtkListBoxRow* row = NULL;
		TubaWidgetsCover* _tmp11_;
		GtkWidget* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar** _tmp16_;
		GtkListBoxRow* _tmp17_ = NULL;
		TubaWidgetsCover* _tmp18_;
		_tmp4_ = widget_cover;
		g_signal_connect_object (_tmp4_, "rs-invalidated", (GCallback) _tuba_views_profile_on_rs_updated_tuba_widgets_cover_rs_invalidated, self, 0);
		_tmp5_ = widget_cover;
		g_signal_connect_object (_tmp5_, "timeline-change", (GCallback) _tuba_views_profile_change_timeline_source_tuba_widgets_cover_timeline_change, self, 0);
		_tmp6_ = widget_cover;
		g_signal_connect_object (_tmp6_, "aria-updated", (GCallback) _tuba_views_profile_on_cover_aria_update_tuba_widgets_cover_aria_updated, self, 0);
		_tmp7_ = widget_cover;
		g_signal_connect_object (_tmp7_, "edit-note", (GCallback) _tuba_views_profile_on_edit_cover_note_tuba_widgets_cover_edit_note, self, 0);
		_tmp8_ = widget_cover;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp8_, "card");
		_tmp9_ = widget_cover;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp9_, "card-spacing");
		_tmp10_ = widget_cover;
		g_signal_connect_object (self, "cover-profile-update", (GCallback) _tuba_widgets_cover_update_cover_from_profile_tuba_views_profile_cover_profile_update, _tmp10_, 0);
		_tmp11_ = widget_cover;
		_tmp12_ = _g_object_ref0 ((GtkWidget*) _tmp11_);
		_tmp13_ = g_strdup ("card-spacing");
		_tmp14_ = g_strdup ("card");
		_tmp15_ = g_strdup ("ttl-profile-cover-container");
		_tmp16_ = g_new0 (gchar*, 3 + 1);
		_tmp16_[0] = _tmp13_;
		_tmp16_[1] = _tmp14_;
		_tmp16_[2] = _tmp15_;
		_tmp17_ = (GtkListBoxRow*) gtk_list_box_row_new ();
		gtk_widget_set_focusable ((GtkWidget*) _tmp17_, TRUE);
		gtk_list_box_row_set_activatable (_tmp17_, FALSE);
		gtk_list_box_row_set_child (_tmp17_, _tmp12_);
		_g_object_unref0 (_tmp12_);
		gtk_widget_set_css_classes ((GtkWidget*) _tmp17_, _tmp16_);
		_tmp16_ = (_vala_array_free (_tmp16_, 3, (GDestroyNotify) g_free), NULL);
		gtk_widget_set_overflow ((GtkWidget*) _tmp17_, GTK_OVERFLOW_HIDDEN);
		g_object_ref_sink (_tmp17_);
		row = _tmp17_;
		_tmp18_ = widget_cover;
		tuba_widgets_cover_update_aria (_tmp18_);
		result = (GtkWidget*) row;
		_g_object_unref0 (widget_cover);
		_g_object_unref0 (widget);
		return result;
	}
	_tmp19_ = widget;
	_tmp20_ = _g_object_ref0 (TUBA_WIDGETS_IS_STATUS (_tmp19_) ? ((TubaWidgetsStatus*) _tmp19_) : NULL);
	widget_status = _tmp20_;
	_tmp22_ = widget_status;
	if (_tmp22_ != NULL) {
		TubaViewsProfileProfileAccount* _tmp23_;
		TubaAPIAccount* _tmp24_;
		TubaAPIAccount* _tmp25_;
		const gchar* _tmp26_;
		const gchar* _tmp27_;
		TubaAccountStore* _tmp28_;
		TubaInstanceAccount* _tmp29_;
		TubaInstanceAccount* _tmp30_;
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		_tmp23_ = self->priv->_profile;
		_tmp24_ = tuba_views_profile_profile_account_get_account (_tmp23_);
		_tmp25_ = _tmp24_;
		_tmp26_ = tuba_api_account_get_id (_tmp25_);
		_tmp27_ = _tmp26_;
		_tmp28_ = tuba_accounts;
		_tmp29_ = tuba_account_store_get_active (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp30_);
		_tmp32_ = _tmp31_;
		_tmp21_ = g_strcmp0 (_tmp27_, _tmp32_) == 0;
	} else {
		_tmp21_ = FALSE;
	}
	if (_tmp21_) {
		TubaWidgetsStatus* _tmp33_;
		TubaWidgetsStatus* _tmp34_;
		_tmp33_ = widget_status;
		tuba_widgets_status_show_toggle_pinned_action (_tmp33_);
		_tmp34_ = widget_status;
		g_signal_connect_object (_tmp34_, "pin-changed", (GCallback) _tuba_views_timeline_on_refresh_tuba_widgets_status_pin_changed, (TubaViewsTimeline*) self, 0);
	}
	_tmp35_ = widget;
	_tmp36_ = _g_object_ref0 (TUBA_WIDGETS_IS_PROFILE_FILTER_GROUP (_tmp35_) ? ((TubaWidgetsProfileFilterGroup*) _tmp35_) : NULL);
	widget_filter_group = _tmp36_;
	_tmp37_ = widget_filter_group;
	if (_tmp37_ != NULL) {
		TubaWidgetsProfileFilterGroup* _tmp38_;
		TubaWidgetsProfileFilterGroup* _tmp39_;
		TubaWidgetsProfileFilterGroup* _tmp40_;
		_tmp38_ = widget_filter_group;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp38_, "card");
		_tmp39_ = widget_filter_group;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp39_, "card-spacing");
		_tmp40_ = widget_filter_group;
		g_signal_connect_object (_tmp40_, "filter-change", (GCallback) _tuba_views_profile_change_filter_tuba_widgets_profile_filter_group_filter_change, self, 0);
	}
	result = widget;
	_g_object_unref0 (widget_filter_group);
	_g_object_unref0 (widget_status);
	_g_object_unref0 (widget_cover);
	return result;
}

static void
tuba_views_profile_real_on_refresh (TubaViewsTimeline* base)
{
	TubaViewsProfile * self;
	TubaViewsProfileErrorMessageRow* _tmp0_;
	self = (TubaViewsProfile*) base;
	_tmp0_ = self->priv->error_message_row;
	tuba_views_profile_error_message_row_set_visible (_tmp0_, FALSE);
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_profile_parent_class)->on_refresh ((TubaViewsTimeline*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
	tuba_views_profile_append_pinned (self, NULL, NULL);
	tuba_views_profile_append_featured_tags (self, NULL, NULL);
}

static void
tuba_views_profile_real_on_manual_refresh (TubaViewsTimeline* base)
{
	TubaViewsProfile * self;
	self = (TubaViewsProfile*) base;
	tuba_views_profile_update_profile_cover (self);
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_profile_parent_class)->on_manual_refresh ((TubaViewsTimeline*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
}

void
tuba_views_profile_change_timeline_source (TubaViewsProfile* self,
                                           const gchar* t_source)
{
	const gchar* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	const gchar* _tmp6_;
	gchar* pleroma = NULL;
	gchar* _tmp24_;
	gboolean _tmp25_ = FALSE;
	const gchar* _tmp26_;
	TubaViewsProfileFilterGroup* _tmp28_;
	const gchar* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp31_;
	TubaViewsProfileProfileAccount* _tmp32_;
	TubaAPIAccount* _tmp33_;
	TubaAPIAccount* _tmp34_;
	const gchar* _tmp35_;
	const gchar* _tmp36_;
	const gchar* _tmp37_;
	const gchar* _tmp38_;
	const gchar* _tmp39_;
	gchar* _tmp40_;
	gchar* _tmp41_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (t_source != NULL);
	if (g_strcmp0 (t_source, "statuses-like") == 0) {
		const gchar* _tmp0_ = NULL;
		TubaWidgetsProfileFilterGroupFilter _tmp1_;
		_tmp1_ = self->priv->_filter;
		if (_tmp1_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED) {
			_tmp0_ = "endorsements";
		} else {
			_tmp0_ = "statuses";
		}
		tuba_views_profile_set_source (self, _tmp0_);
	} else {
		tuba_views_profile_set_source (self, t_source);
	}
	_tmp6_ = self->priv->_source;
	if (g_strcmp0 (_tmp6_, "endorsements") == 0) {
		TubaAccountStore* _tmp7_;
		TubaInstanceAccount* _tmp8_;
		TubaInstanceAccount* _tmp9_;
		TubaAPIInstance* _tmp10_;
		TubaAPIInstance* _tmp11_;
		_tmp7_ = tuba_accounts;
		_tmp8_ = tuba_account_store_get_active (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = tuba_instance_account_get_instance_info (_tmp9_);
		_tmp11_ = _tmp10_;
		_tmp5_ = _tmp11_ != NULL;
	} else {
		_tmp5_ = FALSE;
	}
	if (_tmp5_) {
		TubaAccountStore* _tmp12_;
		TubaInstanceAccount* _tmp13_;
		TubaInstanceAccount* _tmp14_;
		TubaAPIInstance* _tmp15_;
		TubaAPIInstance* _tmp16_;
		TubaAPIPleromaInstance* _tmp17_;
		TubaAPIPleromaInstance* _tmp18_;
		_tmp12_ = tuba_accounts;
		_tmp13_ = tuba_account_store_get_active (_tmp12_);
		_tmp14_ = _tmp13_;
		_tmp15_ = tuba_instance_account_get_instance_info (_tmp14_);
		_tmp16_ = _tmp15_;
		_tmp17_ = tuba_api_instance_get_pleroma (_tmp16_);
		_tmp18_ = _tmp17_;
		_tmp4_ = _tmp18_ != NULL;
	} else {
		_tmp4_ = FALSE;
	}
	if (_tmp4_) {
		TubaAccountStore* _tmp19_;
		TubaInstanceAccount* _tmp20_;
		TubaInstanceAccount* _tmp21_;
		TubaInstanceAccountInstanceFeatures _tmp22_;
		TubaInstanceAccountInstanceFeatures _tmp23_;
		_tmp19_ = tuba_accounts;
		_tmp20_ = tuba_account_store_get_active (_tmp19_);
		_tmp21_ = _tmp20_;
		_tmp22_ = tuba_instance_account_get_tuba_instance_features (_tmp21_);
		_tmp23_ = _tmp22_;
		_tmp3_ = !((_tmp23_ & TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_ICESHRIMP) == TUBA_INSTANCE_ACCOUNT_INSTANCE_FEATURES_ICESHRIMP);
	} else {
		_tmp3_ = FALSE;
	}
	if (_tmp3_) {
		_tmp2_ = "/pleroma";
	} else {
		_tmp2_ = "";
	}
	_tmp24_ = g_strdup (_tmp2_);
	pleroma = _tmp24_;
	_tmp26_ = self->priv->_source;
	if (g_strcmp0 (_tmp26_, "statuses") == 0) {
		_tmp25_ = TRUE;
	} else {
		const gchar* _tmp27_;
		_tmp27_ = self->priv->_source;
		_tmp25_ = g_strcmp0 (_tmp27_, "endorsements") == 0;
	}
	_tmp28_ = self->priv->filter_group;
	tuba_views_profile_filter_group_set_visible (_tmp28_, _tmp25_);
	_tmp29_ = self->priv->_source;
	tuba_views_profile_source_meta_update (self, _tmp29_);
	_tmp30_ = pleroma;
	_tmp31_ = string_to_string (_tmp30_);
	_tmp32_ = self->priv->_profile;
	_tmp33_ = tuba_views_profile_profile_account_get_account (_tmp32_);
	_tmp34_ = _tmp33_;
	_tmp35_ = tuba_api_account_get_id (_tmp34_);
	_tmp36_ = _tmp35_;
	_tmp37_ = string_to_string (_tmp36_);
	_tmp38_ = self->priv->_source;
	_tmp39_ = string_to_string (_tmp38_);
	_tmp40_ = g_strconcat ("/api/v1", _tmp31_, "/accounts/", _tmp37_, "/", _tmp39_, NULL);
	_tmp41_ = _tmp40_;
	tuba_views_timeline_set_url ((TubaViewsTimeline*) self, _tmp41_);
	_g_free0 (_tmp41_);
	tuba_views_profile_invalidate_actions (self, TRUE);
	_g_free0 (pleroma);
}

static void
tuba_views_profile_source_meta_update (TubaViewsProfile* self,
                                       const gchar* t_source)
{
	const gchar* _tmp0_;
	GQuark _tmp2_ = 0U;
	static GQuark _tmp1_label0 = 0;
	static GQuark _tmp1_label1 = 0;
	static GQuark _tmp1_label2 = 0;
	static GQuark _tmp1_label3 = 0;
	g_return_if_fail (self != NULL);
	g_return_if_fail (t_source != NULL);
	_tmp0_ = t_source;
	_tmp2_ = (NULL == _tmp0_) ? 0 : g_quark_from_string (_tmp0_);
	if (_tmp2_ == ((0 != _tmp1_label0) ? _tmp1_label0 : (_tmp1_label0 = g_quark_from_static_string ("statuses")))) {
		switch (0) {
			default:
			{
				tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_STATUS);
				tuba_views_base_set_empty_state_title ((TubaViewsBase*) self, _ ("No Posts"));
				break;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label1) ? _tmp1_label1 : (_tmp1_label1 = g_quark_from_static_string ("followers")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp3_ = NULL;
				TubaViewsProfileProfileAccount* _tmp4_;
				TubaAPIAccount* _tmp5_;
				TubaAPIAccount* _tmp6_;
				gint64 _tmp7_;
				gint64 _tmp8_;
				tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_ACCOUNT);
				_tmp4_ = self->priv->_profile;
				_tmp5_ = tuba_views_profile_profile_account_get_account (_tmp4_);
				_tmp6_ = _tmp5_;
				_tmp7_ = tuba_api_account_get_followers_count (_tmp6_);
				_tmp8_ = _tmp7_;
				if (_tmp8_ > ((gint64) 0)) {
					_tmp3_ = _ ("This user has chosen to not make this information available");
				} else {
					_tmp3_ = _ ("No Followers");
				}
				tuba_views_base_set_empty_state_title ((TubaViewsBase*) self, _tmp3_);
				break;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label2) ? _tmp1_label2 : (_tmp1_label2 = g_quark_from_static_string ("following")))) {
		switch (0) {
			default:
			{
				const gchar* _tmp9_ = NULL;
				TubaViewsProfileProfileAccount* _tmp10_;
				TubaAPIAccount* _tmp11_;
				TubaAPIAccount* _tmp12_;
				gint64 _tmp13_;
				gint64 _tmp14_;
				tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_ACCOUNT);
				_tmp10_ = self->priv->_profile;
				_tmp11_ = tuba_views_profile_profile_account_get_account (_tmp10_);
				_tmp12_ = _tmp11_;
				_tmp13_ = tuba_api_account_get_following_count (_tmp12_);
				_tmp14_ = _tmp13_;
				if (_tmp14_ > ((gint64) 0)) {
					_tmp9_ = _ ("This user has chosen to not make this information available");
				} else {
					_tmp9_ = _ ("This user doesn't follow anyone yet");
				}
				tuba_views_base_set_empty_state_title ((TubaViewsBase*) self, _tmp9_);
				break;
			}
		}
	} else if (_tmp2_ == ((0 != _tmp1_label3) ? _tmp1_label3 : (_tmp1_label3 = g_quark_from_static_string ("endorsements")))) {
		switch (0) {
			default:
			{
				tuba_views_timeline_set_accepts ((TubaViewsTimeline*) self, TUBA_API_TYPE_ACCOUNT);
				tuba_views_base_set_empty_state_title ((TubaViewsBase*) self, _ ("This user doesn't have any featured hashtags or accounts."));
				break;
			}
		}
	} else {
		switch (0) {
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
}

void
tuba_views_profile_change_filter (TubaViewsProfile* self,
                                  TubaWidgetsProfileFilterGroupFilter filter)
{
	gboolean was_featured = FALSE;
	TubaWidgetsProfileFilterGroupFilter _tmp0_;
	gboolean _tmp1_ = FALSE;
	TubaWidgetsProfileFilterGroupFilter _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_filter;
	was_featured = _tmp0_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED;
	tuba_views_profile_set_filter (self, filter);
	_tmp2_ = self->priv->_filter;
	if (_tmp2_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED) {
		_tmp1_ = TRUE;
	} else {
		_tmp1_ = was_featured;
	}
	if (_tmp1_) {
		tuba_views_profile_change_timeline_source (self, "statuses-like");
	} else {
		const gchar* _tmp3_;
		_tmp3_ = self->priv->_source;
		tuba_views_profile_source_meta_update (self, _tmp3_);
		tuba_views_profile_invalidate_actions (self, TRUE);
	}
}

static void
tuba_views_profile_append_featured_tags_data_free (gpointer _data)
{
	TubaViewsProfileAppendFeaturedTagsData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsProfileAppendFeaturedTagsData, _data_);
}

static void
tuba_views_profile_append_featured_tags (TubaViewsProfile* self,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	TubaViewsProfileAppendFeaturedTagsData* _data_;
	TubaViewsProfile* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsProfileAppendFeaturedTagsData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_profile_append_featured_tags_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_profile_append_featured_tags_co (_data_);
}

static void
tuba_views_profile_append_featured_tags_finish (TubaViewsProfile* self,
                                                GAsyncResult* _res_)
{
	TubaViewsProfileAppendFeaturedTagsData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static Block74Data*
block74_data_ref (Block74Data* _data74_)
{
	g_atomic_int_inc (&_data74_->_ref_count_);
	return _data74_;
}

static void
block74_data_unref (void * _userdata_)
{
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
		TubaViewsProfile* self;
		self = _data74_->self;
		_data74_->to_add = (_vala_array_free (_data74_->to_add, _data74_->to_add_length1, (GDestroyNotify) g_object_unref), NULL);
		_g_object_unref0 (self);
		g_slice_free (Block74Data, _data74_);
	}
}

static void
tuba_views_profile_append_featured_tags_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_)
{
	TubaViewsProfileAppendFeaturedTagsData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_profile_append_featured_tags_co (_data_);
}

static void
_vala_array_add93 (GObject** * array,
                   gint* length,
                   gint* size,
                   GObject* value)
{
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (GObject*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}

static void
____lambda149_ (Block74Data* _data74_,
                JsonNode* node,
                GError** error)
{
	TubaViewsProfile* self;
	JsonNode* _tmp0_;
	TubaEntity* _tmp1_;
	self = _data74_->self;
	g_return_if_fail (node != NULL);
	_tmp0_ = __vala_JsonNode_copy0 (node);
	_tmp1_ = tuba_helper_entity_from_json (_tmp0_, TUBA_API_TYPE_FEATURED_TAG, FALSE);
	_vala_array_add93 (&_data74_->to_add, &_data74_->to_add_length1, &_data74_->_to_add_size_, (GObject*) _tmp1_);
}

static void
_____lambda149__tuba_network_node_callback (JsonNode* node,
                                            gpointer self,
                                            GError** error)
{
	____lambda149_ (self, node, error);
}

static gboolean
tuba_views_profile_append_featured_tags_co (TubaViewsProfileAppendFeaturedTagsData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp1_ = _data_->self->priv->_source;
	if (g_strcmp0 (_data_->_tmp1_, "endorsements") == 0) {
		_data_->_tmp2_ = _data_->self->priv->_filter;
		_data_->_tmp0_ = _data_->_tmp2_ == TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED;
	} else {
		_data_->_tmp0_ = FALSE;
	}
	if (_data_->_tmp0_) {
		{
			_data_->_data74_ = g_slice_new0 (Block74Data);
			_data_->_data74_->_ref_count_ = 1;
			_data_->_data74_->self = g_object_ref (_data_->self);
			_data_->_tmp3_ = g_new0 (GObject*, 0 + 1);
			_data_->_data74_->to_add = _data_->_tmp3_;
			_data_->_data74_->to_add_length1 = 0;
			_data_->_data74_->_to_add_size_ = _data_->_data74_->to_add_length1;
			_data_->_tmp4_ = _data_->self->priv->_profile;
			_data_->_tmp5_ = tuba_views_profile_profile_account_get_account (_data_->_tmp4_);
			_data_->_tmp6_ = _data_->_tmp5_;
			_data_->_tmp7_ = tuba_api_account_get_id (_data_->_tmp6_);
			_data_->_tmp8_ = _data_->_tmp7_;
			_data_->_tmp9_ = string_to_string (_data_->_tmp8_);
			_data_->_tmp10_ = g_strconcat ("/api/v1/accounts/", _data_->_tmp9_, "/featured_tags", NULL);
			_data_->_tmp11_ = _data_->_tmp10_;
			_data_->_tmp12_ = tuba_account_holder_get_account ((TubaAccountHolder*) _data_->self);
			_data_->_tmp13_ = _data_->_tmp12_;
			_data_->_tmp14_ = _g_object_ref0 (_data_->_tmp13_);
			_data_->_tmp15_ = NULL;
			_data_->_tmp15_ = tuba_request_v2_new (_data_->_tmp11_, TUBA_REQUEST_V2_METHOD_GET);
			tuba_request_v2_set_account (_data_->_tmp15_, _data_->_tmp14_);
			_g_object_unref0 (_data_->_tmp14_);
			tuba_request_v2_set_ctx (_data_->_tmp15_, (GtkWidget*) _data_->self);
			_data_->_tmp16_ = _data_->_tmp15_;
			_g_free0 (_data_->_tmp11_);
			_data_->req = _data_->_tmp16_;
			_data_->_tmp17_ = _data_->req;
			_data_->_state_ = 1;
			tuba_request_v2_exec (_data_->_tmp17_, tuba_views_profile_append_featured_tags_ready, _data_);
			return FALSE;
			_state_1:
			_data_->_tmp18_ = tuba_request_v2_exec_finish (_data_->_tmp17_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->in_stream = _data_->_tmp18_;
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->req);
				block74_data_unref (_data_->_data74_);
				_data_->_data74_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp19_ = _data_->in_stream;
			_data_->_state_ = 2;
			tuba_network_get_parser_from_inputstream_async (_data_->_tmp19_, NULL, tuba_views_profile_append_featured_tags_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp20_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
			_data_->parser = _data_->_tmp20_;
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->in_stream);
				_g_object_unref0 (_data_->req);
				block74_data_unref (_data_->_data74_);
				_data_->_data74_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp21_ = _data_->parser;
			tuba_network_parse_array (_data_->_tmp21_, _____lambda149__tuba_network_node_callback, block74_data_ref (_data_->_data74_), block74_data_unref, &_data_->_inner_error0_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				_g_object_unref0 (_data_->parser);
				_g_object_unref0 (_data_->in_stream);
				_g_object_unref0 (_data_->req);
				block74_data_unref (_data_->_data74_);
				_data_->_data74_ = NULL;
				goto __catch0_g_error;
			}
			_data_->_tmp22_ = ((TubaViewsContentBase*) _data_->self)->model;
			_data_->_tmp23_ = _data_->_data74_->to_add;
			_data_->_tmp23__length1 = _data_->_data74_->to_add_length1;
			g_list_store_splice (_data_->_tmp22_, (guint) TUBA_VIEWS_PROFILE_TOTAL_STATIC_ITEMS, (guint) 0, _data_->_tmp23_, (guint) _data_->_tmp23__length1);
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			_g_object_unref0 (_data_->req);
			block74_data_unref (_data_->_data74_);
			_data_->_data74_ = NULL;
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp24_ = _data_->e;
			_data_->_tmp25_ = _data_->e;
			_data_->_tmp26_ = _data_->_tmp25_->message;
			tuba_views_base_on_error ((TubaViewsBase*) _data_->self, (gint32) _data_->_tmp24_->code, _data_->_tmp26_);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static void
tuba_views_profile_real_on_content_changed (TubaViewsBase* base)
{
	TubaViewsProfile * self;
	TubaViewsProfileErrorMessageRow* _tmp0_;
	gboolean _tmp1_ = FALSE;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_;
	gboolean _tmp4_;
	self = (TubaViewsProfile*) base;
	_tmp0_ = self->priv->error_message_row;
	tuba_views_profile_error_message_row_set_visible (_tmp0_, FALSE);
	TUBA_VIEWS_BASE_CLASS (tuba_views_profile_parent_class)->on_content_changed ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
	_tmp3_ = tuba_views_timeline_get_has_finished_request ((TubaViewsTimeline*) self);
	_tmp4_ = _tmp3_;
	if (_tmp4_) {
		TubaViewsBaseStatusMessage* _tmp5_;
		TubaViewsBaseStatusMessage* _tmp6_;
		_tmp5_ = tuba_views_base_get_base_status ((TubaViewsBase*) self);
		_tmp6_ = _tmp5_;
		_tmp2_ = _tmp6_ == NULL;
	} else {
		_tmp2_ = FALSE;
	}
	if (_tmp2_) {
		GListStore* _tmp7_;
		_tmp7_ = ((TubaViewsContentBase*) self)->model;
		_tmp1_ = g_list_model_get_n_items ((GListModel*) _tmp7_) == ((guint) TUBA_VIEWS_PROFILE_TOTAL_STATIC_ITEMS);
	} else {
		_tmp1_ = FALSE;
	}
	if (_tmp1_) {
		TubaViewsProfileErrorMessageRow* _tmp8_;
		_tmp8_ = self->priv->error_message_row;
		tuba_views_profile_error_message_row_set_visible (_tmp8_, TRUE);
	}
}

static void
_tuba_views_profile_open_edit_page_gtk_button_clicked (GtkButton* _sender,
                                                       gpointer self)
{
	tuba_views_profile_open_edit_page ((TubaViewsProfile*) self);
}

static void
tuba_views_profile_real_build_header (TubaViewsBase* base)
{
	TubaViewsProfile * self;
	gchar* _tmp0_;
	GtkMenuButton* _tmp1_ = NULL;
	GtkBuilder* menu_builder = NULL;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	GtkBuilder* _tmp5_;
	GtkBuilder* _tmp6_;
	gchar* menu = NULL;
	gchar* _tmp7_;
	GtkMenuButton* _tmp8_;
	GtkBuilder* _tmp9_;
	const gchar* _tmp10_;
	GObject* _tmp11_;
	GtkMenuButton* _tmp12_;
	GtkPopover* _tmp13_;
	GtkPopover* _tmp14_;
	AdwHeaderBar* _tmp15_;
	GtkMenuButton* _tmp16_;
	TubaViewsProfileProfileAccount* _tmp17_;
	TubaAPIAccount* _tmp18_;
	TubaAPIAccount* _tmp19_;
	self = (TubaViewsProfile*) base;
	TUBA_VIEWS_BASE_CLASS (tuba_views_profile_parent_class)->build_header ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
	_tmp0_ = g_strdup ("view-more-symbolic");
	_tmp1_ = (GtkMenuButton*) gtk_menu_button_new ();
	gtk_menu_button_set_icon_name (_tmp1_, _tmp0_);
	_g_free0 (_tmp0_);
	g_object_ref_sink (_tmp1_);
	_g_object_unref0 (self->menu_button);
	self->menu_button = _tmp1_;
	_tmp2_ = string_to_string (BUILD_RESOURCES);
	_tmp3_ = g_strconcat (_tmp2_, "ui/menus.ui", NULL);
	_tmp4_ = _tmp3_;
	_tmp5_ = gtk_builder_new_from_resource (_tmp4_);
	_tmp6_ = _tmp5_;
	_g_free0 (_tmp4_);
	menu_builder = _tmp6_;
	_tmp7_ = g_strdup ("profile-menu");
	menu = _tmp7_;
	_tmp8_ = self->menu_button;
	_tmp9_ = menu_builder;
	_tmp10_ = menu;
	_tmp11_ = gtk_builder_get_object (_tmp9_, _tmp10_);
	gtk_menu_button_set_menu_model (_tmp8_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, g_menu_model_get_type ()) ? ((GMenuModel*) _tmp11_) : NULL);
	_tmp12_ = self->menu_button;
	_tmp13_ = gtk_menu_button_get_popover (_tmp12_);
	_tmp14_ = _tmp13_;
	g_object_set ((GtkWidget*) _tmp14_, "width-request", 250, NULL);
	_tmp15_ = ((TubaViewsBase*) self)->header;
	_tmp16_ = self->menu_button;
	adw_header_bar_pack_end (_tmp15_, (GtkWidget*) _tmp16_);
	_tmp17_ = self->priv->_profile;
	_tmp18_ = tuba_views_profile_profile_account_get_account (_tmp17_);
	_tmp19_ = _tmp18_;
	if (tuba_api_account_is_self (_tmp19_)) {
		GtkButton* edit_btn = NULL;
		gchar* _tmp20_;
		GtkButton* _tmp21_ = NULL;
		GtkButton* _tmp22_;
		AdwHeaderBar* _tmp23_;
		GtkButton* _tmp24_;
		_tmp20_ = g_strdup (_ ("Edit Profile"));
		_tmp21_ = (GtkButton*) gtk_button_new_from_icon_name ("document-edit-symbolic");
		gtk_widget_set_tooltip_text ((GtkWidget*) _tmp21_, _tmp20_);
		_g_free0 (_tmp20_);
		g_object_ref_sink (_tmp21_);
		edit_btn = _tmp21_;
		_tmp22_ = edit_btn;
		g_signal_connect_object (_tmp22_, "clicked", (GCallback) _tuba_views_profile_open_edit_page_gtk_button_clicked, self, 0);
		_tmp23_ = ((TubaViewsBase*) self)->header;
		_tmp24_ = edit_btn;
		adw_header_bar_pack_end (_tmp23_, (GtkWidget*) _tmp24_);
		_g_object_unref0 (edit_btn);
	}
	_g_free0 (menu);
	_g_object_unref0 (menu_builder);
}

static void
_tuba_views_profile_on_edit_save_tuba_dialogs_profile_edit_saved (TubaDialogsProfileEdit* _sender,
                                                                  gpointer self)
{
	tuba_views_profile_on_edit_save ((TubaViewsProfile*) self);
}

static void
tuba_views_profile_open_edit_page (TubaViewsProfile* self)
{
	TubaAPIAccount* _tmp0_ = NULL;
	TubaViewsProfileProfileAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	TubaAPIAccount* _tmp3_;
	TubaDialogsProfileEdit* dialog = NULL;
	TubaDialogsProfileEdit* _tmp10_;
	TubaApplication* _tmp11_;
	TubaDialogsMainWindow* _tmp12_;
	TubaDialogsMainWindow* _tmp13_;
	g_return_if_fail (self != NULL);
	_tmp1_ = self->priv->_profile;
	_tmp2_ = tuba_views_profile_profile_account_get_account (_tmp1_);
	_tmp3_ = _tmp2_;
	if (tuba_api_account_is_self (_tmp3_)) {
		TubaAccountStore* _tmp4_;
		TubaInstanceAccount* _tmp5_;
		TubaInstanceAccount* _tmp6_;
		_tmp4_ = tuba_accounts;
		_tmp5_ = tuba_account_store_get_active (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp0_ = (TubaAPIAccount*) _tmp6_;
	} else {
		TubaViewsProfileProfileAccount* _tmp7_;
		TubaAPIAccount* _tmp8_;
		TubaAPIAccount* _tmp9_;
		_tmp7_ = self->priv->_profile;
		_tmp8_ = tuba_views_profile_profile_account_get_account (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp0_ = _tmp9_;
	}
	_tmp10_ = tuba_dialogs_profile_edit_new (_tmp0_);
	g_object_ref_sink (_tmp10_);
	dialog = _tmp10_;
	g_signal_connect_object (dialog, "saved", (GCallback) _tuba_views_profile_on_edit_save_tuba_dialogs_profile_edit_saved, self, 0);
	_tmp11_ = tuba_app;
	_tmp12_ = tuba_application_get_main_window (_tmp11_);
	_tmp13_ = _tmp12_;
	adw_dialog_present ((AdwDialog*) dialog, (GtkWidget*) _tmp13_);
	_g_object_unref0 (dialog);
}

static void
tuba_views_profile_on_edit_save (TubaViewsProfile* self)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_account (_tmp0_);
	_tmp2_ = _tmp1_;
	if (tuba_api_account_is_self (_tmp2_)) {
		TubaAccountStore* _tmp3_;
		TubaInstanceAccount* _tmp4_;
		TubaInstanceAccount* _tmp5_;
		_tmp3_ = tuba_accounts;
		_tmp4_ = tuba_account_store_get_active (_tmp3_);
		_tmp5_ = _tmp4_;
		g_signal_emit (self, tuba_views_profile_signals[TUBA_VIEWS_PROFILE_COVER_PROFILE_UPDATE_SIGNAL], 0, (TubaAPIAccount*) _tmp5_);
	}
}

static void
__lambda150_ (TubaViewsProfile* self,
              GObject* obj,
              GAsyncResult* res)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	g_return_if_fail (res != NULL);
	_tmp0_ = self->priv->_profile;
	if (tuba_views_profile_profile_account_update_profile_finish (_tmp0_, res)) {
		TubaViewsProfileProfileAccount* _tmp1_;
		TubaAPIAccount* _tmp2_;
		TubaAPIAccount* _tmp3_;
		_tmp1_ = self->priv->_profile;
		_tmp2_ = tuba_views_profile_profile_account_get_account (_tmp1_);
		_tmp3_ = _tmp2_;
		g_signal_emit (self, tuba_views_profile_signals[TUBA_VIEWS_PROFILE_COVER_PROFILE_UPDATE_SIGNAL], 0, _tmp3_);
	}
}

static void
___lambda150__gasync_ready_callback (GObject* source_object,
                                     GAsyncResult* res,
                                     gpointer self)
{
	__lambda150_ ((TubaViewsProfile*) self, source_object, res);
	g_object_unref (self);
}

static void
tuba_views_profile_update_profile_cover (TubaViewsProfile* self)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->_profile;
	tuba_views_profile_profile_account_update_profile (_tmp0_, ___lambda150__gasync_ready_callback, g_object_ref (self));
}

static void
tuba_views_profile_real_clear (TubaViewsBase* base)
{
	TubaViewsProfile * self;
	self = (TubaViewsProfile*) base;
	TUBA_VIEWS_CONTENT_BASE_CLASS (tuba_views_profile_parent_class)->clear_all_but_first ((TubaViewsContentBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts), TUBA_VIEWS_PROFILE_TOTAL_STATIC_ITEMS);
}

static void
tuba_views_profile_on_domain_block_real_data_free (gpointer _data)
{
	TubaViewsProfileOnDomainBlockRealData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsProfileOnDomainBlockRealData, _data_);
}

static void
tuba_views_profile_on_domain_block_real (TubaViewsProfile* self,
                                         gboolean block,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_)
{
	TubaViewsProfileOnDomainBlockRealData* _data_;
	TubaViewsProfile* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsProfileOnDomainBlockRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_profile_on_domain_block_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_data_->block = block;
	tuba_views_profile_on_domain_block_real_co (_data_);
}

static void
tuba_views_profile_on_domain_block_real_finish (TubaViewsProfile* self,
                                                GAsyncResult* _res_)
{
	TubaViewsProfileOnDomainBlockRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_profile_on_domain_block_real_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_)
{
	TubaViewsProfileOnDomainBlockRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_profile_on_domain_block_real_co (_data_);
}

static gboolean
tuba_views_profile_on_domain_block_real_co (TubaViewsProfileOnDomainBlockRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	if (_data_->block) {
		_data_->_tmp0_ = _ ("Block Entire \"%s\"?");
	} else {
		_data_->_tmp0_ = _ ("Unblock Entire \"%s\"?");
	}
	_data_->_tmp1_ = g_strdup (_data_->_tmp0_);
	_data_->q = _data_->_tmp1_;
	if (_data_->block) {
		_data_->_tmp2_ = _ ("Block");
	} else {
		_data_->_tmp2_ = _ ("Unblock");
	}
	_data_->_tmp3_ = tuba_app;
	_data_->_tmp4_ = _data_->q;
	_data_->_tmp5_ = _data_->self->priv->_profile;
	_data_->_tmp6_ = tuba_views_profile_profile_account_get_account (_data_->_tmp5_);
	_data_->_tmp7_ = _data_->_tmp6_;
	_data_->_tmp8_ = tuba_api_account_get_domain (_data_->_tmp7_);
	_data_->_tmp9_ = _data_->_tmp8_;
	_data_->_tmp10_ = _data_->_tmp9_;
	_data_->_tmp11_ = g_strdup_printf (_data_->_tmp4_, _data_->_tmp10_);
	_data_->_tmp12_ = _data_->_tmp11_;
	memset (&_data_->_tmp13_, 0, sizeof (TubaApplicationQuestionText));
	_g_free0 (_data_->_tmp13_.text);
	_data_->_tmp13_.text = _data_->_tmp12_;
	_data_->_tmp13_.use_markup = FALSE;
	memset (&_data_->_tmp14_, 0, sizeof (TubaApplicationQuestionText));
	_g_free0 (_data_->_tmp14_.text);
	_data_->_tmp14_.text = _ ("Blocking a domain will:\n" \
"\n" \
"• Remove its public posts and notifications from your timelines\n" \
"• Remove its followers from your account\n" \
"• Prevent you from following its users");
	_data_->_tmp14_.use_markup = FALSE;
	_data_->_tmp15_ = tuba_app;
	_data_->_tmp16_ = tuba_application_get_main_window (_data_->_tmp15_);
	_data_->_tmp17_ = _data_->_tmp16_;
	memset (&_data_->_tmp18_, 0, sizeof (TubaApplicationQuestionButtons));
	tuba_application_question_button_destroy (&_data_->_tmp18_.yes);
	_data_->_tmp18_.yes = (TubaApplicationQuestionButton) {_data_->_tmp2_, ADW_RESPONSE_DESTRUCTIVE};
	tuba_application_question_button_destroy (&_data_->_tmp18_.no);
	_data_->_tmp18_.no = (TubaApplicationQuestionButton) {_ ("Cancel"), ADW_RESPONSE_DEFAULT};
	_data_->_state_ = 1;
	tuba_application_question (_data_->_tmp3_, &_data_->_tmp13_, &_data_->_tmp14_, (GtkWidget*) _data_->_tmp17_, &_data_->_tmp18_, NULL, FALSE, tuba_views_profile_on_domain_block_real_ready, _data_);
	return FALSE;
	_state_1:
	_data_->_tmp19_ = tuba_application_question_finish (_data_->_tmp3_, _data_->_res_);
	_g_free0 (_data_->_tmp12_);
	_g_free0 (_data_->_tmp10_);
	_data_->question = _data_->_tmp19_;
	if (tuba_application_question_answer_truthy (_data_->question)) {
		if (_data_->block) {
			_data_->_tmp20_ = TUBA_REQUEST_V2_METHOD_POST;
		} else {
			_data_->_tmp20_ = TUBA_REQUEST_V2_METHOD_DELETE;
		}
		_data_->_tmp21_ = tuba_accounts;
		_data_->_tmp22_ = tuba_account_store_get_active (_data_->_tmp21_);
		_data_->_tmp23_ = _data_->_tmp22_;
		_data_->_tmp24_ = _g_object_ref0 (_data_->_tmp23_);
		_data_->_tmp25_ = NULL;
		_data_->_tmp25_ = tuba_request_v2_new ("/api/v1/domain_blocks", _data_->_tmp20_);
		tuba_request_v2_set_account (_data_->_tmp25_, _data_->_tmp24_);
		_g_object_unref0 (_data_->_tmp24_);
		_data_->req = _data_->_tmp25_;
		_data_->_tmp26_ = _data_->req;
		_data_->_tmp27_ = _data_->self->priv->_profile;
		_data_->_tmp28_ = tuba_views_profile_profile_account_get_account (_data_->_tmp27_);
		_data_->_tmp29_ = _data_->_tmp28_;
		_data_->_tmp30_ = tuba_api_account_get_domain (_data_->_tmp29_);
		_data_->_tmp31_ = _data_->_tmp30_;
		_data_->_tmp32_ = _data_->_tmp31_;
		tuba_request_v2_add_parameter (_data_->_tmp26_, "domain", _data_->_tmp32_);
		_g_free0 (_data_->_tmp32_);
		{
			_data_->_tmp33_ = _data_->req;
			_data_->_state_ = 2;
			tuba_request_v2_exec (_data_->_tmp33_, tuba_views_profile_on_domain_block_real_ready, _data_);
			return FALSE;
			_state_2:
			_data_->_tmp34_ = tuba_request_v2_exec_finish (_data_->_tmp33_, _data_->_res_, NULL, &_data_->_inner_error0_);
			_data_->_tmp35_ = _data_->_tmp34_;
			_g_object_unref0 (_data_->_tmp35_);
			if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
				goto __catch0_g_error;
			}
			_data_->_tmp36_ = _data_->self->priv->_profile;
			_data_->_tmp37_ = tuba_views_profile_profile_account_get_rs (_data_->_tmp36_);
			_data_->_tmp38_ = _data_->_tmp37_;
			tuba_api_relationship_request (_data_->_tmp38_);
		}
		goto __finally0;
		__catch0_g_error:
		{
			_data_->e = _data_->_inner_error0_;
			_data_->_inner_error0_ = NULL;
			_data_->_tmp39_ = _data_->self->priv->_profile;
			_data_->_tmp40_ = tuba_views_profile_profile_account_get_account (_data_->_tmp39_);
			_data_->_tmp41_ = _data_->_tmp40_;
			_data_->_tmp42_ = tuba_api_account_get_domain (_data_->_tmp41_);
			_data_->_tmp43_ = _data_->_tmp42_;
			_data_->_tmp44_ = _data_->_tmp43_;
			_data_->_tmp45_ = string_to_string (_data_->_tmp44_);
			_data_->_tmp46_ = _data_->e;
			_data_->_tmp47_ = g_strdup_printf ("%i", _data_->_tmp46_->code);
			_data_->_tmp48_ = _data_->_tmp47_;
			_data_->_tmp49_ = _data_->e;
			_data_->_tmp50_ = _data_->_tmp49_->message;
			_data_->_tmp51_ = string_to_string (_data_->_tmp50_);
			_data_->_tmp52_ = g_strconcat ("Couldn't block domain ", _data_->_tmp45_, ": ", _data_->_tmp48_, " ", _data_->_tmp51_, NULL);
			_data_->_tmp53_ = _data_->_tmp52_;
			g_warning ("Profile.vala:557: %s", _data_->_tmp53_);
			_g_free0 (_data_->_tmp53_);
			_g_free0 (_data_->_tmp48_);
			_g_free0 (_data_->_tmp44_);
			_data_->_tmp54_ = tuba_app;
			_data_->_tmp55_ = _data_->e;
			_data_->_tmp56_ = _data_->_tmp55_->message;
			_data_->_tmp57_ = g_strdup_printf (_ ("Couldn't block domain: %s"), _data_->_tmp56_);
			_data_->_tmp58_ = _data_->_tmp57_;
			g_signal_emit_by_name (_data_->_tmp54_, "toast", _data_->_tmp58_, (guint) 5, NULL, NULL, NULL);
			_g_free0 (_data_->_tmp58_);
			_g_error_free0 (_data_->e);
		}
		__finally0:
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->req);
			_g_free0 (_data_->q);
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
			g_clear_error (&_data_->_inner_error0_);
			g_object_unref (_data_->_async_result);
			return FALSE;
		}
		_g_object_unref0 (_data_->req);
	}
	_g_free0 (_data_->q);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static Block75Data*
block75_data_ref (Block75Data* _data75_)
{
	g_atomic_int_inc (&_data75_->_ref_count_);
	return _data75_;
}

static void
block75_data_unref (void * _userdata_)
{
	Block75Data* _data75_;
	_data75_ = (Block75Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data75_->_ref_count_)) {
		TubaViewsProfile* self;
		self = _data75_->self;
		_g_free0 (_data75_->unendorse_str);
		_g_free0 (_data75_->endorse_str);
		_g_object_unref0 (self);
		g_slice_free (Block75Data, _data75_);
	}
}

static GVariant*
_variant_new19 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static gchar*
bool_to_string (gboolean self)
{
	gchar* result;
	if (self) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup ("true");
		result = _tmp0_;
		return result;
	} else {
		gchar* _tmp1_;
		_tmp1_ = g_strdup ("false");
		result = _tmp1_;
		return result;
	}
}

static void
_vala_TubaAPIRelationshipModifyParam_array_free (TubaAPIRelationshipModifyParam * array,
                                                 gssize array_length)
{
	if (array != NULL) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			tuba_api_relationship_modify_param_destroy (&array[i]);
		}
	}
	g_free (array);
}

static void
__lambda153_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	TubaAPIRelationshipModifyParam _tmp5_ = {0};
	TubaAPIRelationshipModifyParam* _tmp6_;
	TubaAPIRelationshipModifyParam* _tmp7_;
	gint _tmp7__length1;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_rs (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strdup ("notify");
	_tmp4_ = bool_to_string (g_variant_get_boolean (v));
	memset (&_tmp5_, 0, sizeof (TubaAPIRelationshipModifyParam));
	_g_free0 (_tmp5_.param);
	_tmp5_.param = _tmp3_;
	_g_free0 (_tmp5_.val);
	_tmp5_.val = _tmp4_;
	_tmp6_ = g_new0 (TubaAPIRelationshipModifyParam, 1);
	_tmp6_[0] = _tmp5_;
	_tmp7_ = _tmp6_;
	_tmp7__length1 = 1;
	tuba_api_relationship_modify (_tmp2_, "follow", _tmp7_, (gint) 1);
	_tmp7_ = (_vala_TubaAPIRelationshipModifyParam_array_free (_tmp7_, _tmp7__length1), NULL);
	tuba_views_profile_invalidate_actions (self, FALSE);
}

static void
___lambda153__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda153_ ((TubaViewsProfile*) self, value);
}

static void
_tuba_views_base_on_error_tuba_dialogs_profile_lists_errored (TubaDialogsProfileLists* _sender,
                                                              gint32 code,
                                                              const gchar* message,
                                                              gpointer self)
{
	tuba_views_base_on_error ((TubaViewsBase*) self, code, message);
}

static void
__lambda154_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaDialogsProfileLists* dpl = NULL;
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	TubaViewsProfileProfileAccount* _tmp5_;
	TubaAPIAccount* _tmp6_;
	TubaAPIAccount* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	TubaDialogsProfileLists* _tmp11_;
	TubaDialogsProfileLists* _tmp12_;
	TubaApplication* _tmp13_;
	TubaDialogsMainWindow* _tmp14_;
	TubaDialogsMainWindow* _tmp15_;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_account (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_account_get_id (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = self->priv->_profile;
	_tmp6_ = tuba_views_profile_profile_account_get_account (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = tuba_api_account_get_handle (_tmp7_);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = tuba_dialogs_profile_lists_new (_tmp4_, _tmp10_);
	g_object_ref_sink (_tmp11_);
	_tmp12_ = _tmp11_;
	_g_free0 (_tmp10_);
	dpl = _tmp12_;
	g_signal_connect_object (dpl, "errored", (GCallback) _tuba_views_base_on_error_tuba_dialogs_profile_lists_errored, (TubaViewsBase*) self, 0);
	_tmp13_ = tuba_app;
	_tmp14_ = tuba_application_get_main_window (_tmp13_);
	_tmp15_ = _tmp14_;
	adw_dialog_present ((AdwDialog*) dpl, (GtkWidget*) _tmp15_);
	_g_object_unref0 (dpl);
}

static void
___lambda154__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda154_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda162_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	const gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	TubaDialogsComposerDialogPrecompose _tmp9_ = {0};
	const gchar* _tmp10_;
	TubaSettings* _tmp11_;
	const gchar* _tmp12_;
	const gchar* _tmp13_;
	TubaSettings* _tmp14_;
	const gchar* _tmp15_;
	const gchar* _tmp16_;
	TubaDialogsComposerDialog* _tmp17_;
	TubaDialogsComposerDialog* _tmp18_;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_account (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_account_get_handle (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = string_to_string (_tmp5_);
	_tmp7_ = g_strconcat (_tmp6_, " ", NULL);
	_tmp8_ = _tmp7_;
	_g_free0 (_tmp9_.content);
	_tmp9_.content = _tmp8_;
	_g_free0 (_tmp9_.spoiler);
	_tmp9_.spoiler = NULL;
	_g_free0 (_tmp9_.quote_id);
	_tmp9_.quote_id = NULL;
	_g_free0 (_tmp9_.scheduled_id);
	_tmp9_.scheduled_id = NULL;
	_g_free0 (_tmp9_.in_reply_to_id);
	_tmp9_.in_reply_to_id = NULL;
	_g_object_unref0 (_tmp9_.poll);
	_tmp9_.poll = NULL;
	_g_object_unref0 (_tmp9_.media_attachments);
	_tmp9_.media_attachments = NULL;
	_tmp9_.sensitive_media = FALSE;
	_tmp9_.local_only = FALSE;
	_tmp10_ = g_variant_get_string (v, NULL);
	_tmp11_ = tuba_settings;
	_tmp12_ = tuba_settings_get_default_language (_tmp11_);
	_tmp13_ = _tmp12_;
	_tmp14_ = tuba_settings;
	_tmp15_ = tuba_settings_get_default_quote_policy (_tmp14_);
	_tmp16_ = _tmp15_;
	_tmp17_ = tuba_dialogs_composer_dialog_new (&_tmp9_, _tmp10_, _tmp13_, _ ("Post"), FALSE, TRUE, _tmp16_, FALSE);
	g_object_ref_sink (_tmp17_);
	_tmp18_ = _tmp17_;
	_g_object_unref0 (_tmp18_);
	_g_free0 (_tmp8_);
	_g_free0 (_tmp5_);
}

static void
___lambda162__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda162_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda163_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaApplication* _tmp0_;
	TubaDialogsMainWindow* _tmp1_;
	TubaDialogsMainWindow* _tmp2_;
	TubaViewsProfileProfileAccount* _tmp3_;
	TubaAPIAccount* _tmp4_;
	TubaAPIAccount* _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	TubaViewsCollectionList* _tmp8_;
	TubaViewsCollectionList* _tmp9_;
	TubaViewsBase* _tmp10_;
	TubaViewsBase* _tmp11_;
	_tmp0_ = tuba_app;
	_tmp1_ = tuba_application_get_main_window (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->priv->_profile;
	_tmp4_ = tuba_views_profile_profile_account_get_account (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = tuba_api_account_get_id (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = tuba_views_collection_list_new (_tmp7_);
	g_object_ref_sink (_tmp8_);
	_tmp9_ = _tmp8_;
	_tmp10_ = tuba_dialogs_main_window_open_view (_tmp2_, (TubaViewsBase*) _tmp9_);
	_tmp11_ = _tmp10_;
	_g_object_unref0 (_tmp11_);
	_g_object_unref0 (_tmp9_);
}

static void
___lambda163__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda163_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda164_ (TubaViewsProfile* self,
              GVariant* v)
{
	tuba_views_profile_on_edit_note (self, NULL);
}

static void
___lambda164__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda164_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda165_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	TubaApplication* _tmp6_;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_account (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_account_get_full_handle (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	tuba_utils_host_copy (_tmp5_);
	_g_free0 (_tmp5_);
	_tmp6_ = tuba_app;
	g_signal_emit_by_name (_tmp6_, "toast", _ ("Copied handle to clipboard"), (guint) 5, NULL, NULL, NULL);
}

static void
___lambda165__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda165_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda166_ (TubaViewsProfile* self,
              GVariant* v)
{
	gboolean _tmp0_ = FALSE;
	TubaSettings* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	TubaViewsProfileProfileAccount* _tmp19_;
	TubaAPIAccount* _tmp20_;
	TubaAPIAccount* _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	_tmp1_ = tuba_settings;
	_tmp2_ = tuba_settings_get_use_in_app_browser_if_available (_tmp1_);
	_tmp3_ = _tmp2_;
	if (_tmp3_) {
		TubaViewsProfileProfileAccount* _tmp4_;
		TubaAPIAccount* _tmp5_;
		TubaAPIAccount* _tmp6_;
		const gchar* _tmp7_;
		const gchar* _tmp8_;
		_tmp4_ = self->priv->_profile;
		_tmp5_ = tuba_views_profile_profile_account_get_account (_tmp4_);
		_tmp6_ = _tmp5_;
		_tmp7_ = tuba_api_account_get_url (_tmp6_);
		_tmp8_ = _tmp7_;
		_tmp0_ = tuba_views_browser_can_handle_url (_tmp8_);
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaViewsProfileProfileAccount* _tmp9_;
		TubaAPIAccount* _tmp10_;
		TubaAPIAccount* _tmp11_;
		const gchar* _tmp12_;
		const gchar* _tmp13_;
		TubaViewsBrowser* _tmp14_;
		TubaViewsBrowser* _tmp15_;
		TubaApplication* _tmp16_;
		TubaDialogsMainWindow* _tmp17_;
		TubaDialogsMainWindow* _tmp18_;
		_tmp9_ = self->priv->_profile;
		_tmp10_ = tuba_views_profile_profile_account_get_account (_tmp9_);
		_tmp11_ = _tmp10_;
		_tmp12_ = tuba_api_account_get_url (_tmp11_);
		_tmp13_ = _tmp12_;
		_tmp14_ = tuba_views_browser_new_with_url (_tmp13_);
		g_object_ref_sink (_tmp14_);
		_tmp15_ = _tmp14_;
		_tmp16_ = tuba_app;
		_tmp17_ = tuba_application_get_main_window (_tmp16_);
		_tmp18_ = _tmp17_;
		adw_dialog_present ((AdwDialog*) _tmp15_, (GtkWidget*) _tmp18_);
		_g_object_unref0 (_tmp15_);
		return;
	}
	_tmp19_ = self->priv->_profile;
	_tmp20_ = tuba_views_profile_profile_account_get_account (_tmp19_);
	_tmp21_ = _tmp20_;
	_tmp22_ = tuba_api_account_get_url (_tmp21_);
	_tmp23_ = _tmp22_;
	tuba_utils_host_open_url (_tmp23_, NULL, NULL);
}

static void
___lambda166__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda166_ ((TubaViewsProfile*) self, parameter);
}

static void
__lambda167_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIAccount* _tmp1_;
	TubaAPIAccount* _tmp2_;
	TubaDialogsReport* _tmp3_;
	TubaDialogsReport* _tmp4_;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_account (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_dialogs_report_new (_tmp2_, NULL, NULL, NULL);
	g_object_ref_sink (_tmp3_);
	_tmp4_ = _tmp3_;
	_g_object_unref0 (_tmp4_);
}

static void
___lambda167__g_simple_action_activate (GSimpleAction* _sender,
                                        GVariant* parameter,
                                        gpointer self)
{
	__lambda167_ ((TubaViewsProfile*) self, parameter);
}

static GVariant*
_variant_new20 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
__lambda168_ (TubaViewsProfile* self,
              GVariant* v)
{
	gboolean state = FALSE;
	state = g_variant_get_boolean (v);
	if (state) {
		TubaViewsProfileProfileAccount* _tmp0_;
		TubaAPIRelationship* _tmp1_;
		TubaAPIRelationship* _tmp2_;
		TubaViewsProfileProfileAccount* _tmp3_;
		TubaAPIAccount* _tmp4_;
		TubaAPIAccount* _tmp5_;
		gchar* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		_tmp0_ = self->priv->_profile;
		_tmp1_ = tuba_views_profile_profile_account_get_rs (_tmp0_);
		_tmp2_ = _tmp1_;
		_tmp3_ = self->priv->_profile;
		_tmp4_ = tuba_views_profile_profile_account_get_account (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp6_ = tuba_api_account_get_handle (_tmp5_);
		_tmp7_ = _tmp6_;
		_tmp8_ = _tmp7_;
		tuba_api_relationship_question_modify_mute (_tmp2_, _tmp8_);
		_g_free0 (_tmp8_);
	} else {
		TubaViewsProfileProfileAccount* _tmp9_;
		TubaAPIRelationship* _tmp10_;
		TubaAPIRelationship* _tmp11_;
		_tmp9_ = self->priv->_profile;
		_tmp10_ = tuba_views_profile_profile_account_get_rs (_tmp9_);
		_tmp11_ = _tmp10_;
		tuba_api_relationship_modify (_tmp11_, "unmute", NULL, (gint) 0);
	}
}

static void
___lambda168__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda168_ ((TubaViewsProfile*) self, value);
}

static GVariant*
_variant_new21 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
__lambda169_ (TubaViewsProfile* self,
              GVariant* v)
{
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	gboolean state = FALSE;
	TubaViewsProfileProfileAccount* _tmp5_;
	TubaAPIRelationship* _tmp6_;
	TubaAPIRelationship* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	TubaAPIRelationshipModifyParam _tmp10_ = {0};
	TubaAPIRelationshipModifyParam* _tmp11_;
	TubaAPIRelationshipModifyParam* _tmp12_;
	gint _tmp12__length1;
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_rs (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = tuba_api_relationship_get_following (_tmp2_);
	_tmp4_ = _tmp3_;
	if (!_tmp4_) {
		g_warning ("Profile.vala:651: Trying to hide boosts while not following an account" \
".");
		return;
	}
	state = !g_variant_get_boolean (v);
	_tmp5_ = self->priv->_profile;
	_tmp6_ = tuba_views_profile_profile_account_get_rs (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = g_strdup ("reblogs");
	_tmp9_ = bool_to_string (state);
	memset (&_tmp10_, 0, sizeof (TubaAPIRelationshipModifyParam));
	_g_free0 (_tmp10_.param);
	_tmp10_.param = _tmp8_;
	_g_free0 (_tmp10_.val);
	_tmp10_.val = _tmp9_;
	_tmp11_ = g_new0 (TubaAPIRelationshipModifyParam, 1);
	_tmp11_[0] = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp12__length1 = 1;
	tuba_api_relationship_modify (_tmp7_, "follow", _tmp12_, (gint) 1);
	_tmp12_ = (_vala_TubaAPIRelationshipModifyParam_array_free (_tmp12_, _tmp12__length1), NULL);
}

static void
___lambda169__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda169_ ((TubaViewsProfile*) self, value);
}

static GVariant*
_variant_new22 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
__lambda170_ (TubaViewsProfile* self,
              GVariant* v)
{
	gboolean block = FALSE;
	TubaViewsProfileProfileAccount* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	TubaViewsProfileProfileAccount* _tmp3_;
	TubaAPIAccount* _tmp4_;
	TubaAPIAccount* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	block = g_variant_get_boolean (v);
	_tmp0_ = self->priv->_profile;
	_tmp1_ = tuba_views_profile_profile_account_get_rs (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->priv->_profile;
	_tmp4_ = tuba_views_profile_profile_account_get_account (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = tuba_api_account_get_handle (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	tuba_api_relationship_question_modify_block (_tmp2_, _tmp8_, block);
	_g_free0 (_tmp8_);
}

static void
___lambda170__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda170_ ((TubaViewsProfile*) self, value);
}

static GVariant*
_variant_new23 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
__lambda171_ (TubaViewsProfile* self,
              GVariant* v)
{
	gboolean block = FALSE;
	block = g_variant_get_boolean (v);
	tuba_views_profile_on_domain_block_real (self, block, NULL, NULL);
}

static void
___lambda171__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda171_ ((TubaViewsProfile*) self, value);
}

static GVariant*
_variant_new24 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
__lambda172_ (Block75Data* _data75_,
              GVariant* v)
{
	TubaViewsProfile* self;
	const gchar* _tmp0_ = NULL;
	TubaViewsProfileProfileAccount* _tmp2_;
	TubaAPIRelationship* _tmp3_;
	TubaAPIRelationship* _tmp4_;
	self = _data75_->self;
	if (g_variant_get_boolean (v)) {
		const gchar* _tmp1_;
		_tmp1_ = _data75_->endorse_str;
		_tmp0_ = _tmp1_;
	} else {
		_tmp0_ = _data75_->unendorse_str;
	}
	_tmp2_ = self->priv->_profile;
	_tmp3_ = tuba_views_profile_profile_account_get_rs (_tmp2_);
	_tmp4_ = _tmp3_;
	tuba_api_relationship_modify (_tmp4_, _tmp0_, NULL, (gint) 0);
	tuba_views_profile_invalidate_actions (self, FALSE);
}

static void
___lambda172__g_simple_action_change_state (GSimpleAction* _sender,
                                            GVariant* value,
                                            gpointer self)
{
	__lambda172_ (self, value);
}

static void
tuba_views_profile_real_build_actions (TubaViewsBase* base)
{
	TubaViewsProfile * self;
	Block75Data* _data75_;
	GVariant* _tmp0_;
	GSimpleAction* _tmp1_;
	GSimpleAction* _tmp2_;
	GSimpleActionGroup* _tmp3_;
	GSimpleActionGroup* _tmp4_;
	GSimpleAction* _tmp5_;
	GSimpleAction* _tmp6_;
	GSimpleAction* _tmp7_;
	GSimpleActionGroup* _tmp8_;
	GSimpleActionGroup* _tmp9_;
	GSimpleAction* _tmp10_;
	GSimpleAction* mention_action = NULL;
	const GVariantType* _tmp11_;
	GSimpleAction* _tmp12_;
	GSimpleAction* _tmp13_;
	GSimpleActionGroup* _tmp14_;
	GSimpleActionGroup* _tmp15_;
	GSimpleAction* _tmp16_;
	GSimpleAction* collection_action = NULL;
	GSimpleAction* _tmp17_;
	GSimpleAction* _tmp18_;
	GSimpleActionGroup* _tmp19_;
	GSimpleActionGroup* _tmp20_;
	GSimpleAction* _tmp21_;
	gboolean _tmp22_ = FALSE;
	TubaAccountStore* _tmp23_;
	TubaInstanceAccount* _tmp24_;
	TubaInstanceAccount* _tmp25_;
	TubaAPIInstanceV2APIVersions* _tmp26_;
	TubaAPIInstanceV2APIVersions* _tmp27_;
	gint8 _tmp28_;
	gint8 _tmp29_;
	GSimpleAction* _tmp35_;
	GSimpleAction* _tmp36_;
	GSimpleAction* _tmp37_;
	GSimpleActionGroup* _tmp38_;
	GSimpleActionGroup* _tmp39_;
	GSimpleAction* _tmp40_;
	GSimpleAction* copy_handle_action = NULL;
	GSimpleAction* _tmp41_;
	GSimpleAction* _tmp42_;
	GSimpleActionGroup* _tmp43_;
	GSimpleActionGroup* _tmp44_;
	GSimpleAction* _tmp45_;
	GSimpleAction* open_in_browser_action = NULL;
	GSimpleAction* _tmp46_;
	GSimpleAction* _tmp47_;
	GSimpleActionGroup* _tmp48_;
	GSimpleActionGroup* _tmp49_;
	GSimpleAction* _tmp50_;
	GSimpleAction* report_action = NULL;
	GSimpleAction* _tmp51_;
	GSimpleAction* _tmp52_;
	GSimpleActionGroup* _tmp53_;
	GSimpleActionGroup* _tmp54_;
	GSimpleAction* _tmp55_;
	GVariant* _tmp56_;
	GSimpleAction* _tmp57_;
	GSimpleAction* _tmp58_;
	GSimpleActionGroup* _tmp59_;
	GSimpleActionGroup* _tmp60_;
	GSimpleAction* _tmp61_;
	GVariant* _tmp62_;
	GSimpleAction* _tmp63_;
	GSimpleAction* _tmp64_;
	GSimpleActionGroup* _tmp65_;
	GSimpleActionGroup* _tmp66_;
	GSimpleAction* _tmp67_;
	GVariant* _tmp68_;
	GSimpleAction* _tmp69_;
	GSimpleAction* _tmp70_;
	GSimpleActionGroup* _tmp71_;
	GSimpleActionGroup* _tmp72_;
	GSimpleAction* _tmp73_;
	GVariant* _tmp74_;
	GSimpleAction* _tmp75_;
	GSimpleAction* _tmp76_;
	GSimpleActionGroup* _tmp77_;
	GSimpleActionGroup* _tmp78_;
	GSimpleAction* _tmp79_;
	const gchar* _tmp80_ = NULL;
	TubaAccountStore* _tmp81_;
	TubaInstanceAccount* _tmp82_;
	TubaInstanceAccount* _tmp83_;
	TubaAPIInstanceV2APIVersions* _tmp84_;
	TubaAPIInstanceV2APIVersions* _tmp85_;
	gint8 _tmp86_;
	gint8 _tmp87_;
	gchar* _tmp88_;
	const gchar* _tmp89_ = NULL;
	TubaAccountStore* _tmp90_;
	TubaInstanceAccount* _tmp91_;
	TubaInstanceAccount* _tmp92_;
	TubaAPIInstanceV2APIVersions* _tmp93_;
	TubaAPIInstanceV2APIVersions* _tmp94_;
	gint8 _tmp95_;
	gint8 _tmp96_;
	gchar* _tmp97_;
	GVariant* _tmp98_;
	GSimpleAction* _tmp99_;
	GSimpleAction* _tmp100_;
	GSimpleActionGroup* _tmp101_;
	GSimpleActionGroup* _tmp102_;
	GSimpleAction* _tmp103_;
	self = (TubaViewsProfile*) base;
	_data75_ = g_slice_new0 (Block75Data);
	_data75_->_ref_count_ = 1;
	_data75_->self = g_object_ref (self);
	TUBA_VIEWS_BASE_CLASS (tuba_views_profile_parent_class)->build_actions ((TubaViewsBase*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts));
	_tmp0_ = _variant_new19 (FALSE);
	_tmp1_ = g_simple_action_new_stateful ("notify_on_post", NULL, _tmp0_);
	_g_object_unref0 (self->notify_on_new_post_action);
	self->notify_on_new_post_action = _tmp1_;
	_g_variant_unref0 (_tmp0_);
	_tmp2_ = self->notify_on_new_post_action;
	g_signal_connect_object (_tmp2_, "change-state", (GCallback) ___lambda153__g_simple_action_change_state, self, 0);
	_tmp3_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp4_ = _tmp3_;
	_tmp5_ = self->notify_on_new_post_action;
	g_action_map_add_action ((GActionMap*) _tmp4_, (GAction*) _tmp5_);
	_tmp6_ = g_simple_action_new ("ar_list", NULL);
	_g_object_unref0 (self->ar_list_action);
	self->ar_list_action = _tmp6_;
	_tmp7_ = self->ar_list_action;
	g_signal_connect_object (_tmp7_, "activate", (GCallback) ___lambda154__g_simple_action_activate, self, 0);
	_tmp8_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp9_ = _tmp8_;
	_tmp10_ = self->ar_list_action;
	g_action_map_add_action ((GActionMap*) _tmp9_, (GAction*) _tmp10_);
	_tmp11_ = G_VARIANT_TYPE_STRING;
	_tmp12_ = g_simple_action_new ("mention", _tmp11_);
	mention_action = _tmp12_;
	_tmp13_ = mention_action;
	g_signal_connect_object (_tmp13_, "activate", (GCallback) ___lambda162__g_simple_action_activate, self, 0);
	_tmp14_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp15_ = _tmp14_;
	_tmp16_ = mention_action;
	g_action_map_add_action ((GActionMap*) _tmp15_, (GAction*) _tmp16_);
	_tmp17_ = g_simple_action_new ("collections", NULL);
	collection_action = _tmp17_;
	_tmp18_ = collection_action;
	g_signal_connect_object (_tmp18_, "activate", (GCallback) ___lambda163__g_simple_action_activate, self, 0);
	_tmp19_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp20_ = _tmp19_;
	_tmp21_ = collection_action;
	g_action_map_add_action ((GActionMap*) _tmp20_, (GAction*) _tmp21_);
	_tmp23_ = tuba_accounts;
	_tmp24_ = tuba_account_store_get_active (_tmp23_);
	_tmp25_ = _tmp24_;
	_tmp26_ = tuba_instance_account_get_tuba_api_versions (_tmp25_);
	_tmp27_ = _tmp26_;
	_tmp28_ = tuba_api_instance_v2_api_versions_get_mastodon (_tmp27_);
	_tmp29_ = _tmp28_;
	if (((gint) _tmp29_) >= 10) {
		TubaViewsProfileProfileAccount* _tmp30_;
		TubaAPIAccount* _tmp31_;
		TubaAPIAccount* _tmp32_;
		gboolean _tmp33_;
		gboolean _tmp34_;
		_tmp30_ = self->priv->_profile;
		_tmp31_ = tuba_views_profile_profile_account_get_account (_tmp30_);
		_tmp32_ = _tmp31_;
		_tmp33_ = tuba_api_account_get_hide_collections (_tmp32_);
		_tmp34_ = _tmp33_;
		_tmp22_ = !_tmp34_;
	} else {
		_tmp22_ = FALSE;
	}
	_tmp35_ = collection_action;
	g_simple_action_set_enabled (_tmp35_, _tmp22_);
	_tmp36_ = g_simple_action_new ("add-note", NULL);
	_g_object_unref0 (self->add_note_action);
	self->add_note_action = _tmp36_;
	_tmp37_ = self->add_note_action;
	g_signal_connect_object (_tmp37_, "activate", (GCallback) ___lambda164__g_simple_action_activate, self, 0);
	_tmp38_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp39_ = _tmp38_;
	_tmp40_ = self->add_note_action;
	g_action_map_add_action ((GActionMap*) _tmp39_, (GAction*) _tmp40_);
	_tmp41_ = g_simple_action_new ("copy_handle", NULL);
	copy_handle_action = _tmp41_;
	_tmp42_ = copy_handle_action;
	g_signal_connect_object (_tmp42_, "activate", (GCallback) ___lambda165__g_simple_action_activate, self, 0);
	_tmp43_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp44_ = _tmp43_;
	_tmp45_ = copy_handle_action;
	g_action_map_add_action ((GActionMap*) _tmp44_, (GAction*) _tmp45_);
	_tmp46_ = g_simple_action_new ("open_in_browser", NULL);
	open_in_browser_action = _tmp46_;
	_tmp47_ = open_in_browser_action;
	g_signal_connect_object (_tmp47_, "activate", (GCallback) ___lambda166__g_simple_action_activate, self, 0);
	_tmp48_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp49_ = _tmp48_;
	_tmp50_ = open_in_browser_action;
	g_action_map_add_action ((GActionMap*) _tmp49_, (GAction*) _tmp50_);
	_tmp51_ = g_simple_action_new ("report", NULL);
	report_action = _tmp51_;
	_tmp52_ = report_action;
	g_signal_connect_object (_tmp52_, "activate", (GCallback) ___lambda167__g_simple_action_activate, self, 0);
	_tmp53_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp54_ = _tmp53_;
	_tmp55_ = report_action;
	g_action_map_add_action ((GActionMap*) _tmp54_, (GAction*) _tmp55_);
	_tmp56_ = _variant_new20 (FALSE);
	_tmp57_ = g_simple_action_new_stateful ("muting", NULL, _tmp56_);
	_g_object_unref0 (self->muting_action);
	self->muting_action = _tmp57_;
	_g_variant_unref0 (_tmp56_);
	_tmp58_ = self->muting_action;
	g_signal_connect_object (_tmp58_, "change-state", (GCallback) ___lambda168__g_simple_action_change_state, self, 0);
	_tmp59_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp60_ = _tmp59_;
	_tmp61_ = self->muting_action;
	g_action_map_add_action ((GActionMap*) _tmp60_, (GAction*) _tmp61_);
	_tmp62_ = _variant_new21 (FALSE);
	_tmp63_ = g_simple_action_new_stateful ("hiding_reblogs", NULL, _tmp62_);
	_g_object_unref0 (self->hiding_reblogs_action);
	self->hiding_reblogs_action = _tmp63_;
	_g_variant_unref0 (_tmp62_);
	_tmp64_ = self->hiding_reblogs_action;
	g_signal_connect_object (_tmp64_, "change-state", (GCallback) ___lambda169__g_simple_action_change_state, self, 0);
	_tmp65_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp66_ = _tmp65_;
	_tmp67_ = self->hiding_reblogs_action;
	g_action_map_add_action ((GActionMap*) _tmp66_, (GAction*) _tmp67_);
	_tmp68_ = _variant_new22 (FALSE);
	_tmp69_ = g_simple_action_new_stateful ("blocking", NULL, _tmp68_);
	_g_object_unref0 (self->blocking_action);
	self->blocking_action = _tmp69_;
	_g_variant_unref0 (_tmp68_);
	_tmp70_ = self->blocking_action;
	g_signal_connect_object (_tmp70_, "change-state", (GCallback) ___lambda170__g_simple_action_change_state, self, 0);
	_tmp71_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp72_ = _tmp71_;
	_tmp73_ = self->blocking_action;
	g_action_map_add_action ((GActionMap*) _tmp72_, (GAction*) _tmp73_);
	_tmp74_ = _variant_new23 (FALSE);
	_tmp75_ = g_simple_action_new_stateful ("domain_blocking", NULL, _tmp74_);
	_g_object_unref0 (self->domain_blocking_action);
	self->domain_blocking_action = _tmp75_;
	_g_variant_unref0 (_tmp74_);
	_tmp76_ = self->domain_blocking_action;
	g_signal_connect_object (_tmp76_, "change-state", (GCallback) ___lambda171__g_simple_action_change_state, self, 0);
	_tmp77_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp78_ = _tmp77_;
	_tmp79_ = self->domain_blocking_action;
	g_action_map_add_action ((GActionMap*) _tmp78_, (GAction*) _tmp79_);
	_tmp81_ = tuba_accounts;
	_tmp82_ = tuba_account_store_get_active (_tmp81_);
	_tmp83_ = _tmp82_;
	_tmp84_ = tuba_instance_account_get_tuba_api_versions (_tmp83_);
	_tmp85_ = _tmp84_;
	_tmp86_ = tuba_api_instance_v2_api_versions_get_mastodon (_tmp85_);
	_tmp87_ = _tmp86_;
	if (((gint) _tmp87_) >= 6) {
		_tmp80_ = "endorse";
	} else {
		_tmp80_ = "pin";
	}
	_tmp88_ = g_strdup (_tmp80_);
	_data75_->endorse_str = _tmp88_;
	_tmp90_ = tuba_accounts;
	_tmp91_ = tuba_account_store_get_active (_tmp90_);
	_tmp92_ = _tmp91_;
	_tmp93_ = tuba_instance_account_get_tuba_api_versions (_tmp92_);
	_tmp94_ = _tmp93_;
	_tmp95_ = tuba_api_instance_v2_api_versions_get_mastodon (_tmp94_);
	_tmp96_ = _tmp95_;
	if (((gint) _tmp96_) >= 6) {
		_tmp89_ = "unendorse";
	} else {
		_tmp89_ = "unpin";
	}
	_tmp97_ = g_strdup (_tmp89_);
	_data75_->unendorse_str = _tmp97_;
	_tmp98_ = _variant_new24 (FALSE);
	_tmp99_ = g_simple_action_new_stateful ("endorsed", NULL, _tmp98_);
	_g_object_unref0 (self->endorse_action);
	self->endorse_action = _tmp99_;
	_g_variant_unref0 (_tmp98_);
	_tmp100_ = self->endorse_action;
	g_signal_connect_data (_tmp100_, "change-state", (GCallback) ___lambda172__g_simple_action_change_state, block75_data_ref (_data75_), (GClosureNotify) block75_data_unref, 0);
	_tmp101_ = tuba_views_base_get_actions ((TubaViewsBase*) self);
	_tmp102_ = _tmp101_;
	_tmp103_ = self->endorse_action;
	g_action_map_add_action ((GActionMap*) _tmp102_, (GAction*) _tmp103_);
	tuba_views_profile_invalidate_actions (self, FALSE);
	_g_object_unref0 (report_action);
	_g_object_unref0 (open_in_browser_action);
	_g_object_unref0 (copy_handle_action);
	_g_object_unref0 (collection_action);
	_g_object_unref0 (mention_action);
	block75_data_unref (_data75_);
	_data75_ = NULL;
}

static GVariant*
_variant_new25 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new26 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new27 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new28 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new29 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static GVariant*
_variant_new30 (gboolean value)
{
	return g_variant_ref_sink (g_variant_new_boolean (value));
}

static void
tuba_views_profile_invalidate_actions (TubaViewsProfile* self,
                                       gboolean refresh)
{
	GSimpleAction* _tmp0_;
	TubaViewsProfileProfileAccount* _tmp1_;
	TubaAPIRelationship* _tmp2_;
	TubaAPIRelationship* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	GVariant* _tmp6_;
	GSimpleAction* _tmp7_;
	TubaViewsProfileProfileAccount* _tmp8_;
	TubaAPIRelationship* _tmp9_;
	TubaAPIRelationship* _tmp10_;
	gboolean _tmp11_;
	gboolean _tmp12_;
	GVariant* _tmp13_;
	GSimpleAction* _tmp14_;
	TubaViewsProfileProfileAccount* _tmp15_;
	TubaAPIRelationship* _tmp16_;
	TubaAPIRelationship* _tmp17_;
	gboolean _tmp18_;
	gboolean _tmp19_;
	GSimpleAction* _tmp20_;
	TubaViewsProfileProfileAccount* _tmp21_;
	TubaAPIRelationship* _tmp22_;
	TubaAPIRelationship* _tmp23_;
	gboolean _tmp24_;
	gboolean _tmp25_;
	GVariant* _tmp26_;
	GSimpleAction* _tmp27_;
	TubaViewsProfileProfileAccount* _tmp28_;
	TubaAPIRelationship* _tmp29_;
	TubaAPIRelationship* _tmp30_;
	gboolean _tmp31_;
	gboolean _tmp32_;
	GSimpleAction* _tmp33_;
	TubaViewsProfileProfileAccount* _tmp34_;
	TubaAPIRelationship* _tmp35_;
	TubaAPIRelationship* _tmp36_;
	gboolean _tmp37_;
	gboolean _tmp38_;
	GVariant* _tmp39_;
	GSimpleAction* _tmp40_;
	TubaViewsProfileProfileAccount* _tmp41_;
	TubaAPIRelationship* _tmp42_;
	TubaAPIRelationship* _tmp43_;
	gboolean _tmp44_;
	gboolean _tmp45_;
	GVariant* _tmp46_;
	GSimpleAction* _tmp47_;
	TubaAccountStore* _tmp48_;
	TubaInstanceAccount* _tmp49_;
	TubaInstanceAccount* _tmp50_;
	gchar* _tmp51_;
	gchar* _tmp52_;
	gchar* _tmp53_;
	TubaViewsProfileProfileAccount* _tmp54_;
	TubaAPIAccount* _tmp55_;
	TubaAPIAccount* _tmp56_;
	gchar* _tmp57_;
	gchar* _tmp58_;
	gchar* _tmp59_;
	gboolean _tmp60_ = FALSE;
	TubaViewsProfileProfileAccount* _tmp61_;
	TubaAPIAccount* _tmp62_;
	TubaAPIAccount* _tmp63_;
	const gchar* _tmp64_;
	const gchar* _tmp65_;
	TubaAccountStore* _tmp66_;
	TubaInstanceAccount* _tmp67_;
	TubaInstanceAccount* _tmp68_;
	const gchar* _tmp69_;
	const gchar* _tmp70_;
	GSimpleAction* _tmp76_;
	gboolean _tmp77_ = FALSE;
	TubaViewsProfileProfileAccount* _tmp78_;
	TubaAPIAccount* _tmp79_;
	TubaAPIAccount* _tmp80_;
	const gchar* _tmp81_;
	const gchar* _tmp82_;
	TubaAccountStore* _tmp83_;
	TubaInstanceAccount* _tmp84_;
	TubaInstanceAccount* _tmp85_;
	const gchar* _tmp86_;
	const gchar* _tmp87_;
	GSimpleAction* _tmp93_;
	GSimpleAction* _tmp94_;
	TubaViewsProfileProfileAccount* _tmp95_;
	TubaAPIRelationship* _tmp96_;
	TubaAPIRelationship* _tmp97_;
	gboolean _tmp98_;
	gboolean _tmp99_;
	GVariant* _tmp100_;
	GSimpleAction* _tmp101_;
	TubaViewsProfileProfileAccount* _tmp102_;
	TubaAPIAccount* _tmp103_;
	TubaAPIAccount* _tmp104_;
	const gchar* _tmp105_;
	const gchar* _tmp106_;
	TubaAccountStore* _tmp107_;
	TubaInstanceAccount* _tmp108_;
	TubaInstanceAccount* _tmp109_;
	const gchar* _tmp110_;
	const gchar* _tmp111_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->muting_action;
	_tmp1_ = self->priv->_profile;
	_tmp2_ = tuba_views_profile_profile_account_get_rs (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = tuba_api_relationship_get_muting (_tmp3_);
	_tmp5_ = _tmp4_;
	_tmp6_ = _variant_new25 (_tmp5_);
	g_simple_action_set_state (_tmp0_, _tmp6_);
	_g_variant_unref0 (_tmp6_);
	_tmp7_ = self->endorse_action;
	_tmp8_ = self->priv->_profile;
	_tmp9_ = tuba_views_profile_profile_account_get_rs (_tmp8_);
	_tmp10_ = _tmp9_;
	_tmp11_ = tuba_api_relationship_get_endorsed (_tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _variant_new26 (_tmp12_);
	g_simple_action_set_state (_tmp7_, _tmp13_);
	_g_variant_unref0 (_tmp13_);
	_tmp14_ = self->endorse_action;
	_tmp15_ = self->priv->_profile;
	_tmp16_ = tuba_views_profile_profile_account_get_rs (_tmp15_);
	_tmp17_ = _tmp16_;
	_tmp18_ = tuba_api_relationship_get_following (_tmp17_);
	_tmp19_ = _tmp18_;
	g_simple_action_set_enabled (_tmp14_, _tmp19_);
	_tmp20_ = self->hiding_reblogs_action;
	_tmp21_ = self->priv->_profile;
	_tmp22_ = tuba_views_profile_profile_account_get_rs (_tmp21_);
	_tmp23_ = _tmp22_;
	_tmp24_ = tuba_api_relationship_get_showing_reblogs (_tmp23_);
	_tmp25_ = _tmp24_;
	_tmp26_ = _variant_new27 (!_tmp25_);
	g_simple_action_set_state (_tmp20_, _tmp26_);
	_g_variant_unref0 (_tmp26_);
	_tmp27_ = self->hiding_reblogs_action;
	_tmp28_ = self->priv->_profile;
	_tmp29_ = tuba_views_profile_profile_account_get_rs (_tmp28_);
	_tmp30_ = _tmp29_;
	_tmp31_ = tuba_api_relationship_get_following (_tmp30_);
	_tmp32_ = _tmp31_;
	g_simple_action_set_enabled (_tmp27_, _tmp32_);
	_tmp33_ = self->blocking_action;
	_tmp34_ = self->priv->_profile;
	_tmp35_ = tuba_views_profile_profile_account_get_rs (_tmp34_);
	_tmp36_ = _tmp35_;
	_tmp37_ = tuba_api_relationship_get_blocking (_tmp36_);
	_tmp38_ = _tmp37_;
	_tmp39_ = _variant_new28 (_tmp38_);
	g_simple_action_set_state (_tmp33_, _tmp39_);
	_g_variant_unref0 (_tmp39_);
	_tmp40_ = self->domain_blocking_action;
	_tmp41_ = self->priv->_profile;
	_tmp42_ = tuba_views_profile_profile_account_get_rs (_tmp41_);
	_tmp43_ = _tmp42_;
	_tmp44_ = tuba_api_relationship_get_domain_blocking (_tmp43_);
	_tmp45_ = _tmp44_;
	_tmp46_ = _variant_new29 (_tmp45_);
	g_simple_action_set_state (_tmp40_, _tmp46_);
	_g_variant_unref0 (_tmp46_);
	_tmp47_ = self->domain_blocking_action;
	_tmp48_ = tuba_accounts;
	_tmp49_ = tuba_account_store_get_active (_tmp48_);
	_tmp50_ = _tmp49_;
	_tmp51_ = tuba_api_account_get_domain ((TubaAPIAccount*) _tmp50_);
	_tmp52_ = _tmp51_;
	_tmp53_ = _tmp52_;
	_tmp54_ = self->priv->_profile;
	_tmp55_ = tuba_views_profile_profile_account_get_account (_tmp54_);
	_tmp56_ = _tmp55_;
	_tmp57_ = tuba_api_account_get_domain (_tmp56_);
	_tmp58_ = _tmp57_;
	_tmp59_ = _tmp58_;
	g_simple_action_set_enabled (_tmp47_, g_strcmp0 (_tmp53_, _tmp59_) != 0);
	_g_free0 (_tmp59_);
	_g_free0 (_tmp53_);
	_tmp61_ = self->priv->_profile;
	_tmp62_ = tuba_views_profile_profile_account_get_account (_tmp61_);
	_tmp63_ = _tmp62_;
	_tmp64_ = tuba_api_account_get_id (_tmp63_);
	_tmp65_ = _tmp64_;
	_tmp66_ = tuba_accounts;
	_tmp67_ = tuba_account_store_get_active (_tmp66_);
	_tmp68_ = _tmp67_;
	_tmp69_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp68_);
	_tmp70_ = _tmp69_;
	if (g_strcmp0 (_tmp65_, _tmp70_) != 0) {
		TubaViewsProfileProfileAccount* _tmp71_;
		TubaAPIRelationship* _tmp72_;
		TubaAPIRelationship* _tmp73_;
		gboolean _tmp74_;
		gboolean _tmp75_;
		_tmp71_ = self->priv->_profile;
		_tmp72_ = tuba_views_profile_profile_account_get_rs (_tmp71_);
		_tmp73_ = _tmp72_;
		_tmp74_ = tuba_api_relationship_get_following (_tmp73_);
		_tmp75_ = _tmp74_;
		_tmp60_ = _tmp75_;
	} else {
		_tmp60_ = FALSE;
	}
	_tmp76_ = self->ar_list_action;
	g_simple_action_set_enabled (_tmp76_, _tmp60_);
	_tmp78_ = self->priv->_profile;
	_tmp79_ = tuba_views_profile_profile_account_get_account (_tmp78_);
	_tmp80_ = _tmp79_;
	_tmp81_ = tuba_api_account_get_id (_tmp80_);
	_tmp82_ = _tmp81_;
	_tmp83_ = tuba_accounts;
	_tmp84_ = tuba_account_store_get_active (_tmp83_);
	_tmp85_ = _tmp84_;
	_tmp86_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp85_);
	_tmp87_ = _tmp86_;
	if (g_strcmp0 (_tmp82_, _tmp87_) != 0) {
		TubaViewsProfileProfileAccount* _tmp88_;
		TubaAPIRelationship* _tmp89_;
		TubaAPIRelationship* _tmp90_;
		gboolean _tmp91_;
		gboolean _tmp92_;
		_tmp88_ = self->priv->_profile;
		_tmp89_ = tuba_views_profile_profile_account_get_rs (_tmp88_);
		_tmp90_ = _tmp89_;
		_tmp91_ = tuba_api_relationship_get_following (_tmp90_);
		_tmp92_ = _tmp91_;
		_tmp77_ = _tmp92_;
	} else {
		_tmp77_ = FALSE;
	}
	_tmp93_ = self->notify_on_new_post_action;
	g_simple_action_set_enabled (_tmp93_, _tmp77_);
	_tmp94_ = self->notify_on_new_post_action;
	_tmp95_ = self->priv->_profile;
	_tmp96_ = tuba_views_profile_profile_account_get_rs (_tmp95_);
	_tmp97_ = _tmp96_;
	_tmp98_ = tuba_api_relationship_get_notifying (_tmp97_);
	_tmp99_ = _tmp98_;
	_tmp100_ = _variant_new30 (_tmp99_);
	g_simple_action_set_state (_tmp94_, _tmp100_);
	_g_variant_unref0 (_tmp100_);
	_tmp101_ = self->add_note_action;
	_tmp102_ = self->priv->_profile;
	_tmp103_ = tuba_views_profile_profile_account_get_account (_tmp102_);
	_tmp104_ = _tmp103_;
	_tmp105_ = tuba_api_account_get_id (_tmp104_);
	_tmp106_ = _tmp105_;
	_tmp107_ = tuba_accounts;
	_tmp108_ = tuba_account_store_get_active (_tmp107_);
	_tmp109_ = _tmp108_;
	_tmp110_ = tuba_api_account_get_id ((TubaAPIAccount*) _tmp109_);
	_tmp111_ = _tmp110_;
	g_simple_action_set_enabled (_tmp101_, g_strcmp0 (_tmp106_, _tmp111_) != 0);
	if (refresh) {
		tuba_views_timeline_set_page_next ((TubaViewsTimeline*) self, NULL);
		tuba_views_timeline_on_refresh ((TubaViewsTimeline*) self);
	}
}

static void
tuba_views_profile_on_rs_updated (TubaViewsProfile* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_profile_invalidate_actions (self, FALSE);
}

static void
tuba_views_profile_real_append_params_v2 (TubaViewsTimeline* base,
                                          TubaRequestV2* req)
{
	TubaViewsProfile * self;
	gboolean _tmp0_ = FALSE;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	self = (TubaViewsProfile*) base;
	g_return_if_fail (req != NULL);
	_tmp1_ = tuba_views_timeline_get_page_next ((TubaViewsTimeline*) self);
	_tmp2_ = _tmp1_;
	if (_tmp2_ == NULL) {
		const gchar* _tmp3_;
		_tmp3_ = self->priv->_source;
		_tmp0_ = g_strcmp0 (_tmp3_, "statuses") == 0;
	} else {
		_tmp0_ = FALSE;
	}
	if (_tmp0_) {
		TubaWidgetsProfileFilterGroupFilter _tmp4_;
		_tmp4_ = self->priv->_filter;
		switch (_tmp4_) {
			case TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_POSTS:
			{
				tuba_request_v2_add_parameter (req, "exclude_replies", "true");
				break;
			}
			case TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_REPLIES:
			{
				tuba_request_v2_add_parameter (req, "exclude_replies", "false");
				tuba_request_v2_add_parameter (req, "exclude_reblogs", "true");
				break;
			}
			case TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_MEDIA:
			{
				TubaViewsProfileProfileAccount* _tmp5_;
				TubaAPIAccount* _tmp6_;
				TubaAPIAccount* _tmp7_;
				gboolean _tmp8_;
				gboolean _tmp9_;
				tuba_request_v2_add_parameter (req, "only_media", "true");
				_tmp5_ = self->priv->_profile;
				_tmp6_ = tuba_views_profile_profile_account_get_account (_tmp5_);
				_tmp7_ = _tmp6_;
				_tmp8_ = tuba_api_account_get_show_media_replies (_tmp7_);
				_tmp9_ = _tmp8_;
				if (!_tmp9_) {
					tuba_request_v2_add_parameter (req, "exclude_replies", "true");
				}
				break;
			}
			case TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_FEATURED:
			{
				break;
			}
			default:
			{
				g_assert_not_reached ();
			}
		}
	}
	TUBA_VIEWS_TIMELINE_CLASS (tuba_views_profile_parent_class)->append_params_v2 ((TubaViewsTimeline*) G_TYPE_CHECK_INSTANCE_CAST (self, TUBA_VIEWS_TYPE_ACCOUNTS, TubaViewsAccounts), req);
}

static void
tuba_views_profile_on_edit_cover_note (TubaViewsProfile* self)
{
	g_return_if_fail (self != NULL);
	tuba_views_profile_on_edit_note (self, NULL);
}

static void
_tuba_views_profile_on_note_done_tuba_views_profile_note_editor_note_done (TubaViewsProfileNoteEditor* _sender,
                                                                           const gchar* note,
                                                                           gpointer self)
{
	tuba_views_profile_on_note_done ((TubaViewsProfile*) self, note);
}

static void
tuba_views_profile_on_edit_note (TubaViewsProfile* self,
                                 const gchar* note)
{
	const gchar* _tmp0_ = NULL;
	TubaViewsProfileNoteEditor* note_editor = NULL;
	TubaViewsProfileNoteEditor* _tmp6_;
	TubaApplication* _tmp7_;
	TubaDialogsMainWindow* _tmp8_;
	TubaDialogsMainWindow* _tmp9_;
	g_return_if_fail (self != NULL);
	if (note == NULL) {
		TubaViewsProfileProfileAccount* _tmp1_;
		TubaAPIRelationship* _tmp2_;
		TubaAPIRelationship* _tmp3_;
		const gchar* _tmp4_;
		const gchar* _tmp5_;
		_tmp1_ = self->priv->_profile;
		_tmp2_ = tuba_views_profile_profile_account_get_rs (_tmp1_);
		_tmp3_ = _tmp2_;
		_tmp4_ = tuba_api_relationship_get_note (_tmp3_);
		_tmp5_ = _tmp4_;
		_tmp0_ = _tmp5_;
	} else {
		_tmp0_ = note;
	}
	_tmp6_ = tuba_views_profile_note_editor_new (_tmp0_);
	g_object_ref_sink (_tmp6_);
	note_editor = _tmp6_;
	g_signal_connect_object (note_editor, "note-done", (GCallback) _tuba_views_profile_on_note_done_tuba_views_profile_note_editor_note_done, self, 0);
	_tmp7_ = tuba_app;
	_tmp8_ = tuba_application_get_main_window (_tmp7_);
	_tmp9_ = _tmp8_;
	adw_dialog_present ((AdwDialog*) note_editor, (GtkWidget*) _tmp9_);
	_g_object_unref0 (note_editor);
}

static void
tuba_views_profile_on_note_done (TubaViewsProfile* self,
                                 const gchar* new_note)
{
	g_return_if_fail (self != NULL);
	g_return_if_fail (new_note != NULL);
	tuba_views_profile_on_note_done_real (self, new_note, NULL, NULL);
}

static void
tuba_views_profile_on_note_done_real_data_free (gpointer _data)
{
	TubaViewsProfileOnNoteDoneRealData* _data_;
	_data_ = _data;
	_g_free0 (_data_->new_note);
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsProfileOnNoteDoneRealData, _data_);
}

static void
tuba_views_profile_on_note_done_real (TubaViewsProfile* self,
                                      const gchar* new_note,
                                      GAsyncReadyCallback _callback_,
                                      gpointer _user_data_)
{
	TubaViewsProfileOnNoteDoneRealData* _data_;
	TubaViewsProfile* _tmp0_;
	gchar* _tmp1_;
	g_return_if_fail (self != NULL);
	g_return_if_fail (new_note != NULL);
	_data_ = g_slice_new0 (TubaViewsProfileOnNoteDoneRealData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_profile_on_note_done_real_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	_tmp1_ = g_strdup (new_note);
	_g_free0 (_data_->new_note);
	_data_->new_note = _tmp1_;
	tuba_views_profile_on_note_done_real_co (_data_);
}

static void
tuba_views_profile_on_note_done_real_finish (TubaViewsProfile* self,
                                             GAsyncResult* _res_)
{
	TubaViewsProfileOnNoteDoneRealData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
}

static void
tuba_views_profile_on_note_done_real_ready (GObject* source_object,
                                            GAsyncResult* _res_,
                                            gpointer _user_data_)
{
	TubaViewsProfileOnNoteDoneRealData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_profile_on_note_done_real_co (_data_);
}

static gboolean
tuba_views_profile_on_note_done_real_co (TubaViewsProfileOnNoteDoneRealData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	{
		_data_->_tmp0_ = _data_->self->priv->_profile;
		_data_->_tmp1_ = tuba_views_profile_profile_account_get_rs (_data_->_tmp0_);
		_data_->_tmp2_ = _data_->_tmp1_;
		_data_->_state_ = 1;
		tuba_api_relationship_modify_note_real (_data_->_tmp2_, _data_->new_note, tuba_views_profile_on_note_done_real_ready, _data_);
		return FALSE;
		_state_1:
		tuba_api_relationship_modify_note_real_finish (_data_->_tmp2_, _data_->_res_, &_data_->_inner_error0_);
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp3_ = _data_->e;
		_data_->_tmp4_ = g_strdup_printf ("%i", _data_->_tmp3_->code);
		_data_->_tmp5_ = _data_->_tmp4_;
		_data_->_tmp6_ = _data_->e;
		_data_->_tmp7_ = _data_->_tmp6_->message;
		_data_->_tmp8_ = string_to_string (_data_->_tmp7_);
		_data_->_tmp9_ = g_strconcat ("Error while writing note: ", _data_->_tmp5_, " ", _data_->_tmp8_, NULL);
		_data_->_tmp10_ = _data_->_tmp9_;
		g_warning ("Profile.vala:773: %s", _data_->_tmp10_);
		_g_free0 (_data_->_tmp10_);
		_g_free0 (_data_->_tmp5_);
		_data_->_tmp11_ = tuba_app;
		_data_->_tmp12_ = _data_->e;
		_data_->_tmp13_ = _data_->_tmp12_->message;
		_data_->_tmp14_ = g_strdup_printf ("%s: %s", _ ("Error"), _data_->_tmp13_);
		_data_->_tmp15_ = _data_->_tmp14_;
		g_signal_emit_by_name (_data_->_tmp11_, "toast", _data_->_tmp15_, (guint) 5, NULL, NULL, NULL);
		_g_free0 (_data_->_tmp15_);
		tuba_views_profile_on_edit_note (_data_->self, _data_->new_note);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static gboolean
tuba_views_profile_real_get_empty (TubaViewsContentBase* base)
{
	gboolean result;
	TubaViewsProfile* self;
	self = (TubaViewsProfile*) base;
	result = FALSE;
	return result;
}

TubaViewsProfileProfileAccount*
tuba_views_profile_get_profile (TubaViewsProfile* self)
{
	TubaViewsProfileProfileAccount* result;
	TubaViewsProfileProfileAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_profile;
	result = _tmp0_;
	return result;
}

void
tuba_views_profile_set_profile (TubaViewsProfile* self,
                                TubaViewsProfileProfileAccount* value)
{
	TubaViewsProfileProfileAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_get_profile (self);
	if (old_value != value) {
		TubaViewsProfileProfileAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_profile);
		self->priv->_profile = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_PROFILE_PROPERTY]);
	}
}

TubaWidgetsProfileFilterGroupFilter
tuba_views_profile_get_filter (TubaViewsProfile* self)
{
	TubaWidgetsProfileFilterGroupFilter result;
	g_return_val_if_fail (self != NULL, 0);
	result = self->priv->_filter;
	return result;
}

void
tuba_views_profile_set_filter (TubaViewsProfile* self,
                               TubaWidgetsProfileFilterGroupFilter value)
{
	TubaWidgetsProfileFilterGroupFilter old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_get_filter (self);
	if (old_value != value) {
		self->priv->_filter = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_FILTER_PROPERTY]);
	}
}

const gchar*
tuba_views_profile_get_source (TubaViewsProfile* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_source;
	result = _tmp0_;
	return result;
}

void
tuba_views_profile_set_source (TubaViewsProfile* self,
                               const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_get_source (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_source);
		self->priv->_source = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_SOURCE_PROPERTY]);
	}
}

static inline gpointer
tuba_views_profile_note_editor_get_instance_private (TubaViewsProfileNoteEditor* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsProfileNoteEditor_private_offset);
}

static void
_tuba_views_profile_note_editor_on_cancel_gtk_button_clicked (GtkButton* _sender,
                                                              gpointer self)
{
	tuba_views_profile_note_editor_on_cancel ((TubaViewsProfileNoteEditor*) self);
}

static void
_tuba_views_profile_note_editor_on_save_gtk_button_clicked (GtkButton* _sender,
                                                            gpointer self)
{
	tuba_views_profile_note_editor_on_save ((TubaViewsProfileNoteEditor*) self);
}

static void
_tuba_views_profile_note_editor_update_style_scheme_g_object_notify (GObject* _sender,
                                                                     GParamSpec* pspec,
                                                                     gpointer self)
{
	tuba_views_profile_note_editor_update_style_scheme ((TubaViewsProfileNoteEditor*) self);
}

static void
_tuba_views_profile_note_editor_on_editor_buffer_change_gtk_text_buffer_changed (GtkTextBuffer* _sender,
                                                                                 gpointer self)
{
	tuba_views_profile_note_editor_on_editor_buffer_change ((TubaViewsProfileNoteEditor*) self);
}

TubaViewsProfileNoteEditor*
tuba_views_profile_note_editor_construct (GType object_type,
                                          const gchar* note)
{
	TubaViewsProfileNoteEditor * self = NULL;
	AdwToolbarView* toolbar_view = NULL;
	AdwToolbarView* _tmp0_;
	AdwHeaderBar* headerbar = NULL;
	AdwHeaderBar* _tmp1_ = NULL;
	AdwToolbarView* _tmp2_;
	AdwHeaderBar* _tmp3_;
	GtkButton* cancel_btn = NULL;
	GtkButton* _tmp4_;
	GtkButton* _tmp5_;
	GtkButton* save_btn = NULL;
	gchar* _tmp6_;
	gchar** _tmp7_;
	GtkButton* _tmp8_ = NULL;
	GtkButton* _tmp9_;
	AdwHeaderBar* _tmp10_;
	GtkButton* _tmp11_;
	AdwHeaderBar* _tmp12_;
	GtkButton* _tmp13_;
	GtkSourceView* _tmp14_ = NULL;
	GtkSourceView* _tmp15_;
	GtkSourceView* _tmp16_;
	GtkSourceView* _tmp17_;
	GtkAlign _tmp18_ = 0;
	GtkLabel* _tmp19_ = NULL;
	GtkLabel* _tmp20_;
	TubaDialogsComposerComponentsEditorPlaceholderHack* _tmp21_;
	GtkSourceView* _tmp22_;
	TubaDialogsComposerComponentsEditorPlaceholderHack* _tmp23_;
	GtkSourceView* _tmp24_;
	AdwStyleManager* _tmp25_;
	SpellingTextBufferAdapter* adapter = NULL;
	GtkSourceView* _tmp26_;
	GtkTextBuffer* _tmp27_;
	GtkTextBuffer* _tmp28_;
	SpellingChecker* _tmp29_;
	SpellingTextBufferAdapter* _tmp30_;
	GtkSourceView* _tmp31_;
	SpellingTextBufferAdapter* _tmp32_;
	GMenuModel* _tmp33_;
	GtkSourceView* _tmp34_;
	SpellingTextBufferAdapter* _tmp35_;
	SpellingTextBufferAdapter* _tmp36_;
	AdwToolbarView* _tmp37_;
	GtkSourceView* _tmp38_;
	GtkWidget* _tmp39_;
	GtkScrolledWindow* _tmp40_ = NULL;
	GtkScrolledWindow* _tmp41_;
	gchar* _tmp42_;
	gchar* _tmp43_;
	gchar* _tmp44_;
	gchar* _tmp45_;
	gchar* _tmp46_;
	gchar** _tmp47_;
	GtkLabel* _tmp48_ = NULL;
	AdwHeaderBar* _tmp49_;
	GtkLabel* _tmp50_;
	GtkSourceView* _tmp51_;
	GtkTextBuffer* _tmp52_;
	GtkTextBuffer* _tmp53_;
	gboolean _tmp54_ = FALSE;
	AdwToolbarView* _tmp58_;
	self = (TubaViewsProfileNoteEditor*) g_object_new (object_type, NULL);
	adw_dialog_set_can_close ((AdwDialog*) self, FALSE);
	adw_dialog_set_content_width ((AdwDialog*) self, 400);
	adw_dialog_set_content_height ((AdwDialog*) self, 400);
	adw_dialog_set_title ((AdwDialog*) self, _ ("Private Note"));
	_tmp0_ = (AdwToolbarView*) adw_toolbar_view_new ();
	g_object_ref_sink (_tmp0_);
	toolbar_view = _tmp0_;
	_tmp1_ = (AdwHeaderBar*) adw_header_bar_new ();
	adw_header_bar_set_show_end_title_buttons (_tmp1_, FALSE);
	adw_header_bar_set_show_start_title_buttons (_tmp1_, FALSE);
	g_object_ref_sink (_tmp1_);
	headerbar = _tmp1_;
	_tmp2_ = toolbar_view;
	_tmp3_ = headerbar;
	adw_toolbar_view_add_top_bar (_tmp2_, (GtkWidget*) _tmp3_);
	_tmp4_ = (GtkButton*) gtk_button_new_with_label (_ ("Cancel"));
	g_object_ref_sink (_tmp4_);
	cancel_btn = _tmp4_;
	_tmp5_ = cancel_btn;
	g_signal_connect_object (_tmp5_, "clicked", (GCallback) _tuba_views_profile_note_editor_on_cancel_gtk_button_clicked, self, 0);
	_tmp6_ = g_strdup ("suggested-action");
	_tmp7_ = g_new0 (gchar*, 1 + 1);
	_tmp7_[0] = _tmp6_;
	_tmp8_ = (GtkButton*) gtk_button_new_with_label (_ ("Save"));
	gtk_widget_set_css_classes ((GtkWidget*) _tmp8_, _tmp7_);
	_tmp7_ = (_vala_array_free (_tmp7_, 1, (GDestroyNotify) g_free), NULL);
	g_object_ref_sink (_tmp8_);
	save_btn = _tmp8_;
	_tmp9_ = save_btn;
	g_signal_connect_object (_tmp9_, "clicked", (GCallback) _tuba_views_profile_note_editor_on_save_gtk_button_clicked, self, 0);
	_tmp10_ = headerbar;
	_tmp11_ = cancel_btn;
	adw_header_bar_pack_start (_tmp10_, (GtkWidget*) _tmp11_);
	_tmp12_ = headerbar;
	_tmp13_ = save_btn;
	adw_header_bar_pack_end (_tmp12_, (GtkWidget*) _tmp13_);
	_tmp14_ = (GtkSourceView*) gtk_source_view_new ();
	gtk_widget_set_vexpand ((GtkWidget*) _tmp14_, TRUE);
	gtk_widget_set_hexpand ((GtkWidget*) _tmp14_, TRUE);
	gtk_text_view_set_accepts_tab ((GtkTextView*) _tmp14_, FALSE);
	gtk_text_view_set_wrap_mode ((GtkTextView*) _tmp14_, GTK_WRAP_WORD_CHAR);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp14_, 6);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp14_, 6);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp14_, 6);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp14_, 6);
	gtk_text_view_set_input_hints ((GtkTextView*) _tmp14_, (GTK_INPUT_HINT_WORD_COMPLETION | GTK_INPUT_HINT_SPELLCHECK) | GTK_INPUT_HINT_EMOJI);
	g_object_ref_sink (_tmp14_);
	_g_object_unref0 (self->priv->editor);
	self->priv->editor = _tmp14_;
	_tmp15_ = self->priv->editor;
	gtk_widget_remove_css_class ((GtkWidget*) _tmp15_, "view");
	_tmp16_ = self->priv->editor;
	gtk_widget_add_css_class ((GtkWidget*) _tmp16_, "reset");
	_tmp17_ = self->priv->editor;
	g_object_set ((AdwDialog*) self, "focus-widget", (GtkWidget*) _tmp17_, NULL);
	if (gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL) {
		_tmp18_ = GTK_ALIGN_END;
	} else {
		_tmp18_ = GTK_ALIGN_START;
	}
	_tmp19_ = (GtkLabel*) gtk_label_new (_ ("Type your note…"));
	gtk_widget_set_valign ((GtkWidget*) _tmp19_, GTK_ALIGN_START);
	gtk_widget_set_halign ((GtkWidget*) _tmp19_, _tmp18_);
	gtk_label_set_justify (_tmp19_, GTK_JUSTIFY_FILL);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp19_, 3);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp19_, 3);
	gtk_label_set_wrap (_tmp19_, TRUE);
	gtk_label_set_wrap_mode (_tmp19_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_sensitive ((GtkWidget*) _tmp19_, FALSE);
	g_object_ref_sink (_tmp19_);
	_tmp20_ = _tmp19_;
	_tmp21_ = tuba_dialogs_composer_components_editor_placeholder_hack_new (_tmp20_);
	g_object_ref_sink (_tmp21_);
	_g_object_unref0 (self->priv->placeholder);
	self->priv->placeholder = _tmp21_;
	_g_object_unref0 (_tmp20_);
	_tmp22_ = self->priv->editor;
	_tmp23_ = self->priv->placeholder;
	gtk_text_view_add_overlay ((GtkTextView*) _tmp22_, (GtkWidget*) _tmp23_, 0, 0);
	_tmp24_ = self->priv->editor;
	gtk_accessible_update_property ((GtkAccessible*) _tmp24_, GTK_ACCESSIBLE_PROPERTY_PLACEHOLDER, _ ("Type your note…"), -1, -1);
	_tmp25_ = adw_style_manager_get_default ();
	g_signal_connect_object ((GObject*) _tmp25_, "notify::dark", (GCallback) _tuba_views_profile_note_editor_update_style_scheme_g_object_notify, self, 0);
	tuba_views_profile_note_editor_update_style_scheme (self);
	_tmp26_ = self->priv->editor;
	_tmp27_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp26_);
	_tmp28_ = _tmp27_;
	_tmp29_ = spelling_checker_get_default ();
	_tmp30_ = spelling_text_buffer_adapter_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp28_, gtk_source_buffer_get_type (), GtkSourceBuffer), _tmp29_);
	adapter = _tmp30_;
	_tmp31_ = self->priv->editor;
	_tmp32_ = adapter;
	_tmp33_ = spelling_text_buffer_adapter_get_menu_model (_tmp32_);
	gtk_text_view_set_extra_menu ((GtkTextView*) _tmp31_, _tmp33_);
	_tmp34_ = self->priv->editor;
	_tmp35_ = adapter;
	gtk_widget_insert_action_group ((GtkWidget*) _tmp34_, "spelling", (GActionGroup*) _tmp35_);
	_tmp36_ = adapter;
	spelling_text_buffer_adapter_set_enabled (_tmp36_, TRUE);
	_tmp37_ = toolbar_view;
	_tmp38_ = self->priv->editor;
	_tmp39_ = _g_object_ref0 ((GtkWidget*) _tmp38_);
	_tmp40_ = (GtkScrolledWindow*) gtk_scrolled_window_new ();
	gtk_widget_set_hexpand ((GtkWidget*) _tmp40_, TRUE);
	gtk_widget_set_vexpand ((GtkWidget*) _tmp40_, TRUE);
	gtk_scrolled_window_set_child (_tmp40_, _tmp39_);
	_g_object_unref0 (_tmp39_);
	gtk_scrolled_window_set_propagate_natural_height (_tmp40_, TRUE);
	gtk_scrolled_window_set_max_content_height (_tmp40_, 209);
	g_object_ref_sink (_tmp40_);
	_tmp41_ = _tmp40_;
	adw_toolbar_view_set_content (_tmp37_, (GtkWidget*) _tmp41_);
	_g_object_unref0 (_tmp41_);
	_tmp42_ = g_strdup_printf ("%i", TUBA_VIEWS_PROFILE_NOTE_EDITOR_MAX_CHARS);
	_tmp43_ = _tmp42_;
	_tmp44_ = g_strdup (_ ("Remaining Characters"));
	_tmp45_ = g_strdup ("numeric");
	_tmp46_ = g_strdup ("dimmed");
	_tmp47_ = g_new0 (gchar*, 2 + 1);
	_tmp47_[0] = _tmp45_;
	_tmp47_[1] = _tmp46_;
	_tmp48_ = (GtkLabel*) gtk_label_new (_tmp43_);
	gtk_widget_set_tooltip_text ((GtkWidget*) _tmp48_, _tmp44_);
	_g_free0 (_tmp44_);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp48_, _tmp47_);
	_tmp47_ = (_vala_array_free (_tmp47_, 2, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp48_, 6);
	g_object_ref_sink (_tmp48_);
	_g_object_unref0 (self->priv->dialog_char_counter);
	self->priv->dialog_char_counter = _tmp48_;
	_g_free0 (_tmp43_);
	_tmp49_ = headerbar;
	_tmp50_ = self->priv->dialog_char_counter;
	adw_header_bar_pack_end (_tmp49_, (GtkWidget*) _tmp50_);
	_tmp51_ = self->priv->editor;
	_tmp52_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp51_);
	_tmp53_ = _tmp52_;
	g_signal_connect_object (_tmp53_, "changed", (GCallback) _tuba_views_profile_note_editor_on_editor_buffer_change_gtk_text_buffer_changed, self, 0);
	if (note != NULL) {
		_tmp54_ = g_strcmp0 (note, "") != 0;
	} else {
		_tmp54_ = FALSE;
	}
	if (_tmp54_) {
		GtkSourceView* _tmp55_;
		GtkTextBuffer* _tmp56_;
		GtkTextBuffer* _tmp57_;
		_tmp55_ = self->priv->editor;
		_tmp56_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp55_);
		_tmp57_ = _tmp56_;
		g_object_set (_tmp57_, "text", note, NULL);
	}
	_tmp58_ = toolbar_view;
	adw_dialog_set_child ((AdwDialog*) self, (GtkWidget*) _tmp58_);
	_g_object_unref0 (adapter);
	_g_object_unref0 (save_btn);
	_g_object_unref0 (cancel_btn);
	_g_object_unref0 (headerbar);
	_g_object_unref0 (toolbar_view);
	return self;
}

TubaViewsProfileNoteEditor*
tuba_views_profile_note_editor_new (const gchar* note)
{
	return tuba_views_profile_note_editor_construct (TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, note);
}

static void
tuba_views_profile_note_editor_on_editor_buffer_change (TubaViewsProfileNoteEditor* self)
{
	gint total_count = 0;
	GtkSourceView* _tmp0_;
	GtkTextBuffer* _tmp1_;
	GtkTextBuffer* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	gint _tmp6_;
	TubaDialogsComposerComponentsEditorPlaceholderHack* _tmp7_;
	GtkLabel* _tmp8_;
	gchar* _tmp9_;
	gchar* _tmp10_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->editor;
	_tmp1_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp0_);
	_tmp2_ = _tmp1_;
	g_object_get (_tmp2_, "text", &_tmp3_, NULL);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_tmp6_ = tuba_utils_counting_chars (_tmp5_, "en");
	_g_free0 (_tmp5_);
	total_count = _tmp6_;
	_tmp7_ = self->priv->placeholder;
	gtk_widget_set_visible ((GtkWidget*) _tmp7_, total_count == 0);
	_tmp8_ = self->priv->dialog_char_counter;
	_tmp9_ = g_strdup_printf ("%i", TUBA_VIEWS_PROFILE_NOTE_EDITOR_MAX_CHARS - total_count);
	_tmp10_ = _tmp9_;
	gtk_label_set_label (_tmp8_, _tmp10_);
	_g_free0 (_tmp10_);
	if (total_count < TUBA_VIEWS_PROFILE_NOTE_EDITOR_MAX_CHARS) {
		GtkLabel* _tmp11_;
		_tmp11_ = self->priv->dialog_char_counter;
		gtk_widget_remove_css_class ((GtkWidget*) _tmp11_, "error");
	} else {
		GtkLabel* _tmp12_;
		_tmp12_ = self->priv->dialog_char_counter;
		gtk_widget_add_css_class ((GtkWidget*) _tmp12_, "error");
	}
}

static void
tuba_views_profile_note_editor_update_style_scheme (TubaViewsProfileNoteEditor* self)
{
	GtkSourceStyleSchemeManager* manager = NULL;
	GtkSourceStyleSchemeManager* _tmp0_;
	GtkSourceStyleSchemeManager* _tmp1_;
	gchar* scheme_name = NULL;
	gchar* _tmp2_;
	AdwStyleManager* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	GtkSourceView* _tmp8_;
	GtkTextBuffer* _tmp9_;
	GtkTextBuffer* _tmp10_;
	GtkSourceStyleSchemeManager* _tmp11_;
	const gchar* _tmp12_;
	GtkSourceStyleScheme* _tmp13_;
	g_return_if_fail (self != NULL);
	_tmp0_ = gtk_source_style_scheme_manager_get_default ();
	_tmp1_ = _g_object_ref0 (_tmp0_);
	manager = _tmp1_;
	_tmp2_ = g_strdup ("Adwaita");
	scheme_name = _tmp2_;
	_tmp3_ = adw_style_manager_get_default ();
	_tmp4_ = adw_style_manager_get_dark (_tmp3_);
	_tmp5_ = _tmp4_;
	if (_tmp5_) {
		const gchar* _tmp6_;
		gchar* _tmp7_;
		_tmp6_ = scheme_name;
		_tmp7_ = g_strconcat (_tmp6_, "-dark", NULL);
		_g_free0 (scheme_name);
		scheme_name = _tmp7_;
	}
	_tmp8_ = self->priv->editor;
	_tmp9_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp8_);
	_tmp10_ = _tmp9_;
	_tmp11_ = manager;
	_tmp12_ = scheme_name;
	_tmp13_ = gtk_source_style_scheme_manager_get_scheme (_tmp11_, _tmp12_);
	gtk_source_buffer_set_style_scheme (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, gtk_source_buffer_get_type (), GtkSourceBuffer), _tmp13_);
	_g_free0 (scheme_name);
	_g_object_unref0 (manager);
}

static void
tuba_views_profile_note_editor_on_save (TubaViewsProfileNoteEditor* self)
{
	GtkSourceView* _tmp0_;
	GtkTextBuffer* _tmp1_;
	GtkTextBuffer* _tmp2_;
	gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	g_return_if_fail (self != NULL);
	_tmp0_ = self->priv->editor;
	_tmp1_ = gtk_text_view_get_buffer ((GtkTextView*) _tmp0_);
	_tmp2_ = _tmp1_;
	g_object_get (_tmp2_, "text", &_tmp3_, NULL);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	g_signal_emit (self, tuba_views_profile_note_editor_signals[TUBA_VIEWS_PROFILE_NOTE_EDITOR_NOTE_DONE_SIGNAL], 0, _tmp5_);
	_g_free0 (_tmp5_);
	adw_dialog_force_close ((AdwDialog*) self);
}

static void
tuba_views_profile_note_editor_on_cancel (TubaViewsProfileNoteEditor* self)
{
	g_return_if_fail (self != NULL);
	adw_dialog_force_close ((AdwDialog*) self);
}

static void
tuba_views_profile_note_editor_class_init (TubaViewsProfileNoteEditorClass * klass,
                                           gpointer klass_data)
{
	tuba_views_profile_note_editor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsProfileNoteEditor_private_offset);
	G_OBJECT_CLASS (klass)->finalize = tuba_views_profile_note_editor_finalize;
	tuba_views_profile_note_editor_signals[TUBA_VIEWS_PROFILE_NOTE_EDITOR_NOTE_DONE_SIGNAL] = g_signal_new ("note-done", TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
}

static void
tuba_views_profile_note_editor_instance_init (TubaViewsProfileNoteEditor * self,
                                              gpointer klass)
{
	self->priv = tuba_views_profile_note_editor_get_instance_private (self);
}

static void
tuba_views_profile_note_editor_finalize (GObject * obj)
{
	TubaViewsProfileNoteEditor * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_PROFILE_TYPE_NOTE_EDITOR, TubaViewsProfileNoteEditor);
	_g_object_unref0 (self->priv->editor);
	_g_object_unref0 (self->priv->dialog_char_counter);
	_g_object_unref0 (self->priv->placeholder);
	G_OBJECT_CLASS (tuba_views_profile_note_editor_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_profile_note_editor_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsProfileNoteEditorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_profile_note_editor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsProfileNoteEditor), 0, (GInstanceInitFunc) tuba_views_profile_note_editor_instance_init, NULL };
	GType tuba_views_profile_note_editor_type_id;
	tuba_views_profile_note_editor_type_id = g_type_register_static (adw_dialog_get_type (), "TubaViewsProfileNoteEditor", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsProfileNoteEditor_private_offset = g_type_add_instance_private (tuba_views_profile_note_editor_type_id, sizeof (TubaViewsProfileNoteEditorPrivate));
	return tuba_views_profile_note_editor_type_id;
}

GType
tuba_views_profile_note_editor_get_type (void)
{
	static GType tuba_views_profile_note_editor_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_profile_note_editor_type_id__once)) {
		GType tuba_views_profile_note_editor_type_id;
		tuba_views_profile_note_editor_type_id = tuba_views_profile_note_editor_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_profile_note_editor_type_id__once, tuba_views_profile_note_editor_type_id);
	}
	return tuba_views_profile_note_editor_type_id__once;
}

static inline gpointer
tuba_views_profile_profile_account_get_instance_private (TubaViewsProfileProfileAccount* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsProfileProfileAccount_private_offset);
}

TubaViewsProfileProfileAccount*
tuba_views_profile_profile_account_construct (GType object_type,
                                              TubaAPIAccount* t_acc)
{
	TubaViewsProfileProfileAccount * self = NULL;
	TubaAPIRelationship* _tmp0_;
	TubaAPIRelationship* _tmp1_;
	g_return_val_if_fail (t_acc != NULL, NULL);
	_tmp0_ = tuba_api_relationship_new_for_account (t_acc);
	_tmp1_ = _tmp0_;
	self = (TubaViewsProfileProfileAccount*) g_object_new (object_type, "account", t_acc, "rs", _tmp1_, NULL);
	_g_object_unref0 (_tmp1_);
	return self;
}

TubaViewsProfileProfileAccount*
tuba_views_profile_profile_account_new (TubaAPIAccount* t_acc)
{
	return tuba_views_profile_profile_account_construct (TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, t_acc);
}

static void
tuba_views_profile_profile_account_update_profile_data_free (gpointer _data)
{
	TubaViewsProfileProfileAccountUpdateProfileData* _data_;
	_data_ = _data;
	_g_object_unref0 (_data_->self);
	g_slice_free (TubaViewsProfileProfileAccountUpdateProfileData, _data_);
}

void
tuba_views_profile_profile_account_update_profile (TubaViewsProfileProfileAccount* self,
                                                   GAsyncReadyCallback _callback_,
                                                   gpointer _user_data_)
{
	TubaViewsProfileProfileAccountUpdateProfileData* _data_;
	TubaViewsProfileProfileAccount* _tmp0_;
	g_return_if_fail (self != NULL);
	_data_ = g_slice_new0 (TubaViewsProfileProfileAccountUpdateProfileData);
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
	g_task_set_task_data (_data_->_async_result, _data_, tuba_views_profile_profile_account_update_profile_data_free);
	_tmp0_ = _g_object_ref0 (self);
	_data_->self = _tmp0_;
	tuba_views_profile_profile_account_update_profile_co (_data_);
}

gboolean
tuba_views_profile_profile_account_update_profile_finish (TubaViewsProfileProfileAccount* self,
                                                          GAsyncResult* _res_)
{
	gboolean result;
	TubaViewsProfileProfileAccountUpdateProfileData* _data_;
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
	result = _data_->result;
	return result;
}

static void
tuba_views_profile_profile_account_update_profile_ready (GObject* source_object,
                                                         GAsyncResult* _res_,
                                                         gpointer _user_data_)
{
	TubaViewsProfileProfileAccountUpdateProfileData* _data_;
	_data_ = _user_data_;
	_data_->_source_object_ = source_object;
	_data_->_res_ = _res_;
	tuba_views_profile_profile_account_update_profile_co (_data_);
}

static void
_vala_JsonNode_free (JsonNode* self)
{
	g_boxed_free (json_node_get_type (), self);
}

static gboolean
tuba_views_profile_profile_account_update_profile_co (TubaViewsProfileProfileAccountUpdateProfileData* _data_)
{
	switch (_data_->_state_) {
		case 0:
		goto _state_0;
		case 1:
		goto _state_1;
		case 2:
		goto _state_2;
		default:
		g_assert_not_reached ();
	}
	_state_0:
	_data_->_tmp0_ = _data_->self->priv->_account;
	_data_->_tmp1_ = tuba_api_account_get_id (_data_->_tmp0_);
	_data_->_tmp2_ = _data_->_tmp1_;
	_data_->_tmp3_ = string_to_string (_data_->_tmp2_);
	_data_->_tmp4_ = g_strconcat ("/api/v1/accounts/", _data_->_tmp3_, NULL);
	_data_->_tmp5_ = _data_->_tmp4_;
	_data_->_tmp6_ = tuba_accounts;
	_data_->_tmp7_ = tuba_account_store_get_active (_data_->_tmp6_);
	_data_->_tmp8_ = _data_->_tmp7_;
	_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
	_data_->_tmp10_ = NULL;
	_data_->_tmp10_ = tuba_request_v2_new (_data_->_tmp5_, TUBA_REQUEST_V2_METHOD_GET);
	tuba_request_v2_set_account (_data_->_tmp10_, _data_->_tmp9_);
	_g_object_unref0 (_data_->_tmp9_);
	_data_->_tmp11_ = _data_->_tmp10_;
	_g_free0 (_data_->_tmp5_);
	_data_->req = _data_->_tmp11_;
	{
		_data_->_tmp12_ = _data_->req;
		_data_->_state_ = 1;
		tuba_request_v2_exec (_data_->_tmp12_, tuba_views_profile_profile_account_update_profile_ready, _data_);
		return FALSE;
		_state_1:
		_data_->_tmp13_ = tuba_request_v2_exec_finish (_data_->_tmp12_, _data_->_res_, NULL, &_data_->_inner_error0_);
		_data_->in_stream = _data_->_tmp13_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			goto __catch0_g_error;
		}
		_data_->_tmp14_ = _data_->in_stream;
		_data_->_state_ = 2;
		tuba_network_get_parser_from_inputstream_async (_data_->_tmp14_, NULL, tuba_views_profile_profile_account_update_profile_ready, _data_);
		return FALSE;
		_state_2:
		_data_->_tmp15_ = tuba_network_get_parser_from_inputstream_finish (_data_->_res_, &_data_->_inner_error0_);
		_data_->parser = _data_->_tmp15_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			_g_object_unref0 (_data_->in_stream);
			goto __catch0_g_error;
		}
		_data_->_tmp16_ = tuba_network;
		_data_->_tmp17_ = _data_->parser;
		_data_->_tmp18_ = tuba_network_parse_node (_data_->_tmp16_, _data_->_tmp17_);
		_data_->node = _data_->_tmp18_;
		_data_->_tmp19_ = _data_->node;
		_data_->_tmp20_ = tuba_api_account_from (_data_->_tmp19_, &_data_->_inner_error0_);
		_data_->updated = _data_->_tmp20_;
		if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
			__vala_JsonNode_free0 (_data_->node);
			_g_object_unref0 (_data_->parser);
			_g_object_unref0 (_data_->in_stream);
			goto __catch0_g_error;
		}
		_data_->_tmp21_ = _data_->self->priv->_account;
		_data_->_tmp22_ = _data_->updated;
		_data_->_tmp23_ = tuba_api_account_get_display_name (_data_->_tmp22_);
		_data_->_tmp24_ = _data_->_tmp23_;
		tuba_api_account_set_display_name (_data_->_tmp21_, _data_->_tmp24_);
		_data_->_tmp25_ = _data_->self->priv->_account;
		_data_->_tmp26_ = _data_->updated;
		_data_->_tmp27_ = tuba_api_account_get_note (_data_->_tmp26_);
		_data_->_tmp28_ = _data_->_tmp27_;
		tuba_api_account_set_note (_data_->_tmp25_, _data_->_tmp28_);
		_data_->_tmp29_ = _data_->self->priv->_account;
		_data_->_tmp30_ = _data_->updated;
		_data_->_tmp31_ = tuba_api_account_get_locked (_data_->_tmp30_);
		_data_->_tmp32_ = _data_->_tmp31_;
		tuba_api_account_set_locked (_data_->_tmp29_, _data_->_tmp32_);
		_data_->_tmp33_ = _data_->self->priv->_account;
		_data_->_tmp34_ = _data_->updated;
		_data_->_tmp35_ = tuba_api_account_get_header (_data_->_tmp34_);
		_data_->_tmp36_ = _data_->_tmp35_;
		tuba_api_account_set_header (_data_->_tmp33_, _data_->_tmp36_);
		_data_->_tmp37_ = _data_->self->priv->_account;
		_data_->_tmp38_ = _data_->updated;
		_data_->_tmp39_ = tuba_api_account_get_header_description (_data_->_tmp38_);
		_data_->_tmp40_ = _data_->_tmp39_;
		tuba_api_account_set_header_description (_data_->_tmp37_, _data_->_tmp40_);
		_data_->_tmp41_ = _data_->self->priv->_account;
		_data_->_tmp42_ = _data_->updated;
		_data_->_tmp43_ = tuba_api_account_get_avatar (_data_->_tmp42_);
		_data_->_tmp44_ = _data_->_tmp43_;
		tuba_api_account_set_avatar (_data_->_tmp41_, _data_->_tmp44_);
		_data_->_tmp45_ = _data_->self->priv->_account;
		_data_->_tmp46_ = _data_->updated;
		_data_->_tmp47_ = tuba_api_account_get_avatar_description (_data_->_tmp46_);
		_data_->_tmp48_ = _data_->_tmp47_;
		tuba_api_account_set_avatar_description (_data_->_tmp45_, _data_->_tmp48_);
		_data_->_tmp49_ = _data_->self->priv->_account;
		_data_->_tmp50_ = _data_->updated;
		_data_->_tmp51_ = tuba_api_account_get_bot (_data_->_tmp50_);
		_data_->_tmp52_ = _data_->_tmp51_;
		tuba_api_account_set_bot (_data_->_tmp49_, _data_->_tmp52_);
		_data_->_tmp53_ = _data_->self->priv->_account;
		_data_->_tmp54_ = _data_->updated;
		_data_->_tmp55_ = tuba_api_account_get_emojis (_data_->_tmp54_);
		_data_->_tmp56_ = _data_->_tmp55_;
		tuba_api_account_set_emojis (_data_->_tmp53_, _data_->_tmp56_);
		_data_->_tmp57_ = _data_->self->priv->_account;
		_data_->_tmp58_ = _data_->updated;
		_data_->_tmp59_ = tuba_api_account_get_followers_count (_data_->_tmp58_);
		_data_->_tmp60_ = _data_->_tmp59_;
		tuba_api_account_set_followers_count (_data_->_tmp57_, _data_->_tmp60_);
		_data_->_tmp61_ = _data_->self->priv->_account;
		_data_->_tmp62_ = _data_->updated;
		_data_->_tmp63_ = tuba_api_account_get_following_count (_data_->_tmp62_);
		_data_->_tmp64_ = _data_->_tmp63_;
		tuba_api_account_set_following_count (_data_->_tmp61_, _data_->_tmp64_);
		_data_->_tmp65_ = _data_->self->priv->_account;
		_data_->_tmp66_ = _data_->updated;
		_data_->_tmp67_ = tuba_api_account_get_statuses_count (_data_->_tmp66_);
		_data_->_tmp68_ = _data_->_tmp67_;
		tuba_api_account_set_statuses_count (_data_->_tmp65_, _data_->_tmp68_);
		_data_->_tmp69_ = _data_->self->priv->_account;
		_data_->_tmp70_ = _data_->updated;
		_data_->_tmp71_ = tuba_api_account_get_fields (_data_->_tmp70_);
		_data_->_tmp72_ = _data_->_tmp71_;
		tuba_api_account_set_fields (_data_->_tmp69_, _data_->_tmp72_);
		_data_->_tmp73_ = _data_->self->priv->_account;
		_data_->_tmp74_ = _data_->updated;
		_data_->_tmp75_ = tuba_api_account_get_moved (_data_->_tmp74_);
		_data_->_tmp76_ = _data_->_tmp75_;
		tuba_api_account_set_moved (_data_->_tmp73_, _data_->_tmp76_);
		_data_->result = TRUE;
		_g_object_unref0 (_data_->updated);
		__vala_JsonNode_free0 (_data_->node);
		_g_object_unref0 (_data_->parser);
		_g_object_unref0 (_data_->in_stream);
		_g_object_unref0 (_data_->req);
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
		if (_data_->_state_ != 0) {
			while (!g_task_get_completed (_data_->_async_result)) {
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
			}
		}
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	goto __finally0;
	__catch0_g_error:
	{
		_data_->e = _data_->_inner_error0_;
		_data_->_inner_error0_ = NULL;
		_data_->_tmp77_ = _data_->self->priv->_account;
		_data_->_tmp78_ = tuba_api_account_get_id (_data_->_tmp77_);
		_data_->_tmp79_ = _data_->_tmp78_;
		_data_->_tmp80_ = string_to_string (_data_->_tmp79_);
		_data_->_tmp81_ = _data_->e;
		_data_->_tmp82_ = _data_->_tmp81_->message;
		_data_->_tmp83_ = string_to_string (_data_->_tmp82_);
		_data_->_tmp84_ = g_strconcat ("Couldn't update account ", _data_->_tmp80_, ": ", _data_->_tmp83_, NULL);
		_data_->_tmp85_ = _data_->_tmp84_;
		g_warning ("Profile.vala:157: %s", _data_->_tmp85_);
		_g_free0 (_data_->_tmp85_);
		_data_->_tmp86_ = tuba_app;
		_data_->_tmp87_ = _data_->e;
		_data_->_tmp88_ = _data_->_tmp87_->message;
		g_signal_emit_by_name (_data_->_tmp86_, "toast", _data_->_tmp88_, (guint) 5, NULL, NULL, NULL);
		_g_error_free0 (_data_->e);
	}
	__finally0:
	if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
		_g_object_unref0 (_data_->req);
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
		g_clear_error (&_data_->_inner_error0_);
		g_object_unref (_data_->_async_result);
		return FALSE;
	}
	_data_->result = FALSE;
	_g_object_unref0 (_data_->req);
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
	if (_data_->_state_ != 0) {
		while (!g_task_get_completed (_data_->_async_result)) {
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
		}
	}
	g_object_unref (_data_->_async_result);
	return FALSE;
}

static GtkWidget*
tuba_views_profile_profile_account_real_to_widget (TubaWidgetizable* base)
{
	TubaViewsProfileProfileAccount * self;
	TubaWidgetsCover* _tmp0_;
	GtkWidget* result;
	self = (TubaViewsProfileProfileAccount*) base;
	_tmp0_ = tuba_widgets_cover_new (self, FALSE);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

GtkWidget*
tuba_views_profile_profile_account_to_mini_widget (TubaViewsProfileProfileAccount* self)
{
	TubaWidgetsCover* _tmp0_;
	GtkWidget* result;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = tuba_widgets_cover_new (self, TRUE);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

TubaAPIAccount*
tuba_views_profile_profile_account_get_account (TubaViewsProfileProfileAccount* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_account;
	result = _tmp0_;
	return result;
}

void
tuba_views_profile_profile_account_set_account (TubaViewsProfileProfileAccount* self,
                                                TubaAPIAccount* value)
{
	TubaAPIAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_profile_account_get_account (self);
	if (old_value != value) {
		TubaAPIAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_account);
		self->priv->_account = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_profile_account_properties[TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY]);
	}
}

TubaAPIRelationship*
tuba_views_profile_profile_account_get_rs (TubaViewsProfileProfileAccount* self)
{
	TubaAPIRelationship* result;
	TubaAPIRelationship* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_rs;
	result = _tmp0_;
	return result;
}

void
tuba_views_profile_profile_account_set_rs (TubaViewsProfileProfileAccount* self,
                                           TubaAPIRelationship* value)
{
	TubaAPIRelationship* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_profile_account_get_rs (self);
	if (old_value != value) {
		TubaAPIRelationship* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_rs);
		self->priv->_rs = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_profile_account_properties[TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY]);
	}
}

static void
tuba_views_profile_profile_account_class_init (TubaViewsProfileProfileAccountClass * klass,
                                               gpointer klass_data)
{
	tuba_views_profile_profile_account_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsProfileProfileAccount_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_profile_profile_account_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_profile_profile_account_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_profile_profile_account_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY, tuba_views_profile_profile_account_properties[TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY] = g_param_spec_object ("account", "account", "account", TUBA_API_TYPE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY, tuba_views_profile_profile_account_properties[TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY] = g_param_spec_object ("rs", "rs", "rs", TUBA_API_TYPE_RELATIONSHIP, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}

static void
tuba_views_profile_profile_account_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                     gpointer iface_data)
{
	tuba_views_profile_profile_account_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_views_profile_profile_account_real_to_widget;
}

static void
tuba_views_profile_profile_account_instance_init (TubaViewsProfileProfileAccount * self,
                                                  gpointer klass)
{
	self->priv = tuba_views_profile_profile_account_get_instance_private (self);
}

static void
tuba_views_profile_profile_account_finalize (GObject * obj)
{
	TubaViewsProfileProfileAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccount);
	_g_object_unref0 (self->priv->_account);
	_g_object_unref0 (self->priv->_rs);
	G_OBJECT_CLASS (tuba_views_profile_profile_account_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_profile_profile_account_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsProfileProfileAccountClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_profile_profile_account_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsProfileProfileAccount), 0, (GInstanceInitFunc) tuba_views_profile_profile_account_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_views_profile_profile_account_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_views_profile_profile_account_type_id;
	tuba_views_profile_profile_account_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaViewsProfileProfileAccount", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_views_profile_profile_account_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaViewsProfileProfileAccount_private_offset = g_type_add_instance_private (tuba_views_profile_profile_account_type_id, sizeof (TubaViewsProfileProfileAccountPrivate));
	return tuba_views_profile_profile_account_type_id;
}

GType
tuba_views_profile_profile_account_get_type (void)
{
	static GType tuba_views_profile_profile_account_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_profile_profile_account_type_id__once)) {
		GType tuba_views_profile_profile_account_type_id;
		tuba_views_profile_profile_account_type_id = tuba_views_profile_profile_account_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_profile_profile_account_type_id__once, tuba_views_profile_profile_account_type_id);
	}
	return tuba_views_profile_profile_account_type_id__once;
}

static void
_vala_tuba_views_profile_profile_account_get_property (GObject * object,
                                                       guint property_id,
                                                       GValue * value,
                                                       GParamSpec * pspec)
{
	TubaViewsProfileProfileAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccount);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY:
		g_value_set_object (value, tuba_views_profile_profile_account_get_account (self));
		break;
		case TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY:
		g_value_set_object (value, tuba_views_profile_profile_account_get_rs (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_profile_profile_account_set_property (GObject * object,
                                                       guint property_id,
                                                       const GValue * value,
                                                       GParamSpec * pspec)
{
	TubaViewsProfileProfileAccount * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, TubaViewsProfileProfileAccount);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_ACCOUNT_PROPERTY:
		tuba_views_profile_profile_account_set_account (self, g_value_get_object (value));
		break;
		case TUBA_VIEWS_PROFILE_PROFILE_ACCOUNT_RS_PROPERTY:
		tuba_views_profile_profile_account_set_rs (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_views_profile_filter_group_get_instance_private (TubaViewsProfileFilterGroup* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsProfileFilterGroup_private_offset);
}

static GtkWidget*
tuba_views_profile_filter_group_real_to_widget (TubaWidgetizable* base)
{
	TubaViewsProfileFilterGroup * self;
	TubaWidgetsProfileFilterGroup* widget = NULL;
	gboolean _tmp0_;
	gboolean _tmp1_;
	TubaWidgetsProfileFilterGroup* _tmp2_;
	GtkWidget* result;
	self = (TubaViewsProfileFilterGroup*) base;
	_tmp0_ = self->priv->_show_media;
	_tmp1_ = self->priv->_show_featured;
	_tmp2_ = tuba_widgets_profile_filter_group_new (_tmp0_, _tmp1_);
	g_object_ref_sink (_tmp2_);
	widget = _tmp2_;
	g_object_bind_property_with_closures ((GObject*) self, "visible", (GObject*) widget, "visible", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	result = (GtkWidget*) widget;
	return result;
}

TubaViewsProfileFilterGroup*
tuba_views_profile_filter_group_construct (GType object_type)
{
	TubaViewsProfileFilterGroup * self = NULL;
	self = (TubaViewsProfileFilterGroup*) g_object_new (object_type, NULL);
	return self;
}

TubaViewsProfileFilterGroup*
tuba_views_profile_filter_group_new (void)
{
	return tuba_views_profile_filter_group_construct (TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP);
}

gboolean
tuba_views_profile_filter_group_get_visible (TubaViewsProfileFilterGroup* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_visible;
	return result;
}

void
tuba_views_profile_filter_group_set_visible (TubaViewsProfileFilterGroup* self,
                                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_filter_group_get_visible (self);
	if (old_value != value) {
		self->priv->_visible = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY]);
	}
}

gboolean
tuba_views_profile_filter_group_get_show_media (TubaViewsProfileFilterGroup* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_media;
	return result;
}

void
tuba_views_profile_filter_group_set_show_media (TubaViewsProfileFilterGroup* self,
                                                gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_filter_group_get_show_media (self);
	if (old_value != value) {
		self->priv->_show_media = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY]);
	}
}

gboolean
tuba_views_profile_filter_group_get_show_featured (TubaViewsProfileFilterGroup* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_show_featured;
	return result;
}

void
tuba_views_profile_filter_group_set_show_featured (TubaViewsProfileFilterGroup* self,
                                                   gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_filter_group_get_show_featured (self);
	if (old_value != value) {
		self->priv->_show_featured = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY]);
	}
}

static void
tuba_views_profile_filter_group_class_init (TubaViewsProfileFilterGroupClass * klass,
                                            gpointer klass_data)
{
	tuba_views_profile_filter_group_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsProfileFilterGroup_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_profile_filter_group_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_profile_filter_group_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_profile_filter_group_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY] = g_param_spec_boolean ("visible", "visible", "visible", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY] = g_param_spec_boolean ("show-media", "show-media", "show-media", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY, tuba_views_profile_filter_group_properties[TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY] = g_param_spec_boolean ("show-featured", "show-featured", "show-featured", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_profile_filter_group_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                  gpointer iface_data)
{
	tuba_views_profile_filter_group_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_views_profile_filter_group_real_to_widget;
}

static void
tuba_views_profile_filter_group_instance_init (TubaViewsProfileFilterGroup * self,
                                               gpointer klass)
{
	self->priv = tuba_views_profile_filter_group_get_instance_private (self);
	self->priv->_visible = TRUE;
	self->priv->_show_media = TRUE;
	self->priv->_show_featured = TRUE;
}

static void
tuba_views_profile_filter_group_finalize (GObject * obj)
{
	TubaViewsProfileFilterGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroup);
	G_OBJECT_CLASS (tuba_views_profile_filter_group_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_profile_filter_group_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsProfileFilterGroupClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_profile_filter_group_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsProfileFilterGroup), 0, (GInstanceInitFunc) tuba_views_profile_filter_group_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_views_profile_filter_group_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_views_profile_filter_group_type_id;
	tuba_views_profile_filter_group_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaViewsProfileFilterGroup", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_views_profile_filter_group_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaViewsProfileFilterGroup_private_offset = g_type_add_instance_private (tuba_views_profile_filter_group_type_id, sizeof (TubaViewsProfileFilterGroupPrivate));
	return tuba_views_profile_filter_group_type_id;
}

GType
tuba_views_profile_filter_group_get_type (void)
{
	static GType tuba_views_profile_filter_group_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_profile_filter_group_type_id__once)) {
		GType tuba_views_profile_filter_group_type_id;
		tuba_views_profile_filter_group_type_id = tuba_views_profile_filter_group_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_profile_filter_group_type_id__once, tuba_views_profile_filter_group_type_id);
	}
	return tuba_views_profile_filter_group_type_id__once;
}

static void
_vala_tuba_views_profile_filter_group_get_property (GObject * object,
                                                    guint property_id,
                                                    GValue * value,
                                                    GParamSpec * pspec)
{
	TubaViewsProfileFilterGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroup);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY:
		g_value_set_boolean (value, tuba_views_profile_filter_group_get_visible (self));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY:
		g_value_set_boolean (value, tuba_views_profile_filter_group_get_show_media (self));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY:
		g_value_set_boolean (value, tuba_views_profile_filter_group_get_show_featured (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_profile_filter_group_set_property (GObject * object,
                                                    guint property_id,
                                                    const GValue * value,
                                                    GParamSpec * pspec)
{
	TubaViewsProfileFilterGroup * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_FILTER_GROUP, TubaViewsProfileFilterGroup);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_VISIBLE_PROPERTY:
		tuba_views_profile_filter_group_set_visible (self, g_value_get_boolean (value));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_MEDIA_PROPERTY:
		tuba_views_profile_filter_group_set_show_media (self, g_value_get_boolean (value));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_GROUP_SHOW_FEATURED_PROPERTY:
		tuba_views_profile_filter_group_set_show_featured (self, g_value_get_boolean (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_views_profile_error_message_row_get_instance_private (TubaViewsProfileErrorMessageRow* self)
{
	return G_STRUCT_MEMBER_P (self, TubaViewsProfileErrorMessageRow_private_offset);
}

static GtkWidget*
tuba_views_profile_error_message_row_real_to_widget (TubaWidgetizable* base)
{
	TubaViewsProfileErrorMessageRow * self;
	GtkLabel* widget = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	gchar** _tmp2_;
	GtkLabel* _tmp3_ = NULL;
	GtkListBoxRow* row = NULL;
	GtkWidget* _tmp4_;
	GtkListBoxRow* _tmp5_ = NULL;
	GtkWidget* result;
	self = (TubaViewsProfileErrorMessageRow*) base;
	_tmp0_ = self->priv->_message;
	_tmp1_ = g_strdup ("title-1");
	_tmp2_ = g_new0 (gchar*, 1 + 1);
	_tmp2_[0] = _tmp1_;
	_tmp3_ = (GtkLabel*) gtk_label_new (_tmp0_);
	gtk_label_set_wrap (_tmp3_, TRUE);
	gtk_label_set_wrap_mode (_tmp3_, PANGO_WRAP_WORD_CHAR);
	gtk_widget_set_css_classes ((GtkWidget*) _tmp3_, _tmp2_);
	_tmp2_ = (_vala_array_free (_tmp2_, 1, (GDestroyNotify) g_free), NULL);
	gtk_widget_set_margin_start ((GtkWidget*) _tmp3_, 16);
	gtk_widget_set_margin_end ((GtkWidget*) _tmp3_, 16);
	gtk_widget_set_margin_top ((GtkWidget*) _tmp3_, 16);
	gtk_widget_set_margin_bottom ((GtkWidget*) _tmp3_, 16);
	gtk_label_set_justify (_tmp3_, GTK_JUSTIFY_CENTER);
	g_object_ref_sink (_tmp3_);
	widget = _tmp3_;
	_tmp4_ = _g_object_ref0 ((GtkWidget*) widget);
	_tmp5_ = (GtkListBoxRow*) gtk_list_box_row_new ();
	gtk_list_box_row_set_child (_tmp5_, _tmp4_);
	_g_object_unref0 (_tmp4_);
	gtk_widget_set_overflow ((GtkWidget*) _tmp5_, GTK_OVERFLOW_HIDDEN);
	gtk_list_box_row_set_activatable (_tmp5_, FALSE);
	g_object_ref_sink (_tmp5_);
	row = _tmp5_;
	g_object_bind_property_with_closures ((GObject*) self, "visible", (GObject*) row, "visible", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	g_object_bind_property_with_closures ((GObject*) self, "message", (GObject*) widget, "label", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, (GClosureNotify) NULL)));
	result = (GtkWidget*) row;
	_g_object_unref0 (widget);
	return result;
}

TubaViewsProfileErrorMessageRow*
tuba_views_profile_error_message_row_construct (GType object_type)
{
	TubaViewsProfileErrorMessageRow * self = NULL;
	self = (TubaViewsProfileErrorMessageRow*) g_object_new (object_type, NULL);
	return self;
}

TubaViewsProfileErrorMessageRow*
tuba_views_profile_error_message_row_new (void)
{
	return tuba_views_profile_error_message_row_construct (TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW);
}

gboolean
tuba_views_profile_error_message_row_get_visible (TubaViewsProfileErrorMessageRow* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_visible;
	return result;
}

void
tuba_views_profile_error_message_row_set_visible (TubaViewsProfileErrorMessageRow* self,
                                                  gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_error_message_row_get_visible (self);
	if (old_value != value) {
		self->priv->_visible = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_error_message_row_properties[TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY]);
	}
}

const gchar*
tuba_views_profile_error_message_row_get_message (TubaViewsProfileErrorMessageRow* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_message;
	result = _tmp0_;
	return result;
}

void
tuba_views_profile_error_message_row_set_message (TubaViewsProfileErrorMessageRow* self,
                                                  const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_views_profile_error_message_row_get_message (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_message);
		self->priv->_message = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_views_profile_error_message_row_properties[TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY]);
	}
}

static void
tuba_views_profile_error_message_row_class_init (TubaViewsProfileErrorMessageRowClass * klass,
                                                 gpointer klass_data)
{
	tuba_views_profile_error_message_row_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsProfileErrorMessageRow_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_profile_error_message_row_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_profile_error_message_row_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_profile_error_message_row_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY, tuba_views_profile_error_message_row_properties[TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY] = g_param_spec_boolean ("visible", "visible", "visible", TRUE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY, tuba_views_profile_error_message_row_properties[TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY] = g_param_spec_string ("message", "message", "message", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_views_profile_error_message_row_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                       gpointer iface_data)
{
	tuba_views_profile_error_message_row_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_views_profile_error_message_row_real_to_widget;
}

static void
tuba_views_profile_error_message_row_instance_init (TubaViewsProfileErrorMessageRow * self,
                                                    gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_views_profile_error_message_row_get_instance_private (self);
	self->priv->_visible = TRUE;
	_tmp0_ = g_strdup ("");
	self->priv->_message = _tmp0_;
}

static void
tuba_views_profile_error_message_row_finalize (GObject * obj)
{
	TubaViewsProfileErrorMessageRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRow);
	_g_free0 (self->priv->_message);
	G_OBJECT_CLASS (tuba_views_profile_error_message_row_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_profile_error_message_row_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsProfileErrorMessageRowClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_profile_error_message_row_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsProfileErrorMessageRow), 0, (GInstanceInitFunc) tuba_views_profile_error_message_row_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_views_profile_error_message_row_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_views_profile_error_message_row_type_id;
	tuba_views_profile_error_message_row_type_id = g_type_register_static (G_TYPE_OBJECT, "TubaViewsProfileErrorMessageRow", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_views_profile_error_message_row_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaViewsProfileErrorMessageRow_private_offset = g_type_add_instance_private (tuba_views_profile_error_message_row_type_id, sizeof (TubaViewsProfileErrorMessageRowPrivate));
	return tuba_views_profile_error_message_row_type_id;
}

GType
tuba_views_profile_error_message_row_get_type (void)
{
	static GType tuba_views_profile_error_message_row_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_profile_error_message_row_type_id__once)) {
		GType tuba_views_profile_error_message_row_type_id;
		tuba_views_profile_error_message_row_type_id = tuba_views_profile_error_message_row_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_profile_error_message_row_type_id__once, tuba_views_profile_error_message_row_type_id);
	}
	return tuba_views_profile_error_message_row_type_id__once;
}

static void
_vala_tuba_views_profile_error_message_row_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	TubaViewsProfileErrorMessageRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRow);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY:
		g_value_set_boolean (value, tuba_views_profile_error_message_row_get_visible (self));
		break;
		case TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY:
		g_value_set_string (value, tuba_views_profile_error_message_row_get_message (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_profile_error_message_row_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	TubaViewsProfileErrorMessageRow * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_PROFILE_TYPE_ERROR_MESSAGE_ROW, TubaViewsProfileErrorMessageRow);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_VISIBLE_PROPERTY:
		tuba_views_profile_error_message_row_set_visible (self, g_value_get_boolean (value));
		break;
		case TUBA_VIEWS_PROFILE_ERROR_MESSAGE_ROW_MESSAGE_PROPERTY:
		tuba_views_profile_error_message_row_set_message (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_views_profile_class_init (TubaViewsProfileClass * klass,
                               gpointer klass_data)
{
	tuba_views_profile_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaViewsProfile_private_offset);
	((TubaViewsTimelineClass *) klass)->on_request_finish = (void (*) (TubaViewsTimeline*)) tuba_views_profile_real_on_request_finish;
	((TubaViewsContentBaseClass *) klass)->on_create_model_widget = (GtkWidget* (*) (TubaViewsContentBase*, GObject*)) tuba_views_profile_real_on_create_model_widget;
	((TubaViewsTimelineClass *) klass)->on_refresh = (void (*) (TubaViewsTimeline*)) tuba_views_profile_real_on_refresh;
	((TubaViewsTimelineClass *) klass)->on_manual_refresh = (void (*) (TubaViewsTimeline*)) tuba_views_profile_real_on_manual_refresh;
	((TubaViewsBaseClass *) klass)->on_content_changed = (void (*) (TubaViewsBase*)) tuba_views_profile_real_on_content_changed;
	((TubaViewsBaseClass *) klass)->build_header = (void (*) (TubaViewsBase*)) tuba_views_profile_real_build_header;
	((TubaViewsBaseClass *) klass)->clear = (void (*) (TubaViewsBase*)) tuba_views_profile_real_clear;
	((TubaViewsBaseClass *) klass)->build_actions = (void (*) (TubaViewsBase*)) tuba_views_profile_real_build_actions;
	((TubaViewsTimelineClass *) klass)->append_params_v2 = (void (*) (TubaViewsTimeline*, TubaRequestV2*)) tuba_views_profile_real_append_params_v2;
	TUBA_VIEWS_CONTENT_BASE_CLASS (klass)->get_empty = (gboolean (*) (TubaViewsContentBase*)) tuba_views_profile_real_get_empty;
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_views_profile_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_views_profile_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_views_profile_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_EMPTY_PROPERTY, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_EMPTY_PROPERTY] = g_param_spec_boolean ("empty", "empty", "empty", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_PROFILE_PROPERTY, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_PROFILE_PROPERTY] = g_param_spec_object ("profile", "profile", "profile", TUBA_VIEWS_PROFILE_TYPE_PROFILE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_FILTER_PROPERTY, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_FILTER_PROPERTY] = g_param_spec_enum ("filter", "filter", "filter", TUBA_WIDGETS_PROFILE_FILTER_GROUP_TYPE_FILTER, TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_POSTS, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_VIEWS_PROFILE_SOURCE_PROPERTY, tuba_views_profile_properties[TUBA_VIEWS_PROFILE_SOURCE_PROPERTY] = g_param_spec_string ("source", "source", "source", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	tuba_views_profile_signals[TUBA_VIEWS_PROFILE_COVER_PROFILE_UPDATE_SIGNAL] = g_signal_new ("cover-profile-update", TUBA_VIEWS_TYPE_PROFILE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TUBA_API_TYPE_ACCOUNT);
}

static void
tuba_views_profile_instance_init (TubaViewsProfile * self,
                                  gpointer klass)
{
	gchar* _tmp0_;
	TubaViewsProfileErrorMessageRow* _tmp1_ = NULL;
	self->priv = tuba_views_profile_get_instance_private (self);
	self->priv->_filter = TUBA_WIDGETS_PROFILE_FILTER_GROUP_FILTER_POSTS;
	_tmp0_ = g_strdup ("statuses");
	self->priv->_source = _tmp0_;
	_tmp1_ = tuba_views_profile_error_message_row_new ();
	tuba_views_profile_error_message_row_set_visible (_tmp1_, FALSE);
	self->priv->error_message_row = _tmp1_;
}

static void
tuba_views_profile_finalize (GObject * obj)
{
	TubaViewsProfile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfile);
	g_debug ("Profile.vala:263: Destroying Profile view");
	_g_object_unref0 (self->priv->_profile);
	_g_free0 (self->priv->_source);
	_g_object_unref0 (self->menu_button);
	_g_object_unref0 (self->muting_action);
	_g_object_unref0 (self->hiding_reblogs_action);
	_g_object_unref0 (self->blocking_action);
	_g_object_unref0 (self->domain_blocking_action);
	_g_object_unref0 (self->endorse_action);
	_g_object_unref0 (self->ar_list_action);
	_g_object_unref0 (self->add_note_action);
	_g_object_unref0 (self->notify_on_new_post_action);
	_g_object_unref0 (self->priv->filter_group);
	_g_object_unref0 (self->priv->error_message_row);
	G_OBJECT_CLASS (tuba_views_profile_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_views_profile_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaViewsProfileClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_views_profile_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaViewsProfile), 0, (GInstanceInitFunc) tuba_views_profile_instance_init, NULL };
	GType tuba_views_profile_type_id;
	tuba_views_profile_type_id = g_type_register_static (TUBA_VIEWS_TYPE_ACCOUNTS, "TubaViewsProfile", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaViewsProfile_private_offset = g_type_add_instance_private (tuba_views_profile_type_id, sizeof (TubaViewsProfilePrivate));
	return tuba_views_profile_type_id;
}

GType
tuba_views_profile_get_type (void)
{
	static GType tuba_views_profile_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_views_profile_type_id__once)) {
		GType tuba_views_profile_type_id;
		tuba_views_profile_type_id = tuba_views_profile_get_type_once ();
		g_once_init_leave_pointer (&tuba_views_profile_type_id__once, tuba_views_profile_type_id);
	}
	return tuba_views_profile_type_id__once;
}

static void
_vala_tuba_views_profile_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec)
{
	TubaViewsProfile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfile);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_EMPTY_PROPERTY:
		g_value_set_boolean (value, tuba_views_content_base_get_empty ((TubaViewsContentBase*) self));
		break;
		case TUBA_VIEWS_PROFILE_PROFILE_PROPERTY:
		g_value_set_object (value, tuba_views_profile_get_profile (self));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_PROPERTY:
		g_value_set_enum (value, tuba_views_profile_get_filter (self));
		break;
		case TUBA_VIEWS_PROFILE_SOURCE_PROPERTY:
		g_value_set_string (value, tuba_views_profile_get_source (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_views_profile_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec)
{
	TubaViewsProfile * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_VIEWS_TYPE_PROFILE, TubaViewsProfile);
	switch (property_id) {
		case TUBA_VIEWS_PROFILE_PROFILE_PROPERTY:
		tuba_views_profile_set_profile (self, g_value_get_object (value));
		break;
		case TUBA_VIEWS_PROFILE_FILTER_PROPERTY:
		tuba_views_profile_set_filter (self, g_value_get_enum (value));
		break;
		case TUBA_VIEWS_PROFILE_SOURCE_PROPERTY:
		tuba_views_profile_set_source (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

